From 4a1085de1bec5475bf84b7ed006128cfe2bf4256 Mon Sep 17 00:00:00 2001
From: Alexander Borisov <lex.borisov@gmail.com>
Date: Mon, 2 Jun 2025 19:49:46 +0300
Subject: [PATCH v1 2/2] Improve the performance of Unicode Normalization
 Forms.

This changes significantly speeds up the normalize() function.
Similar to the changes in case mapping (fold, lower, upper, or title case),
here we get rid of perfect hashing and replace it with a range index with
a nested branch function to check specific ranges of code points.
This allows us to achieve a performance increase of up to 40%.

Author: Alexander Borisov <lex.borisov@gmail.com>
---
 .../unicode/generate-unicode_norm_table.pl    |   474 +-
 src/common/unicode_norm.c                     |   115 +-
 src/include/common/unicode_norm_hashfunc.h    |  3016 -
 src/include/common/unicode_norm_table.h       | 63227 +++++++++++++---
 src/tools/pgindent/exclude_file_patterns      |     1 -
 5 files changed, 54352 insertions(+), 12481 deletions(-)
 delete mode 100644 src/include/common/unicode_norm_hashfunc.h

diff --git a/src/common/unicode/generate-unicode_norm_table.pl b/src/common/unicode/generate-unicode_norm_table.pl
index 5e4330e458f..c3319afa974 100644
--- a/src/common/unicode/generate-unicode_norm_table.pl
+++ b/src/common/unicode/generate-unicode_norm_table.pl
@@ -14,14 +14,13 @@ use Getopt::Long;
 
 use FindBin;
 use lib "$FindBin::RealBin/../../tools/";
-use PerfectHash;
+use Ranges;
 
 my $output_path = '.';
 
 GetOptions('outdir:s' => \$output_path);
 
 my $output_table_file = "$output_path/unicode_norm_table.h";
-my $output_func_file = "$output_path/unicode_norm_hashfunc.h";
 
 
 my $FH;
@@ -64,23 +63,38 @@ while (my $line = <$FH>)
 	# the data file, currently.)
 	next if hex($code) > 0x10FFFF;
 
+	# The character decomposition mapping field in UnicodeData.txt is a list
+	# of unicode codepoints, separated by space. But it can be prefixed with
+	# so-called compatibility formatting tag, like "<compat>", or "<font>".
+	# The entries with compatibility formatting tags should not be used for
+	# re-composing characters during normalization, so flag them in the table.
+	# (The tag doesn't matter, only whether there is a tag or not)
+	my $compat = 0;
+	if ($decomp =~ /\<.*\>/)
+	{
+		$compat = 1;
+		$decomp =~ s/\<[^][]*\>//g;
+	}
+	my @decomp_elts = split(" ", $decomp);
+
 	# Skip characters with no decompositions and a class of 0, to reduce the
 	# table size.
-	next if $class eq '0' && $decomp eq '';
-
-	my %char_entry = (code => $code, class => $class, decomp => $decomp);
+	next if $class eq '0' && scalar @decomp_elts == 0;
+
+	my %char_entry = (
+		code => $code,
+		class => $class,
+		compat => $compat,
+		decomp => \@decomp_elts,
+		decomp_length => scalar @decomp_elts);
 	push(@characters, \%char_entry);
-	$character_hash{$code} = \%char_entry;
+	$character_hash{ hex($code) } = \%char_entry;
 }
 close $FH;
 
-my $num_characters = scalar @characters;
-
 # Start writing out the output files
 open my $OT, '>', $output_table_file
   or die "Could not open output file $output_table_file: $!\n";
-open my $OF, '>', $output_func_file
-  or die "Could not open output file $output_func_file: $!\n";
 
 print $OT <<HEADER;
 /*-------------------------------------------------------------------------
@@ -103,7 +117,6 @@ print $OT <<HEADER;
  */
 typedef struct
 {
-	uint32		codepoint;		/* Unicode codepoint */
 	uint8		comb_class;		/* combining class of character */
 	uint8		dec_size_flags; /* size and flags of decomposition code list */
 	uint16		dec_index;		/* index into UnicodeDecomp_codepoints, or the
@@ -120,89 +133,67 @@ typedef struct
 #define DECOMPOSITION_IS_INLINE(x) (((x)->dec_size_flags & DECOMP_INLINE) != 0)
 #define DECOMPOSITION_IS_COMPAT(x) (((x)->dec_size_flags & DECOMP_COMPAT) != 0)
 
-/* Table of Unicode codepoints and their decompositions */
-static const pg_unicode_decomposition UnicodeDecompMain[$num_characters] =
-{
 HEADER
 
-print $OF <<HEADER;
-/*-------------------------------------------------------------------------
- *
- * unicode_norm_hashfunc.h
- *	  Perfect hash functions used for Unicode normalization
- *
- * Portions Copyright (c) 1996-2025, PostgreSQL Global Development Group
- * Portions Copyright (c) 1994, Regents of the University of California
- *
- * src/include/common/unicode_norm_hashfunc.h
- *
- *-------------------------------------------------------------------------
- */
-
-/*
- * File auto-generated by src/common/unicode/generate-unicode_norm_table.pl,
- * do not edit. There is deliberately not an #ifndef PG_UNICODE_NORM_HASHFUNC_H
- * here.
- */
-
-#include "common/unicode_norm_table.h"
+# Sorting the values so that the table is always generated in the same way.
+my @sorted_codes = sort { $a <=> $b } keys %character_hash;
+my @decomp_codepoints;
+
+# Collect all codepoints of the decomposition and remove duplicate sequences.
+# Be sure to sort by number of codepoints, from largest to smallest.
+# This is necessary so that shorter ones fit into larger ones.
+foreach my $code (
+	sort {
+		$character_hash{$b}->{decomp_length}
+		  <=> $character_hash{$a}->{decomp_length}
+	} @sorted_codes)
+{
+	my $entry = $character_hash{$code};
+	my $decomp = $entry->{decomp};
 
-/* Typedef for perfect hash functions */
-typedef int (*cp_hash_func) (const void *key);
+	# Skip those values that will be stored directly in the main table.
+	if ($entry->{decomp_length} == 0
+		|| ($entry->{decomp_length} == 1 && length($decomp->[0]) <= 4))
+	{
+		next;
+	}
 
-/* Information for lookups with perfect hash functions */
-typedef struct
-{
-	const pg_unicode_decomposition *decomps;
-	cp_hash_func	hash;
-	int		num_decomps;
-} pg_unicode_decompinfo;
+	# Search for a sequence of decomposition codepoints in the existing data.
+	# If found, we assign a record index; otherwise, we add the sequence to the
+	# end of the existing data.
+	my $index = contains_subarray(\@decomp_codepoints, $decomp);
 
-typedef struct
-{
-	const uint16	*inverse_lookup;
-	cp_hash_func	hash;
-	int		num_recomps;
-} pg_unicode_recompinfo;
+	if ($index == -1)
+	{
+		$index = scalar @decomp_codepoints;
+		push @decomp_codepoints, @$decomp;
+	}
 
-HEADER
+	$entry->{decomp_index} = $index;
+}
 
-my $decomp_index = 0;
-my $decomp_string = "";
-my @dec_cp_packed;
-my $main_index = 0;
-my @rec_info;
+my $main_index = 1;
+my @decomp_main = ("\t{0, 0, 0},\n");
+my %duplicates;
+my %inverse;
+my %decomp_index;
 
 my $last_code = $characters[-1]->{code};
 foreach my $char (@characters)
 {
 	my $code = $char->{code};
 	my $class = $char->{class};
+	my $compat = $char->{compat};
 	my $decomp = $char->{decomp};
-
-	# Save the code point bytes as a string in network order.
-	push @dec_cp_packed, pack('N', hex($char->{code}));
-
-	# The character decomposition mapping field in UnicodeData.txt is a list
-	# of unicode codepoints, separated by space. But it can be prefixed with
-	# so-called compatibility formatting tag, like "<compat>", or "<font>".
-	# The entries with compatibility formatting tags should not be used for
-	# re-composing characters during normalization, so flag them in the table.
-	# (The tag doesn't matter, only whether there is a tag or not)
-	my $compat = 0;
-	if ($decomp =~ /\<.*\>/)
-	{
-		$compat = 1;
-		$decomp =~ s/\<[^][]*\>//g;
-	}
-	my @decomp_elts = split(" ", $decomp);
+	my $index = $char->{decomp_index};
 
 	# Decomposition size
 	# Print size of decomposition
-	my $decomp_size = scalar(@decomp_elts);
+	my $decomp_size = scalar(@$decomp);
 	die if $decomp_size > 0x1F;    # to not overrun bitmask
 
-	my $first_decomp = shift @decomp_elts;
+	my $first_decomp = shift @$decomp;
+	my $first_num = $first_decomp ? hex($first_decomp) : 0;
 
 	my $flags = "";
 	my $comment = "";
@@ -215,8 +206,8 @@ foreach my $char (@characters)
 	if ($decomp_size == 2)
 	{
 		# Should this be used for recomposition?
-		if (   $character_hash{$first_decomp}
-			&& $character_hash{$first_decomp}->{class} != 0)
+		if (   $character_hash{$first_num}
+			&& $character_hash{$first_num}->{class} != 0)
 		{
 			$flags .= " | DECOMP_NO_COMPOSE";
 			$comment = "non-starter decomposition";
@@ -240,19 +231,15 @@ foreach my $char (@characters)
 		# src/common/unicode_norm.c.
 		if (!($flags =~ /DECOMP_COMPAT/ || $flags =~ /DECOMP_NO_COMPOSE/))
 		{
-			push @rec_info,
-			  {
-				code => $code,
-				main_index => $main_index,
-				first => $first_decomp,
-				second => $decomp_elts[0]
-			  };
+			$inverse{$first_num}->{ hex($decomp->[0]) } = hex($code);
 		}
 	}
 
+	my $line;
+
 	if ($decomp_size == 0)
 	{
-		print $OT "\t{0x$code, $class, 0$flags, 0}";
+		$line = "\t{$class, 0$flags, 0}";
 	}
 	elsif ($decomp_size == 1 && length($first_decomp) <= 4)
 	{
@@ -260,153 +247,250 @@ foreach my $char (@characters)
 		# The decomposition consists of a single codepoint, and it fits
 		# in a uint16, so we can store it "inline" in the main table.
 		$flags .= " | DECOMP_INLINE";
-		print $OT "\t{0x$code, $class, 1$flags, 0x$first_decomp}";
+		$line = "\t{$class, 1$flags, 0x$first_decomp}";
 	}
 	else
 	{
-		print $OT "\t{0x$code, $class, $decomp_size$flags, $decomp_index}";
+		$line = "\t{$class, $decomp_size$flags, $index}";
+	}
+
+	# Check for duplicates and discard them.
+	if (exists $duplicates{$line})
+	{
+		$decomp_index{ hex($code) } = $duplicates{$line};
+		next;
+	}
 
-		# Now save the decompositions into a dedicated area that will
-		# be written afterwards.  First build the entry dedicated to
-		# a sub-table with the code and decomposition.
-		$decomp_string .= ",\n" if ($decomp_string ne "");
+	$duplicates{$line} = $main_index;
 
-		$decomp_string .= "\t /* $decomp_index */ 0x$first_decomp";
-		foreach (@decomp_elts)
-		{
-			$decomp_string .= ", 0x$_";
-		}
+	push @decomp_main, $line;
 
-		$decomp_index = $decomp_index + $decomp_size;
-	}
+	# Push a comma after all items except the last one.
+	push @decomp_main, "," unless ($code eq $last_code);
+	push @decomp_main, "\t/* $comment */" if ($comment ne "");
+	push @decomp_main, "\n" unless ($code eq $last_code);
 
-	# Print a comma after all items except the last one.
-	print $OT "," unless ($code eq $last_code);
+	$decomp_index{ hex($code) } = $main_index++;
+}
+
+# Сompile a table with sequences of codepoints for decomposition.
+my @decomp_lines = ("\t");
 
-	print $OT "\t/* $comment */" if ($comment ne "");
-	print $OT "\n";
+foreach my $index (0 .. $#decomp_codepoints)
+{
+	my $code = $decomp_codepoints[$index];
+	push @decomp_lines, "0x$code";
 
-	$main_index++;
+	# Skip tabulation or new line is needed after the last value.
+	last if $index == $#decomp_codepoints;
+
+	push @decomp_lines, ",";
+	# Each line will have 8 codepoints.
+	push @decomp_lines, ($index + 1) % 8 == 0 ? "\n\t" : " ";
 }
-print $OT "\n};\n\n";
+
+# Preparing data for codepoint composition. A situation where two code points
+# need to be converted into one (recomposition of the reordered Unicode string).
+#
+# For table with uint16 numbers.
+# The first two entries are uint32 numbers - first second codepoint.
+# The third entry indicates the number of elements immediately following
+# this entry (third entry).
+# For example:
+#     {code, point, 3, 55, 64, 71, code, point, 2, 23, 45, code, point,...}
+#
+# The reserved value for "not found", like a NULL.
+my @inverse_second = (0, 0, 0);
+my @inverse_codes = (0);
+my %inverse_index;
+
+foreach my $first (sort { $a <=> $b } keys %inverse)
+{
+	my $seconds = $inverse{$first};
+	my @sorted = sort { $a <=> $b } keys %$seconds;
+
+	$inverse_index{$first} = scalar @inverse_second;
+
+	# Store a 32-bit number in two 16-bit numbers.
+	push @inverse_second, $sorted[0] >> 16;
+	push @inverse_second, $sorted[0] & ~(((1 << 16) - 1) << 16);
+	# Store the number of entries.
+	push @inverse_second, $sorted[-1] - $sorted[0];
+
+	foreach my $second ($sorted[0] .. $sorted[-1])
+	{
+		my $index = 0;
+
+		if (exists $seconds->{$second})
+		{
+			$index = scalar @inverse_codes;
+			push @inverse_codes, $seconds->{$second};
+		}
+
+		push @inverse_second, $index;
+	}
+}
+
+my $main_string = join "", @decomp_main;
+my $decomp_length = scalar @decomp_codepoints;
+my $decomp_string = join "", @decomp_lines;
+my $inverse_length = scalar @inverse_codes;
+my $inverse_string = "\t" . join ",\n\t", @inverse_codes;
+my $second_length = scalar @inverse_second;
+my $second_string = "\t" . join ",\n\t", @inverse_second;
 
 # Print the array of decomposed codes.
 print $OT <<HEADER;
-/* codepoints array  */
-static const uint32 UnicodeDecomp_codepoints[$decomp_index] =
+/* Table with basic data for decompositions. */
+static const pg_unicode_decomposition UnicodeDecompMain[$main_index] =
+{
+$main_string
+};
+
+/* Table with sequences of codepoints for decomposition. */
+static const uint32 UnicodeDecompCodepoints[$decomp_length] =
 {
 $decomp_string
 };
-HEADER
 
-# Emit the definition of the decomp hash function.
-my $dec_funcname = 'Decomp_hash_func';
-my $dec_func = PerfectHash::generate_hash_function(\@dec_cp_packed,
-	$dec_funcname, fixed_key_length => 4);
-print $OF "/* Perfect hash function for decomposition */\n";
-print $OF "static $dec_func\n";
-
-# Emit the structure that wraps the hash lookup information into
-# one variable.
-print $OF <<HEADER;
-/* Hash lookup information for decomposition */
-static const pg_unicode_decompinfo UnicodeDecompInfo =
+/*
+ * Table of Unicode codepoints for recomposition of the reordered
+ * Unicode string.
+ */
+static const uint32 UnicodeDecompInverseCodes[$inverse_length] =
+{
+$inverse_string
+};
+
+/*
+ * Table with indexes from the secondary codepoint pointing
+ * to UnicodeDecompInverseCodes.
+ */
+static const uint16 UnicodeDecompInverseSecond[$second_length] =
 {
-	UnicodeDecompMain,
-	$dec_funcname,
-	$num_characters
+$second_string
 };
 
 HEADER
 
-# Find the lowest codepoint that decomposes to each recomposeable
-# code pair and create a mapping to it.
-my $recomp_string = "";
-my @rec_cp_packed;
-my %seenit;
-my $firstentry = 1;
-foreach my $rec (sort recomp_sort @rec_info)
+# Create a range index for decomposition mapping.
+my @decomp_codes = keys %decomp_index;
+my $decomp_range = Ranges::make(\@decomp_codes, 1500);
+my $decomp_table = Ranges::tables($decomp_range, "decomp_map",
+	sub { $decomp_index{ $_[0] } || 0 });
+my $decomp_branch =
+  Ranges::branch_as_text($decomp_range, 0, $#$decomp_range, 1, "decomp_map");
+
+# Create a range index for inverse mapping.
+my @inverse_first = keys %inverse;
+my $inverse_range = Ranges::make(\@inverse_first, 1500);
+my $inverse_table = Ranges::tables($inverse_range, "inverse_map",
+	sub { $inverse_index{ $_[0] } || 0 });
+my $inverse_branch =
+  Ranges::branch_as_text($inverse_range, 0, $#$inverse_range, 1,
+	"inverse_map");
+
+print $OT <<"HEADER";
+/*
+ * Used by normalization_index() to map a codepoint to an index that can be
+ * used in UnicodeDecompMain table.
+ */
+$decomp_table
+
+/*
+ * Used by inverse_index() to map a codepoint to an index that can be
+ * used in UnicodeDecompInverseSecond table.
+ */
+$inverse_table
+
+
+/*
+ * normalization_index()
+ *
+ * Given a code point, compute the index in the decomp_map at which we can find
+ * the offset into the mapping tables.
+ */
+static uint16
+normalization_index(pg_wchar cp)
 {
-	# The hash key is formed by concatenating the bytes of the two
-	# codepoints. See also recompose_code() in common/unicode_norm.c.
-	my $hashkey = (hex($rec->{first}) << 32) | hex($rec->{second});
-
-	# We are only interested in the lowest code point that decomposes
-	# to the given code pair.
-	next if $seenit{$hashkey};
-
-	# Save the hash key bytes in network order
-	push @rec_cp_packed, pack('Q>', $hashkey);
-
-	# Append inverse lookup element
-	$recomp_string .= ",\n" if !$firstentry;
-	$recomp_string .= sprintf "\t/* U+%s+%s -> U+%s */ %s",
-	  $rec->{first},
-	  $rec->{second},
-	  $rec->{code},
-	  $rec->{main_index};
-
-	$seenit{$hashkey} = 1;
-	$firstentry = 0;
+$decomp_branch
+
+	return 0;
 }
 
-# Emit the inverse lookup array containing indexes into UnicodeDecompMain.
-my $num_recomps = scalar @rec_cp_packed;
-print $OF <<HEADER;
-/* Inverse lookup array -- contains indexes into UnicodeDecompMain[] */
-static const uint16 RecompInverseLookup[$num_recomps] =
+/*
+ * inverse_index()
+ *
+ * Like normalization_index(), only the index is searched for in the inverse_map
+ * table.
+ */
+static uint16
+inverse_index(pg_wchar cp)
 {
-$recomp_string
-};
+$inverse_branch
 
-HEADER
+	return 0;
+}
 
-# Emit the definition of the recomposition hash function.
-my $rec_funcname = 'Recomp_hash_func';
-my $rec_func =
-  PerfectHash::generate_hash_function(\@rec_cp_packed, $rec_funcname,
-	fixed_key_length => 8);
-print $OF "/* Perfect hash function for recomposition */\n";
-print $OF "static $rec_func\n";
-
-# Emit the structure that wraps the hash lookup information into
-# one variable.
-print $OF <<HEADER;
-/* Hash lookup information for recomposition */
-static const pg_unicode_recompinfo UnicodeRecompInfo =
+/*
+ * normalization_inverse()
+ *
+ * Returns the code point for recomposition of the reordered Unicode string
+ * based on two code points.
+ * Codepoint 0x0000 means "not found".
+ */
+static pg_wchar
+normalization_inverse(pg_wchar first, pg_wchar second)
 {
-	RecompInverseLookup,
-	$rec_funcname,
-	$num_recomps
-};
+	uint16		idx;
+	uint32		start,
+				stop;
+	const uint16 *entry;
+
+	idx = inverse_index(first);
+	entry = &UnicodeDecompInverseSecond[idx];
+
+	start = entry[0] << 16 | entry[1];
+	stop = start + entry[2];
+
+	if (idx != 0 && second >= start && second <= stop)
+	{
+		return UnicodeDecompInverseCodes[entry[second - start + 3]];
+	}
+
+	return 0x0000;
+}
 HEADER
 
 close $OT;
-close $OF;
 
-sub recomp_sort
+# This function is designed to search for the occurrence of one array as
+# a subarray within another.  This is necessary to find duplicates.
+# It returns the index of the start of the occurrence or -1 if unsuccessful.
+sub contains_subarray
 {
-	my $a1 = hex($a->{first});
-	my $b1 = hex($b->{first});
-
-	my $a2 = hex($a->{second});
-	my $b2 = hex($b->{second});
+	my ($arr1, $arr2) = @_;
+	my $len1 = scalar(@$arr1);
+	my $len2 = scalar(@$arr2);
 
-	# First sort by the first code point
-	return -1 if $a1 < $b1;
-	return 1 if $a1 > $b1;
+	return -1 if $len2 == 0;
+	return -1 if $len2 > $len1;
 
-	# Then sort by the second code point
-	return -1 if $a2 < $b2;
-	return 1 if $a2 > $b2;
+	for my $start (0 .. $len1 - $len2)
+	{
+		my $match = 1;
 
-	# Finally sort by the code point that decomposes into first and
-	# second ones.
-	my $acode = hex($a->{code});
-	my $bcode = hex($b->{code});
+		for my $j (0 .. $len2 - 1)
+		{
+			if ($arr1->[ $start + $j ] ne $arr2->[$j])
+			{
+				$match = 0;
+				last;
+			}
+		}
 
-	return -1 if $acode < $bcode;
-	return 1 if $acode > $bcode;
+		return $start if $match;
+	}
 
-	die "found duplicate entries of recomposeable code pairs";
+	return -1;
 }
diff --git a/src/common/unicode_norm.c b/src/common/unicode_norm.c
index 6654b4cbc49..8f63db18ae1 100644
--- a/src/common/unicode_norm.c
+++ b/src/common/unicode_norm.c
@@ -19,12 +19,10 @@
 #endif
 
 #include "common/unicode_norm.h"
+#include "common/unicode_norm_table.h"
 #ifndef FRONTEND
-#include "common/unicode_norm_hashfunc.h"
 #include "common/unicode_normprops_table.h"
 #include "port/pg_bswap.h"
-#else
-#include "common/unicode_norm_table.h"
 #endif
 
 #ifndef FRONTEND
@@ -46,21 +44,6 @@
 #define NCOUNT		VCOUNT * TCOUNT
 #define SCOUNT		LCOUNT * NCOUNT
 
-#ifdef FRONTEND
-/* comparison routine for bsearch() of decomposition lookup table. */
-static int
-conv_compare(const void *p1, const void *p2)
-{
-	uint32		v1,
-				v2;
-
-	v1 = *(const uint32 *) p1;
-	v2 = ((const pg_unicode_decomposition *) p2)->codepoint;
-	return (v1 > v2) ? 1 : ((v1 == v2) ? 0 : -1);
-}
-
-#endif
-
 /*
  * get_code_entry
  *
@@ -71,38 +54,9 @@ conv_compare(const void *p1, const void *p2)
 static const pg_unicode_decomposition *
 get_code_entry(pg_wchar code)
 {
-#ifndef FRONTEND
-	int			h;
-	uint32		hashkey;
-	pg_unicode_decompinfo decompinfo = UnicodeDecompInfo;
-
-	/*
-	 * Compute the hash function. The hash key is the codepoint with the bytes
-	 * in network order.
-	 */
-	hashkey = pg_hton32(code);
-	h = decompinfo.hash(&hashkey);
-
-	/* An out-of-range result implies no match */
-	if (h < 0 || h >= decompinfo.num_decomps)
-		return NULL;
-
-	/*
-	 * Since it's a perfect hash, we need only match to the specific codepoint
-	 * it identifies.
-	 */
-	if (code != decompinfo.decomps[h].codepoint)
-		return NULL;
+	uint16 idx = normalization_index(code);
 
-	/* Success! */
-	return &decompinfo.decomps[h];
-#else
-	return bsearch(&(code),
-				   UnicodeDecompMain,
-				   lengthof(UnicodeDecompMain),
-				   sizeof(pg_unicode_decomposition),
-				   conv_compare);
-#endif
+	return idx != 0 ? &UnicodeDecompMain[idx] : NULL;
 }
 
 /*
@@ -145,7 +99,7 @@ get_code_decomposition(const pg_unicode_decomposition *entry, int *dec_size)
 	else
 	{
 		*dec_size = DECOMPOSITION_SIZE(entry);
-		return &UnicodeDecomp_codepoints[entry->dec_index];
+		return &UnicodeDecompCodepoints[entry->dec_index];
 	}
 }
 
@@ -245,66 +199,9 @@ recompose_code(uint32 start, uint32 code, uint32 *result)
 	}
 	else
 	{
-		const pg_unicode_decomposition *entry;
-
-		/*
-		 * Do an inverse lookup of the decomposition tables to see if anything
-		 * matches. The comparison just needs to be a perfect match on the
-		 * sub-table of size two, because the start character has already been
-		 * recomposed partially.  This lookup uses a perfect hash function for
-		 * the backend code.
-		 */
-#ifndef FRONTEND
-
-		int			h,
-					inv_lookup_index;
-		uint64		hashkey;
-		pg_unicode_recompinfo recompinfo = UnicodeRecompInfo;
-
-		/*
-		 * Compute the hash function. The hash key is formed by concatenating
-		 * bytes of the two codepoints in network order. See also
-		 * src/common/unicode/generate-unicode_norm_table.pl.
-		 */
-		hashkey = pg_hton64(((uint64) start << 32) | (uint64) code);
-		h = recompinfo.hash(&hashkey);
-
-		/* An out-of-range result implies no match */
-		if (h < 0 || h >= recompinfo.num_recomps)
-			return false;
+		*result = normalization_inverse(start, code);
 
-		inv_lookup_index = recompinfo.inverse_lookup[h];
-		entry = &UnicodeDecompMain[inv_lookup_index];
-
-		if (start == UnicodeDecomp_codepoints[entry->dec_index] &&
-			code == UnicodeDecomp_codepoints[entry->dec_index + 1])
-		{
-			*result = entry->codepoint;
-			return true;
-		}
-
-#else
-
-		int			i;
-
-		for (i = 0; i < lengthof(UnicodeDecompMain); i++)
-		{
-			entry = &UnicodeDecompMain[i];
-
-			if (DECOMPOSITION_SIZE(entry) != 2)
-				continue;
-
-			if (DECOMPOSITION_NO_COMPOSE(entry))
-				continue;
-
-			if (start == UnicodeDecomp_codepoints[entry->dec_index] &&
-				code == UnicodeDecomp_codepoints[entry->dec_index + 1])
-			{
-				*result = entry->codepoint;
-				return true;
-			}
-		}
-#endif							/* !FRONTEND */
+		return *result != 0;
 	}
 
 	return false;
diff --git a/src/include/common/unicode_norm_hashfunc.h b/src/include/common/unicode_norm_hashfunc.h
deleted file mode 100644
index 89e04c744d9..00000000000
--- a/src/include/common/unicode_norm_hashfunc.h
+++ /dev/null
@@ -1,3016 +0,0 @@
-/*-------------------------------------------------------------------------
- *
- * unicode_norm_hashfunc.h
- *	  Perfect hash functions used for Unicode normalization
- *
- * Portions Copyright (c) 1996-2025, PostgreSQL Global Development Group
- * Portions Copyright (c) 1994, Regents of the University of California
- *
- * src/include/common/unicode_norm_hashfunc.h
- *
- *-------------------------------------------------------------------------
- */
-
-/*
- * File auto-generated by src/common/unicode/generate-unicode_norm_table.pl,
- * do not edit. There is deliberately not an #ifndef PG_UNICODE_NORM_HASHFUNC_H
- * here.
- */
-
-#include "common/unicode_norm_table.h"
-
-/* Typedef for perfect hash functions */
-typedef int (*cp_hash_func) (const void *key);
-
-/* Information for lookups with perfect hash functions */
-typedef struct
-{
-	const pg_unicode_decomposition *decomps;
-	cp_hash_func	hash;
-	int		num_decomps;
-} pg_unicode_decompinfo;
-
-typedef struct
-{
-	const uint16	*inverse_lookup;
-	cp_hash_func	hash;
-	int		num_recomps;
-} pg_unicode_recompinfo;
-
-/* Perfect hash function for decomposition */
-static int
-Decomp_hash_func(const void *key)
-{
-	static const int16 h[13687] = {
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 0,     32767, 32767, 32767, 32767, 0,
-		0,     0,     0,     32767, 0,     0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 0,
-		0,     0,     0,     32767, 0,     32767, 0,     32767,
-		0,     32767, 0,     32767, 0,     32767, 0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     32767, 32767, 32767, 32767, 0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		32767, 32767, 0,     32767, 32767, 0,     0,     0,
-		0,     32767, 32767, 32767, 0,     0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		0,     32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		1,     32767, 2,     32767, 32767, 32767, 32767, 2792,
-		32767, 32767, 4,     5,     6,     7,     32767, 32767,
-		8,     9,     10,    32767, 11,    12,    13,    1734,
-		14,    -822,  -822,  17,    18,    3020,  1739,  3021,
-		3022,  3023,  1110,  24,    3024,  3025,  27,    -3019,
-		32767, 29,    30,    3026,  3027,  33,    34,    5016,
-		1754,  -4252, 36,    37,    -4254, -4254, -4254, 32767,
-		40,    41,    42,    43,    44,    45,    1912,  46,
-		47,    48,    49,    50,    51,    52,    53,    54,
-		1770,  55,    606,   57,    58,    59,    60,    1776,
-		1777,  61,    62,    63,    64,    65,    32767, 66,
-		32767, -1290, 6662,  3534,  3534,  3534,  -172,  3322,
-		-170,  -169,  -168,  -167,  3331,  1788,  0,     1790,
-		1791,  1792,  1793,  1794,  1795,  1796,  1797,  1798,
-		1799,  3354,  1801,  1802,  -964,  -964,  -964,  -964,
-		1807,  4976,  4976,  4976,  4976,  4976,  4976,  1814,
-		1815,  4974,  2192,  11244, 2194,  11245, 0,     0,
-		1605,  11251, 0,     11252, 0,     0,     3571,  3571,
-		-47,   -47,   0,     0,     -124,  -123,  -122,  -4877,
-		-4877, -119,  32767, 32767, -118,  0,     -116,  -11032,
-		-114,  -113,  -112,  32767, 32767, -887,  -110,  -109,
-		-885,  -107,  5320,  32767, 32767, -105,  -882,  5328,
-		-102,  -101,  -100,  -99,   -4221, -4221, -4221, -95,
-		-94,   -93,   -92,   -4221, -4221, -4221, -4221, 32767,
-		32767, -4223, -4223, -4223, -4223, -4223, -4223, -4223,
-		-4223, -5481, -4223, -4223, -4223, -4223, -4223, -4223,
-		-4223, -4223, -4223, -4223, -4223, -4223, -4223, -4223,
-		-5495, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 1839,  1840,  1841,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 4663,  4664,  32767,
-		32767, -4255, -4255, 32767, 0,     0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		-4268, -4268, 5881,  5882,  4722,  5884,  5885,  5886,
-		5887,  32767, 5888,  5889,  5890,  5891,  5892,  5893,
-		5894,  5895,  5896,  5897,  5898,  185,   186,   -3976,
-		-3976, -3976, -3976, 6000,  6001,  6002,  6003,  6004,
-		6005,  6006,  198,   5911,  -3968, -3968, -826,  -3968,
-		-3968, -3968, -3968, -3968, 208,   209,   32767, -3967,
-		-3967, -3032, -3967, -3967, -3030, 5922,  5923,  -813,
-		5925,  5926,  219,   220,   5929,  5930,  5931,  224,
-		-4290, -4290, -4290, -4290, -4290, -4290, -4290, 5940,
-		5941,  -4292, -4292, -4292, -4292, -4292, -4292, -4292,
-		-4292, 5950,  5951,  0,     0,     0,     0,     245,
-		0,     0,     0,     0,     0,     0,     0,     253,
-		254,   255,   256,   -635,  258,   259,   260,   261,
-		262,   263,   0,     265,   266,   267,   0,     0,
-		268,   269,   32767, 32767, 32767, 32767, 32767, 32767,
-		270,   271,   272,   273,   274,   275,   276,   277,
-		278,   279,   280,   281,   282,   283,   32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 5981,  32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 0,     32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 2763,
-		975,   32767, 32767, 0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     289,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     4382,  4382,  4382,  0,     7408,
-		4383,  4383,  0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		-4027, 0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     -1642, -1641, -1640, -1639,
-		-1638, 3694,  -1636, 3697,  3698,  3699,  0,     0,
-		-1627, 0,     0,     -1622, -1621, 0,     6198,  -1616,
-		-1615, -1614, -1613, 0,     -1610, -1609, -1608, 0,
-		0,     0,     0,     0,     0,     9558,  -10546,0,
-		6270,  6271,  6272,  6273,  6274,  6275,  -3369, 6277,
-		6545,  6279,  9583,  6281,  -1402, -1402, 6284,  6285,
-		304,   1947,  1947,  1947,  1947,  1947,  -3384, 1947,
-		-3385, -3385, -3385, 315,   316,   1944,  318,   319,
-		1942,  1942,  322,   -5875, 1940,  1940,  1940,  1940,
-		328,   1939,  1939,  1939,  332,   333,   334,   335,
-		336,   337,   -9220, 10885, 340,   -5929, -5929, -5929,
-		-5929, -5929, -5929, 3716,  -5929, -6196, -5929, -9232,
-		-5929, 1755,  1756,  -5929, -5929, 53,    -1589, -1588,
-		-1587, -1586, -1585, 3747,  -1583, 3750,  3751,  3752,
-		53,    53,    -1574, 53,    53,    -1569, -1568, 53,
-		6251,  -1563, -1562, -1561, -1560, 53,    -1557, 5101,
-		-1556, 52,    52,    52,    52,    52,    52,    9610,
-		-10494,52,    6322,  6323,  6324,  6325,  6326,  6327,
-		-3317, 6329,  6597,  6331,  9635,  6333,  -1350, -1350,
-		6336,  6337,  356,   1999,  1999,  1999,  1999,  1999,
-		0,     0,     -2173, -3888, -3337, -5616, 0,     0,
-		432,   -2164, 1985,  0,     0,     0,     1980,  0,
-		0,     0,     0,     -1319, -4683, 1975,  368,   369,
-		370,   371,   372,   0,     -9185, 0,     374,   -5895,
-		-5895, 0,     0,     0,     0,     864,   437,   -16,
-		-16,   440,   32767, 441,   442,   443,   -13,   445,
-		446,   447,   32767, 32767, 32767, 32767, 32767, 6042,
-		6043,  6044,  6045,  430,   431,   0,     2597,  -1551,
-		435,   32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 448,   449,   450,   32767, 451,
-		452,   32767, 32767, 32767, 453,   0,     0,     0,
-		0,     0,     -428,  0,     454,   455,   0,     456,
-		0,     0,     0,     457,   0,     0,     0,     0,
-		458,   459,   460,   0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		3733,  3734,  0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     462,   0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     463,   464,   0,     465,
-		0,     0,     0,     466,   0,     0,     0,     0,
-		467,   0,     469,   0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     5493,  0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		5530,  0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     -4339, -4339, 0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     -7353, -7353, -7353, -5439,
-		0,     0,     -7353, -4354, 0,     0,     485,   486,
-		487,   488,   489,   490,   0,     0,     491,   492,
-		493,   494,   -2541, -5542, 0,     0,     -5544, -5544,
-		-3630, -2543, -5542, -5542, -2543, 504,   -2543, -2543,
-		-2543, -5538, 0,     0,     -2545, -2545, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 3448,
-		3448,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, -3213, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 2540,  2540,
-		2540,  2540,  2540,  0,     4830,  4831,  -307,  -307,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     4166,  0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     -31,   0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     -796,  -795,
-		-794,  -793,  -792,  -791,  1061,  1062,  1063,  1064,
-		1065,  0,     0,     0,     0,     0,     0,     0,
-		-785,  -784,  -783,  -782,  -4016, 0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     -1097, -1096, -1095, -5270, -5270, -1094, -1093,
-		-1092, -2026, -1090, -1089, -2025, -2024, -765,  -4241,
-		-10978,-10978,-5270, -5270, -10978,-10978,0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     3849,  0,
-		0,     0,     0,     3854,  2311,  523,   2313,  0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 5994,  4146,  4146,  5997,  32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		2970,  32767, 32767, 32767, 32767, 1264,  1264,  1264,
-		2215,  2216,  2217,  2218,  2219,  2220,  2221,  32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 5792,  32767,
-		362,   32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, -3774, 32767, 32767, -3776, -3776, -3776, -3776,
-		-5034, -3776, -3776, 32767, 32767, -3778, -3778, -3778,
-		-3778, -3778, -3778, 32767, 32767, -3780, -3780, 32767,
-		-5053, -3781, -3781, -3781, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, -157,  32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		627,   32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 4695,  32767,
-		32767, 2985,  2986,  32767, 32767, 32767, 32767, 628,
-		629,   630,   631,   632,   633,   -5911, 635,   636,
-		637,   638,   639,   640,   641,   642,   643,   644,
-		645,   646,   647,   648,   649,   650,   651,   652,
-		653,   654,   32767, 32767, 32767, 32767, 32767, 32767,
-		-2208, 32767, 8339,  32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 4699,  32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 4700,
-		4701,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 5998,  0,     32767,
-		32767, 32767, 32767, 0,     0,     32767, 32767, 32767,
-		32767, 0,     2987,  32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, -1459,
-		-1459, -1459, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, -1496, -2931, 32767,
-		32767, 32767, 655,   656,   657,   658,   659,   660,
-		661,   662,   663,   32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 664,   32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 4743,  32767, 32767, 32767, -3717, -3716,
-		667,   -6740, 32767, -3714, 670,   671,   672,   673,
-		674,   675,   676,   677,   32767, 678,   679,   680,
-		32767, 681,   4709,  683,   684,   685,   2990,  32767,
-		32767, 32767, 2991,  2992,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 538,   32767, 32767, 32767, 32767, -1583, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 686,   -5583, -5583, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, -1622,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 4710,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		4679,  4711,  4681,  4682,  4683,  4684,  4685,  4686,
-		4687,  4688,  4689,  0,     0,     32767, 0,     32767,
-		32767, 32767, 0,     5257,  32767, 32767, 32767, 6885,
-		6619,  9923,  6621,  -1062, -1062, 6624,  6625,  644,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 1637,  32767, 1637,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 4690,  4691,  4692,  4693,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 4015,  -5630, -5897, -5630, -8933, -5630,
-		2054,  2055,  -5630, -5630, 352,   -1290, -1289, -1288,
-		-1287, -1286, 714,   715,   2889,  4605,  4055,  6335,
-		720,   721,   32767, 2886,  -1262, 724,   725,   726,
-		-1253, 728,   729,   730,   731,   2051,  5416,  -1241,
-		367,   367,   367,   367,   367,   740,   9926,  742,
-		369,   6639,  6640,  746,   747,   748,   749,   -114,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, -8006, -8006, -2024, -3666, -3665,
-		-3664, -3663, -3662, 1670,  -3660, 1673,  1674,  1675,
-		-2024, -2024, -3651, -2024, -2024, 32767, 32767, 32767,
-		32767, 32767, -2866, 32767, 32767, -2865, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, -2866, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, -2866, 32767,
-		32767, 32767, -4485, -4485, 758,   759,   32767, 32767,
-		32767, 760,   -2863, -2862, -2861, -2860, -2859, -2858,
-		-2857, 32767, 32767, 32767, 32767, 32767, 32767, 3014,
-		3015,  3016,  32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 0,     0,     32767, 32767, 32767, 32767, 3017,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 2180,  2180,  32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 768,   32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 769,   770,   771,   32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 0,
-		32767, 32767, 32767, 32767, 32767, 772,   773,   32767,
-		774,   32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 3018,
-		32767, 32767, 0,     32767, 4716,  4717,  32767, 32767,
-		32767, 32767, 32767, 32767, 3019,  0,     3919,  0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     32767, 0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     32767, 32767, 3643,
-		32767, 32767, 3641,  32767, 32767, 0,     0,     -3355,
-		0,     0,     0,     0,     1998,  0,     0,     0,
-		0,     0,     0,     -3366, -3366, -3366, 0,     0,
-		-3368, 0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     32767, 0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     3365,  0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     676,   0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     677,   0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     13799, 0,     0,     0,     9279,  2994,  32767,
-		8461,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		1755,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 3196,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, -4700,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, -3816,
-		360,   361,   362,   -572,  364,   365,   -571,  -570,
-		689,   -2787, -9524, -9524, -3816, -3816, -9524, -9524,
-		-9524, -3816, 699,   700,   701,   702,   703,   704,
-		705,   706,   707,   8659,  5531,  5531,  5531,  32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 0,     32767,
-		32767, 32767, 32767, 32767, 32767, 4746,  4747,  32767,
-		4748,  32767, 32767, 32767, 4749,  -507,  -507,  -507,
-		-507,  -507,  -507,  -507,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, -872,
-		32767, 32767, 3030,  3031,  3032,  3033,  32767, 32767,
-		32767, 32767, 32767, 32767, 32767, -3585, -3585, -3585,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     -10784,-5076, -561,
-		-560,  0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		2304,  2304,  0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     -3368, -3368,
-		798,   32767, -372,  -372,  -372,  -372,  -372,  -372,
-		0,     1160,  0,     0,     0,     0,     0,     0,
-		1161,  0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     5714,  5714,  9877,  9878,  9879,  9880,  0,
-		0,     -97,   -97,   -97,   -97,   -97,   5712,  0,
-		0,     9880,  6739,  0,     9882,  9883,  9884,  9885,
-		5710,  0,     3820,  679,   0,     0,     9886,  9887,
-		8951,  0,     0,     6737,  0,     0,     5708,  5708,
-		0,     0,     0,     5708,  10223, 10224, 10225, 10226,
-		10227, 10228, 10229, 0,     0,     10234, 10235, 10236,
-		10237, 10238, 10239, 10240, 10241, 0,     0,     5952,
-		5953,  5954,  5955,  5711,  5957,  5958,  5959,  5960,
-		5961,  5962,  5963,  5711,  5711,  5711,  5711,  6603,
-		5711,  5711,  5711,  5711,  5711,  5711,  5975,  5711,
-		5711,  5711,  5979,  5980,  32767, 32767, 32767, 32767,
-		803,   32767, 32767, 32767, 804,   32767, 32767, 32767,
-		32767, 32767, 32767, 805,   806,   32767, 807,   808,
-		32767, 809,   0,     5999,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 1389,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 840,   841,   32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		842,   32767, 843,   32767, 844,   32767, 32767, 32767,
-		32767, 32767, 0,     0,     10606, 0,     845,   5378,
-		0,     0,     0,     0,     1113,  1113,  1113,  1113,
-		1113,  1113,  1113,  1113,  1113,  -6838, -3709, -3708,
-		-3707, 0,     -3493, 0,     0,     0,     0,     -3497,
-		-1953, -164,  -1953, -1953, 5407,  5408,  -1955, -1955,
-		-1955, -1955, -1955, -1955, -3509, -1955, -1955, 812,
-		813,   814,   815,   -1955, -5123, -5122, -5121, -5120,
-		-5119, -5118, -14675,5430,  -5115, -2332, -11383,-2332,
-		-11382,-136,  -135,  -1739, -11384,-11651,-11384,-131,
-		-130,  -3700, -3699, -80,   5447,  -126,  -125,  0,
-		0,     0,     4756,  4757,  0,     5456,  -1715, 0,
-		-117,  0,     10917, 0,     0,     0,     5465,  5466,
-		776,   0,     0,     777,   0,     -5426, 5473,  5474,
-		0,     778,   -5431, 0,     0,     0,     0,     4123,
-		4124,  4125,  0,     0,     0,     0,     4130,  4131,
-		4132,  4133,  4134,  4135,  4136,  4137,  4138,  4139,
-		4140,  4141,  4142,  4143,  5402,  4145,  4146,  4147,
-		4148,  4149,  4150,  4151,  4152,  4153,  4154,  4155,
-		4156,  4157,  4158,  5431,  5432,  4161,  4162,  4163,
-		4164,  4165,  4166,  4167,  4168,  4169,  4170,  4171,
-		4172,  4173,  4174,  4175,  4176,  4177,  4178,  4179,
-		32767, 32767, 4180,  4181,  4182,  4183,  4184,  4185,
-		4186,  4187,  4188,  4189,  4190,  4191,  4192,  6044,
-		6045,  6046,  6047,  6048,  4198,  4199,  4200,  4201,
-		4202,  4203,  4204,  4205,  4206,  4207,  4208,  974,
-		4210,  11136, 3906,  3907,  3908,  3909,  3910,  3911,
-		3912,  3913,  3914,  3915,  3916,  3917,  5988,  5989,
-		0,     0,     3919,  3920,  3921,  3922,  -6053, -6053,
-		-6053, -6053, -6053, -6053, -6053, -244,  -5956, 3924,
-		3925,  784,   3927,  3928,  3929,  3930,  3931,  -244,
-		-244,  3932,  3933,  3934,  3000,  3936,  3937,  3001,
-		3002,  4261,  785,   -5952, -5952, -244,  -244,  -5952,
-		-5952, -5952, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, -5739, -408,
-		-408,  -408,  32767, 32767, 32767, 32767, 3724,  823,
-		824,   32767, 32767, 32767, 32767, 32767, 32767, -421,
-		-2028, -2027, -2026, -2025, -2024, 517,   -4312, -4312,
-		827,   828,   522,   523,   524,   525,   526,   527,
-		528,   529,   530,   531,   532,   533,   534,   535,
-		536,   537,   538,   539,   540,   541,   542,   543,
-		544,   545,   546,   547,   548,   -3617, 550,   551,
-		552,   553,   554,   555,   556,   32767, 557,   32767,
-		558,   559,   32767, 560,   561,   32767, 562,   32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     32767, 32767, 32767,
-		32767, 32767, 32767, 0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     -1191, -1191,
-		-1191, -2792, 0,     0,     0,     0,     -2791, -2790,
-		-4408, 0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     -2791, -2790,
-		-2789, 0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     837,   838,   0,     0,     -3001, 3038,
-		-3001, -3001, -3001, -1087, 0,     -2999, -2999, 0,
-		3047,  0,     0,     0,     -2995, -2995, 0,     0,
-		0,     0,     4287,  0,     0,     4292,  4293,  0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     -550,  0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     3918,  0,     0,     0,     0,     9976,  0,
-		0,     0,     0,     -6065, -6065, 0,     0,     0,
-		0,     3142,  0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     935,   0,     0,     937,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     9645,  0,     -267,  0,     -3303, 0,
-		7684,  7685,  0,     0,     5982,  4340,  4341,  4342,
-		4343,  4344,  9676,  4346,  4347,  9679,  9680,  4350,
-		4351,  4352,  4353,  4354,  4355,  4356,  4357,  4358,
-		4359,  4360,  4361,  4362,  4363,  4364,  4365,  4366,
-		5974,  5974,  5974,  5974,  5974,  5974,  15532, -4572,
-		5974,  3192,  12244, 3194,  12245, 12246, 12247, 2603,
-		12249, 12517, 12251, 999,   12252, 4569,  4569,  12255,
-		12256, 6275,  7918,  7918,  7918,  7918,  7918,  2587,
-		7918,  2586,  2586,  2586,  6286,  6287,  7915,  6289,
-		6290,  7913,  7913,  6293,  96,    7911,  7911,  7911,
-		7911,  6299,  7910,  1253,  7911,  6304,  6305,  6306,
-		6307,  6308,  6309,  -3248, 16857, 6312,  43,    43,
-		43,    43,    43,    43,    9688,  43,    -224,  43,
-		-3260, 43,    7727,  7728,  43,    43,    6025,  1253,
-		6234,  1253,  6384,  6385,  10526, -3272, 1253,  6388,
-		10531, 1253,  1253,  1253,  1253,  6392,  6393,  0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     6053,  6054,  6055,
-		6056,  6057,  6058,  32767, 6059,  6060,  6061,  6062,
-		32767, 6063,  32767, 6064,  32767, 32767, 32767, 4761,
-		32767, 32767, 6065,  32767, 4762,  4763,  32767, 9404,
-		32767, 6067,  4764,  6068,  32767, 6069,  6070,  6071,
-		32767, 6072,  6073,  32767, 6074,  32767, 32767, 6075,
-		32767, 6076,  32767, 6077,  32767, 6078,  32767, 6079,
-		32767, 4374,  4374,  32767, 4373,  32767, 32767, 5324,
-		5325,  5326,  5327,  32767, 6087,  6088,  6089,  6090,
-		6091,  3057,  6093,  32767, 6094,  4376,  -4013, 4376,
-		32767, 4375,  4375,  4375,  4375,  32767, 4374,  32767,
-		4373,  6104,  6105,  6106,  6107,  6108,  6109,  6110,
-		6111,  -3652, 881,   -645,  -645,  -1903, 6116,  6117,
-		6118,  4399,  4400,  4401,  6122,  6123,  3567,  3567,
-		4406,  6127,  7410,  6129,  32767, 32767, 32767, 32767,
-		32767, 7409,  7410,  4412,  32767, 6133,  4414,  4415,
-		6136,  6137,  32767, 4420,  9402,  6140,  134,   134,
-		13933, 134,   134,   134,   9413,  4429,  6149,  4432,
-		6151,  4435,  6153,  6304,  6305,  6306,  6307,  6308,
-		6309,  6310,  6311,  6312,  6313,  6314,  1068,  6316,
-		5378,  6318,  5379,  6320,  803,   6322,  -2232, 6324,
-		6325,  6326,  1074,  6328,  6329,  6330,  6331,  6332,
-		6333,  6334,  6335,  6336,  6337,  6338,  6339,  6340,
-		6341,  6342,  6343,  6344,  6345,  6346,  6347,  6348,
-		6349,  6350,  6351,  6352,  6353,  6354,  6355,  6356,
-		6357,  6358,  6359,  6360,  5417,  6362,  6363,  6364,
-		6365,  6366,  6367,  5423,  6369,  5424,  6371,  6372,
-		5426,  5426,  6375,  5427,  5427,  6378,  6379,  6380,
-		6381,  6382,  6383,  6384,  6385,  6386,  6387,  6388,
-		6389,  6390,  6391,  6392,  6393,  6394,  6395,  6396,
-		6397,  6398,  6399,  6400,  6401,  6402,  6403,  6404,
-		6405,  6406,  6407,  6408,  6409,  6410,  6411,  6412,
-		6413,  6414,  6415,  6416,  6417,  6418,  6419,  6420,
-		6421,  6422,  7182,  5465,  6425,  6426,  6427,  6428,
-		6429,  6430,  6431,  6432,  6433,  6434,  6435,  6436,
-		6437,  6438,  6439,  6440,  6441,  6442,  6443,  6444,
-		6445,  6446,  6447,  6448,  6449,  6450,  6451,  6452,
-		6453,  6454,  6455,  6456,  6457,  6458,  6459,  6460,
-		6461,  6462,  6463,  6464,  6465,  6466,  6467,  6468,
-		6469,  6470,  6471,  6472,  6473,  6474,  6475,  6476,
-		6477,  6478,  5519,  5519,  6481,  6482,  6483,  6484,
-		6485,  6486,  6487,  6488,  6489,  6490,  6491,  6492,
-		6493,  6494,  6495,  6496,  6497,  6498,  6499,  6500,
-		6501,  6502,  6503,  6504,  6505,  6506,  6507,  6508,
-		6509,  6510,  6511,  6512,  6513,  6514,  6515,  6516,
-		6517,  6518,  6519,  6520,  6521,  6522,  6523,  6524,
-		6525,  6526,  6527,  6528,  6529,  6530,  6531,  6532,
-		6533,  1330,  6535,  6536,  6537,  6538,  5577,  6540,
-		6541,  6542,  6543,  6544,  6545,  6546,  6547,  6548,
-		6549,  6550,  5588,  5588,  6553,  6554,  6555,  6556,
-		32767, 6557,  1728,  1728,  6867,  6868,  6562,  6563,
-		6564,  6565,  6566,  6567,  6568,  6569,  6570,  6571,
-		6572,  6573,  6574,  6575,  6576,  6577,  6578,  6579,
-		6580,  6581,  6582,  6583,  6584,  6585,  6586,  6587,
-		6588,  2423,  6590,  6591,  6592,  6593,  6594,  6595,
-		6596,  6597,  6598,  6599,  6600,  6601,  6602,  6603,
-		6604,  6605,  6606,  6607,  6608,  6609,  6610,  6611,
-		6612,  6613,  6614,  6615,  6616,  6617,  6618,  6619,
-		6620,  6621,  6622,  6623,  6624,  6625,  6626,  6627,
-		6628,  6629,  6630,  6631,  6632,  6633,  6634,  6635,
-		6636,  6637,  6638,  6639,  6640,  6641,  6642,  6643,
-		6644,  6645,  6646,  6647,  6648,  6649,  6650,  6651,
-		6652,  6653,  6654,  6655,  6656,  6657,  6658,  6659,
-		6660,  6661,  6693,  6663,  6664,  6665,  6666,  6667,
-		6668,  6669,  6670,  6671,  6672,  6673,  6674,  6675,
-		6676,  6677,  6678,  6679,  7476,  7476,  7476,  7476,
-		7476,  7476,  5625,  5625,  5625,  5625,  5625,  6691,
-		6692,  6693,  6694,  6695,  6696,  6697,  7483,  7483,
-		7483,  7483,  10718, 6703,  6704,  6705,  6706,  6707,
-		6708,  6709,  6710,  6711,  6712,  6713,  6714,  6715,
-		6716,  6717,  6718,  6719,  6720,  6721,  6722,  6723,
-		6724,  6725,  6726,  6727,  6728,  6729,  6730,  6731,
-		6732,  6733,  6734,  6735,  6736,  6737,  6738,  7836,
-		7836,  7836,  12012, 12013, 7838,  7838,  7838,  8773,
-		7838,  7838,  8775,  8775,  7517,  10994, 17732, 17733,
-		12026, 12027, 17736, 17737, 6760,  6761,  6762,  6763,
-		6764,  6765,  6766,  6767,  6768,  6769,  6770,  6771,
-		6772,  6773,  6774,  6775,  2927,  6777,  6778,  6779,
-		6780,  2927,  4471,  6260,  4471,  6785,  6786,  6787,
-		6788,  6789,  6790,  6791,  6792,  6793,  6794,  6795,
-		6796,  6797,  6798,  6799,  6800,  6801,  6802,  6803,
-		6804,  6805,  6806,  6807,  6808,  6809,  6810,  6811,
-		6812,  32767, 3411,  5540,  5541,  3411,  12221, 3411,
-		3411,  3411,  3411,  5548,  5549,  5550,  5551,  5552,
-		5553,  5554,  5555,  5556,  5557,  5558,  5559,  5560,
-		5561,  5562,  5563,  5564,  5565,  5566,  5567,  5568,
-		32767, 32767, 32767, 32767, 32767, 32767, 3915,  32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 6155,  6156,  6157,  6158,  6159,
-		6160,  6161,  6162,  6163,  6164,  6165,  32767, 32767,
-		32767, 32767, 32767, 6166,  6167,  6168,  6169,  6170,
-		6171,  6172,  6173,  6174,  6175,  6176,  6177,  6178,
-		6179,  6180,  4615,  4616,  4617,  4618,  4619,  6186,
-		6187,  6188,  6189,  6190,  6191,  6192,  6193,  6194,
-		6195,  6196,  32767, 6197,  6198,  6199,  6200,  6201,
-		7637,  4495,  4495,  6205,  4052,  4052,  6208,  6209,
-		6210,  6211,  6212,  6213,  6214,  6215,  6216,  6217,
-		6218,  6219,  6220,  6221,  6222,  6223,  6224,  6225,
-		6226,  6227,  6228,  32767, 32767, 0,     0,     32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 6229,  6230,  6231,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 0,     32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 6232,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		884,   885,   886,   32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 0,     32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 0,     32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 5994,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 6233,  6234,  6235,  32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 6236,  6237,  6238,  6239,
-		6240,  6241,  6242,  6243,  6244,  6245,  6246,  6247,
-		6248,  6249,  6250,  6251,  6252,  6253,  6254,  6255,
-		6256,  6257,  6258,  6259,  6260,  6261,  6262,  6263,
-		6264,  6265,  6266,  6267,  6268,  6269,  6270,  6271,
-		6272,  6273,  6274,  6275,  6276,  6277,  6278,  6279,
-		32767, 32767, 32767, 32767, 6280,  6281,  6282,  6283,
-		6284,  6285,  6286,  6287,  6288,  4770,  32767, 4771,
-		4772,  32767, 32767, 32767, 6289,  6290,  32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, -5160, 2071,
-		2071,  2071,  2071,  32767, 2070,  2070,  2070,  2070,
-		2070,  2070,  2070,  0,     0,     6236,  6237,  2075,
-		2075,  2075,  2075,  12051, 12052, 12053, 12054, 12055,
-		12056, 12057, 6249,  11962, 2083,  2083,  5225,  2083,
-		2083,  2083,  2083,  2083,  6259,  6260,  2085,  2085,
-		2085,  3020,  2085,  2085,  3022,  3022,  32767, 5240,
-		11978, 11979, 6272,  6273,  11982, 11983, 11984, 6277,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 4773,  32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 415,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, -2468, -2468,
-		-2468, -2468, -2468, -2468, -2468, -2468, -2468, -2468,
-		-2468, -2468, -2468, -2468, -2468, -2468, -2468, -2468,
-		2089,  2090,  2091,  -2465, -2465, -2465, -2465, -2465,
-		-2465, 2098,  2099,  -2463, -2463, -2463, -2463, -2463,
-		-2463, 2106,  2107,  -2461, -2461, -2461, -2461, -2461,
-		-2461, 0,     0,     -2459, -2459, -2459, 2119,  2120,
-		2121,  -2456, 2123,  2124,  2125,  2126,  2127,  2128,
-		0,     0,     2131,  -6678, 2133,  2134,  2135,  2136,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     2158,  2159,  2160,
-		2161,  2162,  2163,  2164,  2165,  2166,  2167,  2168,
-		2169,  2170,  2171,  2172,  2173,  2174,  2175,  2176,
-		2177,  2178,  2179,  2180,  2181,  -2412, -2412, -2412,
-		-2412, -2412, 2187,  2188,  2025,  2190,  2191,  2192,
-		2193,  2194,  2195,  2196,  2197,  2198,  2199,  2200,
-		2201,  2202,  2203,  2204,  2205,  2206,  2207,  2208,
-		2209,  2210,  2211,  2212,  2213,  2214,  2215,  2216,
-		2217,  2218,  2219,  2220,  2221,  0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     1566,  1566,
-		1566,  1566,  1566,  0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     32767, 0,
-		0,     0,     0,     0,     -1435, 1708,  1709,  0,
-		2154,  2155,  0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 0,     0,     0,     32767, 32767, 4774,  4775,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 0,
-		32767, 32767, 32767, 32767, 0,     0,     0,     0,
-		0,     0,     0,     0,     -2552, 0,     0,     32767,
-		0,     32767, 32767, 32767, 1551,  293,   3770,  32767,
-		32767, 32767, 32767, 0,     32767, 0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		0,     0,     0,     32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 0,     32767, 32767, 32767, 0,
-		0,     32767, 0,     0,     32767, 32767, 32767, 32767,
-		0,     32767, 0,     32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 0,     0,     0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 0,     32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 0,     32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, -4309, -4309, 0,     32767,
-		0,     -4310, -4577, -4310, -7613, -4310, 3374,  3375,
-		-4310, -4310, 1672,  -3100, 1881,  -3100, 2031,  2032,
-		6173,  -7625, -3100, 2035,  6178,  -3100, -3100, -3100,
-		-3100, 2039,  2040,  32767, 0,     -4353, -4353, 0,
-		-4352, 0,     0,     -4350, 0,     -4349, -4349, -4349,
-		-4349, 32767, 0,     32767, 32767, 32767, 32767, 32767,
-		32767, 0,     32767, 0,     0,     32767, 0,     0,
-		32767, 0,     0,     32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 0,     0,     0,     0,
-		0,     951,   952,   953,   954,   955,   956,   957,
-		1717,  0,     32767, 32767, 32767, -1317, 32767, 32767,
-		32767, 0,     -8389, 0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     32767, 32767, 32767,
-		32767, 32767, 32767, 887,   888,   32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		0,     0,     32767, -5009, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 0,     32767, 32767, 32767,
-		32767, 32767, 32767, 5520,  32767, 32767, 32767, 32767,
-		0,     0,     32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 5990,  5991,  5992,  5993,  32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 890,   32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 891,   32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		0,     32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 799,   32767, 32767, 32767,
-		32767, 800,   32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 801,   802,   32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 0,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 0,     0,
-		0,     0,     0,     0,     6545,  0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		0,     32767, 32767, 32767, 0,     32767, 32767, 32767,
-		32767, 32767, 32767, 0,     0,     32767, 0,     0,
-		32767, 0,     32767, 32767, 32767, 32767, 32767, 32767,
-		-5711, 241,   242,   243,   244,   0,     246,   247,
-		248,   249,   250,   251,   252,   0,     0,     0,
-		0,     892,   0,     0,     0,     0,     0,     0,
-		264,   0,     0,     0,     32767, 32767, 0,     0,
-		32767, 32767, 32767, 32767, 32767, 32767, 0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 0,     0,     0,     0,     0,     0,     0,
-		0,     0,     32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 0,     32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 893,   -266,  895,   32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		284,   285,   286,   287,   288,   0,     290,   291,
-		292,   32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 0,     0,     0,     0,
-		0,     0,     0,     32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 0,
-		293,   294,   295,   296,   297,   298,   32767, 32767,
-		299,   -4082, -4081, -4080, 303,   0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     32767, 0,     0,     0,     0,
-		0,     32767, 0,     32767, 0,     0,     32767, 0,
-		0,     32767, 0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, -4245, -4245, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     32767, 32767, 32767, 32767,
-		32767, 32767, -689,  32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, -706,
-		-706,  -706,  -706,  -706,  -706,  -706,  -706,  32767,
-		32767, -7551, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, -4377, -4377, -8024, -8023, -4377, -4377,
-		-3916, -4377, -4377, -4377, -4377, -4377, -4377, -4377,
-		32767, -4378, -4378, -4378, -4378, -4378, -4378, -4378,
-		-4378, -4378, -4378, -4378, -4378, -4378, -4378, -4378,
-		-4378, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 150,   1867,  150,   0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     5247,  0,     939,   0,     940,   0,     5518,
-		0,     8555,  0,     0,     0,     5253,  0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     944,
-		0,     0,     0,     0,     0,     0,     945,   0,
-		946,   0,     0,     947,   948,   0,     949,   950,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     -759,  959,   0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     960,   961,   0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     5204,  0,     0,     0,
-		0,     962,   0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     963,   964,   0,
-		0,     0,     0,     32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 5186,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 0,     32767,
-		0,     0,     32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 5256,  -4973, -4973, 32767,
-		5261,  5262,  5263,  5264,  5265,  5266,  5267,  -4974,
-		-4974, 978,   979,   980,   981,   32767, 982,   983,
-		984,   985,   986,   987,   988,   32767, 32767, 32767,
-		32767, 1624,  32767, 32767, 32767, 32767, 32767, 32767,
-		990,   32767, 32767, 0,     991,   992,   32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 4759,
-		4760,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, -723,  -722,  -2974, 32767, 996,   -719,  -168,
-		-717,  -716,  -715,  1002,  1003,  1004,  -712,  -711,
-		32767, -710,  1008,  1009,  1010,  1011,  -2060, 5892,
-		2764,  2764,  2764,  1017,  1018,  1019,  1020,  1021,
-		1022,  2567,  1024,  32767, 1025,  1026,  1027,  1028,
-		1029,  1030,  1031,  1032,  1033,  1034,  2589,  1036,
-		1037,  -1729, -1729, -1729, -1729, 1042,  4211,  4211,
-		4211,  4211,  4211,  4211,  1049,  1050,  4209,  1427,
-		32767, 32767, 32767, 0,     0,     32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, -825,  32767, 32767,
-		32767, 32767, 32767, 4718,  4719,  4720,  32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 4721,  4722,
-		4723,  4724,  4725,  4726,  4727,  6291,  6292,  6293,
-		4728,  4729,  4730,  4731,  4732,  6299,  6300,  -4992,
-		1070,  1071,  1072,  1073,  1074,  1075,  1076,  1077,
-		1078,  1079,  1080,  4733,  1082,  4734,  1084,  1085,
-		1086,  1087,  1088,  1089,  1090,  1091,  1092,  1093,
-		1094,  1095,  1096,  1097,  1098,  1099,  1100,  1101,
-		1102,  1103,  1104,  1105,  1106,  1107,  1108,  1109,
-		1110,  1111,  1112,  1113,  1114,  1115,  1116,  1117,
-		1118,  1119,  1120,  1121,  1122,  1123,  1124,  1125,
-		1126,  1127,  1128,  1129,  1130,  1131,  1132,  1133,
-		1134,  1135,  1136,  1137,  1138,  1139,  1140,  1141,
-		1142,  1143,  1144,  1145,  1146,  4737,  1148,  4738,
-		4739,  1151,  1152,  1153,  1154,  32767, 4740,  4741,
-		4742,  1158,  1159,  1160,  1161,  1162,  1163,  1164,
-		1165,  1166,  1167,  1168,  1169,  1170,  1171,  1172,
-		1173,  1174,  1175,  1176,  1177,  1178,  1179,  1180,
-		1181,  1182,  1183,  1184,  1185,  1186,  1187,  1188,
-		1189,  1190,  1191,  1192,  1193,  1194,  11979, 6272,
-		1758,  1758,  1199,  1200,  1201,  1202,  1203,  1204,
-		1205,  1206,  1207,  1208,  1209,  1210,  1211,  1212,
-		1213,  1214,  1215,  1216,  1217,  1218,  1219,  1220,
-		1221,  1222,  1223,  1224,  1225,  1226,  1227,  1228,
-		1229,  -1074, -1073, 1232,  1233,  1234,  1235,  1236,
-		1237,  1238,  1239,  1240,  1241,  1242,  1243,  1244,
-		1245,  1246,  1247,  1248,  1249,  1250,  1251,  1252,
-		1253,  1254,  1255,  1256,  1257,  1258,  1259,  1260,
-		1261,  1262,  1263,  1264,  1265,  1266,  1267,  1268,
-		1269,  1270,  1271,  1272,  1273,  1274,  1275,  1276,
-		1277,  1278,  1279,  1280,  1281,  1282,  1283,  1284,
-		1285,  1286,  1287,  1288,  1289,  1290,  1291,  1292,
-		1293,  1294,  1295,  1296,  1297,  1298,  1299,  1300,
-		1301,  1302,  1303,  1304,  1305,  1306,  1307,  4676,
-		4677,  512,   32767, 32767, 32767, 32767, 1683,  1684,
-		1685,  1314,  155,   1316,  1317,  1318,  1319,  1320,
-		1321,  161,   1323,  1324,  1325,  1326,  1327,  1328,
-		1329,  1330,  1331,  1332,  1333,  1334,  1335,  1336,
-		1337,  1338,  -4375, -4374, -8536, -8536, -8536, -8536,
-		1345,  1346,  1444,  1445,  1446,  1447,  1448,  -4360,
-		1353,  1354,  -8525, -5383, 1357,  -8524, -8524, -8524,
-		-8524, -4348, 1363,  -2456, 686,   1366,  1367,  -8518,
-		-8518, -7581, 1371,  1372,  -5364, 1374,  1375,  -4332,
-		-4331, 1378,  1379,  1380,  -4327, -8841, -8841, -8841,
-		-8841, -8841, -8841, -8841, 1389,  1390,  -8843, -8843,
-		-8843, -8843, -8843, -8843, -8843, -8843, 1399,  1400,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 5957,
-		2655,  -5028, -5028, 2658,  2659,  -3322, -1679, -1679,
-		-1679, -1679, -1679, -7010, -1679, -1679, -7010, -7010,
-		-1679, -1679, -1679, -1679, -1679, 32767, 32767, -1681,
-		-1681, -1681, -1681, -1681, -1681, 32767, 32767, -1683,
-		-1683, -3290, -3289, -3288, -3287, -3286, -3285, -12842,
-		7263,  -3282, -499,  -9550, -499,  -9549, -9549, -9549,
-		96,    -9549, -9816, -9549, 1704,  -9548, -1864, -1863,
-		-9548, -9548, -3566, -5208, -5207, -5206, -5205, -5204,
-		128,   -5202, 131,   132,   133,   32767, 32767, -5195,
-		-3568, -3568, -5190, -5189, -3568, 32767, 32767, -5185,
-		-5184, -5183, -3570, -5180, 1478,  -5179, -3571, 32767,
-		-3572, 32767, -3573, 32767, 5984,  32767, -3575, 2695,
-		2696,  2697,  2698,  2699,  2700,  -6944, 2702,  2970,
-		2704,  6008,  2706,  -4977, -4977, 2709,  2710,  -3271,
-		1502,  -3478, 1504,  -3626, -3626, -7766, 6033,  1509,
-		-3625, -7767, 1512,  1513,  1514,  32767, 32767, -3625,
-		-3625, -3625, -3625, -3625, -3625, -3625, 1522,  -3624,
-		1524,  1525,  1526,  1527,  1528,  1529,  0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     3128,  0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     1581,  -673,  0,     784,   0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     3025,  0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     -6843,
-		-6843, 0,     0,     0,     1619,  1620,  1621,  0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     -2788, 32767, 32767,
-		1634,  1635,  1636,  1637,  1638,  1639,  1640,  1641,
-		4194,  1643,  1644,  32767, 32767, 32767, 32767, 32767,
-		32767, 1352,  32767, 32767, 32767, 32767, 32767, 1646,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 1647,  1648,  1649,  32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 1650,
-		32767, 32767, 32767, 1651,  1652,  32767, 1653,  1654,
-		32767, 32767, 32767, 32767, 1655,  32767, 1656,  32767,
-		32767, 32767, 32767, 399,   399,   32767, 32767, 1657,
-		1658,  1659,  32767, 32767, 32767, 32767, 32767, 32767,
-		0,     0,     0,     0,     32767, 32767, 32767, 1660,
-		32767, 32767, 32767, 32767, 32767, 6619,  32767, 1661,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		5971,  5972,  5973,  5974,  1664,  5975,  6243,  5977,
-		9281,  5979,  -1704, -1704, 5982,  5983,  2,     4775,
-		-205,  4777,  -353,  -353,  -4493, 9306,  4782,  -352,
-		-4494, 4785,  4786,  4787,  4788,  -350,  -350,  6044,
-		1691,  6045,  6046,  1694,  6047,  1696,  1697,  6048,
-		1699,  6049,  6050,  6051,  6052,  0,     0,     0,
-		0,     0,     0,     32767, 0,     0,     0,     0,
-		1704,  0,     32767, 0,     32767, 32767, 32767, 32767,
-		32767, 32767, 0,     32767, 32767, 32767, -3338, -3338,
-		-3338, 0,     32767, 0,     32767, 0,     0,     0,
-		32767, 0,     0,     32767, 0,     32767, 32767, 0,
-		0,     0,     0,     0,     32767, 0,     32767, 0,
-		1705,  1706,  1707,  1708,  1709,  759,   759,   759,
-		759,   759,   759,   759,   0,     0,     0,     0,
-		0,     3035,  0,     32767, 0,     1719,  10109, 1721,
-		1722,  1723,  1724,  1725,  1726,  1727,  1728,  1729,
-		1730,  0,     0,     0,     0,     0,     0,     0,
-		0,     9764,  6757,  6758,  6759,  8018,  0,     0,
-		0,     1720,  1720,  1720,  0,     0,     2557,  2558,
-		1720,  0,     -1282, 0,     -1281, -1281, -1281, 633,
-		1720,  -1279, -1279, 1720,  4767,  0,     1720,  1720,
-		0,     0,     1718,  1718,  -3263, 0,     6007,  6008,
-		-7790, 6010,  6011,  6012,  -3266, 1719,  0,     1718,
-		0,     1717,  0,     -150,  1717,  1717,  1717,  32767,
-		1716,  1716,  1716,  3969,  1715,  0,     1716,  1166,
-		1716,  1716,  1716,  0,     0,     0,     1717,  1717,
-		1717,  1717,  0,     0,     0,     0,     3072,  -4879,
-		-1750, -1749, -1748, 0,     0,     0,     0,     0,
-		0,     -1544, 0,     1789,  0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     -1554, 0,
-		0,     2767,  2768,  2769,  2770,  0,     -3168, -3167,
-		-3166, -3165, -3164, -3163, 0,     0,     -3158, -375,
-		-9426, -375,  -9425, 1821,  1822,  218,   -9427, 1825,
-		-9426, 1827,  1828,  -1742, -1741, 1878,  1879,  1833,
-		1834,  32767, 32767, 32767, 32767, 2642,  -4765, -1739,
-		-1738, 32767, 1835,  32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 2718,  -3491, 3174,  3174,  3174,
-		-3669, -3669, -3669, -3669, -3669, -5232, -5232, -5232,
-		-3666, -3666, -3666, -3666, -3666, -5232, -5232, 6061,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     -3652, 0,     -3651, 0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     -3590, 0,     -3589,
-		-3589, 0,     0,     0,     0,     32767, 1842,  32767,
-		32767, 32767, 32767, 1843,  32767, 32767, 1844,  32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		0,     32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 1845,  32767,
-		1846,  32767, 32767, 32767, 32767, 32767, 1847,  1848,
-		0,     1849,  1850,  0,     32767, 32767, 0,     0,
-		0,     32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 1851,  32767, 32767, 1852,  32767,
-		32767, 1853,  32767, 1854,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, -4903, 32767, -6162, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 137,
-		1858,  3141,  1860,  3142,  32767, 32767, 1229,  143,
-		32767, 32767, 144,   -2902, 0,     0,     32767, 32767,
-		32767, 32767, 148,   5130,  0,     0,     -4140, 9659,
-		32767, 0,     -4142, 5137,  5138,  0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     32767,
-		0,     5148,  5149,  5150,  5151,  5152,  5153,  4782,
-		3623,  3623,  3623,  3623,  3623,  3623,  3623,  3623,
-		3623,  3623,  3623,  3623,  3623,  3623,  6751,  3623,
-		3623,  3623,  3623,  3623,  3623,  3623,  3623,  3623,
-		3623,  3623,  3623,  3623,  32767, 3622,  3622,  3622,
-		3622,  32767, 3621,  3621,  3621,  0,     3622,  32767,
-		3621,  32767, 32767, 32767, 3618,  3618,  3618,  3618,
-		3618,  3618,  3618,  32767, 2944,  0,     4402,  3618,
-		3618,  3618,  3618,  3618,  3618,  3618,  3618,  3618,
-		3618,  3618,  3618,  3618,  0,     0,     3620,  3620,
-		3620,  3620,  3620,  3620,  -762,  6646,  3621,  3621,
-		3621,  3621,  3621,  3621,  3621,  3621,  3621,  3621,
-		-3222, -3222, 3621,  3621,  3621,  5240,  5241,  5242,
-		0,     0,     3623,  3623,  3623,  0,     3624,  3624,
-		3624,  3624,  3624,  3624,  3624,  3624,  836,   0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     -3647, -3646, 0,     0,
-		461,   0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     468,   0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 0,     0,     32767, 0,     470,   471,   32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 472,   473,   474,   475,   476,   32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 775,   32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 4803,  4804,  7596,  7596,  7596,
-		4808,  4809,  4810,  4811,  4812,  4813,  4814,  4815,
-		4816,  4817,  4818,  4819,  4820,  4821,  4822,  4823,
-		4824,  3988,  3988,  4827,  4828,  7830,  1792,  7832,
-		7833,  7834,  5921,  4835,  7835,  7836,  4838,  0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     3036,  6038,  0,
-		6040,  6041,  6042,  4129,  3043,  6043,  6044,  3046,
-		0,     3048,  3049,  3050,  6046,  6047,  3053,  3054,
-		3055,  3056,  -1230, 3058,  3059,  -1232, -1232, 3062,
-		3063,  3064,  3065,  3066,  3067,  3068,  3069,  3070,
-		3071,  3072,  3073,  3074,  3075,  3076,  3077,  3078,
-		3079,  3080,  3081,  3632,  3083,  3084,  3085,  3086,
-		3087,  3088,  3089,  3090,  3091,  3092,  3093,  3094,
-		3095,  3096,  3097,  3098,  3099,  3100,  3101,  3102,
-		3103,  -814,  3105,  3106,  3107,  3108,  -6867, 3110,
-		3111,  3112,  3113,  9179,  9180,  3116,  3117,  3118,
-		3119,  -22,   3121,  3122,  3123,  3124,  3125,  3126,
-		3127,  3128,  3129,  3130,  2196,  3132,  3133,  2197,
-		3135,  3136,  3137,  3138,  3139,  3140,  3141,  3142,
-		3143,  3144,  -6500, 3146,  3414,  3148,  6452,  3150,
-		-4533, -4533, 3153,  3154,  -2827, -1184, -1184, -1184,
-		-1184, -1184, -6515, -1184, -1184, -6515, -6515, -1184,
-		-1184, -1184, -1184, -1184, -1184, -1184, -1184, -1184,
-		-1184, -1184, -1184, -1184, -1184, -1184, -1184, -1184,
-		-2791, -2790, -2789, -2788, -2787, -2786, -12343,7762,
-		-2783, 0,     -9051, 0,     -9050, -9050, -9050, 595,
-		-9050, -9317, -9050, 2203,  -9049, -1365, -1364, -9049,
-		-9049, -3067, -4709, -4708, -4707, -4706, -4705, 627,
-		-4703, 630,   631,   632,   -3067, -3067, -4694, -3067,
-		-3067, -4689, -4688, -3067, 3131,  -4683, -4682, -4681,
-		-4680, -3067, -4677, 1981,  -4676, -3068, -3068, -3068,
-		-3068, -3068, -3068, 6490,  -13614,-3068, 3202,  3203,
-		3204,  3205,  3206,  3207,  -6437, 3209,  3477,  3211,
-		6515,  3213,  -4470, -4470, 3216,  3217,  -2764, 2009,
-		-2971, 2011,  -3119, -3119, -7259, 6540,  2016,  -3118,
-		-7260, 2019,  2020,  2021,  2022,  -3116, -3116, 3278,
-		3279,  3280,  3281,  3282,  3283,  3284,  3285,  3286,
-		3287,  3288,  3289,  3290,  3291,  32767, 3292,  3293,
-		-869,  -869,  -869,  -869,  9107,  9108,  9109,  9110,
-		9111,  9112,  9113,  3305,  32767, 32767, -863,  32767,
-		-864,  32767, 32767, -866,  -866,  3310,  3311,  -864,
-		-864,  -864,  71,    -864,  -864,  32767, 72,    32767,
-		2290,  32767, 32767, 3320,  3321,  32767, 32767, 32767,
-		3322,  -1192, -1192, -1192, -1192, -1192, -1192, -1192,
-		-1192, -1192, -1192, -1192, -1192, -1192, -1192, -1192,
-		-1192, -1192, -1192, -1192, -1192, -1192, -1192, -1192,
-		-1192, -1192, -1192, -1192, -1192, -1192, -1192, -1192,
-		-1192, -1192, -1192, -1192, -1192, -1192, -1192, -1192,
-		-1192, -1192, -1192, 3365,  3366,  3367,  -1189, -1189,
-		-1189, -1189, -1189, -1189, 3374,  3375,  -1187, -1187,
-		-1187, -1187, -1187, -1187, 3382,  3383,  -1185, -1185,
-		-1185, -1185, -1185, -1185, 32767, 32767, -1185, -1185,
-		-1185, 3393,  3394,  3395,  -1182, 3397,  3398,  3399,
-		3400,  3401,  3402,  1274,  1274,  3405,  -5404, 3407,
-		3408,  3409,  3410,  1274,  1274,  1274,  1274,  1274,
-		1274,  1274,  1274,  1274,  1274,  1274,  1274,  1274,
-		1274,  1274,  1274,  1274,  1274,  1274,  1274,  1274,
-		3432,  3433,  3434,  3435,  3436,  3437,  3438,  3439,
-		3440,  3441,  3442,  3443,  3444,  3445,  3446,  3447,
-		3448,  3449,  3450,  3451,  3452,  3453,  3454,  3455,
-		-1138, -1138, -1138, -1138, -1138, 3461,  3462,  3299,
-		3464,  3465,  3466,  3467,  3468,  3469,  3470,  3471,
-		3472,  3473,  3474,  3475,  3476,  3477,  3478,  3479,
-		3480,  3481,  3482,  3483,  3484,  3485,  3486,  3487,
-		3488,  3489,  3490,  3491,  3492,  3493,  3494,  3495,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 3496,
-		3497,  3498,  3499,  3500,  3501,  3502,  32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 3503,  3211,  3211,  3211,  3211,  32767,
-		32767, 32767, 32767, 32767, 7590,  7590,  7590,  3208,
-		3512,  3513,  3514,  3515,  3516,  3517,  3518,  3519,
-		3520,  3521,  3522,  3523,  3524,  3525,  3526,  3527,
-		3528,  3529,  3530,  3531,  3532,  3533,  32767, 3534,
-		3535,  3536,  3537,  3538,  32767, 3539,  32767, 3540,
-		3541,  32767, 3542,  3543,  32767, 3544,  3545,  3546,
-		3547,  3548,  3549,  3550,  3551,  3552,  3553,  3554,
-		3555,  3556,  3557,  3558,  3559,  3560,  3561,  3562,
-		3563,  3564,  3565,  3566,  3567,  3568,  3569,  3570,
-		3571,  3572,  3573,  3574,  3575,  3576,  3577,  3578,
-		3579,  3580,  3581,  3582,  3583,  3584,  3585,  3586,
-		3587,  3588,  3589,  3590,  3591,  3592,  3593,  3594,
-		3595,  3596,  3597,  3598,  3599,  3600,  3601,  3602,
-		3603,  3604,  3605,  3606,  3607,  3608,  3609,  3610,
-		3611,  3612,  3613,  3614,  3615,  3616,  3617,  3618,
-		3619,  3620,  3621,  3622,  3623,  3624,  3625,  3626,
-		3627,  3628,  3629,  3630,  3631,  3632,  3633,  3634,
-		3635,  3636,  3637,  3638,  3639,  3640,  3641,  3642,
-		3643,  3644,  3645,  3646,  3647,  3648,  3649,  3650,
-		3651,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 3652,  3653,  3654,  3655,  3656,  3657,
-		3658,  3659,  3660,  3661,  3662,  3663,  3664,  3665,
-		3666,  3667,  3668,  3669,  3670,  3671,  3672,  3673,
-		3674,  3675,  3676,  3677,  3678,  3679,  3680,  3681,
-		3682,  3683,  3684,  3685,  3686,  3687,  3688,  3689,
-		3690,  3691,  3692,  3693,  3694,  3695,  3696,  32767,
-		3244,  3698,  3699,  3700,  3701,  3702,  4131,  3704,
-		3251,  3251,  3707,  3252,  3709,  3710,  3711,  3255,
-		3713,  3714,  3715,  3716,  3259,  3259,  3259,  3720,
-		3721,  3722,  3723,  3724,  3725,  3726,  3727,  3728,
-		3729,  3730,  3731,  3732,  0,     0,     3735,  3736,
-		3737,  3738,  3739,  3740,  3741,  3742,  3743,  3744,
-		3745,  3746,  3747,  3748,  3749,  3750,  3751,  3752,
-		3753,  3754,  3755,  3756,  3757,  3758,  3759,  3760,
-		3761,  3300,  3763,  3764,  3765,  3766,  3767,  3768,
-		3769,  3770,  3771,  3772,  3773,  3774,  3775,  3776,
-		3777,  3778,  3779,  3780,  3781,  3782,  3783,  3784,
-		3322,  3322,  3787,  3323,  3789,  3790,  3791,  3326,
-		3793,  3794,  3795,  3796,  3330,  3798,  3330,  3800,
-		3801,  3802,  3803,  3804,  3805,  3806,  3807,  3808,
-		3809,  3810,  3811,  3812,  3813,  3814,  3815,  3816,
-		3817,  3818,  3819,  3820,  3821,  3822,  3823,  3824,
-		3825,  -1667, 3827,  3828,  3829,  3830,  3831,  3832,
-		3833,  3834,  3835,  3836,  3837,  3838,  3839,  3840,
-		3841,  3842,  3843,  3844,  -1685, 3846,  3847,  3848,
-		3849,  3850,  3851,  3852,  3853,  3854,  3855,  3856,
-		3857,  3858,  3859,  3860,  3861,  3862,  3863,  3864,
-		3865,  3866,  3867,  3868,  3869,  3870,  3871,  3872,
-		3873,  3874,  3875,  3876,  3877,  3878,  3879,  3880,
-		3881,  3882,  3883,  3884,  3885,  3886,  3887,  3888,
-		3889,  3890,  3891,  3892,  3893,  3894,  3895,  3896,
-		3897,  8237,  8238,  3900,  3901,  3902,  3903,  3904,
-		3905,  3906,  3907,  3908,  3909,  3910,  3911,  3912,
-		11266, 11267, 11268, 9355,  3917,  3918,  11272, 8274,
-		3921,  3922,  3438,  3438,  3438,  3438,  3438,  3438,
-		3929,  3930,  3440,  3440,  3440,  3440,  6476,  9478,
-		3937,  3938,  9483,  9484,  7571,  6485,  9485,  9486,
-		6488,  3442,  6490,  6491,  6492,  9488,  3951,  3952,
-		32767, -866,  -866,  -866,  -866,  -866,  -866,  -29,
-		-28,   -866,  -866,  -3867, 2172,  -3867, -3867, -3867,
-		-1953, -866,  -3865, -3865, -866,  3973,  3974,  3975,
-		3976,  3977,  3978,  3979,  3980,  3981,  3982,  3983,
-		3984,  3985,  3986,  951,   -2050, 3989,  -2050, -2050,
-		-2050, -136,  951,   -2048, -2048, 951,   3998,  951,
-		951,   951,   -2044, -2044, 951,   951,   951,   951,
-		5238,  951,   951,   5243,  5244,  951,   951,   32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 383,   933,   933,   933,   933,   933,   933,
-		933,   933,   933,   933,   933,   933,   933,   933,
-		933,   933,   933,   933,   933,   933,   933,   4851,
-		933,   933,   933,   933,   10909, 933,   933,   933,
-		933,   -5132, -5132, 933,   933,   933,   933,   4075,
-		933,   933,   933,   933,   933,   933,   933,   933,
-		933,   933,   1868,  933,   933,   1870,  933,   933,
-		933,   933,   933,   933,   933,   933,   933,   933,
-		10578, 0,     32767, 931,   -2372, 931,   8615,  8616,
-		931,   931,   6913,  5271,  5272,  5273,  5274,  5275,
-		10607, 5277,  5278,  10610, 10611, 5281,  5282,  5283,
-		5284,  5285,  5286,  5287,  5288,  5289,  5290,  5291,
-		5292,  5293,  5294,  5295,  5296,  5297,  6905,  6905,
-		6905,  6905,  6905,  6905,  16463, -3641, 6905,  4123,
-		13175, 4125,  13176, 13177, 13178, 3534,  13180, 13448,
-		13182, 32767, 32767, 32767, 0,     32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 0,     0,     32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, -2357, 17748, 7203,  934,   934,   934,   934,
-		934,   934,   10579, 934,   667,   934,   32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 4146,  4147,  4148,  4149,  4150,  4151,
-		4152,  4153,  4154,  4155,  32767, 32767, 32767, 32767,
-		32767, 32767, 4156,  4157,  4158,  4159,  4160,  4161,
-		4162,  4163,  4164,  4165,  4166,  4167,  4168,  4169,
-		4170,  4171,  4172,  4173,  4174,  4175,  4176,  4177,
-		4178,  4179,  4180,  4181,  4182,  5374,  5375,  5376,
-		6978,  4187,  4188,  4189,  4190,  6982,  6982,  32767,
-		32767, 4193,  4194,  4195,  4196,  4197,  4198,  4199,
-		4200,  4201,  4202,  4203,  4204,  32767, 6995,  6995,
-		4207,  4208,  4209,  4210,  4211,  4212,  4213,  4214,
-		4215,  4216,  4217,  4218,  4219,  4220,  4221,  4222,
-		4223,  32767, 3386,  4225,  4226,  7228,  32767, 32767,
-		32767, 32767, 5315,  4229,  7229,  32767, 4231,  32767,
-		4232,  4233,  4234,  7230,  7231,  4237,  4238,  4239,
-		4240,  -46,   4242,  4243,  -48,   -48,   4246,  4247,
-		4248,  4249,  4250,  4251,  4252,  4253,  4254,  4255,
-		4256,  4257,  4258,  4259,  4260,  4261,  4262,  4263,
-		4264,  4265,  4816,  4267,  4268,  4269,  4270,  4271,
-		4272,  4273,  4274,  4275,  4276,  4277,  4278,  4279,
-		4280,  4281,  4282,  4283,  4284,  4285,  4286,  4287,
-		370,   4289,  4290,  4291,  4292,  -5683, 4294,  4295,
-		4296,  4297,  10363, 10364, 4300,  4301,  4302,  4303,
-		1162,  4305,  4306,  4307,  4308,  4309,  4310,  4311,
-		4312,  4313,  4314,  3380,  4316,  4317,  3381,  4319,
-		4320,  4321,  4322,  4323,  4324,  4325,  4326,  4327,
-		4328,  -5316, 4330,  4598,  4332,  7636,  4334,  -3349,
-		-3349, 4337,  4338,  -1643, 0,     0,     0,     0,
-		0,     -5331, 0,     0,     -5331, -5331, 0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     4126,
-		4127,  4128,  4129,  0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     -1258, 0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		-1272, -1272, 0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     -1851, -1851, -1851, -1851,
-		-1851, 0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     3235,  0,     -6925, 306,
-		306,   306,   306,   306,   306,   306,   306,   306,
-		306,   306,   306,   -1764, -1764, 4472,  4473,  311,
-		311,   311,   311,   10287, 10288, 10289, 10290, 10291,
-		10292, 10293, 4485,  10198, 319,   319,   3461,  319,
-		319,   319,   319,   319,   4495,  4496,  321,   321,
-		321,   1256,  321,   321,   1258,  1258,  0,     3477,
-		10215, 10216, 4509,  4510,  10219, 10220, 10221, 4514,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     4579,  4580,  4581,  4582,
-		4583,  4584,  32767, 2455,  4586,  -4223, 4588,  4589,
-		4590,  4591,  32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 4885,  4886,  4887,
-		4888,  4889,  4890,  4891,  4892,  4893,  4894,  4895,
-		4896,  4897,  4898,  4899,  4900,  4901,  4902,  4903,
-		4904,  4616,  4906,  4907,  4908,  4909,  4910,  4911,
-		4912,  4913,  4914,  4915,  4916,  4917,  4918,  4919,
-		4920,  4921,  4922,  4923,  4924,  4925,  4926,  4927,
-		4928,  4929,  4930,  4931,  4932,  4933,  4934,  4935,
-		4936,  4937,  4938,  4939,  4940,  4941,  4942,  4943,
-		4944,  4945,  4946,  4947,  4948,  567,   568,   569,
-		4952,  -2455, 571,   572,   4956,  4957,  4958,  4959,
-		4960,  4961,  4962,  4963,  4964,  4965,  4966,  4967,
-		4968,  4969,  32767, 4970,  4971,  4972,  4973,  4974,
-		4975,  4976,  4977,  4978,  4979,  4980,  6623,  6623,
-		6623,  6623,  6623,  1292,  6623,  1291,  1291,  1291,
-		4991,  4992,  6620,  4994,  4995,  6618,  6618,  4998,
-		-1199, 6616,  6616,  6616,  6616,  5004,  6615,  6615,
-		6615,  5008,  5009,  5010,  5011,  5012,  5013,  -4544,
-		15561, 5016,  -1253, -1253, -1253, -1253, -1253, -1253,
-		8392,  -1253, -1520, -1253, -4556, -1253, 6431,  6432,
-		-1253, -1253, 4729,  3087,  3088,  3089,  3090,  3091,
-		8423,  3093,  3094,  8426,  8427,  3097,  3098,  3099,
-		3100,  3101,  3102,  3103,  3104,  3105,  3106,  3107,
-		3108,  3109,  3110,  3111,  3112,  3113,  4721,  4721,
-		4721,  4721,  4721,  4721,  14279, -5825, 4721,  1939,
-		10991, 1941,  10992, 10993, 10994, 1350,  10996, 11264,
-		10998, -254,  10999, 3316,  3316,  11002, 11003, 5022,
-		6665,  6665,  6665,  6665,  6665,  1334,  6665,  1333,
-		1333,  1333,  5033,  5034,  6662,  5036,  5037,  6660,
-		6660,  5040,  -1157, 6658,  6658,  6658,  6658,  5046,
-		6657,  0,     6658,  5051,  5052,  5053,  5054,  5055,
-		5056,  -4501, 15604, 5059,  -1210, -1210, -1210, -1210,
-		-1210, -1210, 8435,  -1210, -1477, -1210, -4513, -1210,
-		6474,  6475,  -1210, -1210, 4772,  0,     4981,  0,
-		5131,  5132,  9273,  -4525, 0,     5135,  9278,  0,
-		0,     0,     0,     5139,  5140,  5141,  5142,  5143,
-		5144,  5145,  5146,  0,     5147,  0,     0,     0,
-		0,     0,     0,     1530,  1531,  1532,  1533,  1534,
-		1535,  1536,  1537,  1538,  1539,  1540,  1541,  1542,
-		1543,  1544,  -1583, 1546,  1547,  1548,  1549,  1550,
-		1551,  1552,  1553,  1554,  1555,  1556,  1557,  1558,
-		1559,  1560,  1561,  1562,  1563,  1564,  1565,  1566,
-		1567,  5189,  1568,  1569,  1570,  1571,  1572,  1573,
-		1574,  1575,  1576,  1577,  1578,  1579,  1580,  0,
-		2255,  5200,  799,   1584,  1585,  1586,  1587,  1588,
-		1589,  1590,  1591,  1592,  1593,  1594,  1595,  1596,
-		5215,  5216,  1597,  1598,  1599,  1600,  1601,  1602,
-		5985,  -1422, 1604,  1605,  1606,  1607,  1608,  1609,
-		1610,  1611,  1612,  1613,  8457,  8458,  1616,  1617,
-		1618,  0,     0,     0,     5243,  5244,  1622,  1623,
-		1624,  5248,  1625,  1626,  1627,  1628,  1629,  1630,
-		1631,  1632,  4421,  5258,  5259,  5260,  5261,  5262,
-		5263,  5264,  5265,  5266,  5267,  5268,  5269,  5270,
-		5271,  5272,  5273,  5274,  5275,  5276,  5277,  5278,
-		5279,  5280,  5281,  5282,  5283,  5284,  5285,  5286,
-		8934,  8934,  5289,  5290,  4830,  5292,  5293,  5294,
-		5295,  5296,  5297,  5298,  5299,  5300,  5301,  5302,
-		5303,  5304,  5305,  5306,  5307,  5308,  5309,  5310,
-		5311,  5312,  5313,  5314,  5315,  5316,  5317,  5318,
-		5319,  5320,  5321,  5322,  5323,  5324,  5325,  5326,
-		5327,  5328,  5329,  5330,  5331,  5332,  5333,  5334,
-		5335,  5336,  5337,  5338,  5339,  5340,  5341,  5342,
-		5343,  5344,  5345,  5346,  5347,  5348,  5349,  5350,
-		5351,  5352,  5353,  5354,  5355,  5356,  5357,  5358,
-		4891,  5360,  5361,  5362,  5363,  5364,  5365,  5366,
-		5367,  5368,  5369,  5370,  5371,  5372,  32767, 5373,
-		5374,  -5231, 5376,  4532,  0,     5379,  5380,  5381,
-		5382,  4270,  4271,  4272,  4273,  4274,  4275,  4276,
-		4277,  4278,  12230, 9102,  9102,  9102,  5396,  8890,
-		5398,  5399,  5400,  5401,  8899,  7356,  5568,  7358,
-		7359,  0,     0,     7364,  7365,  7366,  7367,  7368,
-		7369,  8924,  7371,  7372,  4606,  4606,  4606,  4606,
-		7377,  10546, 10546, 10546, 10546, 10546, 10546, 20104,
-		0,     10546, 7764,  16816, 7766,  16817, 5572,  5572,
-		7177,  16823, 17091, 16825, 5573,  5573,  9144,  9144,
-		5526,  0,     5574,  5574,  5450,  5451,  5452,  697,
-		697,   5455,  0,     7172,  5458,  5576,  5460,  -5456,
-		5462,  5463,  5464,  0,     0,     4691,  5468,  5469,
-		4693,  5471,  10898, 0,     0,     5475,  4698,  10908,
-		5478,  5479,  5480,  5481,  1359,  1359,  1359,  5485,
-		5486,  5487,  5488,  1359,  1359,  1359,  1359,  1359,
-		1359,  1359,  1359,  1359,  1359,  1359,  1359,  1359,
-		1359,  101,   1359,  1359,  1359,  1359,  1359,  1359,
-		1359,  1359,  1359,  1359,  1359,  1359,  1359,  1359,
-		87,    87,    1359,  1359,  1359,  1359,  1359,  1359,
-		1359,  1359,  1359,  1359,  1359,  1359,  1359,  1359,
-		1359,  1359,  1359,  1359,  1359,  1359,  1359,  1359,
-		1359,  1359,  1359,  1359,  1359,  1359,  1359,  1359,
-		1359,  1359,  1359,  1359,  -492,  -492,  -492,  -492,
-		-492,  1359,  1359,  1359,  1359,  1359,  1359,  1359,
-		1359,  1359,  1359,  1359,  4594,  1359,  -5566, 1665,
-		1665,  1665,  1665,  1665,  1665,  1665,  1665,  1665,
-		1665,  1665,  1665,  -405,  -405,  5585,  5586,  1668,
-		1668,  1668,  1668,  11644, 11645, 11646, 11647, 11648,
-		11649, 11650, 5842,  11555, 1676,  1676,  4818,  1676,
-		1676,  1676,  1676,  1676,  5852,  5853,  1678,  1678,
-		1678,  2613,  1678,  1678,  2615,  2615,  1357,  4834,
-		11572, 11573, 5866,  5867,  11576, 11577, 11578, 5871,
-		1357,  1357,  1357,  1357,  1357,  1357,  1357,  1357,
-		1357,  -6594, -3465, -3464, -3463, 244,   -3249, 244,
-		244,   244,   244,   -3253, -1709, 80,    -1709, -1709,
-		5651,  5652,  -1711, -1711, -1711, -1711, -1711, -1711,
-		-3265, -1711, -1711, 1056,  1057,  1058,  1059,  -1711,
-		-4879, -4878, -4877, -4876, -4875, -4874, -14431,5674,
-		-4871, -2088, -11139,-2088, -11138,108,   109,   -1495,
-		-11140,-11407,-11140,113,   114,   -3456, -3455, 164,
-		5691,  118,   119,   244,   244,   244,   5000,  5001,
-		244,   5700,  -1471, 244,   127,   244,   11161, 244,
-		244,   244,   5709,  5710,  1020,  244,   244,   1021,
-		244,   -5182, 5717,  5718,  244,   1022,  -5187, 244,
-		244,   244,   244,   4367,  4368,  4369,  244,   244,
-		244,   244,   4374,  4375,  4376,  4377,  4378,  4379,
-		4380,  4381,  4382,  4383,  4384,  4385,  4386,  4387,
-		5646,  4389,  4390,  4391,  4392,  4393,  4394,  4395,
-		4396,  4397,  4398,  4399,  4400,  4401,  4402,  5675,
-		5676,  4405,  4406,  4407,  4408,  4409,  4410,  4411,
-		4412,  4413,  4414,  4415,  4416,  4417,  4418,  4419,
-		4420,  4421,  4422,  4423,  4424,  4425,  4426,  4427,
-		4428,  4429,  4430,  4431,  4432,  4433,  4434,  4435,
-		4436,  4437,  4438,  6290,  6291,  6292,  6293,  6294,
-		4444,  4445,  4446,  4447,  4448,  4449,  4450,  4451,
-		4452,  4453,  4454,  1220,  4456,  11382, 4152,  4153,
-		4154,  4155,  4156,  4157,  4158,  4159,  4160,  4161,
-		4162,  4163,  6234,  6235,  0,     0,     4163,  4164,
-		4165,  4166,  -5809, -5809, -5809, -5809, -5809, -5809,
-		-5809, 0,     -5712, 4168,  4169,  1028,  4171,  4172,
-		4173,  4174,  4175,  0,     0,     4176,  4177,  4178,
-		3244,  4180,  4181,  3245,  3246,  4505,  1029,  -5708,
-		-5708, 0,     0,     -5708, -5708, -5708, 0,     4515,
-		4516,  4517,  4518,  4519,  4520,  4521,  4522,  4523,
-		4524,  4525,  4526,  4527,  4528,  4529,  4530,  4531,
-		4532,  4533,  4534,  4535,  4536,  4537,  4538,  4539,
-		4540,  4541,  4542,  4543,  4544,  4545,  4546,  4547,
-		4548,  4549,  4550,  4551,  4552,  4553,  4554,  4555,
-		4556,  0,     0,     0,     4557,  4558,  4559,  4560,
-		4561,  4562,  0,     0,     4563,  4564,  4565,  4566,
-		4567,  4568,  0,     0,     4569,  4570,  4571,  4572,
-		4573,  4574,  2114,  2115,  4575,  4576,  4577,  0,
-		0,     0,     4578,  0,     0,     0,     0,     0,
-		0,     2129,  2130,  0,     8810,  0,     0,     0,
-		0,     2137,  2138,  2139,  2140,  2141,  2142,  2143,
-		2144,  2145,  2146,  2147,  2148,  2149,  2150,  2151,
-		2152,  2153,  2154,  2155,  2156,  2157,  0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     4594,  4595,
-		4596,  4597,  4598,  0,     0,     164,   0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     0,     0,
-		0,     0,     0,     0,     0,     0,     2222,  2223,
-		2224,  2225,  2226,  2227,  2228,  2229,  2230,  2231,
-		2232,  2233,  2234,  2235,  2236,  2237,  2238,  2239,
-		2240,  2241,  2242,  2243,  2244,  2245,  2246,  2247,
-		2248,  2249,  2250,  2251,  2252,  2253,  2254,  2255,
-		2256,  2257,  2258,  2259,  2260,  2261,  2262,  2263,
-		2264,  2265,  2266,  2267,  2268,  2269,  2270,  705,
-		706,   707,   708,   709,   2276,  2277,  2278,  2279,
-		2280,  2281,  2282,  2283,  2284,  32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		2285,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 2286,  2287,  2288,  2289,  2290,  2291,
-		32767, 32767, 32767, 32767, 32767, 32767, 2292,  32767,
-		2293,  2294,  2295,  32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 2296,  32767, 2297,  32767,
-		2298,  32767, 2299,  32767, 2300,  32767, 2301,  32767,
-		2302,  32767, 2303,  32767, 2304,  32767, 2305,  32767,
-		2306,  32767, 2307,  32767, 32767, 2308,  32767, 2309,
-		32767, 2310,  32767, 32767, 32767, 32767, 32767, 32767,
-		2311,  2312,  32767, 2313,  2314,  32767, 2315,  2316,
-		32767, 2317,  2318,  32767, 2319,  2320,  32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 2321,  32767, 32767, 32767,
-		32767, 2322,  2323,  2324,  2325,  32767, 2326,  2327,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 2328,  32767, 2329,  32767,
-		2330,  32767, 2331,  32767, 2332,  32767, 2333,  32767,
-		2334,  32767, 2335,  32767, 2336,  32767, 2337,  32767,
-		2338,  32767, 2339,  32767, 32767, 2340,  32767, 2341,
-		32767, 2342,  32767, 32767, 32767, 32767, 32767, 32767,
-		2343,  2344,  32767, 2345,  2346,  32767, 2347,  2348,
-		32767, 2349,  2350,  32767, 2351,  2352,  32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 2353,  32767, 32767, 2354,
-		2355,  2356,  2357,  32767, 32767, 32767, 2358,  2359,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 2360,  2361,  2362,  2363,  2364,  2365,
-		2366,  2367,  2368,  2369,  2370,  2371,  2372,  2373,
-		2374,  -753,  2376,  2377,  2378,  2379,  2380,  2381,
-		2382,  2383,  2384,  2385,  2386,  2387,  2388,  2389,
-		2390,  2391,  2392,  2393,  2394,  2395,  2396,  2397,
-		2398,  2399,  2400,  2401,  2402,  2403,  2404,  2405,
-		2406,  2407,  2408,  2409,  2410,  2411,  831,   3086,
-		2414,  1631,  2416,  2417,  2418,  2419,  2420,  2421,
-		2422,  2423,  2424,  2425,  2426,  2427,  2428,  2429,
-		2430,  2431,  2432,  2433,  2434,  2435,  2436,  2437,
-		-587,  2439,  2440,  2441,  2442,  2443,  2444,  2445,
-		2446,  2447,  2448,  9292,  9293,  2451,  2452,  2453,
-		32767, 32767, 32767, 2454,  2455,  2456,  2457,  2458,
-		2459,  2460,  2461,  2462,  2463,  2464,  2465,  2466,
-		2467,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 4599,  32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 4600,  32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 2468,  -1450, 2470,  2471,  2472,  2473,
-		2474,  2475,  2476,  2477,  2478,  2479,  2480,  2481,
-		2482,  2483,  2484,  2485,  2486,  2487,  2488,  2489,
-		2490,  2491,  2492,  2493,  2494,  2495,  2496,  2497,
-		2498,  32767, 2499,  2500,  2501,  2502,  2503,  2504,
-		2505,  2506,  2507,  2508,  2509,  2510,  2511,  2512,
-		2513,  2514,  2515,  2516,  2517,  2518,  2519,  2520,
-		2521,  2522,  2523,  2524,  2525,  2526,  2527,  2528,
-		2529,  2530,  2531,  2532,  2533,  2534,  2535,  2536,
-		2537,  2538,  32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 2539,  2540,  5896,  2542,  2543,  2544,
-		2545,  548,   2547,  2548,  2549,  2550,  2551,  2552,
-		5919,  5920,  5921,  2556,  2557,  5926,  2559,  2560,
-		2561,  2562,  2563,  2564,  2565,  2566,  2567,  2568,
-		2569,  2570,  2571,  2572,  2573,  2574,  2575,  2576,
-		2577,  2578,  2579,  2580,  2581,  2582,  2583,  2584,
-		2585,  32767, 2586,  2587,  2588,  2589,  2590,  2591,
-		2592,  2593,  2594,  2595,  2596,  2597,  2598,  2599,
-		2600,  2601,  2602,  2603,  2604,  2605,  2606,  2607,
-		2608,  2609,  2610,  2611,  2612,  2613,  2614,  2615,
-		2616,  2617,  2618,  2619,  2620,  2621,  2622,  2623,
-		2624,  2625,  2626,  2627,  2628,  2629,  2630,  2631,
-		2632,  2633,  2634,  2635,  2636,  2637,  2638,  2639,
-		2640,  2641,  2642,  2643,  2644,  2645,  2646,  2647,
-		2648,  2649,  2650,  2651,  2652,  2653,  2654,  2655,
-		2656,  2657,  2658,  2659,  2660,  2661,  -703,  2663,
-		2664,  2665,  2666,  2667,  2668,  2669,  2670,  2671,
-		2672,  2673,  2674,  1999,  2676,  2677,  2678,  2679,
-		2680,  2681,  2682,  2683,  2684,  2685,  2686,  2687,
-		2688,  2689,  2690,  2014,  2692,  2693,  2694,  2695,
-		2696,  2697,  2698,  2699,  2700,  2701,  2702,  2703,
-		2704,  2705,  2706,  2707,  2708,  2709,  -11089,2711,
-		2712,  2713,  32767, 2714,  2715,  2716,  2717,  2718,
-		8050,  2720,  2721,  8053,  8054,  2724,  2725,  2726,
-		2727,  2728,  2729,  2730,  2731,  2732,  2733,  2734,
-		2735,  2736,  2737,  2738,  2739,  2740,  2741,  2742,
-		2743,  2744,  2745,  2746,  2747,  2748,  -1377, -1377,
-		-1377, -1377, 2753,  2754,  2755,  2756,  2757,  2758,
-		2759,  2760,  2761,  2762,  2763,  2764,  2765,  2766,
-		4025,  2768,  2769,  2770,  2771,  2772,  2773,  2774,
-		2775,  2776,  2777,  2778,  2779,  2780,  2781,  4054,
-		4055,  2784,  2785,  2786,  2787,  2788,  2789,  2790,
-		2791,  2792,  2793,  2794,  2795,  2796,  2797,  2798,
-		2799,  2800,  2801,  2802,  2803,  2804,  2805,  2806,
-		2807,  2808,  2809,  2810,  2811,  2812,  2813,  2814,
-		2815,  2816,  2817,  4669,  4670,  4671,  4672,  4673,
-		2823,  2824,  2825,  2826,  2827,  2828,  2829,  2830,
-		2831,  2832,  2833,  -401,  2835,  9761,  2531,  2532,
-		2533,  2534,  2535,  2536,  2537,  2538,  2539,  2540,
-		2541,  2542,  4613,  4614,  -1621, -1621, 2542,  2543,
-		2544,  2545,  -7430, -7430, -7430, -7430, -7430, -7430,
-		-7430, -1621, -7333, 2547,  2548,  -593,  2550,  2551,
-		2552,  2553,  2554,  -1621, -1621, 2555,  2556,  2557,
-		1623,  2559,  2560,  1624,  1625,  2884,  -592,  -7329,
-		-7329, -1621, -1621, -7329, -7329, -7329, -1621, 2894,
-		2895,  2896,  2897,  2898,  2899,  2900,  2901,  2902,
-		2903,  2904,  2905,  2906,  2907,  2908,  2909,  2910,
-		2911,  2912,  2913,  2914,  2915,  2916,  2917,  2918,
-		2919,  2920,  2921,  2922,  2923,  2924,  2925,  2926,
-		2927,  2928,  2929,  2930,  2931,  2932,  2933,  2934,
-		2935,  2936,  2937,  2938,  2939,  2940,  2941,  2942,
-		2943,  2944,  2945,  2946,  2947,  2948,  2949,  2950,
-		2951,  2952,  2953,  2954,  2955,  2956,  2957,  2958,
-		2959,  2960,  2961,  2962,  2963,  2964,  2965,  2966,
-		2967,  2968,  2969,  32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 0,     0,     0,     0,
-		0,     32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 0,     32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 0,
-		0,     0,     0,     0,     0,     32767, 32767, 32767,
-		32767, 32767, 32767, 0,     32767, 0,     0,     0,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 0,     32767, 0,     32767, 0,     32767, 0,
-		32767, 0,     32767, 0,     32767, 0,     32767, 0,
-		32767, 0,     32767, 0,     32767, 0,     32767, 0,
-		32767, 32767, 0,     32767, 0,     32767, 0,     32767,
-		32767, 32767, 32767, 32767, 32767, 0,     0,     32767,
-		0,     0,     32767, 0,     0,     32767, 0,     0,
-		32767, 0,     0,     32767, 32767, 32767, 32767
-	};
-
-	const unsigned char *k = (const unsigned char *) key;
-	size_t		keylen = 4;
-	uint32		a = 0;
-	uint32		b = 1;
-
-	while (keylen--)
-	{
-		unsigned char c = *k++;
-
-		a = a * 257 + c;
-		b = b * 8191 + c;
-	}
-	return h[a % 13687] + h[b % 13687];
-}
-
-/* Hash lookup information for decomposition */
-static const pg_unicode_decompinfo UnicodeDecompInfo =
-{
-	UnicodeDecompMain,
-	Decomp_hash_func,
-	6843
-};
-
-/* Inverse lookup array -- contains indexes into UnicodeDecompMain[] */
-static const uint16 RecompInverseLookup[961] =
-{
-	/* U+003C+0338 -> U+226E */ 1858,
-	/* U+003D+0338 -> U+2260 */ 1855,
-	/* U+003E+0338 -> U+226F */ 1859,
-	/* U+0041+0300 -> U+00C0 */ 14,
-	/* U+0041+0301 -> U+00C1 */ 15,
-	/* U+0041+0302 -> U+00C2 */ 16,
-	/* U+0041+0303 -> U+00C3 */ 17,
-	/* U+0041+0304 -> U+0100 */ 67,
-	/* U+0041+0306 -> U+0102 */ 69,
-	/* U+0041+0307 -> U+0226 */ 270,
-	/* U+0041+0308 -> U+00C4 */ 18,
-	/* U+0041+0309 -> U+1EA2 */ 1313,
-	/* U+0041+030A -> U+00C5 */ 19,
-	/* U+0041+030C -> U+01CD */ 194,
-	/* U+0041+030F -> U+0200 */ 240,
-	/* U+0041+0311 -> U+0202 */ 242,
-	/* U+0041+0323 -> U+1EA0 */ 1311,
-	/* U+0041+0325 -> U+1E00 */ 1155,
-	/* U+0041+0328 -> U+0104 */ 71,
-	/* U+0042+0307 -> U+1E02 */ 1157,
-	/* U+0042+0323 -> U+1E04 */ 1159,
-	/* U+0042+0331 -> U+1E06 */ 1161,
-	/* U+0043+0301 -> U+0106 */ 73,
-	/* U+0043+0302 -> U+0108 */ 75,
-	/* U+0043+0307 -> U+010A */ 77,
-	/* U+0043+030C -> U+010C */ 79,
-	/* U+0043+0327 -> U+00C7 */ 20,
-	/* U+0044+0307 -> U+1E0A */ 1165,
-	/* U+0044+030C -> U+010E */ 81,
-	/* U+0044+0323 -> U+1E0C */ 1167,
-	/* U+0044+0327 -> U+1E10 */ 1171,
-	/* U+0044+032D -> U+1E12 */ 1173,
-	/* U+0044+0331 -> U+1E0E */ 1169,
-	/* U+0045+0300 -> U+00C8 */ 21,
-	/* U+0045+0301 -> U+00C9 */ 22,
-	/* U+0045+0302 -> U+00CA */ 23,
-	/* U+0045+0303 -> U+1EBC */ 1339,
-	/* U+0045+0304 -> U+0112 */ 83,
-	/* U+0045+0306 -> U+0114 */ 85,
-	/* U+0045+0307 -> U+0116 */ 87,
-	/* U+0045+0308 -> U+00CB */ 24,
-	/* U+0045+0309 -> U+1EBA */ 1337,
-	/* U+0045+030C -> U+011A */ 91,
-	/* U+0045+030F -> U+0204 */ 244,
-	/* U+0045+0311 -> U+0206 */ 246,
-	/* U+0045+0323 -> U+1EB8 */ 1335,
-	/* U+0045+0327 -> U+0228 */ 272,
-	/* U+0045+0328 -> U+0118 */ 89,
-	/* U+0045+032D -> U+1E18 */ 1179,
-	/* U+0045+0330 -> U+1E1A */ 1181,
-	/* U+0046+0307 -> U+1E1E */ 1185,
-	/* U+0047+0301 -> U+01F4 */ 230,
-	/* U+0047+0302 -> U+011C */ 93,
-	/* U+0047+0304 -> U+1E20 */ 1187,
-	/* U+0047+0306 -> U+011E */ 95,
-	/* U+0047+0307 -> U+0120 */ 97,
-	/* U+0047+030C -> U+01E6 */ 216,
-	/* U+0047+0327 -> U+0122 */ 99,
-	/* U+0048+0302 -> U+0124 */ 101,
-	/* U+0048+0307 -> U+1E22 */ 1189,
-	/* U+0048+0308 -> U+1E26 */ 1193,
-	/* U+0048+030C -> U+021E */ 268,
-	/* U+0048+0323 -> U+1E24 */ 1191,
-	/* U+0048+0327 -> U+1E28 */ 1195,
-	/* U+0048+032E -> U+1E2A */ 1197,
-	/* U+0049+0300 -> U+00CC */ 25,
-	/* U+0049+0301 -> U+00CD */ 26,
-	/* U+0049+0302 -> U+00CE */ 27,
-	/* U+0049+0303 -> U+0128 */ 103,
-	/* U+0049+0304 -> U+012A */ 105,
-	/* U+0049+0306 -> U+012C */ 107,
-	/* U+0049+0307 -> U+0130 */ 111,
-	/* U+0049+0308 -> U+00CF */ 28,
-	/* U+0049+0309 -> U+1EC8 */ 1351,
-	/* U+0049+030C -> U+01CF */ 196,
-	/* U+0049+030F -> U+0208 */ 248,
-	/* U+0049+0311 -> U+020A */ 250,
-	/* U+0049+0323 -> U+1ECA */ 1353,
-	/* U+0049+0328 -> U+012E */ 109,
-	/* U+0049+0330 -> U+1E2C */ 1199,
-	/* U+004A+0302 -> U+0134 */ 114,
-	/* U+004B+0301 -> U+1E30 */ 1203,
-	/* U+004B+030C -> U+01E8 */ 218,
-	/* U+004B+0323 -> U+1E32 */ 1205,
-	/* U+004B+0327 -> U+0136 */ 116,
-	/* U+004B+0331 -> U+1E34 */ 1207,
-	/* U+004C+0301 -> U+0139 */ 118,
-	/* U+004C+030C -> U+013D */ 122,
-	/* U+004C+0323 -> U+1E36 */ 1209,
-	/* U+004C+0327 -> U+013B */ 120,
-	/* U+004C+032D -> U+1E3C */ 1215,
-	/* U+004C+0331 -> U+1E3A */ 1213,
-	/* U+004D+0301 -> U+1E3E */ 1217,
-	/* U+004D+0307 -> U+1E40 */ 1219,
-	/* U+004D+0323 -> U+1E42 */ 1221,
-	/* U+004E+0300 -> U+01F8 */ 232,
-	/* U+004E+0301 -> U+0143 */ 126,
-	/* U+004E+0303 -> U+00D1 */ 29,
-	/* U+004E+0307 -> U+1E44 */ 1223,
-	/* U+004E+030C -> U+0147 */ 130,
-	/* U+004E+0323 -> U+1E46 */ 1225,
-	/* U+004E+0327 -> U+0145 */ 128,
-	/* U+004E+032D -> U+1E4A */ 1229,
-	/* U+004E+0331 -> U+1E48 */ 1227,
-	/* U+004F+0300 -> U+00D2 */ 30,
-	/* U+004F+0301 -> U+00D3 */ 31,
-	/* U+004F+0302 -> U+00D4 */ 32,
-	/* U+004F+0303 -> U+00D5 */ 33,
-	/* U+004F+0304 -> U+014C */ 133,
-	/* U+004F+0306 -> U+014E */ 135,
-	/* U+004F+0307 -> U+022E */ 278,
-	/* U+004F+0308 -> U+00D6 */ 34,
-	/* U+004F+0309 -> U+1ECE */ 1357,
-	/* U+004F+030B -> U+0150 */ 137,
-	/* U+004F+030C -> U+01D1 */ 198,
-	/* U+004F+030F -> U+020C */ 252,
-	/* U+004F+0311 -> U+020E */ 254,
-	/* U+004F+031B -> U+01A0 */ 181,
-	/* U+004F+0323 -> U+1ECC */ 1355,
-	/* U+004F+0328 -> U+01EA */ 220,
-	/* U+0050+0301 -> U+1E54 */ 1239,
-	/* U+0050+0307 -> U+1E56 */ 1241,
-	/* U+0052+0301 -> U+0154 */ 139,
-	/* U+0052+0307 -> U+1E58 */ 1243,
-	/* U+0052+030C -> U+0158 */ 143,
-	/* U+0052+030F -> U+0210 */ 256,
-	/* U+0052+0311 -> U+0212 */ 258,
-	/* U+0052+0323 -> U+1E5A */ 1245,
-	/* U+0052+0327 -> U+0156 */ 141,
-	/* U+0052+0331 -> U+1E5E */ 1249,
-	/* U+0053+0301 -> U+015A */ 145,
-	/* U+0053+0302 -> U+015C */ 147,
-	/* U+0053+0307 -> U+1E60 */ 1251,
-	/* U+0053+030C -> U+0160 */ 151,
-	/* U+0053+0323 -> U+1E62 */ 1253,
-	/* U+0053+0326 -> U+0218 */ 264,
-	/* U+0053+0327 -> U+015E */ 149,
-	/* U+0054+0307 -> U+1E6A */ 1261,
-	/* U+0054+030C -> U+0164 */ 155,
-	/* U+0054+0323 -> U+1E6C */ 1263,
-	/* U+0054+0326 -> U+021A */ 266,
-	/* U+0054+0327 -> U+0162 */ 153,
-	/* U+0054+032D -> U+1E70 */ 1267,
-	/* U+0054+0331 -> U+1E6E */ 1265,
-	/* U+0055+0300 -> U+00D9 */ 35,
-	/* U+0055+0301 -> U+00DA */ 36,
-	/* U+0055+0302 -> U+00DB */ 37,
-	/* U+0055+0303 -> U+0168 */ 157,
-	/* U+0055+0304 -> U+016A */ 159,
-	/* U+0055+0306 -> U+016C */ 161,
-	/* U+0055+0308 -> U+00DC */ 38,
-	/* U+0055+0309 -> U+1EE6 */ 1381,
-	/* U+0055+030A -> U+016E */ 163,
-	/* U+0055+030B -> U+0170 */ 165,
-	/* U+0055+030C -> U+01D3 */ 200,
-	/* U+0055+030F -> U+0214 */ 260,
-	/* U+0055+0311 -> U+0216 */ 262,
-	/* U+0055+031B -> U+01AF */ 183,
-	/* U+0055+0323 -> U+1EE4 */ 1379,
-	/* U+0055+0324 -> U+1E72 */ 1269,
-	/* U+0055+0328 -> U+0172 */ 167,
-	/* U+0055+032D -> U+1E76 */ 1273,
-	/* U+0055+0330 -> U+1E74 */ 1271,
-	/* U+0056+0303 -> U+1E7C */ 1279,
-	/* U+0056+0323 -> U+1E7E */ 1281,
-	/* U+0057+0300 -> U+1E80 */ 1283,
-	/* U+0057+0301 -> U+1E82 */ 1285,
-	/* U+0057+0302 -> U+0174 */ 169,
-	/* U+0057+0307 -> U+1E86 */ 1289,
-	/* U+0057+0308 -> U+1E84 */ 1287,
-	/* U+0057+0323 -> U+1E88 */ 1291,
-	/* U+0058+0307 -> U+1E8A */ 1293,
-	/* U+0058+0308 -> U+1E8C */ 1295,
-	/* U+0059+0300 -> U+1EF2 */ 1393,
-	/* U+0059+0301 -> U+00DD */ 39,
-	/* U+0059+0302 -> U+0176 */ 171,
-	/* U+0059+0303 -> U+1EF8 */ 1399,
-	/* U+0059+0304 -> U+0232 */ 282,
-	/* U+0059+0307 -> U+1E8E */ 1297,
-	/* U+0059+0308 -> U+0178 */ 173,
-	/* U+0059+0309 -> U+1EF6 */ 1397,
-	/* U+0059+0323 -> U+1EF4 */ 1395,
-	/* U+005A+0301 -> U+0179 */ 174,
-	/* U+005A+0302 -> U+1E90 */ 1299,
-	/* U+005A+0307 -> U+017B */ 176,
-	/* U+005A+030C -> U+017D */ 178,
-	/* U+005A+0323 -> U+1E92 */ 1301,
-	/* U+005A+0331 -> U+1E94 */ 1303,
-	/* U+0061+0300 -> U+00E0 */ 40,
-	/* U+0061+0301 -> U+00E1 */ 41,
-	/* U+0061+0302 -> U+00E2 */ 42,
-	/* U+0061+0303 -> U+00E3 */ 43,
-	/* U+0061+0304 -> U+0101 */ 68,
-	/* U+0061+0306 -> U+0103 */ 70,
-	/* U+0061+0307 -> U+0227 */ 271,
-	/* U+0061+0308 -> U+00E4 */ 44,
-	/* U+0061+0309 -> U+1EA3 */ 1314,
-	/* U+0061+030A -> U+00E5 */ 45,
-	/* U+0061+030C -> U+01CE */ 195,
-	/* U+0061+030F -> U+0201 */ 241,
-	/* U+0061+0311 -> U+0203 */ 243,
-	/* U+0061+0323 -> U+1EA1 */ 1312,
-	/* U+0061+0325 -> U+1E01 */ 1156,
-	/* U+0061+0328 -> U+0105 */ 72,
-	/* U+0062+0307 -> U+1E03 */ 1158,
-	/* U+0062+0323 -> U+1E05 */ 1160,
-	/* U+0062+0331 -> U+1E07 */ 1162,
-	/* U+0063+0301 -> U+0107 */ 74,
-	/* U+0063+0302 -> U+0109 */ 76,
-	/* U+0063+0307 -> U+010B */ 78,
-	/* U+0063+030C -> U+010D */ 80,
-	/* U+0063+0327 -> U+00E7 */ 46,
-	/* U+0064+0307 -> U+1E0B */ 1166,
-	/* U+0064+030C -> U+010F */ 82,
-	/* U+0064+0323 -> U+1E0D */ 1168,
-	/* U+0064+0327 -> U+1E11 */ 1172,
-	/* U+0064+032D -> U+1E13 */ 1174,
-	/* U+0064+0331 -> U+1E0F */ 1170,
-	/* U+0065+0300 -> U+00E8 */ 47,
-	/* U+0065+0301 -> U+00E9 */ 48,
-	/* U+0065+0302 -> U+00EA */ 49,
-	/* U+0065+0303 -> U+1EBD */ 1340,
-	/* U+0065+0304 -> U+0113 */ 84,
-	/* U+0065+0306 -> U+0115 */ 86,
-	/* U+0065+0307 -> U+0117 */ 88,
-	/* U+0065+0308 -> U+00EB */ 50,
-	/* U+0065+0309 -> U+1EBB */ 1338,
-	/* U+0065+030C -> U+011B */ 92,
-	/* U+0065+030F -> U+0205 */ 245,
-	/* U+0065+0311 -> U+0207 */ 247,
-	/* U+0065+0323 -> U+1EB9 */ 1336,
-	/* U+0065+0327 -> U+0229 */ 273,
-	/* U+0065+0328 -> U+0119 */ 90,
-	/* U+0065+032D -> U+1E19 */ 1180,
-	/* U+0065+0330 -> U+1E1B */ 1182,
-	/* U+0066+0307 -> U+1E1F */ 1186,
-	/* U+0067+0301 -> U+01F5 */ 231,
-	/* U+0067+0302 -> U+011D */ 94,
-	/* U+0067+0304 -> U+1E21 */ 1188,
-	/* U+0067+0306 -> U+011F */ 96,
-	/* U+0067+0307 -> U+0121 */ 98,
-	/* U+0067+030C -> U+01E7 */ 217,
-	/* U+0067+0327 -> U+0123 */ 100,
-	/* U+0068+0302 -> U+0125 */ 102,
-	/* U+0068+0307 -> U+1E23 */ 1190,
-	/* U+0068+0308 -> U+1E27 */ 1194,
-	/* U+0068+030C -> U+021F */ 269,
-	/* U+0068+0323 -> U+1E25 */ 1192,
-	/* U+0068+0327 -> U+1E29 */ 1196,
-	/* U+0068+032E -> U+1E2B */ 1198,
-	/* U+0068+0331 -> U+1E96 */ 1305,
-	/* U+0069+0300 -> U+00EC */ 51,
-	/* U+0069+0301 -> U+00ED */ 52,
-	/* U+0069+0302 -> U+00EE */ 53,
-	/* U+0069+0303 -> U+0129 */ 104,
-	/* U+0069+0304 -> U+012B */ 106,
-	/* U+0069+0306 -> U+012D */ 108,
-	/* U+0069+0308 -> U+00EF */ 54,
-	/* U+0069+0309 -> U+1EC9 */ 1352,
-	/* U+0069+030C -> U+01D0 */ 197,
-	/* U+0069+030F -> U+0209 */ 249,
-	/* U+0069+0311 -> U+020B */ 251,
-	/* U+0069+0323 -> U+1ECB */ 1354,
-	/* U+0069+0328 -> U+012F */ 110,
-	/* U+0069+0330 -> U+1E2D */ 1200,
-	/* U+006A+0302 -> U+0135 */ 115,
-	/* U+006A+030C -> U+01F0 */ 226,
-	/* U+006B+0301 -> U+1E31 */ 1204,
-	/* U+006B+030C -> U+01E9 */ 219,
-	/* U+006B+0323 -> U+1E33 */ 1206,
-	/* U+006B+0327 -> U+0137 */ 117,
-	/* U+006B+0331 -> U+1E35 */ 1208,
-	/* U+006C+0301 -> U+013A */ 119,
-	/* U+006C+030C -> U+013E */ 123,
-	/* U+006C+0323 -> U+1E37 */ 1210,
-	/* U+006C+0327 -> U+013C */ 121,
-	/* U+006C+032D -> U+1E3D */ 1216,
-	/* U+006C+0331 -> U+1E3B */ 1214,
-	/* U+006D+0301 -> U+1E3F */ 1218,
-	/* U+006D+0307 -> U+1E41 */ 1220,
-	/* U+006D+0323 -> U+1E43 */ 1222,
-	/* U+006E+0300 -> U+01F9 */ 233,
-	/* U+006E+0301 -> U+0144 */ 127,
-	/* U+006E+0303 -> U+00F1 */ 55,
-	/* U+006E+0307 -> U+1E45 */ 1224,
-	/* U+006E+030C -> U+0148 */ 131,
-	/* U+006E+0323 -> U+1E47 */ 1226,
-	/* U+006E+0327 -> U+0146 */ 129,
-	/* U+006E+032D -> U+1E4B */ 1230,
-	/* U+006E+0331 -> U+1E49 */ 1228,
-	/* U+006F+0300 -> U+00F2 */ 56,
-	/* U+006F+0301 -> U+00F3 */ 57,
-	/* U+006F+0302 -> U+00F4 */ 58,
-	/* U+006F+0303 -> U+00F5 */ 59,
-	/* U+006F+0304 -> U+014D */ 134,
-	/* U+006F+0306 -> U+014F */ 136,
-	/* U+006F+0307 -> U+022F */ 279,
-	/* U+006F+0308 -> U+00F6 */ 60,
-	/* U+006F+0309 -> U+1ECF */ 1358,
-	/* U+006F+030B -> U+0151 */ 138,
-	/* U+006F+030C -> U+01D2 */ 199,
-	/* U+006F+030F -> U+020D */ 253,
-	/* U+006F+0311 -> U+020F */ 255,
-	/* U+006F+031B -> U+01A1 */ 182,
-	/* U+006F+0323 -> U+1ECD */ 1356,
-	/* U+006F+0328 -> U+01EB */ 221,
-	/* U+0070+0301 -> U+1E55 */ 1240,
-	/* U+0070+0307 -> U+1E57 */ 1242,
-	/* U+0072+0301 -> U+0155 */ 140,
-	/* U+0072+0307 -> U+1E59 */ 1244,
-	/* U+0072+030C -> U+0159 */ 144,
-	/* U+0072+030F -> U+0211 */ 257,
-	/* U+0072+0311 -> U+0213 */ 259,
-	/* U+0072+0323 -> U+1E5B */ 1246,
-	/* U+0072+0327 -> U+0157 */ 142,
-	/* U+0072+0331 -> U+1E5F */ 1250,
-	/* U+0073+0301 -> U+015B */ 146,
-	/* U+0073+0302 -> U+015D */ 148,
-	/* U+0073+0307 -> U+1E61 */ 1252,
-	/* U+0073+030C -> U+0161 */ 152,
-	/* U+0073+0323 -> U+1E63 */ 1254,
-	/* U+0073+0326 -> U+0219 */ 265,
-	/* U+0073+0327 -> U+015F */ 150,
-	/* U+0074+0307 -> U+1E6B */ 1262,
-	/* U+0074+0308 -> U+1E97 */ 1306,
-	/* U+0074+030C -> U+0165 */ 156,
-	/* U+0074+0323 -> U+1E6D */ 1264,
-	/* U+0074+0326 -> U+021B */ 267,
-	/* U+0074+0327 -> U+0163 */ 154,
-	/* U+0074+032D -> U+1E71 */ 1268,
-	/* U+0074+0331 -> U+1E6F */ 1266,
-	/* U+0075+0300 -> U+00F9 */ 61,
-	/* U+0075+0301 -> U+00FA */ 62,
-	/* U+0075+0302 -> U+00FB */ 63,
-	/* U+0075+0303 -> U+0169 */ 158,
-	/* U+0075+0304 -> U+016B */ 160,
-	/* U+0075+0306 -> U+016D */ 162,
-	/* U+0075+0308 -> U+00FC */ 64,
-	/* U+0075+0309 -> U+1EE7 */ 1382,
-	/* U+0075+030A -> U+016F */ 164,
-	/* U+0075+030B -> U+0171 */ 166,
-	/* U+0075+030C -> U+01D4 */ 201,
-	/* U+0075+030F -> U+0215 */ 261,
-	/* U+0075+0311 -> U+0217 */ 263,
-	/* U+0075+031B -> U+01B0 */ 184,
-	/* U+0075+0323 -> U+1EE5 */ 1380,
-	/* U+0075+0324 -> U+1E73 */ 1270,
-	/* U+0075+0328 -> U+0173 */ 168,
-	/* U+0075+032D -> U+1E77 */ 1274,
-	/* U+0075+0330 -> U+1E75 */ 1272,
-	/* U+0076+0303 -> U+1E7D */ 1280,
-	/* U+0076+0323 -> U+1E7F */ 1282,
-	/* U+0077+0300 -> U+1E81 */ 1284,
-	/* U+0077+0301 -> U+1E83 */ 1286,
-	/* U+0077+0302 -> U+0175 */ 170,
-	/* U+0077+0307 -> U+1E87 */ 1290,
-	/* U+0077+0308 -> U+1E85 */ 1288,
-	/* U+0077+030A -> U+1E98 */ 1307,
-	/* U+0077+0323 -> U+1E89 */ 1292,
-	/* U+0078+0307 -> U+1E8B */ 1294,
-	/* U+0078+0308 -> U+1E8D */ 1296,
-	/* U+0079+0300 -> U+1EF3 */ 1394,
-	/* U+0079+0301 -> U+00FD */ 65,
-	/* U+0079+0302 -> U+0177 */ 172,
-	/* U+0079+0303 -> U+1EF9 */ 1400,
-	/* U+0079+0304 -> U+0233 */ 283,
-	/* U+0079+0307 -> U+1E8F */ 1298,
-	/* U+0079+0308 -> U+00FF */ 66,
-	/* U+0079+0309 -> U+1EF7 */ 1398,
-	/* U+0079+030A -> U+1E99 */ 1308,
-	/* U+0079+0323 -> U+1EF5 */ 1396,
-	/* U+007A+0301 -> U+017A */ 175,
-	/* U+007A+0302 -> U+1E91 */ 1300,
-	/* U+007A+0307 -> U+017C */ 177,
-	/* U+007A+030C -> U+017E */ 179,
-	/* U+007A+0323 -> U+1E93 */ 1302,
-	/* U+007A+0331 -> U+1E95 */ 1304,
-	/* U+00A8+0300 -> U+1FED */ 1619,
-	/* U+00A8+0301 -> U+0385 */ 419,
-	/* U+00A8+0342 -> U+1FC1 */ 1579,
-	/* U+00C2+0300 -> U+1EA6 */ 1317,
-	/* U+00C2+0301 -> U+1EA4 */ 1315,
-	/* U+00C2+0303 -> U+1EAA */ 1321,
-	/* U+00C2+0309 -> U+1EA8 */ 1319,
-	/* U+00C4+0304 -> U+01DE */ 210,
-	/* U+00C5+0301 -> U+01FA */ 234,
-	/* U+00C6+0301 -> U+01FC */ 236,
-	/* U+00C6+0304 -> U+01E2 */ 214,
-	/* U+00C7+0301 -> U+1E08 */ 1163,
-	/* U+00CA+0300 -> U+1EC0 */ 1343,
-	/* U+00CA+0301 -> U+1EBE */ 1341,
-	/* U+00CA+0303 -> U+1EC4 */ 1347,
-	/* U+00CA+0309 -> U+1EC2 */ 1345,
-	/* U+00CF+0301 -> U+1E2E */ 1201,
-	/* U+00D4+0300 -> U+1ED2 */ 1361,
-	/* U+00D4+0301 -> U+1ED0 */ 1359,
-	/* U+00D4+0303 -> U+1ED6 */ 1365,
-	/* U+00D4+0309 -> U+1ED4 */ 1363,
-	/* U+00D5+0301 -> U+1E4C */ 1231,
-	/* U+00D5+0304 -> U+022C */ 276,
-	/* U+00D5+0308 -> U+1E4E */ 1233,
-	/* U+00D6+0304 -> U+022A */ 274,
-	/* U+00D8+0301 -> U+01FE */ 238,
-	/* U+00DC+0300 -> U+01DB */ 208,
-	/* U+00DC+0301 -> U+01D7 */ 204,
-	/* U+00DC+0304 -> U+01D5 */ 202,
-	/* U+00DC+030C -> U+01D9 */ 206,
-	/* U+00E2+0300 -> U+1EA7 */ 1318,
-	/* U+00E2+0301 -> U+1EA5 */ 1316,
-	/* U+00E2+0303 -> U+1EAB */ 1322,
-	/* U+00E2+0309 -> U+1EA9 */ 1320,
-	/* U+00E4+0304 -> U+01DF */ 211,
-	/* U+00E5+0301 -> U+01FB */ 235,
-	/* U+00E6+0301 -> U+01FD */ 237,
-	/* U+00E6+0304 -> U+01E3 */ 215,
-	/* U+00E7+0301 -> U+1E09 */ 1164,
-	/* U+00EA+0300 -> U+1EC1 */ 1344,
-	/* U+00EA+0301 -> U+1EBF */ 1342,
-	/* U+00EA+0303 -> U+1EC5 */ 1348,
-	/* U+00EA+0309 -> U+1EC3 */ 1346,
-	/* U+00EF+0301 -> U+1E2F */ 1202,
-	/* U+00F4+0300 -> U+1ED3 */ 1362,
-	/* U+00F4+0301 -> U+1ED1 */ 1360,
-	/* U+00F4+0303 -> U+1ED7 */ 1366,
-	/* U+00F4+0309 -> U+1ED5 */ 1364,
-	/* U+00F5+0301 -> U+1E4D */ 1232,
-	/* U+00F5+0304 -> U+022D */ 277,
-	/* U+00F5+0308 -> U+1E4F */ 1234,
-	/* U+00F6+0304 -> U+022B */ 275,
-	/* U+00F8+0301 -> U+01FF */ 239,
-	/* U+00FC+0300 -> U+01DC */ 209,
-	/* U+00FC+0301 -> U+01D8 */ 205,
-	/* U+00FC+0304 -> U+01D6 */ 203,
-	/* U+00FC+030C -> U+01DA */ 207,
-	/* U+0102+0300 -> U+1EB0 */ 1327,
-	/* U+0102+0301 -> U+1EAE */ 1325,
-	/* U+0102+0303 -> U+1EB4 */ 1331,
-	/* U+0102+0309 -> U+1EB2 */ 1329,
-	/* U+0103+0300 -> U+1EB1 */ 1328,
-	/* U+0103+0301 -> U+1EAF */ 1326,
-	/* U+0103+0303 -> U+1EB5 */ 1332,
-	/* U+0103+0309 -> U+1EB3 */ 1330,
-	/* U+0112+0300 -> U+1E14 */ 1175,
-	/* U+0112+0301 -> U+1E16 */ 1177,
-	/* U+0113+0300 -> U+1E15 */ 1176,
-	/* U+0113+0301 -> U+1E17 */ 1178,
-	/* U+014C+0300 -> U+1E50 */ 1235,
-	/* U+014C+0301 -> U+1E52 */ 1237,
-	/* U+014D+0300 -> U+1E51 */ 1236,
-	/* U+014D+0301 -> U+1E53 */ 1238,
-	/* U+015A+0307 -> U+1E64 */ 1255,
-	/* U+015B+0307 -> U+1E65 */ 1256,
-	/* U+0160+0307 -> U+1E66 */ 1257,
-	/* U+0161+0307 -> U+1E67 */ 1258,
-	/* U+0168+0301 -> U+1E78 */ 1275,
-	/* U+0169+0301 -> U+1E79 */ 1276,
-	/* U+016A+0308 -> U+1E7A */ 1277,
-	/* U+016B+0308 -> U+1E7B */ 1278,
-	/* U+017F+0307 -> U+1E9B */ 1310,
-	/* U+01A0+0300 -> U+1EDC */ 1371,
-	/* U+01A0+0301 -> U+1EDA */ 1369,
-	/* U+01A0+0303 -> U+1EE0 */ 1375,
-	/* U+01A0+0309 -> U+1EDE */ 1373,
-	/* U+01A0+0323 -> U+1EE2 */ 1377,
-	/* U+01A1+0300 -> U+1EDD */ 1372,
-	/* U+01A1+0301 -> U+1EDB */ 1370,
-	/* U+01A1+0303 -> U+1EE1 */ 1376,
-	/* U+01A1+0309 -> U+1EDF */ 1374,
-	/* U+01A1+0323 -> U+1EE3 */ 1378,
-	/* U+01AF+0300 -> U+1EEA */ 1385,
-	/* U+01AF+0301 -> U+1EE8 */ 1383,
-	/* U+01AF+0303 -> U+1EEE */ 1389,
-	/* U+01AF+0309 -> U+1EEC */ 1387,
-	/* U+01AF+0323 -> U+1EF0 */ 1391,
-	/* U+01B0+0300 -> U+1EEB */ 1386,
-	/* U+01B0+0301 -> U+1EE9 */ 1384,
-	/* U+01B0+0303 -> U+1EEF */ 1390,
-	/* U+01B0+0309 -> U+1EED */ 1388,
-	/* U+01B0+0323 -> U+1EF1 */ 1392,
-	/* U+01B7+030C -> U+01EE */ 224,
-	/* U+01EA+0304 -> U+01EC */ 222,
-	/* U+01EB+0304 -> U+01ED */ 223,
-	/* U+0226+0304 -> U+01E0 */ 212,
-	/* U+0227+0304 -> U+01E1 */ 213,
-	/* U+0228+0306 -> U+1E1C */ 1183,
-	/* U+0229+0306 -> U+1E1D */ 1184,
-	/* U+022E+0304 -> U+0230 */ 280,
-	/* U+022F+0304 -> U+0231 */ 281,
-	/* U+0292+030C -> U+01EF */ 225,
-	/* U+0391+0300 -> U+1FBA */ 1572,
-	/* U+0391+0301 -> U+0386 */ 420,
-	/* U+0391+0304 -> U+1FB9 */ 1571,
-	/* U+0391+0306 -> U+1FB8 */ 1570,
-	/* U+0391+0313 -> U+1F08 */ 1409,
-	/* U+0391+0314 -> U+1F09 */ 1410,
-	/* U+0391+0345 -> U+1FBC */ 1574,
-	/* U+0395+0300 -> U+1FC8 */ 1585,
-	/* U+0395+0301 -> U+0388 */ 422,
-	/* U+0395+0313 -> U+1F18 */ 1423,
-	/* U+0395+0314 -> U+1F19 */ 1424,
-	/* U+0397+0300 -> U+1FCA */ 1587,
-	/* U+0397+0301 -> U+0389 */ 423,
-	/* U+0397+0313 -> U+1F28 */ 1437,
-	/* U+0397+0314 -> U+1F29 */ 1438,
-	/* U+0397+0345 -> U+1FCC */ 1589,
-	/* U+0399+0300 -> U+1FDA */ 1601,
-	/* U+0399+0301 -> U+038A */ 424,
-	/* U+0399+0304 -> U+1FD9 */ 1600,
-	/* U+0399+0306 -> U+1FD8 */ 1599,
-	/* U+0399+0308 -> U+03AA */ 429,
-	/* U+0399+0313 -> U+1F38 */ 1453,
-	/* U+0399+0314 -> U+1F39 */ 1454,
-	/* U+039F+0300 -> U+1FF8 */ 1627,
-	/* U+039F+0301 -> U+038C */ 425,
-	/* U+039F+0313 -> U+1F48 */ 1467,
-	/* U+039F+0314 -> U+1F49 */ 1468,
-	/* U+03A1+0314 -> U+1FEC */ 1618,
-	/* U+03A5+0300 -> U+1FEA */ 1616,
-	/* U+03A5+0301 -> U+038E */ 426,
-	/* U+03A5+0304 -> U+1FE9 */ 1615,
-	/* U+03A5+0306 -> U+1FE8 */ 1614,
-	/* U+03A5+0308 -> U+03AB */ 430,
-	/* U+03A5+0314 -> U+1F59 */ 1481,
-	/* U+03A9+0300 -> U+1FFA */ 1629,
-	/* U+03A9+0301 -> U+038F */ 427,
-	/* U+03A9+0313 -> U+1F68 */ 1493,
-	/* U+03A9+0314 -> U+1F69 */ 1494,
-	/* U+03A9+0345 -> U+1FFC */ 1631,
-	/* U+03AC+0345 -> U+1FB4 */ 1567,
-	/* U+03AE+0345 -> U+1FC4 */ 1582,
-	/* U+03B1+0300 -> U+1F70 */ 1501,
-	/* U+03B1+0301 -> U+03AC */ 431,
-	/* U+03B1+0304 -> U+1FB1 */ 1564,
-	/* U+03B1+0306 -> U+1FB0 */ 1563,
-	/* U+03B1+0313 -> U+1F00 */ 1401,
-	/* U+03B1+0314 -> U+1F01 */ 1402,
-	/* U+03B1+0342 -> U+1FB6 */ 1568,
-	/* U+03B1+0345 -> U+1FB3 */ 1566,
-	/* U+03B5+0300 -> U+1F72 */ 1503,
-	/* U+03B5+0301 -> U+03AD */ 432,
-	/* U+03B5+0313 -> U+1F10 */ 1417,
-	/* U+03B5+0314 -> U+1F11 */ 1418,
-	/* U+03B7+0300 -> U+1F74 */ 1505,
-	/* U+03B7+0301 -> U+03AE */ 433,
-	/* U+03B7+0313 -> U+1F20 */ 1429,
-	/* U+03B7+0314 -> U+1F21 */ 1430,
-	/* U+03B7+0342 -> U+1FC6 */ 1583,
-	/* U+03B7+0345 -> U+1FC3 */ 1581,
-	/* U+03B9+0300 -> U+1F76 */ 1507,
-	/* U+03B9+0301 -> U+03AF */ 434,
-	/* U+03B9+0304 -> U+1FD1 */ 1594,
-	/* U+03B9+0306 -> U+1FD0 */ 1593,
-	/* U+03B9+0308 -> U+03CA */ 436,
-	/* U+03B9+0313 -> U+1F30 */ 1445,
-	/* U+03B9+0314 -> U+1F31 */ 1446,
-	/* U+03B9+0342 -> U+1FD6 */ 1597,
-	/* U+03BF+0300 -> U+1F78 */ 1509,
-	/* U+03BF+0301 -> U+03CC */ 438,
-	/* U+03BF+0313 -> U+1F40 */ 1461,
-	/* U+03BF+0314 -> U+1F41 */ 1462,
-	/* U+03C1+0313 -> U+1FE4 */ 1610,
-	/* U+03C1+0314 -> U+1FE5 */ 1611,
-	/* U+03C5+0300 -> U+1F7A */ 1511,
-	/* U+03C5+0301 -> U+03CD */ 439,
-	/* U+03C5+0304 -> U+1FE1 */ 1607,
-	/* U+03C5+0306 -> U+1FE0 */ 1606,
-	/* U+03C5+0308 -> U+03CB */ 437,
-	/* U+03C5+0313 -> U+1F50 */ 1473,
-	/* U+03C5+0314 -> U+1F51 */ 1474,
-	/* U+03C5+0342 -> U+1FE6 */ 1612,
-	/* U+03C9+0300 -> U+1F7C */ 1513,
-	/* U+03C9+0301 -> U+03CE */ 440,
-	/* U+03C9+0313 -> U+1F60 */ 1485,
-	/* U+03C9+0314 -> U+1F61 */ 1486,
-	/* U+03C9+0342 -> U+1FF6 */ 1625,
-	/* U+03C9+0345 -> U+1FF3 */ 1623,
-	/* U+03CA+0300 -> U+1FD2 */ 1595,
-	/* U+03CA+0301 -> U+0390 */ 428,
-	/* U+03CA+0342 -> U+1FD7 */ 1598,
-	/* U+03CB+0300 -> U+1FE2 */ 1608,
-	/* U+03CB+0301 -> U+03B0 */ 435,
-	/* U+03CB+0342 -> U+1FE7 */ 1613,
-	/* U+03CE+0345 -> U+1FF4 */ 1624,
-	/* U+03D2+0301 -> U+03D3 */ 444,
-	/* U+03D2+0308 -> U+03D4 */ 445,
-	/* U+0406+0308 -> U+0407 */ 457,
-	/* U+0410+0306 -> U+04D0 */ 479,
-	/* U+0410+0308 -> U+04D2 */ 481,
-	/* U+0413+0301 -> U+0403 */ 456,
-	/* U+0415+0300 -> U+0400 */ 454,
-	/* U+0415+0306 -> U+04D6 */ 483,
-	/* U+0415+0308 -> U+0401 */ 455,
-	/* U+0416+0306 -> U+04C1 */ 477,
-	/* U+0416+0308 -> U+04DC */ 487,
-	/* U+0417+0308 -> U+04DE */ 489,
-	/* U+0418+0300 -> U+040D */ 459,
-	/* U+0418+0304 -> U+04E2 */ 491,
-	/* U+0418+0306 -> U+0419 */ 461,
-	/* U+0418+0308 -> U+04E4 */ 493,
-	/* U+041A+0301 -> U+040C */ 458,
-	/* U+041E+0308 -> U+04E6 */ 495,
-	/* U+0423+0304 -> U+04EE */ 501,
-	/* U+0423+0306 -> U+040E */ 460,
-	/* U+0423+0308 -> U+04F0 */ 503,
-	/* U+0423+030B -> U+04F2 */ 505,
-	/* U+0427+0308 -> U+04F4 */ 507,
-	/* U+042B+0308 -> U+04F8 */ 509,
-	/* U+042D+0308 -> U+04EC */ 499,
-	/* U+0430+0306 -> U+04D1 */ 480,
-	/* U+0430+0308 -> U+04D3 */ 482,
-	/* U+0433+0301 -> U+0453 */ 465,
-	/* U+0435+0300 -> U+0450 */ 463,
-	/* U+0435+0306 -> U+04D7 */ 484,
-	/* U+0435+0308 -> U+0451 */ 464,
-	/* U+0436+0306 -> U+04C2 */ 478,
-	/* U+0436+0308 -> U+04DD */ 488,
-	/* U+0437+0308 -> U+04DF */ 490,
-	/* U+0438+0300 -> U+045D */ 468,
-	/* U+0438+0304 -> U+04E3 */ 492,
-	/* U+0438+0306 -> U+0439 */ 462,
-	/* U+0438+0308 -> U+04E5 */ 494,
-	/* U+043A+0301 -> U+045C */ 467,
-	/* U+043E+0308 -> U+04E7 */ 496,
-	/* U+0443+0304 -> U+04EF */ 502,
-	/* U+0443+0306 -> U+045E */ 469,
-	/* U+0443+0308 -> U+04F1 */ 504,
-	/* U+0443+030B -> U+04F3 */ 506,
-	/* U+0447+0308 -> U+04F5 */ 508,
-	/* U+044B+0308 -> U+04F9 */ 510,
-	/* U+044D+0308 -> U+04ED */ 500,
-	/* U+0456+0308 -> U+0457 */ 466,
-	/* U+0474+030F -> U+0476 */ 470,
-	/* U+0475+030F -> U+0477 */ 471,
-	/* U+04D8+0308 -> U+04DA */ 485,
-	/* U+04D9+0308 -> U+04DB */ 486,
-	/* U+04E8+0308 -> U+04EA */ 497,
-	/* U+04E9+0308 -> U+04EB */ 498,
-	/* U+0627+0653 -> U+0622 */ 574,
-	/* U+0627+0654 -> U+0623 */ 575,
-	/* U+0627+0655 -> U+0625 */ 577,
-	/* U+0648+0654 -> U+0624 */ 576,
-	/* U+064A+0654 -> U+0626 */ 578,
-	/* U+06C1+0654 -> U+06C2 */ 606,
-	/* U+06D2+0654 -> U+06D3 */ 607,
-	/* U+06D5+0654 -> U+06C0 */ 605,
-	/* U+0928+093C -> U+0929 */ 751,
-	/* U+0930+093C -> U+0931 */ 752,
-	/* U+0933+093C -> U+0934 */ 753,
-	/* U+09C7+09BE -> U+09CB */ 769,
-	/* U+09C7+09D7 -> U+09CC */ 770,
-	/* U+0B47+0B3E -> U+0B4B */ 788,
-	/* U+0B47+0B56 -> U+0B48 */ 787,
-	/* U+0B47+0B57 -> U+0B4C */ 789,
-	/* U+0B92+0BD7 -> U+0B94 */ 793,
-	/* U+0BC6+0BBE -> U+0BCA */ 794,
-	/* U+0BC6+0BD7 -> U+0BCC */ 796,
-	/* U+0BC7+0BBE -> U+0BCB */ 795,
-	/* U+0C46+0C56 -> U+0C48 */ 799,
-	/* U+0CBF+0CD5 -> U+0CC0 */ 804,
-	/* U+0CC6+0CC2 -> U+0CCA */ 807,
-	/* U+0CC6+0CD5 -> U+0CC7 */ 805,
-	/* U+0CC6+0CD6 -> U+0CC8 */ 806,
-	/* U+0CCA+0CD5 -> U+0CCB */ 808,
-	/* U+0D46+0D3E -> U+0D4A */ 812,
-	/* U+0D46+0D57 -> U+0D4C */ 814,
-	/* U+0D47+0D3E -> U+0D4B */ 813,
-	/* U+0DD9+0DCA -> U+0DDA */ 817,
-	/* U+0DD9+0DCF -> U+0DDC */ 818,
-	/* U+0DD9+0DDF -> U+0DDE */ 820,
-	/* U+0DDC+0DCA -> U+0DDD */ 819,
-	/* U+1025+102E -> U+1026 */ 878,
-	/* U+1B05+1B35 -> U+1B06 */ 938,
-	/* U+1B07+1B35 -> U+1B08 */ 939,
-	/* U+1B09+1B35 -> U+1B0A */ 940,
-	/* U+1B0B+1B35 -> U+1B0C */ 941,
-	/* U+1B0D+1B35 -> U+1B0E */ 942,
-	/* U+1B11+1B35 -> U+1B12 */ 943,
-	/* U+1B3A+1B35 -> U+1B3B */ 945,
-	/* U+1B3C+1B35 -> U+1B3D */ 946,
-	/* U+1B3E+1B35 -> U+1B40 */ 947,
-	/* U+1B3F+1B35 -> U+1B41 */ 948,
-	/* U+1B42+1B35 -> U+1B43 */ 949,
-	/* U+1E36+0304 -> U+1E38 */ 1211,
-	/* U+1E37+0304 -> U+1E39 */ 1212,
-	/* U+1E5A+0304 -> U+1E5C */ 1247,
-	/* U+1E5B+0304 -> U+1E5D */ 1248,
-	/* U+1E62+0307 -> U+1E68 */ 1259,
-	/* U+1E63+0307 -> U+1E69 */ 1260,
-	/* U+1EA0+0302 -> U+1EAC */ 1323,
-	/* U+1EA0+0306 -> U+1EB6 */ 1333,
-	/* U+1EA1+0302 -> U+1EAD */ 1324,
-	/* U+1EA1+0306 -> U+1EB7 */ 1334,
-	/* U+1EB8+0302 -> U+1EC6 */ 1349,
-	/* U+1EB9+0302 -> U+1EC7 */ 1350,
-	/* U+1ECC+0302 -> U+1ED8 */ 1367,
-	/* U+1ECD+0302 -> U+1ED9 */ 1368,
-	/* U+1F00+0300 -> U+1F02 */ 1403,
-	/* U+1F00+0301 -> U+1F04 */ 1405,
-	/* U+1F00+0342 -> U+1F06 */ 1407,
-	/* U+1F00+0345 -> U+1F80 */ 1515,
-	/* U+1F01+0300 -> U+1F03 */ 1404,
-	/* U+1F01+0301 -> U+1F05 */ 1406,
-	/* U+1F01+0342 -> U+1F07 */ 1408,
-	/* U+1F01+0345 -> U+1F81 */ 1516,
-	/* U+1F02+0345 -> U+1F82 */ 1517,
-	/* U+1F03+0345 -> U+1F83 */ 1518,
-	/* U+1F04+0345 -> U+1F84 */ 1519,
-	/* U+1F05+0345 -> U+1F85 */ 1520,
-	/* U+1F06+0345 -> U+1F86 */ 1521,
-	/* U+1F07+0345 -> U+1F87 */ 1522,
-	/* U+1F08+0300 -> U+1F0A */ 1411,
-	/* U+1F08+0301 -> U+1F0C */ 1413,
-	/* U+1F08+0342 -> U+1F0E */ 1415,
-	/* U+1F08+0345 -> U+1F88 */ 1523,
-	/* U+1F09+0300 -> U+1F0B */ 1412,
-	/* U+1F09+0301 -> U+1F0D */ 1414,
-	/* U+1F09+0342 -> U+1F0F */ 1416,
-	/* U+1F09+0345 -> U+1F89 */ 1524,
-	/* U+1F0A+0345 -> U+1F8A */ 1525,
-	/* U+1F0B+0345 -> U+1F8B */ 1526,
-	/* U+1F0C+0345 -> U+1F8C */ 1527,
-	/* U+1F0D+0345 -> U+1F8D */ 1528,
-	/* U+1F0E+0345 -> U+1F8E */ 1529,
-	/* U+1F0F+0345 -> U+1F8F */ 1530,
-	/* U+1F10+0300 -> U+1F12 */ 1419,
-	/* U+1F10+0301 -> U+1F14 */ 1421,
-	/* U+1F11+0300 -> U+1F13 */ 1420,
-	/* U+1F11+0301 -> U+1F15 */ 1422,
-	/* U+1F18+0300 -> U+1F1A */ 1425,
-	/* U+1F18+0301 -> U+1F1C */ 1427,
-	/* U+1F19+0300 -> U+1F1B */ 1426,
-	/* U+1F19+0301 -> U+1F1D */ 1428,
-	/* U+1F20+0300 -> U+1F22 */ 1431,
-	/* U+1F20+0301 -> U+1F24 */ 1433,
-	/* U+1F20+0342 -> U+1F26 */ 1435,
-	/* U+1F20+0345 -> U+1F90 */ 1531,
-	/* U+1F21+0300 -> U+1F23 */ 1432,
-	/* U+1F21+0301 -> U+1F25 */ 1434,
-	/* U+1F21+0342 -> U+1F27 */ 1436,
-	/* U+1F21+0345 -> U+1F91 */ 1532,
-	/* U+1F22+0345 -> U+1F92 */ 1533,
-	/* U+1F23+0345 -> U+1F93 */ 1534,
-	/* U+1F24+0345 -> U+1F94 */ 1535,
-	/* U+1F25+0345 -> U+1F95 */ 1536,
-	/* U+1F26+0345 -> U+1F96 */ 1537,
-	/* U+1F27+0345 -> U+1F97 */ 1538,
-	/* U+1F28+0300 -> U+1F2A */ 1439,
-	/* U+1F28+0301 -> U+1F2C */ 1441,
-	/* U+1F28+0342 -> U+1F2E */ 1443,
-	/* U+1F28+0345 -> U+1F98 */ 1539,
-	/* U+1F29+0300 -> U+1F2B */ 1440,
-	/* U+1F29+0301 -> U+1F2D */ 1442,
-	/* U+1F29+0342 -> U+1F2F */ 1444,
-	/* U+1F29+0345 -> U+1F99 */ 1540,
-	/* U+1F2A+0345 -> U+1F9A */ 1541,
-	/* U+1F2B+0345 -> U+1F9B */ 1542,
-	/* U+1F2C+0345 -> U+1F9C */ 1543,
-	/* U+1F2D+0345 -> U+1F9D */ 1544,
-	/* U+1F2E+0345 -> U+1F9E */ 1545,
-	/* U+1F2F+0345 -> U+1F9F */ 1546,
-	/* U+1F30+0300 -> U+1F32 */ 1447,
-	/* U+1F30+0301 -> U+1F34 */ 1449,
-	/* U+1F30+0342 -> U+1F36 */ 1451,
-	/* U+1F31+0300 -> U+1F33 */ 1448,
-	/* U+1F31+0301 -> U+1F35 */ 1450,
-	/* U+1F31+0342 -> U+1F37 */ 1452,
-	/* U+1F38+0300 -> U+1F3A */ 1455,
-	/* U+1F38+0301 -> U+1F3C */ 1457,
-	/* U+1F38+0342 -> U+1F3E */ 1459,
-	/* U+1F39+0300 -> U+1F3B */ 1456,
-	/* U+1F39+0301 -> U+1F3D */ 1458,
-	/* U+1F39+0342 -> U+1F3F */ 1460,
-	/* U+1F40+0300 -> U+1F42 */ 1463,
-	/* U+1F40+0301 -> U+1F44 */ 1465,
-	/* U+1F41+0300 -> U+1F43 */ 1464,
-	/* U+1F41+0301 -> U+1F45 */ 1466,
-	/* U+1F48+0300 -> U+1F4A */ 1469,
-	/* U+1F48+0301 -> U+1F4C */ 1471,
-	/* U+1F49+0300 -> U+1F4B */ 1470,
-	/* U+1F49+0301 -> U+1F4D */ 1472,
-	/* U+1F50+0300 -> U+1F52 */ 1475,
-	/* U+1F50+0301 -> U+1F54 */ 1477,
-	/* U+1F50+0342 -> U+1F56 */ 1479,
-	/* U+1F51+0300 -> U+1F53 */ 1476,
-	/* U+1F51+0301 -> U+1F55 */ 1478,
-	/* U+1F51+0342 -> U+1F57 */ 1480,
-	/* U+1F59+0300 -> U+1F5B */ 1482,
-	/* U+1F59+0301 -> U+1F5D */ 1483,
-	/* U+1F59+0342 -> U+1F5F */ 1484,
-	/* U+1F60+0300 -> U+1F62 */ 1487,
-	/* U+1F60+0301 -> U+1F64 */ 1489,
-	/* U+1F60+0342 -> U+1F66 */ 1491,
-	/* U+1F60+0345 -> U+1FA0 */ 1547,
-	/* U+1F61+0300 -> U+1F63 */ 1488,
-	/* U+1F61+0301 -> U+1F65 */ 1490,
-	/* U+1F61+0342 -> U+1F67 */ 1492,
-	/* U+1F61+0345 -> U+1FA1 */ 1548,
-	/* U+1F62+0345 -> U+1FA2 */ 1549,
-	/* U+1F63+0345 -> U+1FA3 */ 1550,
-	/* U+1F64+0345 -> U+1FA4 */ 1551,
-	/* U+1F65+0345 -> U+1FA5 */ 1552,
-	/* U+1F66+0345 -> U+1FA6 */ 1553,
-	/* U+1F67+0345 -> U+1FA7 */ 1554,
-	/* U+1F68+0300 -> U+1F6A */ 1495,
-	/* U+1F68+0301 -> U+1F6C */ 1497,
-	/* U+1F68+0342 -> U+1F6E */ 1499,
-	/* U+1F68+0345 -> U+1FA8 */ 1555,
-	/* U+1F69+0300 -> U+1F6B */ 1496,
-	/* U+1F69+0301 -> U+1F6D */ 1498,
-	/* U+1F69+0342 -> U+1F6F */ 1500,
-	/* U+1F69+0345 -> U+1FA9 */ 1556,
-	/* U+1F6A+0345 -> U+1FAA */ 1557,
-	/* U+1F6B+0345 -> U+1FAB */ 1558,
-	/* U+1F6C+0345 -> U+1FAC */ 1559,
-	/* U+1F6D+0345 -> U+1FAD */ 1560,
-	/* U+1F6E+0345 -> U+1FAE */ 1561,
-	/* U+1F6F+0345 -> U+1FAF */ 1562,
-	/* U+1F70+0345 -> U+1FB2 */ 1565,
-	/* U+1F74+0345 -> U+1FC2 */ 1580,
-	/* U+1F7C+0345 -> U+1FF2 */ 1622,
-	/* U+1FB6+0345 -> U+1FB7 */ 1569,
-	/* U+1FBF+0300 -> U+1FCD */ 1590,
-	/* U+1FBF+0301 -> U+1FCE */ 1591,
-	/* U+1FBF+0342 -> U+1FCF */ 1592,
-	/* U+1FC6+0345 -> U+1FC7 */ 1584,
-	/* U+1FF6+0345 -> U+1FF7 */ 1626,
-	/* U+1FFE+0300 -> U+1FDD */ 1603,
-	/* U+1FFE+0301 -> U+1FDE */ 1604,
-	/* U+1FFE+0342 -> U+1FDF */ 1605,
-	/* U+2190+0338 -> U+219A */ 1836,
-	/* U+2192+0338 -> U+219B */ 1837,
-	/* U+2194+0338 -> U+21AE */ 1838,
-	/* U+21D0+0338 -> U+21CD */ 1839,
-	/* U+21D2+0338 -> U+21CF */ 1841,
-	/* U+21D4+0338 -> U+21CE */ 1840,
-	/* U+2203+0338 -> U+2204 */ 1842,
-	/* U+2208+0338 -> U+2209 */ 1843,
-	/* U+220B+0338 -> U+220C */ 1844,
-	/* U+2223+0338 -> U+2224 */ 1845,
-	/* U+2225+0338 -> U+2226 */ 1846,
-	/* U+223C+0338 -> U+2241 */ 1851,
-	/* U+2243+0338 -> U+2244 */ 1852,
-	/* U+2245+0338 -> U+2247 */ 1853,
-	/* U+2248+0338 -> U+2249 */ 1854,
-	/* U+224D+0338 -> U+226D */ 1857,
-	/* U+2261+0338 -> U+2262 */ 1856,
-	/* U+2264+0338 -> U+2270 */ 1860,
-	/* U+2265+0338 -> U+2271 */ 1861,
-	/* U+2272+0338 -> U+2274 */ 1862,
-	/* U+2273+0338 -> U+2275 */ 1863,
-	/* U+2276+0338 -> U+2278 */ 1864,
-	/* U+2277+0338 -> U+2279 */ 1865,
-	/* U+227A+0338 -> U+2280 */ 1866,
-	/* U+227B+0338 -> U+2281 */ 1867,
-	/* U+227C+0338 -> U+22E0 */ 1876,
-	/* U+227D+0338 -> U+22E1 */ 1877,
-	/* U+2282+0338 -> U+2284 */ 1868,
-	/* U+2283+0338 -> U+2285 */ 1869,
-	/* U+2286+0338 -> U+2288 */ 1870,
-	/* U+2287+0338 -> U+2289 */ 1871,
-	/* U+2291+0338 -> U+22E2 */ 1878,
-	/* U+2292+0338 -> U+22E3 */ 1879,
-	/* U+22A2+0338 -> U+22AC */ 1872,
-	/* U+22A8+0338 -> U+22AD */ 1873,
-	/* U+22A9+0338 -> U+22AE */ 1874,
-	/* U+22AB+0338 -> U+22AF */ 1875,
-	/* U+22B2+0338 -> U+22EA */ 1880,
-	/* U+22B3+0338 -> U+22EB */ 1881,
-	/* U+22B4+0338 -> U+22EC */ 1882,
-	/* U+22B5+0338 -> U+22ED */ 1883,
-	/* U+3046+3099 -> U+3094 */ 2321,
-	/* U+304B+3099 -> U+304C */ 2296,
-	/* U+304D+3099 -> U+304E */ 2297,
-	/* U+304F+3099 -> U+3050 */ 2298,
-	/* U+3051+3099 -> U+3052 */ 2299,
-	/* U+3053+3099 -> U+3054 */ 2300,
-	/* U+3055+3099 -> U+3056 */ 2301,
-	/* U+3057+3099 -> U+3058 */ 2302,
-	/* U+3059+3099 -> U+305A */ 2303,
-	/* U+305B+3099 -> U+305C */ 2304,
-	/* U+305D+3099 -> U+305E */ 2305,
-	/* U+305F+3099 -> U+3060 */ 2306,
-	/* U+3061+3099 -> U+3062 */ 2307,
-	/* U+3064+3099 -> U+3065 */ 2308,
-	/* U+3066+3099 -> U+3067 */ 2309,
-	/* U+3068+3099 -> U+3069 */ 2310,
-	/* U+306F+3099 -> U+3070 */ 2311,
-	/* U+306F+309A -> U+3071 */ 2312,
-	/* U+3072+3099 -> U+3073 */ 2313,
-	/* U+3072+309A -> U+3074 */ 2314,
-	/* U+3075+3099 -> U+3076 */ 2315,
-	/* U+3075+309A -> U+3077 */ 2316,
-	/* U+3078+3099 -> U+3079 */ 2317,
-	/* U+3078+309A -> U+307A */ 2318,
-	/* U+307B+3099 -> U+307C */ 2319,
-	/* U+307B+309A -> U+307D */ 2320,
-	/* U+309D+3099 -> U+309E */ 2326,
-	/* U+30A6+3099 -> U+30F4 */ 2353,
-	/* U+30AB+3099 -> U+30AC */ 2328,
-	/* U+30AD+3099 -> U+30AE */ 2329,
-	/* U+30AF+3099 -> U+30B0 */ 2330,
-	/* U+30B1+3099 -> U+30B2 */ 2331,
-	/* U+30B3+3099 -> U+30B4 */ 2332,
-	/* U+30B5+3099 -> U+30B6 */ 2333,
-	/* U+30B7+3099 -> U+30B8 */ 2334,
-	/* U+30B9+3099 -> U+30BA */ 2335,
-	/* U+30BB+3099 -> U+30BC */ 2336,
-	/* U+30BD+3099 -> U+30BE */ 2337,
-	/* U+30BF+3099 -> U+30C0 */ 2338,
-	/* U+30C1+3099 -> U+30C2 */ 2339,
-	/* U+30C4+3099 -> U+30C5 */ 2340,
-	/* U+30C6+3099 -> U+30C7 */ 2341,
-	/* U+30C8+3099 -> U+30C9 */ 2342,
-	/* U+30CF+3099 -> U+30D0 */ 2343,
-	/* U+30CF+309A -> U+30D1 */ 2344,
-	/* U+30D2+3099 -> U+30D3 */ 2345,
-	/* U+30D2+309A -> U+30D4 */ 2346,
-	/* U+30D5+3099 -> U+30D6 */ 2347,
-	/* U+30D5+309A -> U+30D7 */ 2348,
-	/* U+30D8+3099 -> U+30D9 */ 2349,
-	/* U+30D8+309A -> U+30DA */ 2350,
-	/* U+30DB+3099 -> U+30DC */ 2351,
-	/* U+30DB+309A -> U+30DD */ 2352,
-	/* U+30EF+3099 -> U+30F7 */ 2354,
-	/* U+30F0+3099 -> U+30F8 */ 2355,
-	/* U+30F1+3099 -> U+30F9 */ 2356,
-	/* U+30F2+3099 -> U+30FA */ 2357,
-	/* U+30FD+3099 -> U+30FE */ 2358,
-	/* U+105D2+0307 -> U+105C9 */ 4599,
-	/* U+105DA+0307 -> U+105E4 */ 4600,
-	/* U+11099+110BA -> U+1109A */ 4697,
-	/* U+1109B+110BA -> U+1109C */ 4698,
-	/* U+110A5+110BA -> U+110AB */ 4699,
-	/* U+11131+11127 -> U+1112E */ 4705,
-	/* U+11132+11127 -> U+1112F */ 4706,
-	/* U+11347+1133E -> U+1134B */ 4718,
-	/* U+11347+11357 -> U+1134C */ 4719,
-	/* U+11382+113C9 -> U+11383 */ 4733,
-	/* U+11384+113BB -> U+11385 */ 4734,
-	/* U+1138B+113C2 -> U+1138E */ 4735,
-	/* U+11390+113C9 -> U+11391 */ 4736,
-	/* U+113C2+113B8 -> U+113C7 */ 4738,
-	/* U+113C2+113C2 -> U+113C5 */ 4737,
-	/* U+113C2+113C9 -> U+113C8 */ 4739,
-	/* U+114B9+114B0 -> U+114BC */ 4747,
-	/* U+114B9+114BA -> U+114BB */ 4746,
-	/* U+114B9+114BD -> U+114BE */ 4748,
-	/* U+115B8+115AF -> U+115BA */ 4751,
-	/* U+115B9+115AF -> U+115BB */ 4752,
-	/* U+11935+11930 -> U+11938 */ 4761,
-	/* U+1611E+1611E -> U+16121 */ 4776,
-	/* U+1611E+1611F -> U+16123 */ 4778,
-	/* U+1611E+16120 -> U+16125 */ 4780,
-	/* U+1611E+16129 -> U+16122 */ 4777,
-	/* U+16121+1611F -> U+16126 */ 4781,
-	/* U+16121+16120 -> U+16128 */ 4783,
-	/* U+16122+1611F -> U+16127 */ 4782,
-	/* U+16129+1611F -> U+16124 */ 4779,
-	/* U+16D63+16D67 -> U+16D69 */ 4798,
-	/* U+16D67+16D67 -> U+16D68 */ 4797,
-	/* U+16D69+16D67 -> U+16D6A */ 4799
-};
-
-/* Perfect hash function for recomposition */
-static int
-Recomp_hash_func(const void *key)
-{
-	static const int16 h[1923] = {
-		-109,  -96,   32767, 0,     -844,  -182,  -292,  32767,
-		830,   793,   794,   665,   0,     -9,    32767, 32767,
-		32767, 32767, 32767, 428,   32767, 32767, 32767, 502,
-		0,     32767, -230,  144,   356,   -76,   0,     243,
-		665,   32767, 32767, -1003, 244,   0,     32767, 32767,
-		573,   246,   125,   32767, 32767, 32767, 0,     32767,
-		32767, 32767, 32767, 0,     245,   32767, 723,   32767,
-		0,     889,   32767, 32767, 32767, 0,     32767, 32767,
-		0,     173,   157,   1215,  254,   255,   -126,  0,
-		0,     504,   459,   -11,   238,   -188,  722,   247,
-		260,   32767, -184,  -6,    2102,  -578,  32767, 32767,
-		-598,  -670,  260,   19,    32767, -472,  32767, 664,
-		511,   0,     32767, 345,   291,   0,     -370,  176,
-		32767, 1017,  -139,  -519,  -30,   0,     -24,   -23,
-		481,   -253,  -1813, 32767, 0,     935,   32767, 32767,
-		-443,  32767, 773,   32767, 32767, 32767, -507,  427,
-		0,     32767, 899,   32767, 32767, 277,   0,     32767,
-		32767, 0,     842,   854,   0,     32767, 936,   621,
-		-195,  32767, 0,     32767, 707,   268,   32767, 32767,
-		435,   32767, 32767, 32767, 0,     267,   88,    72,
-		32767, 487,   32767, 32767, 32767, 0,     32767, 32767,
-		32767, 32767, 32767, 875,   -312,  32767, 483,   875,
-		270,   89,    32767, 483,   32767, 32767, 32767, 32767,
-		708,   273,   2053,  -63,   -242,  -479,  32767, 352,
-		32767, 32767, 0,     560,   544,   32767, 32767, 32767,
-		0,     0,     32767, 0,     32767, 32767, 32767, 525,
-		274,   32767, 404,   386,   518,   32767, -357,  32767,
-		-45,   1154,  276,   32767, 149,   0,     277,   714,
-		313,   32767, 32767, 32767, 32767, 32767, 841,   460,
-		431,   32767, 32767, -49,   32767, 32767, 32767, 32767,
-		32767, 32767, 0,     876,   280,   281,   131,   388,
-		283,   32767, 1125,  32767, 695,   712,   32767, 0,
-		713,   1732,  0,     32767, 0,     231,   32767, 0,
-		32767, -755,  32767, 32767, 32767, 435,   32767, 0,
-		951,   952,   32767, 32767, 464,   867,   1298,  0,
-		660,   -55,   0,     292,   663,   118,   661,   -722,
-		435,   816,   328,   0,     323,   323,   -258,  -684,
-		2114,  0,     302,   0,     32767, 32767, 1607,  32767,
-		0,     32767, 32767, 0,     810,   32767, -543,  -5,
-		515,   32767, 0,     877,   304,   32767, 472,   32767,
-		683,   -549,  258,   285,   -904,  32767, 148,   1202,
-		1044,  0,     32767, 32767, 659,   1395,  905,   32767,
-		32767, 32767, -626,  32767, 32767, 32767, 32767, 672,
-		0,     32767, -139,  32767, 32767, 0,     0,     660,
-		1,     32767, -955,  -293,  616,   391,   632,   -126,
-		32767, 32767, 1610,  -166,  754,   324,   32767, 32767,
-		931,   32767, 32767, 32767, 0,     32767, 32767, 32767,
-		32767, 0,     32767, 32767, 302,   391,   32767, 32767,
-		516,   32767, 32767, 1131,  670,   544,   308,   286,
-		0,     0,     32767, 32767, 531,   -629,  -35,   0,
-		6,     -63,   485,   0,     0,     -486,  -58,   0,
-		0,     38,    470,   -20,   0,     32767, 0,     0,
-		956,   32767, 0,     294,   -759,  0,     32767, 32767,
-		-362,  73,    316,   588,   314,   32767, 609,   0,
-		318,   32767, 32767, 32767, -759,  1466,  -212,  32767,
-		1910,  226,   653,   32767, 219,   32767, 32767, 0,
-		0,     32767, 1045,  -6,    -6,    32767, 0,     163,
-		0,     0,     -9,    879,   -369,  32767, -18,   321,
-		322,   32767, 32767, -449,  1082,  324,   57,    32767,
-		-403,  252,   697,   0,     491,   552,   0,     32767,
-		32767, 32767, 864,   32767, 0,     32767, 929,   -582,
-		32767, 32767, 32767, 1521,  32767, 32767, 32767, 212,
-		326,   -542,  332,   333,   334,   -490,  692,   336,
-		32767, 337,   338,   31,    0,     714,   348,   34,
-		342,   32767, 1602,  32767, 687,   143,   32767, 0,
-		32767, 32767, 0,     32767, 196,   -21,   32767, 32767,
-		-4,    32767, 32767, 880,   -211,  203,   32767, 1078,
-		83,    1661,  32767, 32767, 283,   787,   348,   32767,
-		0,     -464,  0,     32767, 725,   -431,  -811,  -322,
-		7,     32767, -315,  267,   694,   -2103, 12,    247,
-		13,    692,   32767, -1593, 32767, 15,    32767, 32767,
-		830,   0,     623,   354,   32767, 32767, -154,  0,
-		264,   -712,  32767, 357,   32767, 32767, 220,   -242,
-		32767, 921,   905,   32767, -1184, 549,   32767, 19,
-		319,   32767, 551,   32767, 1307,  0,     32767, 32767,
-		32767, 0,     566,   881,   822,   936,   326,   89,
-		-313,  32767, 250,   0,     359,   360,   32767, 32767,
-		32767, 32767, -575,  20,    32767, 98,    23,    32767,
-		287,   744,   124,   1027,  32767, 0,     564,   0,
-		-548,  -497,  982,   32767, 32767, 32767, 32767, 32767,
-		35,    316,   -1859, 343,   364,   786,   0,     32767,
-		366,   4,     0,     753,   581,   524,   270,   686,
-		0,     -382,  32767, -1189, 0,     747,   32767, 363,
-		32767, 32767, -1782, 32767, 28,    32767, 677,   452,
-		210,   0,     884,   882,   -258,  32767, -1099, -222,
-		32767, 32767, 32767, 32767, 373,   671,   32767, 311,
-		32767, 370,   32767, -831,  101,   32,    35,    36,
-		-1159, 930,   38,    39,    -148,  -148,  32767, 32767,
-		-150,  -803,  1185,  675,   32767, -152,  32767, 0,
-		633,   467,   -279,  827,   32767, 1273,  -410,  136,
-		32767, 527,   842,   397,   32767, 1149,  376,   45,
-		2221,  20,    0,     -421,  47,    925,   0,     363,
-		368,   -384,  0,     32767, -230,  32767, -532,  32767,
-		32767, 32767, 0,     32767, 634,   219,   -6,    397,
-		32767, 32767, 692,   385,   361,   483,   526,   32767,
-		0,     32767, 628,   728,   2167,  51,    892,   32767,
-		-326,  -595,  54,    55,    32767, 825,   0,     0,
-		933,   32767, 32767, 32767, 828,   32767, 32767, 883,
-		-144,  32767, 32767, 32767, 933,   0,     0,     209,
-		1580,  790,   0,     0,     32767, 32767, 32767, 730,
-		731,   32767, 58,    57,    457,   557,   32767, 59,
-		60,    0,     -1438, 32767, 1016,  32767, 1344,  683,
-		32767, 0,     32767, 32767, 32767, 32767, 32767, 558,
-		45,    32767, 0,     32767, 0,     0,     843,   0,
-		32767, 0,     503,   62,    488,   600,   -395,  -328,
-		69,    566,   -355,  1027,  -737,  -72,   -606,  32767,
-		74,    32767, 32767, 1144,  32767, -75,   32767, 884,
-		-144,  32767, 22,    598,   32767, 792,   32767, 32767,
-		32767, 32767, 32767, -336,  32767, 32767, 0,     45,
-		0,     32767, 658,   637,   78,    95,    -962,  0,
-		0,     32767, 256,   0,     -247,  -201,  32767, 32767,
-		447,   0,     0,     0,     32767, 445,   806,   860,
-		-39,   74,    32767, -6,    32767, 529,   32767, 700,
-		307,   179,   0,     893,   32767, 835,   0,     -29,
-		32767, 32767, 32767, 32767, -754,  32767, 32767, 32767,
-		-702,  -227,  -55,   0,     517,   -196,  32767, 784,
-		177,   0,     -1082, 597,   -166,  797,   32767, 32767,
-		613,   32767, 1211,  32767, -283,  126,   32767, 83,
-		526,   -1584, 533,   172,   950,   0,     0,     32767,
-		32767, -1767, -88,   32767, 87,    -1289, 773,   953,
-		1131,  0,     0,     32767, 1374,  0,     32767, 32767,
-		32767, 798,   32767, 0,     1547,  158,   613,   32767,
-		32767, -822,  32767, 88,    473,   474,   378,   89,
-		940,   659,   352,   -270,  0,     -1015, 477,   32767,
-		901,   91,    1068,  32767, 0,     0,     32767, 32767,
-		0,     32767, 461,   404,   32767, 46,    -65,   32767,
-		32767, 815,   822,   32767, 32767, 32767, 406,   925,
-		338,   -487,  0,     97,    438,   -464,  32767, 98,
-		0,     0,     1113,  0,     -416,  0,     32767, 0,
-		-35,   0,     180,   413,   32767, 32767, 0,     -219,
-		568,   175,   0,     0,     32767, 503,   0,     32767,
-		528,   32767, 32767, -464,  733,   140,   106,   101,
-		171,   32767, 109,   110,   597,   170,   32767, 113,
-		76,    103,   32767, 115,   559,   116,   32767, -213,
-		32767, 0,     597,   823,   32767, 801,   32767, 479,
-		803,   631,   723,   32767, 538,   -394,  468,   -200,
-		411,   29,    32767, 32767, -1347, 361,   32767, -458,
-		655,   32767, 32767, 32767, -791,  0,     32767, 540,
-		541,   32767, 32767, -14,   959,   32767, 0,     462,
-		32767, 802,   32767, 32767, 846,   734,   32767, 32767,
-		735,   32767, 32767, 32767, 32767, 32767, 0,     32767,
-		32767, -685,  32767, 32767, 32767, 32767, 32767, 32767,
-		0,     44,    32767, 0,     807,   131,   349,   0,
-		0,     7,     -94,   423,   0,     529,   32767, 32767,
-		32767, 286,   0,     32767, -145,  400,   281,   445,
-		32767, 122,   32767, -300,  600,   571,   769,   945,
-		518,   0,     461,   32767, -254,  32767, -423,  -534,
-		462,   396,   0,     886,   425,   -956,  809,   145,
-		573,   810,   0,     401,   0,     -1069, 0,     151,
-		1011,  0,     0,     81,    32767, -411,  0,     -687,
-		859,   451,   -1447, 132,   32767, 32767, 32767, 32767,
-		-154,  32,    32767, 32767, 32767, 32767, 0,     32767,
-		32767, 32767, 37,    408,   0,     811,   326,   32767,
-		0,     -374,  32767, -184,  741,   -376,  91,    134,
-		32767, 486,   135,   -40,   579,   373,   32767, 547,
-		32767, 32767, 32767, 32767, -259,  873,   0,     0,
-		0,     825,   -373,  0,     32767, 0,     0,     308,
-		340,   -373,  32767, 0,     0,     32767, -1259, 32767,
-		742,   32767, 643,   139,   144,   349,   -79,   147,
-		148,   32767, 149,   732,   425,   -219,  152,   -446,
-		556,   143,   32767, 155,   165,   -1314, 0,     888,
-		439,   32767, 0,     0,     0,     813,   405,   29,
-		32767, 6,     0,     0,     743,   32767, 1902,  158,
-		159,   32767, 381,   0,     -102,  196,   0,     769,
-		-419,  -596,  0,     782,   162,   32767, 32767, -580,
-		32767, 32767, 32767, 32767, 1126,  32767, 32767, 412,
-		32767, 814,   824,   32767, 32767, 0,     32767, 32767,
-		744,   32767, 32767, 746,   0,     1480,  167,   0,
-		1189,  32767, 32767, 168,   169,   32767, 0,     32767,
-		906,   32767, 32767, 32767, 32767, 32767, 32767, 601,
-		32767, 32767, -278,  0,     32767, 1261,  414,   32767,
-		32767, 32767, 32767, 375,   378,   589,   644,   750,
-		751,   937,   32767, 590,   32767, 591,   32767, 171,
-		172,   32767, 32767, 32767, 32767, 1195,  32767, 32767,
-		721,   0,     0,     -505,  -14,   6,     0,     0,
-		0,     1058,  -718,  99,    0,     372,   327,   32767,
-		729,   -166,  32767, 0,     173,   -939,  175,   592,
-		177,   576,   32767, 213,   179,   0,     0,     514,
-		620,   32767, 32767, 32767, 32767, 0,     32767, 32767,
-		958,   -240,  0,     -840,  32767, 379,   32767, 0,
-		0,     752,   673,   -432,  159,   -877,  32767, -416,
-		32767, 182,   -211,  0,     0,     594,   32767, 184,
-		-1070, 32767, 32767, 32767, 185,   0,     0,     32767,
-		710,   32767, 32767, 32767, 32767, 928,   32767, 32767,
-		0,     126,   942,   32767, 0,     0,     32767, 867,
-		697,   -355,  32767, 625,   0,     596,   32767, 597,
-		-243,  583,   32767, 0,     0,     0,     0,     0,
-		584,   650,   0,     32767, 515,   32767, 0,     892,
-		0,     0,     -271,  274,   32767, 418,   32767, 0,
-		32767, 32767, 32767, 440,   -1147, 32767, 0,     32767,
-		32767, 651,   652,   564,   32767, 32767, 32767, 0,
-		32767, 32767, 32767, 32767, 947,   -68,   32767, 688,
-		32767, 0,     0,     689,   915,   916,   0,     0,
-		-204,  225,   0,     0,     0,     0,     32767, -275,
-		370,   0,     599,   -402,  32767, 571,   0,     32767,
-		1470,  594,   32767, 772,   773,   1458,  0,     907,
-		1048,  32767, 128,   4,     32767, 0,     32767, 1880,
-		32767, 32767, 0,     0,     684,   32767, 0,     262,
-		32767, 32767, 32767, 32767, 757,   32767, 32767, 0,
-		196,   32767, -258,  -552,  -998,  0,     950,   774,
-		-35,   32767, 0,     32767, 0,     32767, 15,    32767,
-		0,     32767, 0,     27,    198,   760,   32767, 32767,
-		1204,  32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		620,   32767, 32767, 760,   761,   32767, 32767, 32767,
-		32767, 32767, 32767, 32767, 32767, 32767, 32767, 32767,
-		32767, 0,     0,     32767, 32767, 0,     32767, 0,
-		1195,  918,   32767, 32767, 32767, 32767, 0,     0,
-		32767, 32767, 32767, 32767, 903,   32767, 32767, 763,
-		764,   0,     32767, 0,     32767, 32767, 0,     32767,
-		833,   32767, 32767, 32767, 1132,  32767, 32767, 32767,
-		32767, 32767, 32767, 0,     450,   32767, 32767, 420,
-		32767, 32767, 32767, 32767, -68,   2,     0,     0,
-		1196,  0,     0,     0,     188,   189,   190,   191,
-		192,   600,   0,     -632,  -43,   196,   89,    489,
-		294,   1248,  32767, 1043,  32767, 492,   32767, 32767,
-		519,   0,     32767, 863,   32767, 32767, 32767, 0,
-		32767, 765,   493,   467,   0,     32767, 32767, 201,
-		32767, 432,   849,   32767, 279,   0,     0,     204,
-		834,   32767, 0,     32767, 1670,  32767, 0,     32767,
-		0,     32767, 32767, 32767, 919,   929,   32767, 0,
-		32767, -363,  0,     32767, 32767, 0,     434,   -56,
-		32767, 436,   0,     349,   0,     207,   208,   437,
-		32767, 0,     32767, -694,  -408,  32767, 0,     32767,
-		210,   206,   0,     653,   32767, 32767, 0,     402,
-		1105,  0,     32767, 693,   0,     0,     938,   32767,
-		32767, 32767, 438,   541,   131,   440,   871,   32767,
-		32767, 0,     32767, 279,   32767, 32767, 287,   212,
-		0,     0,     32767, 32767, 367,   32767, 696,   697,
-		32767, 0,     0,     0,     0,     32767, 32767, 32767,
-		32767, 32767, 32767, 0,     32767, 0,     -1321, 32767,
-		0,     176,   32767, 214,   218,   724,   234,   215,
-		222,   32767, 223,   -834,  943,   127,   32767, 496,
-		-100,  217,   0,     394,   32767, 229,   32767, 0,
-		0,     17,    421,   415,   447,   0,     32767, 686,
-		32767, 32767, 1845,  138,   32767, 32767, 872,   230,
-		32767, 601,   851,   471,   232,   603,   32767, 778,
-		698,   233,   32767, 699,   -439,  32767, 0,     32767,
-		32767, 32767, 663,   32767, 32767, 32767, 32767, -298,
-		449,   32767, -463,  687,   32767, 32767, 427,   32767,
-		0,     0,     0,     0,     0,     236,   193,   826,
-		238,   0,     108
-	};
-
-	const unsigned char *k = (const unsigned char *) key;
-	size_t		keylen = 8;
-	uint32		a = 0;
-	uint32		b = 0;
-
-	while (keylen--)
-	{
-		unsigned char c = *k++;
-
-		a = a * 257 + c;
-		b = b * 17 + c;
-	}
-	return h[a % 1923] + h[b % 1923];
-}
-
-/* Hash lookup information for recomposition */
-static const pg_unicode_recompinfo UnicodeRecompInfo =
-{
-	RecompInverseLookup,
-	Recomp_hash_func,
-	961
-};
diff --git a/src/include/common/unicode_norm_table.h b/src/include/common/unicode_norm_table.h
index 6c983135996..c468c85a9db 100644
--- a/src/include/common/unicode_norm_table.h
+++ b/src/include/common/unicode_norm_table.h
@@ -18,7 +18,6 @@
  */
 typedef struct
 {
-	uint32		codepoint;		/* Unicode codepoint */
 	uint8		comb_class;		/* combining class of character */
 	uint8		dec_size_flags; /* size and flags of decomposition code list */
 	uint16		dec_index;		/* index into UnicodeDecomp_codepoints, or the
@@ -35,9168 +34,54076 @@ typedef struct
 #define DECOMPOSITION_IS_INLINE(x) (((x)->dec_size_flags & DECOMP_INLINE) != 0)
 #define DECOMPOSITION_IS_COMPAT(x) (((x)->dec_size_flags & DECOMP_COMPAT) != 0)
 
-/* Table of Unicode codepoints and their decompositions */
-static const pg_unicode_decomposition UnicodeDecompMain[6843] =
+/* Table with basic data for decompositions. */
+static const pg_unicode_decomposition UnicodeDecompMain[3943] =
 {
-	{0x00A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x00A8, 0, 2 | DECOMP_COMPAT, 0},
-	{0x00AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x00AF, 0, 2 | DECOMP_COMPAT, 2},
-	{0x00B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x00B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x00B4, 0, 2 | DECOMP_COMPAT, 4},
-	{0x00B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
-	{0x00B8, 0, 2 | DECOMP_COMPAT, 6},
-	{0x00B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x00BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x00BC, 0, 3 | DECOMP_COMPAT, 8},
-	{0x00BD, 0, 3 | DECOMP_COMPAT, 11},
-	{0x00BE, 0, 3 | DECOMP_COMPAT, 14},
-	{0x00C0, 0, 2, 17},
-	{0x00C1, 0, 2, 19},
-	{0x00C2, 0, 2, 21},
-	{0x00C3, 0, 2, 23},
-	{0x00C4, 0, 2, 25},
-	{0x00C5, 0, 2, 27},
-	{0x00C7, 0, 2, 29},
-	{0x00C8, 0, 2, 31},
-	{0x00C9, 0, 2, 33},
-	{0x00CA, 0, 2, 35},
-	{0x00CB, 0, 2, 37},
-	{0x00CC, 0, 2, 39},
-	{0x00CD, 0, 2, 41},
-	{0x00CE, 0, 2, 43},
-	{0x00CF, 0, 2, 45},
-	{0x00D1, 0, 2, 47},
-	{0x00D2, 0, 2, 49},
-	{0x00D3, 0, 2, 51},
-	{0x00D4, 0, 2, 53},
-	{0x00D5, 0, 2, 55},
-	{0x00D6, 0, 2, 57},
-	{0x00D9, 0, 2, 59},
-	{0x00DA, 0, 2, 61},
-	{0x00DB, 0, 2, 63},
-	{0x00DC, 0, 2, 65},
-	{0x00DD, 0, 2, 67},
-	{0x00E0, 0, 2, 69},
-	{0x00E1, 0, 2, 71},
-	{0x00E2, 0, 2, 73},
-	{0x00E3, 0, 2, 75},
-	{0x00E4, 0, 2, 77},
-	{0x00E5, 0, 2, 79},
-	{0x00E7, 0, 2, 81},
-	{0x00E8, 0, 2, 83},
-	{0x00E9, 0, 2, 85},
-	{0x00EA, 0, 2, 87},
-	{0x00EB, 0, 2, 89},
-	{0x00EC, 0, 2, 91},
-	{0x00ED, 0, 2, 93},
-	{0x00EE, 0, 2, 95},
-	{0x00EF, 0, 2, 97},
-	{0x00F1, 0, 2, 99},
-	{0x00F2, 0, 2, 101},
-	{0x00F3, 0, 2, 103},
-	{0x00F4, 0, 2, 105},
-	{0x00F5, 0, 2, 107},
-	{0x00F6, 0, 2, 109},
-	{0x00F9, 0, 2, 111},
-	{0x00FA, 0, 2, 113},
-	{0x00FB, 0, 2, 115},
-	{0x00FC, 0, 2, 117},
-	{0x00FD, 0, 2, 119},
-	{0x00FF, 0, 2, 121},
-	{0x0100, 0, 2, 123},
-	{0x0101, 0, 2, 125},
-	{0x0102, 0, 2, 127},
-	{0x0103, 0, 2, 129},
-	{0x0104, 0, 2, 131},
-	{0x0105, 0, 2, 133},
-	{0x0106, 0, 2, 135},
-	{0x0107, 0, 2, 137},
-	{0x0108, 0, 2, 139},
-	{0x0109, 0, 2, 141},
-	{0x010A, 0, 2, 143},
-	{0x010B, 0, 2, 145},
-	{0x010C, 0, 2, 147},
-	{0x010D, 0, 2, 149},
-	{0x010E, 0, 2, 151},
-	{0x010F, 0, 2, 153},
-	{0x0112, 0, 2, 155},
-	{0x0113, 0, 2, 157},
-	{0x0114, 0, 2, 159},
-	{0x0115, 0, 2, 161},
-	{0x0116, 0, 2, 163},
-	{0x0117, 0, 2, 165},
-	{0x0118, 0, 2, 167},
-	{0x0119, 0, 2, 169},
-	{0x011A, 0, 2, 171},
-	{0x011B, 0, 2, 173},
-	{0x011C, 0, 2, 175},
-	{0x011D, 0, 2, 177},
-	{0x011E, 0, 2, 179},
-	{0x011F, 0, 2, 181},
-	{0x0120, 0, 2, 183},
-	{0x0121, 0, 2, 185},
-	{0x0122, 0, 2, 187},
-	{0x0123, 0, 2, 189},
-	{0x0124, 0, 2, 191},
-	{0x0125, 0, 2, 193},
-	{0x0128, 0, 2, 195},
-	{0x0129, 0, 2, 197},
-	{0x012A, 0, 2, 199},
-	{0x012B, 0, 2, 201},
-	{0x012C, 0, 2, 203},
-	{0x012D, 0, 2, 205},
-	{0x012E, 0, 2, 207},
-	{0x012F, 0, 2, 209},
-	{0x0130, 0, 2, 211},
-	{0x0132, 0, 2 | DECOMP_COMPAT, 213},
-	{0x0133, 0, 2 | DECOMP_COMPAT, 215},
-	{0x0134, 0, 2, 217},
-	{0x0135, 0, 2, 219},
-	{0x0136, 0, 2, 221},
-	{0x0137, 0, 2, 223},
-	{0x0139, 0, 2, 225},
-	{0x013A, 0, 2, 227},
-	{0x013B, 0, 2, 229},
-	{0x013C, 0, 2, 231},
-	{0x013D, 0, 2, 233},
-	{0x013E, 0, 2, 235},
-	{0x013F, 0, 2 | DECOMP_COMPAT, 237},
-	{0x0140, 0, 2 | DECOMP_COMPAT, 239},
-	{0x0143, 0, 2, 241},
-	{0x0144, 0, 2, 243},
-	{0x0145, 0, 2, 245},
-	{0x0146, 0, 2, 247},
-	{0x0147, 0, 2, 249},
-	{0x0148, 0, 2, 251},
-	{0x0149, 0, 2 | DECOMP_COMPAT, 253},
-	{0x014C, 0, 2, 255},
-	{0x014D, 0, 2, 257},
-	{0x014E, 0, 2, 259},
-	{0x014F, 0, 2, 261},
-	{0x0150, 0, 2, 263},
-	{0x0151, 0, 2, 265},
-	{0x0154, 0, 2, 267},
-	{0x0155, 0, 2, 269},
-	{0x0156, 0, 2, 271},
-	{0x0157, 0, 2, 273},
-	{0x0158, 0, 2, 275},
-	{0x0159, 0, 2, 277},
-	{0x015A, 0, 2, 279},
-	{0x015B, 0, 2, 281},
-	{0x015C, 0, 2, 283},
-	{0x015D, 0, 2, 285},
-	{0x015E, 0, 2, 287},
-	{0x015F, 0, 2, 289},
-	{0x0160, 0, 2, 291},
-	{0x0161, 0, 2, 293},
-	{0x0162, 0, 2, 295},
-	{0x0163, 0, 2, 297},
-	{0x0164, 0, 2, 299},
-	{0x0165, 0, 2, 301},
-	{0x0168, 0, 2, 303},
-	{0x0169, 0, 2, 305},
-	{0x016A, 0, 2, 307},
-	{0x016B, 0, 2, 309},
-	{0x016C, 0, 2, 311},
-	{0x016D, 0, 2, 313},
-	{0x016E, 0, 2, 315},
-	{0x016F, 0, 2, 317},
-	{0x0170, 0, 2, 319},
-	{0x0171, 0, 2, 321},
-	{0x0172, 0, 2, 323},
-	{0x0173, 0, 2, 325},
-	{0x0174, 0, 2, 327},
-	{0x0175, 0, 2, 329},
-	{0x0176, 0, 2, 331},
-	{0x0177, 0, 2, 333},
-	{0x0178, 0, 2, 335},
-	{0x0179, 0, 2, 337},
-	{0x017A, 0, 2, 339},
-	{0x017B, 0, 2, 341},
-	{0x017C, 0, 2, 343},
-	{0x017D, 0, 2, 345},
-	{0x017E, 0, 2, 347},
-	{0x017F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x01A0, 0, 2, 349},
-	{0x01A1, 0, 2, 351},
-	{0x01AF, 0, 2, 353},
-	{0x01B0, 0, 2, 355},
-	{0x01C4, 0, 2 | DECOMP_COMPAT, 357},
-	{0x01C5, 0, 2 | DECOMP_COMPAT, 359},
-	{0x01C6, 0, 2 | DECOMP_COMPAT, 361},
-	{0x01C7, 0, 2 | DECOMP_COMPAT, 363},
-	{0x01C8, 0, 2 | DECOMP_COMPAT, 365},
-	{0x01C9, 0, 2 | DECOMP_COMPAT, 367},
-	{0x01CA, 0, 2 | DECOMP_COMPAT, 369},
-	{0x01CB, 0, 2 | DECOMP_COMPAT, 371},
-	{0x01CC, 0, 2 | DECOMP_COMPAT, 373},
-	{0x01CD, 0, 2, 375},
-	{0x01CE, 0, 2, 377},
-	{0x01CF, 0, 2, 379},
-	{0x01D0, 0, 2, 381},
-	{0x01D1, 0, 2, 383},
-	{0x01D2, 0, 2, 385},
-	{0x01D3, 0, 2, 387},
-	{0x01D4, 0, 2, 389},
-	{0x01D5, 0, 2, 391},
-	{0x01D6, 0, 2, 393},
-	{0x01D7, 0, 2, 395},
-	{0x01D8, 0, 2, 397},
-	{0x01D9, 0, 2, 399},
-	{0x01DA, 0, 2, 401},
-	{0x01DB, 0, 2, 403},
-	{0x01DC, 0, 2, 405},
-	{0x01DE, 0, 2, 407},
-	{0x01DF, 0, 2, 409},
-	{0x01E0, 0, 2, 411},
-	{0x01E1, 0, 2, 413},
-	{0x01E2, 0, 2, 415},
-	{0x01E3, 0, 2, 417},
-	{0x01E6, 0, 2, 419},
-	{0x01E7, 0, 2, 421},
-	{0x01E8, 0, 2, 423},
-	{0x01E9, 0, 2, 425},
-	{0x01EA, 0, 2, 427},
-	{0x01EB, 0, 2, 429},
-	{0x01EC, 0, 2, 431},
-	{0x01ED, 0, 2, 433},
-	{0x01EE, 0, 2, 435},
-	{0x01EF, 0, 2, 437},
-	{0x01F0, 0, 2, 439},
-	{0x01F1, 0, 2 | DECOMP_COMPAT, 441},
-	{0x01F2, 0, 2 | DECOMP_COMPAT, 443},
-	{0x01F3, 0, 2 | DECOMP_COMPAT, 445},
-	{0x01F4, 0, 2, 447},
-	{0x01F5, 0, 2, 449},
-	{0x01F8, 0, 2, 451},
-	{0x01F9, 0, 2, 453},
-	{0x01FA, 0, 2, 455},
-	{0x01FB, 0, 2, 457},
-	{0x01FC, 0, 2, 459},
-	{0x01FD, 0, 2, 461},
-	{0x01FE, 0, 2, 463},
-	{0x01FF, 0, 2, 465},
-	{0x0200, 0, 2, 467},
-	{0x0201, 0, 2, 469},
-	{0x0202, 0, 2, 471},
-	{0x0203, 0, 2, 473},
-	{0x0204, 0, 2, 475},
-	{0x0205, 0, 2, 477},
-	{0x0206, 0, 2, 479},
-	{0x0207, 0, 2, 481},
-	{0x0208, 0, 2, 483},
-	{0x0209, 0, 2, 485},
-	{0x020A, 0, 2, 487},
-	{0x020B, 0, 2, 489},
-	{0x020C, 0, 2, 491},
-	{0x020D, 0, 2, 493},
-	{0x020E, 0, 2, 495},
-	{0x020F, 0, 2, 497},
-	{0x0210, 0, 2, 499},
-	{0x0211, 0, 2, 501},
-	{0x0212, 0, 2, 503},
-	{0x0213, 0, 2, 505},
-	{0x0214, 0, 2, 507},
-	{0x0215, 0, 2, 509},
-	{0x0216, 0, 2, 511},
-	{0x0217, 0, 2, 513},
-	{0x0218, 0, 2, 515},
-	{0x0219, 0, 2, 517},
-	{0x021A, 0, 2, 519},
-	{0x021B, 0, 2, 521},
-	{0x021E, 0, 2, 523},
-	{0x021F, 0, 2, 525},
-	{0x0226, 0, 2, 527},
-	{0x0227, 0, 2, 529},
-	{0x0228, 0, 2, 531},
-	{0x0229, 0, 2, 533},
-	{0x022A, 0, 2, 535},
-	{0x022B, 0, 2, 537},
-	{0x022C, 0, 2, 539},
-	{0x022D, 0, 2, 541},
-	{0x022E, 0, 2, 543},
-	{0x022F, 0, 2, 545},
-	{0x0230, 0, 2, 547},
-	{0x0231, 0, 2, 549},
-	{0x0232, 0, 2, 551},
-	{0x0233, 0, 2, 553},
-	{0x02B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x02B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0266},
-	{0x02B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x02B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x02B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0279},
-	{0x02B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027B},
-	{0x02B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0281},
-	{0x02B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x02B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x02D8, 0, 2 | DECOMP_COMPAT, 555},
-	{0x02D9, 0, 2 | DECOMP_COMPAT, 557},
-	{0x02DA, 0, 2 | DECOMP_COMPAT, 559},
-	{0x02DB, 0, 2 | DECOMP_COMPAT, 561},
-	{0x02DC, 0, 2 | DECOMP_COMPAT, 563},
-	{0x02DD, 0, 2 | DECOMP_COMPAT, 565},
-	{0x02E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0263},
-	{0x02E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x02E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x02E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x02E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0295},
-	{0x0300, 230, 0, 0},
-	{0x0301, 230, 0, 0},
-	{0x0302, 230, 0, 0},
-	{0x0303, 230, 0, 0},
-	{0x0304, 230, 0, 0},
-	{0x0305, 230, 0, 0},
-	{0x0306, 230, 0, 0},
-	{0x0307, 230, 0, 0},
-	{0x0308, 230, 0, 0},
-	{0x0309, 230, 0, 0},
-	{0x030A, 230, 0, 0},
-	{0x030B, 230, 0, 0},
-	{0x030C, 230, 0, 0},
-	{0x030D, 230, 0, 0},
-	{0x030E, 230, 0, 0},
-	{0x030F, 230, 0, 0},
-	{0x0310, 230, 0, 0},
-	{0x0311, 230, 0, 0},
-	{0x0312, 230, 0, 0},
-	{0x0313, 230, 0, 0},
-	{0x0314, 230, 0, 0},
-	{0x0315, 232, 0, 0},
-	{0x0316, 220, 0, 0},
-	{0x0317, 220, 0, 0},
-	{0x0318, 220, 0, 0},
-	{0x0319, 220, 0, 0},
-	{0x031A, 232, 0, 0},
-	{0x031B, 216, 0, 0},
-	{0x031C, 220, 0, 0},
-	{0x031D, 220, 0, 0},
-	{0x031E, 220, 0, 0},
-	{0x031F, 220, 0, 0},
-	{0x0320, 220, 0, 0},
-	{0x0321, 202, 0, 0},
-	{0x0322, 202, 0, 0},
-	{0x0323, 220, 0, 0},
-	{0x0324, 220, 0, 0},
-	{0x0325, 220, 0, 0},
-	{0x0326, 220, 0, 0},
-	{0x0327, 202, 0, 0},
-	{0x0328, 202, 0, 0},
-	{0x0329, 220, 0, 0},
-	{0x032A, 220, 0, 0},
-	{0x032B, 220, 0, 0},
-	{0x032C, 220, 0, 0},
-	{0x032D, 220, 0, 0},
-	{0x032E, 220, 0, 0},
-	{0x032F, 220, 0, 0},
-	{0x0330, 220, 0, 0},
-	{0x0331, 220, 0, 0},
-	{0x0332, 220, 0, 0},
-	{0x0333, 220, 0, 0},
-	{0x0334, 1, 0, 0},
-	{0x0335, 1, 0, 0},
-	{0x0336, 1, 0, 0},
-	{0x0337, 1, 0, 0},
-	{0x0338, 1, 0, 0},
-	{0x0339, 220, 0, 0},
-	{0x033A, 220, 0, 0},
-	{0x033B, 220, 0, 0},
-	{0x033C, 220, 0, 0},
-	{0x033D, 230, 0, 0},
-	{0x033E, 230, 0, 0},
-	{0x033F, 230, 0, 0},
-	{0x0340, 230, 1 | DECOMP_INLINE, 0x0300},
-	{0x0341, 230, 1 | DECOMP_INLINE, 0x0301},
-	{0x0342, 230, 0, 0},
-	{0x0343, 230, 1 | DECOMP_INLINE, 0x0313},
-	{0x0344, 230, 2 | DECOMP_NO_COMPOSE, 567},	/* non-starter decomposition */
-	{0x0345, 240, 0, 0},
-	{0x0346, 230, 0, 0},
-	{0x0347, 220, 0, 0},
-	{0x0348, 220, 0, 0},
-	{0x0349, 220, 0, 0},
-	{0x034A, 230, 0, 0},
-	{0x034B, 230, 0, 0},
-	{0x034C, 230, 0, 0},
-	{0x034D, 220, 0, 0},
-	{0x034E, 220, 0, 0},
-	{0x0350, 230, 0, 0},
-	{0x0351, 230, 0, 0},
-	{0x0352, 230, 0, 0},
-	{0x0353, 220, 0, 0},
-	{0x0354, 220, 0, 0},
-	{0x0355, 220, 0, 0},
-	{0x0356, 220, 0, 0},
-	{0x0357, 230, 0, 0},
-	{0x0358, 232, 0, 0},
-	{0x0359, 220, 0, 0},
-	{0x035A, 220, 0, 0},
-	{0x035B, 230, 0, 0},
-	{0x035C, 233, 0, 0},
-	{0x035D, 234, 0, 0},
-	{0x035E, 234, 0, 0},
-	{0x035F, 233, 0, 0},
-	{0x0360, 234, 0, 0},
-	{0x0361, 234, 0, 0},
-	{0x0362, 233, 0, 0},
-	{0x0363, 230, 0, 0},
-	{0x0364, 230, 0, 0},
-	{0x0365, 230, 0, 0},
-	{0x0366, 230, 0, 0},
-	{0x0367, 230, 0, 0},
-	{0x0368, 230, 0, 0},
-	{0x0369, 230, 0, 0},
-	{0x036A, 230, 0, 0},
-	{0x036B, 230, 0, 0},
-	{0x036C, 230, 0, 0},
-	{0x036D, 230, 0, 0},
-	{0x036E, 230, 0, 0},
-	{0x036F, 230, 0, 0},
-	{0x0374, 0, 1 | DECOMP_INLINE, 0x02B9},
-	{0x037A, 0, 2 | DECOMP_COMPAT, 569},
-	{0x037E, 0, 1 | DECOMP_INLINE, 0x003B},
-	{0x0384, 0, 2 | DECOMP_COMPAT, 571},
-	{0x0385, 0, 2, 573},
-	{0x0386, 0, 2, 575},
-	{0x0387, 0, 1 | DECOMP_INLINE, 0x00B7},
-	{0x0388, 0, 2, 577},
-	{0x0389, 0, 2, 579},
-	{0x038A, 0, 2, 581},
-	{0x038C, 0, 2, 583},
-	{0x038E, 0, 2, 585},
-	{0x038F, 0, 2, 587},
-	{0x0390, 0, 2, 589},
-	{0x03AA, 0, 2, 591},
-	{0x03AB, 0, 2, 593},
-	{0x03AC, 0, 2, 595},
-	{0x03AD, 0, 2, 597},
-	{0x03AE, 0, 2, 599},
-	{0x03AF, 0, 2, 601},
-	{0x03B0, 0, 2, 603},
-	{0x03CA, 0, 2, 605},
-	{0x03CB, 0, 2, 607},
-	{0x03CC, 0, 2, 609},
-	{0x03CD, 0, 2, 611},
-	{0x03CE, 0, 2, 613},
-	{0x03D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
-	{0x03D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
-	{0x03D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
-	{0x03D3, 0, 2, 615},
-	{0x03D4, 0, 2, 617},
-	{0x03D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
-	{0x03D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
-	{0x03F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
-	{0x03F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
-	{0x03F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
-	{0x03F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
-	{0x03F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
-	{0x03F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
-	{0x0400, 0, 2, 619},
-	{0x0401, 0, 2, 621},
-	{0x0403, 0, 2, 623},
-	{0x0407, 0, 2, 625},
-	{0x040C, 0, 2, 627},
-	{0x040D, 0, 2, 629},
-	{0x040E, 0, 2, 631},
-	{0x0419, 0, 2, 633},
-	{0x0439, 0, 2, 635},
-	{0x0450, 0, 2, 637},
-	{0x0451, 0, 2, 639},
-	{0x0453, 0, 2, 641},
-	{0x0457, 0, 2, 643},
-	{0x045C, 0, 2, 645},
-	{0x045D, 0, 2, 647},
-	{0x045E, 0, 2, 649},
-	{0x0476, 0, 2, 651},
-	{0x0477, 0, 2, 653},
-	{0x0483, 230, 0, 0},
-	{0x0484, 230, 0, 0},
-	{0x0485, 230, 0, 0},
-	{0x0486, 230, 0, 0},
-	{0x0487, 230, 0, 0},
-	{0x04C1, 0, 2, 655},
-	{0x04C2, 0, 2, 657},
-	{0x04D0, 0, 2, 659},
-	{0x04D1, 0, 2, 661},
-	{0x04D2, 0, 2, 663},
-	{0x04D3, 0, 2, 665},
-	{0x04D6, 0, 2, 667},
-	{0x04D7, 0, 2, 669},
-	{0x04DA, 0, 2, 671},
-	{0x04DB, 0, 2, 673},
-	{0x04DC, 0, 2, 675},
-	{0x04DD, 0, 2, 677},
-	{0x04DE, 0, 2, 679},
-	{0x04DF, 0, 2, 681},
-	{0x04E2, 0, 2, 683},
-	{0x04E3, 0, 2, 685},
-	{0x04E4, 0, 2, 687},
-	{0x04E5, 0, 2, 689},
-	{0x04E6, 0, 2, 691},
-	{0x04E7, 0, 2, 693},
-	{0x04EA, 0, 2, 695},
-	{0x04EB, 0, 2, 697},
-	{0x04EC, 0, 2, 699},
-	{0x04ED, 0, 2, 701},
-	{0x04EE, 0, 2, 703},
-	{0x04EF, 0, 2, 705},
-	{0x04F0, 0, 2, 707},
-	{0x04F1, 0, 2, 709},
-	{0x04F2, 0, 2, 711},
-	{0x04F3, 0, 2, 713},
-	{0x04F4, 0, 2, 715},
-	{0x04F5, 0, 2, 717},
-	{0x04F8, 0, 2, 719},
-	{0x04F9, 0, 2, 721},
-	{0x0587, 0, 2 | DECOMP_COMPAT, 723},
-	{0x0591, 220, 0, 0},
-	{0x0592, 230, 0, 0},
-	{0x0593, 230, 0, 0},
-	{0x0594, 230, 0, 0},
-	{0x0595, 230, 0, 0},
-	{0x0596, 220, 0, 0},
-	{0x0597, 230, 0, 0},
-	{0x0598, 230, 0, 0},
-	{0x0599, 230, 0, 0},
-	{0x059A, 222, 0, 0},
-	{0x059B, 220, 0, 0},
-	{0x059C, 230, 0, 0},
-	{0x059D, 230, 0, 0},
-	{0x059E, 230, 0, 0},
-	{0x059F, 230, 0, 0},
-	{0x05A0, 230, 0, 0},
-	{0x05A1, 230, 0, 0},
-	{0x05A2, 220, 0, 0},
-	{0x05A3, 220, 0, 0},
-	{0x05A4, 220, 0, 0},
-	{0x05A5, 220, 0, 0},
-	{0x05A6, 220, 0, 0},
-	{0x05A7, 220, 0, 0},
-	{0x05A8, 230, 0, 0},
-	{0x05A9, 230, 0, 0},
-	{0x05AA, 220, 0, 0},
-	{0x05AB, 230, 0, 0},
-	{0x05AC, 230, 0, 0},
-	{0x05AD, 222, 0, 0},
-	{0x05AE, 228, 0, 0},
-	{0x05AF, 230, 0, 0},
-	{0x05B0, 10, 0, 0},
-	{0x05B1, 11, 0, 0},
-	{0x05B2, 12, 0, 0},
-	{0x05B3, 13, 0, 0},
-	{0x05B4, 14, 0, 0},
-	{0x05B5, 15, 0, 0},
-	{0x05B6, 16, 0, 0},
-	{0x05B7, 17, 0, 0},
-	{0x05B8, 18, 0, 0},
-	{0x05B9, 19, 0, 0},
-	{0x05BA, 19, 0, 0},
-	{0x05BB, 20, 0, 0},
-	{0x05BC, 21, 0, 0},
-	{0x05BD, 22, 0, 0},
-	{0x05BF, 23, 0, 0},
-	{0x05C1, 24, 0, 0},
-	{0x05C2, 25, 0, 0},
-	{0x05C4, 230, 0, 0},
-	{0x05C5, 220, 0, 0},
-	{0x05C7, 18, 0, 0},
-	{0x0610, 230, 0, 0},
-	{0x0611, 230, 0, 0},
-	{0x0612, 230, 0, 0},
-	{0x0613, 230, 0, 0},
-	{0x0614, 230, 0, 0},
-	{0x0615, 230, 0, 0},
-	{0x0616, 230, 0, 0},
-	{0x0617, 230, 0, 0},
-	{0x0618, 30, 0, 0},
-	{0x0619, 31, 0, 0},
-	{0x061A, 32, 0, 0},
-	{0x0622, 0, 2, 725},
-	{0x0623, 0, 2, 727},
-	{0x0624, 0, 2, 729},
-	{0x0625, 0, 2, 731},
-	{0x0626, 0, 2, 733},
-	{0x064B, 27, 0, 0},
-	{0x064C, 28, 0, 0},
-	{0x064D, 29, 0, 0},
-	{0x064E, 30, 0, 0},
-	{0x064F, 31, 0, 0},
-	{0x0650, 32, 0, 0},
-	{0x0651, 33, 0, 0},
-	{0x0652, 34, 0, 0},
-	{0x0653, 230, 0, 0},
-	{0x0654, 230, 0, 0},
-	{0x0655, 220, 0, 0},
-	{0x0656, 220, 0, 0},
-	{0x0657, 230, 0, 0},
-	{0x0658, 230, 0, 0},
-	{0x0659, 230, 0, 0},
-	{0x065A, 230, 0, 0},
-	{0x065B, 230, 0, 0},
-	{0x065C, 220, 0, 0},
-	{0x065D, 230, 0, 0},
-	{0x065E, 230, 0, 0},
-	{0x065F, 220, 0, 0},
-	{0x0670, 35, 0, 0},
-	{0x0675, 0, 2 | DECOMP_COMPAT, 735},
-	{0x0676, 0, 2 | DECOMP_COMPAT, 737},
-	{0x0677, 0, 2 | DECOMP_COMPAT, 739},
-	{0x0678, 0, 2 | DECOMP_COMPAT, 741},
-	{0x06C0, 0, 2, 743},
-	{0x06C2, 0, 2, 745},
-	{0x06D3, 0, 2, 747},
-	{0x06D6, 230, 0, 0},
-	{0x06D7, 230, 0, 0},
-	{0x06D8, 230, 0, 0},
-	{0x06D9, 230, 0, 0},
-	{0x06DA, 230, 0, 0},
-	{0x06DB, 230, 0, 0},
-	{0x06DC, 230, 0, 0},
-	{0x06DF, 230, 0, 0},
-	{0x06E0, 230, 0, 0},
-	{0x06E1, 230, 0, 0},
-	{0x06E2, 230, 0, 0},
-	{0x06E3, 220, 0, 0},
-	{0x06E4, 230, 0, 0},
-	{0x06E7, 230, 0, 0},
-	{0x06E8, 230, 0, 0},
-	{0x06EA, 220, 0, 0},
-	{0x06EB, 230, 0, 0},
-	{0x06EC, 230, 0, 0},
-	{0x06ED, 220, 0, 0},
-	{0x0711, 36, 0, 0},
-	{0x0730, 230, 0, 0},
-	{0x0731, 220, 0, 0},
-	{0x0732, 230, 0, 0},
-	{0x0733, 230, 0, 0},
-	{0x0734, 220, 0, 0},
-	{0x0735, 230, 0, 0},
-	{0x0736, 230, 0, 0},
-	{0x0737, 220, 0, 0},
-	{0x0738, 220, 0, 0},
-	{0x0739, 220, 0, 0},
-	{0x073A, 230, 0, 0},
-	{0x073B, 220, 0, 0},
-	{0x073C, 220, 0, 0},
-	{0x073D, 230, 0, 0},
-	{0x073E, 220, 0, 0},
-	{0x073F, 230, 0, 0},
-	{0x0740, 230, 0, 0},
-	{0x0741, 230, 0, 0},
-	{0x0742, 220, 0, 0},
-	{0x0743, 230, 0, 0},
-	{0x0744, 220, 0, 0},
-	{0x0745, 230, 0, 0},
-	{0x0746, 220, 0, 0},
-	{0x0747, 230, 0, 0},
-	{0x0748, 220, 0, 0},
-	{0x0749, 230, 0, 0},
-	{0x074A, 230, 0, 0},
-	{0x07EB, 230, 0, 0},
-	{0x07EC, 230, 0, 0},
-	{0x07ED, 230, 0, 0},
-	{0x07EE, 230, 0, 0},
-	{0x07EF, 230, 0, 0},
-	{0x07F0, 230, 0, 0},
-	{0x07F1, 230, 0, 0},
-	{0x07F2, 220, 0, 0},
-	{0x07F3, 230, 0, 0},
-	{0x07FD, 220, 0, 0},
-	{0x0816, 230, 0, 0},
-	{0x0817, 230, 0, 0},
-	{0x0818, 230, 0, 0},
-	{0x0819, 230, 0, 0},
-	{0x081B, 230, 0, 0},
-	{0x081C, 230, 0, 0},
-	{0x081D, 230, 0, 0},
-	{0x081E, 230, 0, 0},
-	{0x081F, 230, 0, 0},
-	{0x0820, 230, 0, 0},
-	{0x0821, 230, 0, 0},
-	{0x0822, 230, 0, 0},
-	{0x0823, 230, 0, 0},
-	{0x0825, 230, 0, 0},
-	{0x0826, 230, 0, 0},
-	{0x0827, 230, 0, 0},
-	{0x0829, 230, 0, 0},
-	{0x082A, 230, 0, 0},
-	{0x082B, 230, 0, 0},
-	{0x082C, 230, 0, 0},
-	{0x082D, 230, 0, 0},
-	{0x0859, 220, 0, 0},
-	{0x085A, 220, 0, 0},
-	{0x085B, 220, 0, 0},
-	{0x0897, 230, 0, 0},
-	{0x0898, 230, 0, 0},
-	{0x0899, 220, 0, 0},
-	{0x089A, 220, 0, 0},
-	{0x089B, 220, 0, 0},
-	{0x089C, 230, 0, 0},
-	{0x089D, 230, 0, 0},
-	{0x089E, 230, 0, 0},
-	{0x089F, 230, 0, 0},
-	{0x08CA, 230, 0, 0},
-	{0x08CB, 230, 0, 0},
-	{0x08CC, 230, 0, 0},
-	{0x08CD, 230, 0, 0},
-	{0x08CE, 230, 0, 0},
-	{0x08CF, 220, 0, 0},
-	{0x08D0, 220, 0, 0},
-	{0x08D1, 220, 0, 0},
-	{0x08D2, 220, 0, 0},
-	{0x08D3, 220, 0, 0},
-	{0x08D4, 230, 0, 0},
-	{0x08D5, 230, 0, 0},
-	{0x08D6, 230, 0, 0},
-	{0x08D7, 230, 0, 0},
-	{0x08D8, 230, 0, 0},
-	{0x08D9, 230, 0, 0},
-	{0x08DA, 230, 0, 0},
-	{0x08DB, 230, 0, 0},
-	{0x08DC, 230, 0, 0},
-	{0x08DD, 230, 0, 0},
-	{0x08DE, 230, 0, 0},
-	{0x08DF, 230, 0, 0},
-	{0x08E0, 230, 0, 0},
-	{0x08E1, 230, 0, 0},
-	{0x08E3, 220, 0, 0},
-	{0x08E4, 230, 0, 0},
-	{0x08E5, 230, 0, 0},
-	{0x08E6, 220, 0, 0},
-	{0x08E7, 230, 0, 0},
-	{0x08E8, 230, 0, 0},
-	{0x08E9, 220, 0, 0},
-	{0x08EA, 230, 0, 0},
-	{0x08EB, 230, 0, 0},
-	{0x08EC, 230, 0, 0},
-	{0x08ED, 220, 0, 0},
-	{0x08EE, 220, 0, 0},
-	{0x08EF, 220, 0, 0},
-	{0x08F0, 27, 0, 0},
-	{0x08F1, 28, 0, 0},
-	{0x08F2, 29, 0, 0},
-	{0x08F3, 230, 0, 0},
-	{0x08F4, 230, 0, 0},
-	{0x08F5, 230, 0, 0},
-	{0x08F6, 220, 0, 0},
-	{0x08F7, 230, 0, 0},
-	{0x08F8, 230, 0, 0},
-	{0x08F9, 220, 0, 0},
-	{0x08FA, 220, 0, 0},
-	{0x08FB, 230, 0, 0},
-	{0x08FC, 230, 0, 0},
-	{0x08FD, 230, 0, 0},
-	{0x08FE, 230, 0, 0},
-	{0x08FF, 230, 0, 0},
-	{0x0929, 0, 2, 749},
-	{0x0931, 0, 2, 751},
-	{0x0934, 0, 2, 753},
-	{0x093C, 7, 0, 0},
-	{0x094D, 9, 0, 0},
-	{0x0951, 230, 0, 0},
-	{0x0952, 220, 0, 0},
-	{0x0953, 230, 0, 0},
-	{0x0954, 230, 0, 0},
-	{0x0958, 0, 2 | DECOMP_NO_COMPOSE, 755},	/* in exclusion list */
-	{0x0959, 0, 2 | DECOMP_NO_COMPOSE, 757},	/* in exclusion list */
-	{0x095A, 0, 2 | DECOMP_NO_COMPOSE, 759},	/* in exclusion list */
-	{0x095B, 0, 2 | DECOMP_NO_COMPOSE, 761},	/* in exclusion list */
-	{0x095C, 0, 2 | DECOMP_NO_COMPOSE, 763},	/* in exclusion list */
-	{0x095D, 0, 2 | DECOMP_NO_COMPOSE, 765},	/* in exclusion list */
-	{0x095E, 0, 2 | DECOMP_NO_COMPOSE, 767},	/* in exclusion list */
-	{0x095F, 0, 2 | DECOMP_NO_COMPOSE, 769},	/* in exclusion list */
-	{0x09BC, 7, 0, 0},
-	{0x09CB, 0, 2, 771},
-	{0x09CC, 0, 2, 773},
-	{0x09CD, 9, 0, 0},
-	{0x09DC, 0, 2 | DECOMP_NO_COMPOSE, 775},	/* in exclusion list */
-	{0x09DD, 0, 2 | DECOMP_NO_COMPOSE, 777},	/* in exclusion list */
-	{0x09DF, 0, 2 | DECOMP_NO_COMPOSE, 779},	/* in exclusion list */
-	{0x09FE, 230, 0, 0},
-	{0x0A33, 0, 2 | DECOMP_NO_COMPOSE, 781},	/* in exclusion list */
-	{0x0A36, 0, 2 | DECOMP_NO_COMPOSE, 783},	/* in exclusion list */
-	{0x0A3C, 7, 0, 0},
-	{0x0A4D, 9, 0, 0},
-	{0x0A59, 0, 2 | DECOMP_NO_COMPOSE, 785},	/* in exclusion list */
-	{0x0A5A, 0, 2 | DECOMP_NO_COMPOSE, 787},	/* in exclusion list */
-	{0x0A5B, 0, 2 | DECOMP_NO_COMPOSE, 789},	/* in exclusion list */
-	{0x0A5E, 0, 2 | DECOMP_NO_COMPOSE, 791},	/* in exclusion list */
-	{0x0ABC, 7, 0, 0},
-	{0x0ACD, 9, 0, 0},
-	{0x0B3C, 7, 0, 0},
-	{0x0B48, 0, 2, 793},
-	{0x0B4B, 0, 2, 795},
-	{0x0B4C, 0, 2, 797},
-	{0x0B4D, 9, 0, 0},
-	{0x0B5C, 0, 2 | DECOMP_NO_COMPOSE, 799},	/* in exclusion list */
-	{0x0B5D, 0, 2 | DECOMP_NO_COMPOSE, 801},	/* in exclusion list */
-	{0x0B94, 0, 2, 803},
-	{0x0BCA, 0, 2, 805},
-	{0x0BCB, 0, 2, 807},
-	{0x0BCC, 0, 2, 809},
-	{0x0BCD, 9, 0, 0},
-	{0x0C3C, 7, 0, 0},
-	{0x0C48, 0, 2, 811},
-	{0x0C4D, 9, 0, 0},
-	{0x0C55, 84, 0, 0},
-	{0x0C56, 91, 0, 0},
-	{0x0CBC, 7, 0, 0},
-	{0x0CC0, 0, 2, 813},
-	{0x0CC7, 0, 2, 815},
-	{0x0CC8, 0, 2, 817},
-	{0x0CCA, 0, 2, 819},
-	{0x0CCB, 0, 2, 821},
-	{0x0CCD, 9, 0, 0},
-	{0x0D3B, 9, 0, 0},
-	{0x0D3C, 9, 0, 0},
-	{0x0D4A, 0, 2, 823},
-	{0x0D4B, 0, 2, 825},
-	{0x0D4C, 0, 2, 827},
-	{0x0D4D, 9, 0, 0},
-	{0x0DCA, 9, 0, 0},
-	{0x0DDA, 0, 2, 829},
-	{0x0DDC, 0, 2, 831},
-	{0x0DDD, 0, 2, 833},
-	{0x0DDE, 0, 2, 835},
-	{0x0E33, 0, 2 | DECOMP_COMPAT, 837},
-	{0x0E38, 103, 0, 0},
-	{0x0E39, 103, 0, 0},
-	{0x0E3A, 9, 0, 0},
-	{0x0E48, 107, 0, 0},
-	{0x0E49, 107, 0, 0},
-	{0x0E4A, 107, 0, 0},
-	{0x0E4B, 107, 0, 0},
-	{0x0EB3, 0, 2 | DECOMP_COMPAT, 839},
-	{0x0EB8, 118, 0, 0},
-	{0x0EB9, 118, 0, 0},
-	{0x0EBA, 9, 0, 0},
-	{0x0EC8, 122, 0, 0},
-	{0x0EC9, 122, 0, 0},
-	{0x0ECA, 122, 0, 0},
-	{0x0ECB, 122, 0, 0},
-	{0x0EDC, 0, 2 | DECOMP_COMPAT, 841},
-	{0x0EDD, 0, 2 | DECOMP_COMPAT, 843},
-	{0x0F0C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0F0B},
-	{0x0F18, 220, 0, 0},
-	{0x0F19, 220, 0, 0},
-	{0x0F35, 220, 0, 0},
-	{0x0F37, 220, 0, 0},
-	{0x0F39, 216, 0, 0},
-	{0x0F43, 0, 2 | DECOMP_NO_COMPOSE, 845},	/* in exclusion list */
-	{0x0F4D, 0, 2 | DECOMP_NO_COMPOSE, 847},	/* in exclusion list */
-	{0x0F52, 0, 2 | DECOMP_NO_COMPOSE, 849},	/* in exclusion list */
-	{0x0F57, 0, 2 | DECOMP_NO_COMPOSE, 851},	/* in exclusion list */
-	{0x0F5C, 0, 2 | DECOMP_NO_COMPOSE, 853},	/* in exclusion list */
-	{0x0F69, 0, 2 | DECOMP_NO_COMPOSE, 855},	/* in exclusion list */
-	{0x0F71, 129, 0, 0},
-	{0x0F72, 130, 0, 0},
-	{0x0F73, 0, 2 | DECOMP_NO_COMPOSE, 857},	/* non-starter decomposition */
-	{0x0F74, 132, 0, 0},
-	{0x0F75, 0, 2 | DECOMP_NO_COMPOSE, 859},	/* non-starter decomposition */
-	{0x0F76, 0, 2 | DECOMP_NO_COMPOSE, 861},	/* in exclusion list */
-	{0x0F77, 0, 2 | DECOMP_COMPAT, 863},
-	{0x0F78, 0, 2 | DECOMP_NO_COMPOSE, 865},	/* in exclusion list */
-	{0x0F79, 0, 2 | DECOMP_COMPAT, 867},
-	{0x0F7A, 130, 0, 0},
-	{0x0F7B, 130, 0, 0},
-	{0x0F7C, 130, 0, 0},
-	{0x0F7D, 130, 0, 0},
-	{0x0F80, 130, 0, 0},
-	{0x0F81, 0, 2 | DECOMP_NO_COMPOSE, 869},	/* non-starter decomposition */
-	{0x0F82, 230, 0, 0},
-	{0x0F83, 230, 0, 0},
-	{0x0F84, 9, 0, 0},
-	{0x0F86, 230, 0, 0},
-	{0x0F87, 230, 0, 0},
-	{0x0F93, 0, 2 | DECOMP_NO_COMPOSE, 871},	/* in exclusion list */
-	{0x0F9D, 0, 2 | DECOMP_NO_COMPOSE, 873},	/* in exclusion list */
-	{0x0FA2, 0, 2 | DECOMP_NO_COMPOSE, 875},	/* in exclusion list */
-	{0x0FA7, 0, 2 | DECOMP_NO_COMPOSE, 877},	/* in exclusion list */
-	{0x0FAC, 0, 2 | DECOMP_NO_COMPOSE, 879},	/* in exclusion list */
-	{0x0FB9, 0, 2 | DECOMP_NO_COMPOSE, 881},	/* in exclusion list */
-	{0x0FC6, 220, 0, 0},
-	{0x1026, 0, 2, 883},
-	{0x1037, 7, 0, 0},
-	{0x1039, 9, 0, 0},
-	{0x103A, 9, 0, 0},
-	{0x108D, 220, 0, 0},
-	{0x10FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x10DC},
-	{0x135D, 230, 0, 0},
-	{0x135E, 230, 0, 0},
-	{0x135F, 230, 0, 0},
-	{0x1714, 9, 0, 0},
-	{0x1715, 9, 0, 0},
-	{0x1734, 9, 0, 0},
-	{0x17D2, 9, 0, 0},
-	{0x17DD, 230, 0, 0},
-	{0x18A9, 228, 0, 0},
-	{0x1939, 222, 0, 0},
-	{0x193A, 230, 0, 0},
-	{0x193B, 220, 0, 0},
-	{0x1A17, 230, 0, 0},
-	{0x1A18, 220, 0, 0},
-	{0x1A60, 9, 0, 0},
-	{0x1A75, 230, 0, 0},
-	{0x1A76, 230, 0, 0},
-	{0x1A77, 230, 0, 0},
-	{0x1A78, 230, 0, 0},
-	{0x1A79, 230, 0, 0},
-	{0x1A7A, 230, 0, 0},
-	{0x1A7B, 230, 0, 0},
-	{0x1A7C, 230, 0, 0},
-	{0x1A7F, 220, 0, 0},
-	{0x1AB0, 230, 0, 0},
-	{0x1AB1, 230, 0, 0},
-	{0x1AB2, 230, 0, 0},
-	{0x1AB3, 230, 0, 0},
-	{0x1AB4, 230, 0, 0},
-	{0x1AB5, 220, 0, 0},
-	{0x1AB6, 220, 0, 0},
-	{0x1AB7, 220, 0, 0},
-	{0x1AB8, 220, 0, 0},
-	{0x1AB9, 220, 0, 0},
-	{0x1ABA, 220, 0, 0},
-	{0x1ABB, 230, 0, 0},
-	{0x1ABC, 230, 0, 0},
-	{0x1ABD, 220, 0, 0},
-	{0x1ABF, 220, 0, 0},
-	{0x1AC0, 220, 0, 0},
-	{0x1AC1, 230, 0, 0},
-	{0x1AC2, 230, 0, 0},
-	{0x1AC3, 220, 0, 0},
-	{0x1AC4, 220, 0, 0},
-	{0x1AC5, 230, 0, 0},
-	{0x1AC6, 230, 0, 0},
-	{0x1AC7, 230, 0, 0},
-	{0x1AC8, 230, 0, 0},
-	{0x1AC9, 230, 0, 0},
-	{0x1ACA, 220, 0, 0},
-	{0x1ACB, 230, 0, 0},
-	{0x1ACC, 230, 0, 0},
-	{0x1ACD, 230, 0, 0},
-	{0x1ACE, 230, 0, 0},
-	{0x1B06, 0, 2, 885},
-	{0x1B08, 0, 2, 887},
-	{0x1B0A, 0, 2, 889},
-	{0x1B0C, 0, 2, 891},
-	{0x1B0E, 0, 2, 893},
-	{0x1B12, 0, 2, 895},
-	{0x1B34, 7, 0, 0},
-	{0x1B3B, 0, 2, 897},
-	{0x1B3D, 0, 2, 899},
-	{0x1B40, 0, 2, 901},
-	{0x1B41, 0, 2, 903},
-	{0x1B43, 0, 2, 905},
-	{0x1B44, 9, 0, 0},
-	{0x1B6B, 230, 0, 0},
-	{0x1B6C, 220, 0, 0},
-	{0x1B6D, 230, 0, 0},
-	{0x1B6E, 230, 0, 0},
-	{0x1B6F, 230, 0, 0},
-	{0x1B70, 230, 0, 0},
-	{0x1B71, 230, 0, 0},
-	{0x1B72, 230, 0, 0},
-	{0x1B73, 230, 0, 0},
-	{0x1BAA, 9, 0, 0},
-	{0x1BAB, 9, 0, 0},
-	{0x1BE6, 7, 0, 0},
-	{0x1BF2, 9, 0, 0},
-	{0x1BF3, 9, 0, 0},
-	{0x1C37, 7, 0, 0},
-	{0x1CD0, 230, 0, 0},
-	{0x1CD1, 230, 0, 0},
-	{0x1CD2, 230, 0, 0},
-	{0x1CD4, 1, 0, 0},
-	{0x1CD5, 220, 0, 0},
-	{0x1CD6, 220, 0, 0},
-	{0x1CD7, 220, 0, 0},
-	{0x1CD8, 220, 0, 0},
-	{0x1CD9, 220, 0, 0},
-	{0x1CDA, 230, 0, 0},
-	{0x1CDB, 230, 0, 0},
-	{0x1CDC, 220, 0, 0},
-	{0x1CDD, 220, 0, 0},
-	{0x1CDE, 220, 0, 0},
-	{0x1CDF, 220, 0, 0},
-	{0x1CE0, 230, 0, 0},
-	{0x1CE2, 1, 0, 0},
-	{0x1CE3, 1, 0, 0},
-	{0x1CE4, 1, 0, 0},
-	{0x1CE5, 1, 0, 0},
-	{0x1CE6, 1, 0, 0},
-	{0x1CE7, 1, 0, 0},
-	{0x1CE8, 1, 0, 0},
-	{0x1CED, 220, 0, 0},
-	{0x1CF4, 230, 0, 0},
-	{0x1CF8, 230, 0, 0},
-	{0x1CF9, 230, 0, 0},
-	{0x1D2C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D2D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00C6},
-	{0x1D2E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x018E},
-	{0x1D33, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D38, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D3A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D3C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D3D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0222},
-	{0x1D3E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D3F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D40, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D41, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D43, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D44, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0250},
-	{0x1D45, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0251},
-	{0x1D46, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D02},
-	{0x1D47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D48, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D4A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0259},
-	{0x1D4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025B},
-	{0x1D4C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025C},
-	{0x1D4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x014B},
-	{0x1D52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D53, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0254},
-	{0x1D54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D16},
-	{0x1D55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D17},
-	{0x1D56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D1D},
-	{0x1D5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026F},
-	{0x1D5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D25},
-	{0x1D5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
-	{0x1D5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
-	{0x1D5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
-	{0x1D60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
-	{0x1D61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
-	{0x1D62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
-	{0x1D67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
-	{0x1D68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
-	{0x1D69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
-	{0x1D6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
-	{0x1D78, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043D},
-	{0x1D9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0252},
-	{0x1D9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0255},
-	{0x1D9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00F0},
-	{0x1D9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025C},
-	{0x1DA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1DA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025F},
-	{0x1DA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0261},
-	{0x1DA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0265},
-	{0x1DA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0268},
-	{0x1DA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0269},
-	{0x1DA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026A},
-	{0x1DA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D7B},
-	{0x1DA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029D},
-	{0x1DA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026D},
-	{0x1DAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D85},
-	{0x1DAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029F},
-	{0x1DAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0271},
-	{0x1DAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0270},
-	{0x1DAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0272},
-	{0x1DAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0273},
-	{0x1DB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0274},
-	{0x1DB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0275},
-	{0x1DB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0278},
-	{0x1DB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0282},
-	{0x1DB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0283},
-	{0x1DB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01AB},
-	{0x1DB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0289},
-	{0x1DB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028A},
-	{0x1DB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D1C},
-	{0x1DB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028B},
-	{0x1DBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028C},
-	{0x1DBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1DBC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0290},
-	{0x1DBD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0291},
-	{0x1DBE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0292},
-	{0x1DBF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
-	{0x1DC0, 230, 0, 0},
-	{0x1DC1, 230, 0, 0},
-	{0x1DC2, 220, 0, 0},
-	{0x1DC3, 230, 0, 0},
-	{0x1DC4, 230, 0, 0},
-	{0x1DC5, 230, 0, 0},
-	{0x1DC6, 230, 0, 0},
-	{0x1DC7, 230, 0, 0},
-	{0x1DC8, 230, 0, 0},
-	{0x1DC9, 230, 0, 0},
-	{0x1DCA, 220, 0, 0},
-	{0x1DCB, 230, 0, 0},
-	{0x1DCC, 230, 0, 0},
-	{0x1DCD, 234, 0, 0},
-	{0x1DCE, 214, 0, 0},
-	{0x1DCF, 220, 0, 0},
-	{0x1DD0, 202, 0, 0},
-	{0x1DD1, 230, 0, 0},
-	{0x1DD2, 230, 0, 0},
-	{0x1DD3, 230, 0, 0},
-	{0x1DD4, 230, 0, 0},
-	{0x1DD5, 230, 0, 0},
-	{0x1DD6, 230, 0, 0},
-	{0x1DD7, 230, 0, 0},
-	{0x1DD8, 230, 0, 0},
-	{0x1DD9, 230, 0, 0},
-	{0x1DDA, 230, 0, 0},
-	{0x1DDB, 230, 0, 0},
-	{0x1DDC, 230, 0, 0},
-	{0x1DDD, 230, 0, 0},
-	{0x1DDE, 230, 0, 0},
-	{0x1DDF, 230, 0, 0},
-	{0x1DE0, 230, 0, 0},
-	{0x1DE1, 230, 0, 0},
-	{0x1DE2, 230, 0, 0},
-	{0x1DE3, 230, 0, 0},
-	{0x1DE4, 230, 0, 0},
-	{0x1DE5, 230, 0, 0},
-	{0x1DE6, 230, 0, 0},
-	{0x1DE7, 230, 0, 0},
-	{0x1DE8, 230, 0, 0},
-	{0x1DE9, 230, 0, 0},
-	{0x1DEA, 230, 0, 0},
-	{0x1DEB, 230, 0, 0},
-	{0x1DEC, 230, 0, 0},
-	{0x1DED, 230, 0, 0},
-	{0x1DEE, 230, 0, 0},
-	{0x1DEF, 230, 0, 0},
-	{0x1DF0, 230, 0, 0},
-	{0x1DF1, 230, 0, 0},
-	{0x1DF2, 230, 0, 0},
-	{0x1DF3, 230, 0, 0},
-	{0x1DF4, 230, 0, 0},
-	{0x1DF5, 230, 0, 0},
-	{0x1DF6, 232, 0, 0},
-	{0x1DF7, 228, 0, 0},
-	{0x1DF8, 228, 0, 0},
-	{0x1DF9, 220, 0, 0},
-	{0x1DFA, 218, 0, 0},
-	{0x1DFB, 230, 0, 0},
-	{0x1DFC, 233, 0, 0},
-	{0x1DFD, 220, 0, 0},
-	{0x1DFE, 230, 0, 0},
-	{0x1DFF, 220, 0, 0},
-	{0x1E00, 0, 2, 907},
-	{0x1E01, 0, 2, 909},
-	{0x1E02, 0, 2, 911},
-	{0x1E03, 0, 2, 913},
-	{0x1E04, 0, 2, 915},
-	{0x1E05, 0, 2, 917},
-	{0x1E06, 0, 2, 919},
-	{0x1E07, 0, 2, 921},
-	{0x1E08, 0, 2, 923},
-	{0x1E09, 0, 2, 925},
-	{0x1E0A, 0, 2, 927},
-	{0x1E0B, 0, 2, 929},
-	{0x1E0C, 0, 2, 931},
-	{0x1E0D, 0, 2, 933},
-	{0x1E0E, 0, 2, 935},
-	{0x1E0F, 0, 2, 937},
-	{0x1E10, 0, 2, 939},
-	{0x1E11, 0, 2, 941},
-	{0x1E12, 0, 2, 943},
-	{0x1E13, 0, 2, 945},
-	{0x1E14, 0, 2, 947},
-	{0x1E15, 0, 2, 949},
-	{0x1E16, 0, 2, 951},
-	{0x1E17, 0, 2, 953},
-	{0x1E18, 0, 2, 955},
-	{0x1E19, 0, 2, 957},
-	{0x1E1A, 0, 2, 959},
-	{0x1E1B, 0, 2, 961},
-	{0x1E1C, 0, 2, 963},
-	{0x1E1D, 0, 2, 965},
-	{0x1E1E, 0, 2, 967},
-	{0x1E1F, 0, 2, 969},
-	{0x1E20, 0, 2, 971},
-	{0x1E21, 0, 2, 973},
-	{0x1E22, 0, 2, 975},
-	{0x1E23, 0, 2, 977},
-	{0x1E24, 0, 2, 979},
-	{0x1E25, 0, 2, 981},
-	{0x1E26, 0, 2, 983},
-	{0x1E27, 0, 2, 985},
-	{0x1E28, 0, 2, 987},
-	{0x1E29, 0, 2, 989},
-	{0x1E2A, 0, 2, 991},
-	{0x1E2B, 0, 2, 993},
-	{0x1E2C, 0, 2, 995},
-	{0x1E2D, 0, 2, 997},
-	{0x1E2E, 0, 2, 999},
-	{0x1E2F, 0, 2, 1001},
-	{0x1E30, 0, 2, 1003},
-	{0x1E31, 0, 2, 1005},
-	{0x1E32, 0, 2, 1007},
-	{0x1E33, 0, 2, 1009},
-	{0x1E34, 0, 2, 1011},
-	{0x1E35, 0, 2, 1013},
-	{0x1E36, 0, 2, 1015},
-	{0x1E37, 0, 2, 1017},
-	{0x1E38, 0, 2, 1019},
-	{0x1E39, 0, 2, 1021},
-	{0x1E3A, 0, 2, 1023},
-	{0x1E3B, 0, 2, 1025},
-	{0x1E3C, 0, 2, 1027},
-	{0x1E3D, 0, 2, 1029},
-	{0x1E3E, 0, 2, 1031},
-	{0x1E3F, 0, 2, 1033},
-	{0x1E40, 0, 2, 1035},
-	{0x1E41, 0, 2, 1037},
-	{0x1E42, 0, 2, 1039},
-	{0x1E43, 0, 2, 1041},
-	{0x1E44, 0, 2, 1043},
-	{0x1E45, 0, 2, 1045},
-	{0x1E46, 0, 2, 1047},
-	{0x1E47, 0, 2, 1049},
-	{0x1E48, 0, 2, 1051},
-	{0x1E49, 0, 2, 1053},
-	{0x1E4A, 0, 2, 1055},
-	{0x1E4B, 0, 2, 1057},
-	{0x1E4C, 0, 2, 1059},
-	{0x1E4D, 0, 2, 1061},
-	{0x1E4E, 0, 2, 1063},
-	{0x1E4F, 0, 2, 1065},
-	{0x1E50, 0, 2, 1067},
-	{0x1E51, 0, 2, 1069},
-	{0x1E52, 0, 2, 1071},
-	{0x1E53, 0, 2, 1073},
-	{0x1E54, 0, 2, 1075},
-	{0x1E55, 0, 2, 1077},
-	{0x1E56, 0, 2, 1079},
-	{0x1E57, 0, 2, 1081},
-	{0x1E58, 0, 2, 1083},
-	{0x1E59, 0, 2, 1085},
-	{0x1E5A, 0, 2, 1087},
-	{0x1E5B, 0, 2, 1089},
-	{0x1E5C, 0, 2, 1091},
-	{0x1E5D, 0, 2, 1093},
-	{0x1E5E, 0, 2, 1095},
-	{0x1E5F, 0, 2, 1097},
-	{0x1E60, 0, 2, 1099},
-	{0x1E61, 0, 2, 1101},
-	{0x1E62, 0, 2, 1103},
-	{0x1E63, 0, 2, 1105},
-	{0x1E64, 0, 2, 1107},
-	{0x1E65, 0, 2, 1109},
-	{0x1E66, 0, 2, 1111},
-	{0x1E67, 0, 2, 1113},
-	{0x1E68, 0, 2, 1115},
-	{0x1E69, 0, 2, 1117},
-	{0x1E6A, 0, 2, 1119},
-	{0x1E6B, 0, 2, 1121},
-	{0x1E6C, 0, 2, 1123},
-	{0x1E6D, 0, 2, 1125},
-	{0x1E6E, 0, 2, 1127},
-	{0x1E6F, 0, 2, 1129},
-	{0x1E70, 0, 2, 1131},
-	{0x1E71, 0, 2, 1133},
-	{0x1E72, 0, 2, 1135},
-	{0x1E73, 0, 2, 1137},
-	{0x1E74, 0, 2, 1139},
-	{0x1E75, 0, 2, 1141},
-	{0x1E76, 0, 2, 1143},
-	{0x1E77, 0, 2, 1145},
-	{0x1E78, 0, 2, 1147},
-	{0x1E79, 0, 2, 1149},
-	{0x1E7A, 0, 2, 1151},
-	{0x1E7B, 0, 2, 1153},
-	{0x1E7C, 0, 2, 1155},
-	{0x1E7D, 0, 2, 1157},
-	{0x1E7E, 0, 2, 1159},
-	{0x1E7F, 0, 2, 1161},
-	{0x1E80, 0, 2, 1163},
-	{0x1E81, 0, 2, 1165},
-	{0x1E82, 0, 2, 1167},
-	{0x1E83, 0, 2, 1169},
-	{0x1E84, 0, 2, 1171},
-	{0x1E85, 0, 2, 1173},
-	{0x1E86, 0, 2, 1175},
-	{0x1E87, 0, 2, 1177},
-	{0x1E88, 0, 2, 1179},
-	{0x1E89, 0, 2, 1181},
-	{0x1E8A, 0, 2, 1183},
-	{0x1E8B, 0, 2, 1185},
-	{0x1E8C, 0, 2, 1187},
-	{0x1E8D, 0, 2, 1189},
-	{0x1E8E, 0, 2, 1191},
-	{0x1E8F, 0, 2, 1193},
-	{0x1E90, 0, 2, 1195},
-	{0x1E91, 0, 2, 1197},
-	{0x1E92, 0, 2, 1199},
-	{0x1E93, 0, 2, 1201},
-	{0x1E94, 0, 2, 1203},
-	{0x1E95, 0, 2, 1205},
-	{0x1E96, 0, 2, 1207},
-	{0x1E97, 0, 2, 1209},
-	{0x1E98, 0, 2, 1211},
-	{0x1E99, 0, 2, 1213},
-	{0x1E9A, 0, 2 | DECOMP_COMPAT, 1215},
-	{0x1E9B, 0, 2, 1217},
-	{0x1EA0, 0, 2, 1219},
-	{0x1EA1, 0, 2, 1221},
-	{0x1EA2, 0, 2, 1223},
-	{0x1EA3, 0, 2, 1225},
-	{0x1EA4, 0, 2, 1227},
-	{0x1EA5, 0, 2, 1229},
-	{0x1EA6, 0, 2, 1231},
-	{0x1EA7, 0, 2, 1233},
-	{0x1EA8, 0, 2, 1235},
-	{0x1EA9, 0, 2, 1237},
-	{0x1EAA, 0, 2, 1239},
-	{0x1EAB, 0, 2, 1241},
-	{0x1EAC, 0, 2, 1243},
-	{0x1EAD, 0, 2, 1245},
-	{0x1EAE, 0, 2, 1247},
-	{0x1EAF, 0, 2, 1249},
-	{0x1EB0, 0, 2, 1251},
-	{0x1EB1, 0, 2, 1253},
-	{0x1EB2, 0, 2, 1255},
-	{0x1EB3, 0, 2, 1257},
-	{0x1EB4, 0, 2, 1259},
-	{0x1EB5, 0, 2, 1261},
-	{0x1EB6, 0, 2, 1263},
-	{0x1EB7, 0, 2, 1265},
-	{0x1EB8, 0, 2, 1267},
-	{0x1EB9, 0, 2, 1269},
-	{0x1EBA, 0, 2, 1271},
-	{0x1EBB, 0, 2, 1273},
-	{0x1EBC, 0, 2, 1275},
-	{0x1EBD, 0, 2, 1277},
-	{0x1EBE, 0, 2, 1279},
-	{0x1EBF, 0, 2, 1281},
-	{0x1EC0, 0, 2, 1283},
-	{0x1EC1, 0, 2, 1285},
-	{0x1EC2, 0, 2, 1287},
-	{0x1EC3, 0, 2, 1289},
-	{0x1EC4, 0, 2, 1291},
-	{0x1EC5, 0, 2, 1293},
-	{0x1EC6, 0, 2, 1295},
-	{0x1EC7, 0, 2, 1297},
-	{0x1EC8, 0, 2, 1299},
-	{0x1EC9, 0, 2, 1301},
-	{0x1ECA, 0, 2, 1303},
-	{0x1ECB, 0, 2, 1305},
-	{0x1ECC, 0, 2, 1307},
-	{0x1ECD, 0, 2, 1309},
-	{0x1ECE, 0, 2, 1311},
-	{0x1ECF, 0, 2, 1313},
-	{0x1ED0, 0, 2, 1315},
-	{0x1ED1, 0, 2, 1317},
-	{0x1ED2, 0, 2, 1319},
-	{0x1ED3, 0, 2, 1321},
-	{0x1ED4, 0, 2, 1323},
-	{0x1ED5, 0, 2, 1325},
-	{0x1ED6, 0, 2, 1327},
-	{0x1ED7, 0, 2, 1329},
-	{0x1ED8, 0, 2, 1331},
-	{0x1ED9, 0, 2, 1333},
-	{0x1EDA, 0, 2, 1335},
-	{0x1EDB, 0, 2, 1337},
-	{0x1EDC, 0, 2, 1339},
-	{0x1EDD, 0, 2, 1341},
-	{0x1EDE, 0, 2, 1343},
-	{0x1EDF, 0, 2, 1345},
-	{0x1EE0, 0, 2, 1347},
-	{0x1EE1, 0, 2, 1349},
-	{0x1EE2, 0, 2, 1351},
-	{0x1EE3, 0, 2, 1353},
-	{0x1EE4, 0, 2, 1355},
-	{0x1EE5, 0, 2, 1357},
-	{0x1EE6, 0, 2, 1359},
-	{0x1EE7, 0, 2, 1361},
-	{0x1EE8, 0, 2, 1363},
-	{0x1EE9, 0, 2, 1365},
-	{0x1EEA, 0, 2, 1367},
-	{0x1EEB, 0, 2, 1369},
-	{0x1EEC, 0, 2, 1371},
-	{0x1EED, 0, 2, 1373},
-	{0x1EEE, 0, 2, 1375},
-	{0x1EEF, 0, 2, 1377},
-	{0x1EF0, 0, 2, 1379},
-	{0x1EF1, 0, 2, 1381},
-	{0x1EF2, 0, 2, 1383},
-	{0x1EF3, 0, 2, 1385},
-	{0x1EF4, 0, 2, 1387},
-	{0x1EF5, 0, 2, 1389},
-	{0x1EF6, 0, 2, 1391},
-	{0x1EF7, 0, 2, 1393},
-	{0x1EF8, 0, 2, 1395},
-	{0x1EF9, 0, 2, 1397},
-	{0x1F00, 0, 2, 1399},
-	{0x1F01, 0, 2, 1401},
-	{0x1F02, 0, 2, 1403},
-	{0x1F03, 0, 2, 1405},
-	{0x1F04, 0, 2, 1407},
-	{0x1F05, 0, 2, 1409},
-	{0x1F06, 0, 2, 1411},
-	{0x1F07, 0, 2, 1413},
-	{0x1F08, 0, 2, 1415},
-	{0x1F09, 0, 2, 1417},
-	{0x1F0A, 0, 2, 1419},
-	{0x1F0B, 0, 2, 1421},
-	{0x1F0C, 0, 2, 1423},
-	{0x1F0D, 0, 2, 1425},
-	{0x1F0E, 0, 2, 1427},
-	{0x1F0F, 0, 2, 1429},
-	{0x1F10, 0, 2, 1431},
-	{0x1F11, 0, 2, 1433},
-	{0x1F12, 0, 2, 1435},
-	{0x1F13, 0, 2, 1437},
-	{0x1F14, 0, 2, 1439},
-	{0x1F15, 0, 2, 1441},
-	{0x1F18, 0, 2, 1443},
-	{0x1F19, 0, 2, 1445},
-	{0x1F1A, 0, 2, 1447},
-	{0x1F1B, 0, 2, 1449},
-	{0x1F1C, 0, 2, 1451},
-	{0x1F1D, 0, 2, 1453},
-	{0x1F20, 0, 2, 1455},
-	{0x1F21, 0, 2, 1457},
-	{0x1F22, 0, 2, 1459},
-	{0x1F23, 0, 2, 1461},
-	{0x1F24, 0, 2, 1463},
-	{0x1F25, 0, 2, 1465},
-	{0x1F26, 0, 2, 1467},
-	{0x1F27, 0, 2, 1469},
-	{0x1F28, 0, 2, 1471},
-	{0x1F29, 0, 2, 1473},
-	{0x1F2A, 0, 2, 1475},
-	{0x1F2B, 0, 2, 1477},
-	{0x1F2C, 0, 2, 1479},
-	{0x1F2D, 0, 2, 1481},
-	{0x1F2E, 0, 2, 1483},
-	{0x1F2F, 0, 2, 1485},
-	{0x1F30, 0, 2, 1487},
-	{0x1F31, 0, 2, 1489},
-	{0x1F32, 0, 2, 1491},
-	{0x1F33, 0, 2, 1493},
-	{0x1F34, 0, 2, 1495},
-	{0x1F35, 0, 2, 1497},
-	{0x1F36, 0, 2, 1499},
-	{0x1F37, 0, 2, 1501},
-	{0x1F38, 0, 2, 1503},
-	{0x1F39, 0, 2, 1505},
-	{0x1F3A, 0, 2, 1507},
-	{0x1F3B, 0, 2, 1509},
-	{0x1F3C, 0, 2, 1511},
-	{0x1F3D, 0, 2, 1513},
-	{0x1F3E, 0, 2, 1515},
-	{0x1F3F, 0, 2, 1517},
-	{0x1F40, 0, 2, 1519},
-	{0x1F41, 0, 2, 1521},
-	{0x1F42, 0, 2, 1523},
-	{0x1F43, 0, 2, 1525},
-	{0x1F44, 0, 2, 1527},
-	{0x1F45, 0, 2, 1529},
-	{0x1F48, 0, 2, 1531},
-	{0x1F49, 0, 2, 1533},
-	{0x1F4A, 0, 2, 1535},
-	{0x1F4B, 0, 2, 1537},
-	{0x1F4C, 0, 2, 1539},
-	{0x1F4D, 0, 2, 1541},
-	{0x1F50, 0, 2, 1543},
-	{0x1F51, 0, 2, 1545},
-	{0x1F52, 0, 2, 1547},
-	{0x1F53, 0, 2, 1549},
-	{0x1F54, 0, 2, 1551},
-	{0x1F55, 0, 2, 1553},
-	{0x1F56, 0, 2, 1555},
-	{0x1F57, 0, 2, 1557},
-	{0x1F59, 0, 2, 1559},
-	{0x1F5B, 0, 2, 1561},
-	{0x1F5D, 0, 2, 1563},
-	{0x1F5F, 0, 2, 1565},
-	{0x1F60, 0, 2, 1567},
-	{0x1F61, 0, 2, 1569},
-	{0x1F62, 0, 2, 1571},
-	{0x1F63, 0, 2, 1573},
-	{0x1F64, 0, 2, 1575},
-	{0x1F65, 0, 2, 1577},
-	{0x1F66, 0, 2, 1579},
-	{0x1F67, 0, 2, 1581},
-	{0x1F68, 0, 2, 1583},
-	{0x1F69, 0, 2, 1585},
-	{0x1F6A, 0, 2, 1587},
-	{0x1F6B, 0, 2, 1589},
-	{0x1F6C, 0, 2, 1591},
-	{0x1F6D, 0, 2, 1593},
-	{0x1F6E, 0, 2, 1595},
-	{0x1F6F, 0, 2, 1597},
-	{0x1F70, 0, 2, 1599},
-	{0x1F71, 0, 1 | DECOMP_INLINE, 0x03AC},
-	{0x1F72, 0, 2, 1601},
-	{0x1F73, 0, 1 | DECOMP_INLINE, 0x03AD},
-	{0x1F74, 0, 2, 1603},
-	{0x1F75, 0, 1 | DECOMP_INLINE, 0x03AE},
-	{0x1F76, 0, 2, 1605},
-	{0x1F77, 0, 1 | DECOMP_INLINE, 0x03AF},
-	{0x1F78, 0, 2, 1607},
-	{0x1F79, 0, 1 | DECOMP_INLINE, 0x03CC},
-	{0x1F7A, 0, 2, 1609},
-	{0x1F7B, 0, 1 | DECOMP_INLINE, 0x03CD},
-	{0x1F7C, 0, 2, 1611},
-	{0x1F7D, 0, 1 | DECOMP_INLINE, 0x03CE},
-	{0x1F80, 0, 2, 1613},
-	{0x1F81, 0, 2, 1615},
-	{0x1F82, 0, 2, 1617},
-	{0x1F83, 0, 2, 1619},
-	{0x1F84, 0, 2, 1621},
-	{0x1F85, 0, 2, 1623},
-	{0x1F86, 0, 2, 1625},
-	{0x1F87, 0, 2, 1627},
-	{0x1F88, 0, 2, 1629},
-	{0x1F89, 0, 2, 1631},
-	{0x1F8A, 0, 2, 1633},
-	{0x1F8B, 0, 2, 1635},
-	{0x1F8C, 0, 2, 1637},
-	{0x1F8D, 0, 2, 1639},
-	{0x1F8E, 0, 2, 1641},
-	{0x1F8F, 0, 2, 1643},
-	{0x1F90, 0, 2, 1645},
-	{0x1F91, 0, 2, 1647},
-	{0x1F92, 0, 2, 1649},
-	{0x1F93, 0, 2, 1651},
-	{0x1F94, 0, 2, 1653},
-	{0x1F95, 0, 2, 1655},
-	{0x1F96, 0, 2, 1657},
-	{0x1F97, 0, 2, 1659},
-	{0x1F98, 0, 2, 1661},
-	{0x1F99, 0, 2, 1663},
-	{0x1F9A, 0, 2, 1665},
-	{0x1F9B, 0, 2, 1667},
-	{0x1F9C, 0, 2, 1669},
-	{0x1F9D, 0, 2, 1671},
-	{0x1F9E, 0, 2, 1673},
-	{0x1F9F, 0, 2, 1675},
-	{0x1FA0, 0, 2, 1677},
-	{0x1FA1, 0, 2, 1679},
-	{0x1FA2, 0, 2, 1681},
-	{0x1FA3, 0, 2, 1683},
-	{0x1FA4, 0, 2, 1685},
-	{0x1FA5, 0, 2, 1687},
-	{0x1FA6, 0, 2, 1689},
-	{0x1FA7, 0, 2, 1691},
-	{0x1FA8, 0, 2, 1693},
-	{0x1FA9, 0, 2, 1695},
-	{0x1FAA, 0, 2, 1697},
-	{0x1FAB, 0, 2, 1699},
-	{0x1FAC, 0, 2, 1701},
-	{0x1FAD, 0, 2, 1703},
-	{0x1FAE, 0, 2, 1705},
-	{0x1FAF, 0, 2, 1707},
-	{0x1FB0, 0, 2, 1709},
-	{0x1FB1, 0, 2, 1711},
-	{0x1FB2, 0, 2, 1713},
-	{0x1FB3, 0, 2, 1715},
-	{0x1FB4, 0, 2, 1717},
-	{0x1FB6, 0, 2, 1719},
-	{0x1FB7, 0, 2, 1721},
-	{0x1FB8, 0, 2, 1723},
-	{0x1FB9, 0, 2, 1725},
-	{0x1FBA, 0, 2, 1727},
-	{0x1FBB, 0, 1 | DECOMP_INLINE, 0x0386},
-	{0x1FBC, 0, 2, 1729},
-	{0x1FBD, 0, 2 | DECOMP_COMPAT, 1731},
-	{0x1FBE, 0, 1 | DECOMP_INLINE, 0x03B9},
-	{0x1FBF, 0, 2 | DECOMP_COMPAT, 1733},
-	{0x1FC0, 0, 2 | DECOMP_COMPAT, 1735},
-	{0x1FC1, 0, 2, 1737},
-	{0x1FC2, 0, 2, 1739},
-	{0x1FC3, 0, 2, 1741},
-	{0x1FC4, 0, 2, 1743},
-	{0x1FC6, 0, 2, 1745},
-	{0x1FC7, 0, 2, 1747},
-	{0x1FC8, 0, 2, 1749},
-	{0x1FC9, 0, 1 | DECOMP_INLINE, 0x0388},
-	{0x1FCA, 0, 2, 1751},
-	{0x1FCB, 0, 1 | DECOMP_INLINE, 0x0389},
-	{0x1FCC, 0, 2, 1753},
-	{0x1FCD, 0, 2, 1755},
-	{0x1FCE, 0, 2, 1757},
-	{0x1FCF, 0, 2, 1759},
-	{0x1FD0, 0, 2, 1761},
-	{0x1FD1, 0, 2, 1763},
-	{0x1FD2, 0, 2, 1765},
-	{0x1FD3, 0, 1 | DECOMP_INLINE, 0x0390},
-	{0x1FD6, 0, 2, 1767},
-	{0x1FD7, 0, 2, 1769},
-	{0x1FD8, 0, 2, 1771},
-	{0x1FD9, 0, 2, 1773},
-	{0x1FDA, 0, 2, 1775},
-	{0x1FDB, 0, 1 | DECOMP_INLINE, 0x038A},
-	{0x1FDD, 0, 2, 1777},
-	{0x1FDE, 0, 2, 1779},
-	{0x1FDF, 0, 2, 1781},
-	{0x1FE0, 0, 2, 1783},
-	{0x1FE1, 0, 2, 1785},
-	{0x1FE2, 0, 2, 1787},
-	{0x1FE3, 0, 1 | DECOMP_INLINE, 0x03B0},
-	{0x1FE4, 0, 2, 1789},
-	{0x1FE5, 0, 2, 1791},
-	{0x1FE6, 0, 2, 1793},
-	{0x1FE7, 0, 2, 1795},
-	{0x1FE8, 0, 2, 1797},
-	{0x1FE9, 0, 2, 1799},
-	{0x1FEA, 0, 2, 1801},
-	{0x1FEB, 0, 1 | DECOMP_INLINE, 0x038E},
-	{0x1FEC, 0, 2, 1803},
-	{0x1FED, 0, 2, 1805},
-	{0x1FEE, 0, 1 | DECOMP_INLINE, 0x0385},
-	{0x1FEF, 0, 1 | DECOMP_INLINE, 0x0060},
-	{0x1FF2, 0, 2, 1807},
-	{0x1FF3, 0, 2, 1809},
-	{0x1FF4, 0, 2, 1811},
-	{0x1FF6, 0, 2, 1813},
-	{0x1FF7, 0, 2, 1815},
-	{0x1FF8, 0, 2, 1817},
-	{0x1FF9, 0, 1 | DECOMP_INLINE, 0x038C},
-	{0x1FFA, 0, 2, 1819},
-	{0x1FFB, 0, 1 | DECOMP_INLINE, 0x038F},
-	{0x1FFC, 0, 2, 1821},
-	{0x1FFD, 0, 1 | DECOMP_INLINE, 0x00B4},
-	{0x1FFE, 0, 2 | DECOMP_COMPAT, 1823},
-	{0x2000, 0, 1 | DECOMP_INLINE, 0x2002},
-	{0x2001, 0, 1 | DECOMP_INLINE, 0x2003},
-	{0x2002, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2003, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2004, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2005, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2006, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2007, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2008, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2009, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x200A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2011, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2010},
-	{0x2017, 0, 2 | DECOMP_COMPAT, 1825},
-	{0x2024, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002E},
-	{0x2025, 0, 2 | DECOMP_COMPAT, 1827},
-	{0x2026, 0, 3 | DECOMP_COMPAT, 1829},
-	{0x202F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2033, 0, 2 | DECOMP_COMPAT, 1832},
-	{0x2034, 0, 3 | DECOMP_COMPAT, 1834},
-	{0x2036, 0, 2 | DECOMP_COMPAT, 1837},
-	{0x2037, 0, 3 | DECOMP_COMPAT, 1839},
-	{0x203C, 0, 2 | DECOMP_COMPAT, 1842},
-	{0x203E, 0, 2 | DECOMP_COMPAT, 1844},
-	{0x2047, 0, 2 | DECOMP_COMPAT, 1846},
-	{0x2048, 0, 2 | DECOMP_COMPAT, 1848},
-	{0x2049, 0, 2 | DECOMP_COMPAT, 1850},
-	{0x2057, 0, 4 | DECOMP_COMPAT, 1852},
-	{0x205F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x2070, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x2071, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x2074, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x2075, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x2076, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x2077, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x2078, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x2079, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x207A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
-	{0x207B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2212},
-	{0x207C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
-	{0x207D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
-	{0x207E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
-	{0x207F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x2080, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x2081, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x2082, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x2083, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x2084, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x2085, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x2086, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x2087, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x2088, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x2089, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x208A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
-	{0x208B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2212},
-	{0x208C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
-	{0x208D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
-	{0x208E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
-	{0x2090, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x2091, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x2092, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x2093, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x2094, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0259},
-	{0x2095, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x2096, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x2097, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x2098, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x2099, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x209A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x209B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x209C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x20A8, 0, 2 | DECOMP_COMPAT, 1856},
-	{0x20D0, 230, 0, 0},
-	{0x20D1, 230, 0, 0},
-	{0x20D2, 1, 0, 0},
-	{0x20D3, 1, 0, 0},
-	{0x20D4, 230, 0, 0},
-	{0x20D5, 230, 0, 0},
-	{0x20D6, 230, 0, 0},
-	{0x20D7, 230, 0, 0},
-	{0x20D8, 1, 0, 0},
-	{0x20D9, 1, 0, 0},
-	{0x20DA, 1, 0, 0},
-	{0x20DB, 230, 0, 0},
-	{0x20DC, 230, 0, 0},
-	{0x20E1, 230, 0, 0},
-	{0x20E5, 1, 0, 0},
-	{0x20E6, 1, 0, 0},
-	{0x20E7, 230, 0, 0},
-	{0x20E8, 220, 0, 0},
-	{0x20E9, 230, 0, 0},
-	{0x20EA, 1, 0, 0},
-	{0x20EB, 1, 0, 0},
-	{0x20EC, 220, 0, 0},
-	{0x20ED, 220, 0, 0},
-	{0x20EE, 220, 0, 0},
-	{0x20EF, 220, 0, 0},
-	{0x20F0, 230, 0, 0},
-	{0x2100, 0, 3 | DECOMP_COMPAT, 1858},
-	{0x2101, 0, 3 | DECOMP_COMPAT, 1861},
-	{0x2102, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x2103, 0, 2 | DECOMP_COMPAT, 1864},
-	{0x2105, 0, 3 | DECOMP_COMPAT, 1866},
-	{0x2106, 0, 3 | DECOMP_COMPAT, 1869},
-	{0x2107, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0190},
-	{0x2109, 0, 2 | DECOMP_COMPAT, 1872},
-	{0x210A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x210B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x210C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x210D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x210E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x210F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0127},
-	{0x2110, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x2111, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x2112, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x2113, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x2115, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x2116, 0, 2 | DECOMP_COMPAT, 1874},
-	{0x2119, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x211A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x211B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x211C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x211D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x2120, 0, 2 | DECOMP_COMPAT, 1876},
-	{0x2121, 0, 3 | DECOMP_COMPAT, 1878},
-	{0x2122, 0, 2 | DECOMP_COMPAT, 1881},
-	{0x2124, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x2126, 0, 1 | DECOMP_INLINE, 0x03A9},
-	{0x2128, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x212A, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x212B, 0, 1 | DECOMP_INLINE, 0x00C5},
-	{0x212C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x212D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x212F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x2130, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x2131, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x2133, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x2134, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x2135, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D0},
-	{0x2136, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D1},
-	{0x2137, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D2},
-	{0x2138, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D3},
-	{0x2139, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x213B, 0, 3 | DECOMP_COMPAT, 1883},
-	{0x213C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
-	{0x213D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
-	{0x213E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
-	{0x213F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
-	{0x2140, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2211},
-	{0x2145, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x2146, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x2147, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x2148, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x2149, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x2150, 0, 3 | DECOMP_COMPAT, 1886},
-	{0x2151, 0, 3 | DECOMP_COMPAT, 1889},
-	{0x2152, 0, 4 | DECOMP_COMPAT, 1892},
-	{0x2153, 0, 3 | DECOMP_COMPAT, 1896},
-	{0x2154, 0, 3 | DECOMP_COMPAT, 1899},
-	{0x2155, 0, 3 | DECOMP_COMPAT, 1902},
-	{0x2156, 0, 3 | DECOMP_COMPAT, 1905},
-	{0x2157, 0, 3 | DECOMP_COMPAT, 1908},
-	{0x2158, 0, 3 | DECOMP_COMPAT, 1911},
-	{0x2159, 0, 3 | DECOMP_COMPAT, 1914},
-	{0x215A, 0, 3 | DECOMP_COMPAT, 1917},
-	{0x215B, 0, 3 | DECOMP_COMPAT, 1920},
-	{0x215C, 0, 3 | DECOMP_COMPAT, 1923},
-	{0x215D, 0, 3 | DECOMP_COMPAT, 1926},
-	{0x215E, 0, 3 | DECOMP_COMPAT, 1929},
-	{0x215F, 0, 2 | DECOMP_COMPAT, 1932},
-	{0x2160, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x2161, 0, 2 | DECOMP_COMPAT, 1934},
-	{0x2162, 0, 3 | DECOMP_COMPAT, 1936},
-	{0x2163, 0, 2 | DECOMP_COMPAT, 1939},
-	{0x2164, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x2165, 0, 2 | DECOMP_COMPAT, 1941},
-	{0x2166, 0, 3 | DECOMP_COMPAT, 1943},
-	{0x2167, 0, 4 | DECOMP_COMPAT, 1946},
-	{0x2168, 0, 2 | DECOMP_COMPAT, 1950},
-	{0x2169, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x216A, 0, 2 | DECOMP_COMPAT, 1952},
-	{0x216B, 0, 3 | DECOMP_COMPAT, 1954},
-	{0x216C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x216D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x216E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x216F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x2170, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x2171, 0, 2 | DECOMP_COMPAT, 1957},
-	{0x2172, 0, 3 | DECOMP_COMPAT, 1959},
-	{0x2173, 0, 2 | DECOMP_COMPAT, 1962},
-	{0x2174, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x2175, 0, 2 | DECOMP_COMPAT, 1964},
-	{0x2176, 0, 3 | DECOMP_COMPAT, 1966},
-	{0x2177, 0, 4 | DECOMP_COMPAT, 1969},
-	{0x2178, 0, 2 | DECOMP_COMPAT, 1973},
-	{0x2179, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x217A, 0, 2 | DECOMP_COMPAT, 1975},
-	{0x217B, 0, 3 | DECOMP_COMPAT, 1977},
-	{0x217C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x217D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x217E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x217F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x2189, 0, 3 | DECOMP_COMPAT, 1980},
-	{0x219A, 0, 2, 1983},
-	{0x219B, 0, 2, 1985},
-	{0x21AE, 0, 2, 1987},
-	{0x21CD, 0, 2, 1989},
-	{0x21CE, 0, 2, 1991},
-	{0x21CF, 0, 2, 1993},
-	{0x2204, 0, 2, 1995},
-	{0x2209, 0, 2, 1997},
-	{0x220C, 0, 2, 1999},
-	{0x2224, 0, 2, 2001},
-	{0x2226, 0, 2, 2003},
-	{0x222C, 0, 2 | DECOMP_COMPAT, 2005},
-	{0x222D, 0, 3 | DECOMP_COMPAT, 2007},
-	{0x222F, 0, 2 | DECOMP_COMPAT, 2010},
-	{0x2230, 0, 3 | DECOMP_COMPAT, 2012},
-	{0x2241, 0, 2, 2015},
-	{0x2244, 0, 2, 2017},
-	{0x2247, 0, 2, 2019},
-	{0x2249, 0, 2, 2021},
-	{0x2260, 0, 2, 2023},
-	{0x2262, 0, 2, 2025},
-	{0x226D, 0, 2, 2027},
-	{0x226E, 0, 2, 2029},
-	{0x226F, 0, 2, 2031},
-	{0x2270, 0, 2, 2033},
-	{0x2271, 0, 2, 2035},
-	{0x2274, 0, 2, 2037},
-	{0x2275, 0, 2, 2039},
-	{0x2278, 0, 2, 2041},
-	{0x2279, 0, 2, 2043},
-	{0x2280, 0, 2, 2045},
-	{0x2281, 0, 2, 2047},
-	{0x2284, 0, 2, 2049},
-	{0x2285, 0, 2, 2051},
-	{0x2288, 0, 2, 2053},
-	{0x2289, 0, 2, 2055},
-	{0x22AC, 0, 2, 2057},
-	{0x22AD, 0, 2, 2059},
-	{0x22AE, 0, 2, 2061},
-	{0x22AF, 0, 2, 2063},
-	{0x22E0, 0, 2, 2065},
-	{0x22E1, 0, 2, 2067},
-	{0x22E2, 0, 2, 2069},
-	{0x22E3, 0, 2, 2071},
-	{0x22EA, 0, 2, 2073},
-	{0x22EB, 0, 2, 2075},
-	{0x22EC, 0, 2, 2077},
-	{0x22ED, 0, 2, 2079},
-	{0x2329, 0, 1 | DECOMP_INLINE, 0x3008},
-	{0x232A, 0, 1 | DECOMP_INLINE, 0x3009},
-	{0x2460, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x2461, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x2462, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x2463, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x2464, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x2465, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x2466, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x2467, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x2468, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x2469, 0, 2 | DECOMP_COMPAT, 2081},
-	{0x246A, 0, 2 | DECOMP_COMPAT, 2083},
-	{0x246B, 0, 2 | DECOMP_COMPAT, 2085},
-	{0x246C, 0, 2 | DECOMP_COMPAT, 2087},
-	{0x246D, 0, 2 | DECOMP_COMPAT, 2089},
-	{0x246E, 0, 2 | DECOMP_COMPAT, 2091},
-	{0x246F, 0, 2 | DECOMP_COMPAT, 2093},
-	{0x2470, 0, 2 | DECOMP_COMPAT, 2095},
-	{0x2471, 0, 2 | DECOMP_COMPAT, 2097},
-	{0x2472, 0, 2 | DECOMP_COMPAT, 2099},
-	{0x2473, 0, 2 | DECOMP_COMPAT, 2101},
-	{0x2474, 0, 3 | DECOMP_COMPAT, 2103},
-	{0x2475, 0, 3 | DECOMP_COMPAT, 2106},
-	{0x2476, 0, 3 | DECOMP_COMPAT, 2109},
-	{0x2477, 0, 3 | DECOMP_COMPAT, 2112},
-	{0x2478, 0, 3 | DECOMP_COMPAT, 2115},
-	{0x2479, 0, 3 | DECOMP_COMPAT, 2118},
-	{0x247A, 0, 3 | DECOMP_COMPAT, 2121},
-	{0x247B, 0, 3 | DECOMP_COMPAT, 2124},
-	{0x247C, 0, 3 | DECOMP_COMPAT, 2127},
-	{0x247D, 0, 4 | DECOMP_COMPAT, 2130},
-	{0x247E, 0, 4 | DECOMP_COMPAT, 2134},
-	{0x247F, 0, 4 | DECOMP_COMPAT, 2138},
-	{0x2480, 0, 4 | DECOMP_COMPAT, 2142},
-	{0x2481, 0, 4 | DECOMP_COMPAT, 2146},
-	{0x2482, 0, 4 | DECOMP_COMPAT, 2150},
-	{0x2483, 0, 4 | DECOMP_COMPAT, 2154},
-	{0x2484, 0, 4 | DECOMP_COMPAT, 2158},
-	{0x2485, 0, 4 | DECOMP_COMPAT, 2162},
-	{0x2486, 0, 4 | DECOMP_COMPAT, 2166},
-	{0x2487, 0, 4 | DECOMP_COMPAT, 2170},
-	{0x2488, 0, 2 | DECOMP_COMPAT, 2174},
-	{0x2489, 0, 2 | DECOMP_COMPAT, 2176},
-	{0x248A, 0, 2 | DECOMP_COMPAT, 2178},
-	{0x248B, 0, 2 | DECOMP_COMPAT, 2180},
-	{0x248C, 0, 2 | DECOMP_COMPAT, 2182},
-	{0x248D, 0, 2 | DECOMP_COMPAT, 2184},
-	{0x248E, 0, 2 | DECOMP_COMPAT, 2186},
-	{0x248F, 0, 2 | DECOMP_COMPAT, 2188},
-	{0x2490, 0, 2 | DECOMP_COMPAT, 2190},
-	{0x2491, 0, 3 | DECOMP_COMPAT, 2192},
-	{0x2492, 0, 3 | DECOMP_COMPAT, 2195},
-	{0x2493, 0, 3 | DECOMP_COMPAT, 2198},
-	{0x2494, 0, 3 | DECOMP_COMPAT, 2201},
-	{0x2495, 0, 3 | DECOMP_COMPAT, 2204},
-	{0x2496, 0, 3 | DECOMP_COMPAT, 2207},
-	{0x2497, 0, 3 | DECOMP_COMPAT, 2210},
-	{0x2498, 0, 3 | DECOMP_COMPAT, 2213},
-	{0x2499, 0, 3 | DECOMP_COMPAT, 2216},
-	{0x249A, 0, 3 | DECOMP_COMPAT, 2219},
-	{0x249B, 0, 3 | DECOMP_COMPAT, 2222},
-	{0x249C, 0, 3 | DECOMP_COMPAT, 2225},
-	{0x249D, 0, 3 | DECOMP_COMPAT, 2228},
-	{0x249E, 0, 3 | DECOMP_COMPAT, 2231},
-	{0x249F, 0, 3 | DECOMP_COMPAT, 2234},
-	{0x24A0, 0, 3 | DECOMP_COMPAT, 2237},
-	{0x24A1, 0, 3 | DECOMP_COMPAT, 2240},
-	{0x24A2, 0, 3 | DECOMP_COMPAT, 2243},
-	{0x24A3, 0, 3 | DECOMP_COMPAT, 2246},
-	{0x24A4, 0, 3 | DECOMP_COMPAT, 2249},
-	{0x24A5, 0, 3 | DECOMP_COMPAT, 2252},
-	{0x24A6, 0, 3 | DECOMP_COMPAT, 2255},
-	{0x24A7, 0, 3 | DECOMP_COMPAT, 2258},
-	{0x24A8, 0, 3 | DECOMP_COMPAT, 2261},
-	{0x24A9, 0, 3 | DECOMP_COMPAT, 2264},
-	{0x24AA, 0, 3 | DECOMP_COMPAT, 2267},
-	{0x24AB, 0, 3 | DECOMP_COMPAT, 2270},
-	{0x24AC, 0, 3 | DECOMP_COMPAT, 2273},
-	{0x24AD, 0, 3 | DECOMP_COMPAT, 2276},
-	{0x24AE, 0, 3 | DECOMP_COMPAT, 2279},
-	{0x24AF, 0, 3 | DECOMP_COMPAT, 2282},
-	{0x24B0, 0, 3 | DECOMP_COMPAT, 2285},
-	{0x24B1, 0, 3 | DECOMP_COMPAT, 2288},
-	{0x24B2, 0, 3 | DECOMP_COMPAT, 2291},
-	{0x24B3, 0, 3 | DECOMP_COMPAT, 2294},
-	{0x24B4, 0, 3 | DECOMP_COMPAT, 2297},
-	{0x24B5, 0, 3 | DECOMP_COMPAT, 2300},
-	{0x24B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x24B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x24B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x24B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x24BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x24BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x24BC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x24BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x24BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x24BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x24C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x24C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x24C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x24C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x24C4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x24C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x24C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x24C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x24C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x24C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x24CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x24CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x24CC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x24CD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x24CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x24CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x24D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x24D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x24D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x24D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x24D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x24D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x24D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x24D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x24D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x24D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x24DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x24DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x24DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x24DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x24DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x24DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x24E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x24E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x24E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x24E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x24E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x24E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x24E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x24E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x24E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x24E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x24EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x2A0C, 0, 4 | DECOMP_COMPAT, 2303},
-	{0x2A74, 0, 3 | DECOMP_COMPAT, 2307},
-	{0x2A75, 0, 2 | DECOMP_COMPAT, 2310},
-	{0x2A76, 0, 3 | DECOMP_COMPAT, 2312},
-	{0x2ADC, 0, 2 | DECOMP_NO_COMPOSE, 2315},	/* in exclusion list */
-	{0x2C7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x2C7D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x2CEF, 230, 0, 0},
-	{0x2CF0, 230, 0, 0},
-	{0x2CF1, 230, 0, 0},
-	{0x2D6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2D61},
-	{0x2D7F, 9, 0, 0},
-	{0x2DE0, 230, 0, 0},
-	{0x2DE1, 230, 0, 0},
-	{0x2DE2, 230, 0, 0},
-	{0x2DE3, 230, 0, 0},
-	{0x2DE4, 230, 0, 0},
-	{0x2DE5, 230, 0, 0},
-	{0x2DE6, 230, 0, 0},
-	{0x2DE7, 230, 0, 0},
-	{0x2DE8, 230, 0, 0},
-	{0x2DE9, 230, 0, 0},
-	{0x2DEA, 230, 0, 0},
-	{0x2DEB, 230, 0, 0},
-	{0x2DEC, 230, 0, 0},
-	{0x2DED, 230, 0, 0},
-	{0x2DEE, 230, 0, 0},
-	{0x2DEF, 230, 0, 0},
-	{0x2DF0, 230, 0, 0},
-	{0x2DF1, 230, 0, 0},
-	{0x2DF2, 230, 0, 0},
-	{0x2DF3, 230, 0, 0},
-	{0x2DF4, 230, 0, 0},
-	{0x2DF5, 230, 0, 0},
-	{0x2DF6, 230, 0, 0},
-	{0x2DF7, 230, 0, 0},
-	{0x2DF8, 230, 0, 0},
-	{0x2DF9, 230, 0, 0},
-	{0x2DFA, 230, 0, 0},
-	{0x2DFB, 230, 0, 0},
-	{0x2DFC, 230, 0, 0},
-	{0x2DFD, 230, 0, 0},
-	{0x2DFE, 230, 0, 0},
-	{0x2DFF, 230, 0, 0},
-	{0x2E9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BCD},
-	{0x2EF3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F9F},
-	{0x2F00, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
-	{0x2F01, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E28},
-	{0x2F02, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E36},
-	{0x2F03, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E3F},
-	{0x2F04, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E59},
-	{0x2F05, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E85},
-	{0x2F06, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
-	{0x2F07, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EA0},
-	{0x2F08, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EBA},
-	{0x2F09, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x513F},
-	{0x2F0A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5165},
-	{0x2F0B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x516B},
-	{0x2F0C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5182},
-	{0x2F0D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5196},
-	{0x2F0E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51AB},
-	{0x2F0F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51E0},
-	{0x2F10, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51F5},
-	{0x2F11, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5200},
-	{0x2F12, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x529B},
-	{0x2F13, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x52F9},
-	{0x2F14, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5315},
-	{0x2F15, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x531A},
-	{0x2F16, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5338},
-	{0x2F17, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5341},
-	{0x2F18, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x535C},
-	{0x2F19, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5369},
-	{0x2F1A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5382},
-	{0x2F1B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53B6},
-	{0x2F1C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53C8},
-	{0x2F1D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53E3},
-	{0x2F1E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x56D7},
-	{0x2F1F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x571F},
-	{0x2F20, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x58EB},
-	{0x2F21, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5902},
-	{0x2F22, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x590A},
-	{0x2F23, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5915},
-	{0x2F24, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5927},
-	{0x2F25, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5973},
-	{0x2F26, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B50},
-	{0x2F27, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B80},
-	{0x2F28, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5BF8},
-	{0x2F29, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C0F},
-	{0x2F2A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C22},
-	{0x2F2B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C38},
-	{0x2F2C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C6E},
-	{0x2F2D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C71},
-	{0x2F2E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DDB},
-	{0x2F2F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DE5},
-	{0x2F30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DF1},
-	{0x2F31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DFE},
-	{0x2F32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E72},
-	{0x2F33, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7A},
-	{0x2F34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7F},
-	{0x2F35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5EF4},
-	{0x2F36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5EFE},
-	{0x2F37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F0B},
-	{0x2F38, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F13},
-	{0x2F39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F50},
-	{0x2F3A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F61},
-	{0x2F3B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F73},
-	{0x2F3C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5FC3},
-	{0x2F3D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6208},
-	{0x2F3E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6236},
-	{0x2F3F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x624B},
-	{0x2F40, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x652F},
-	{0x2F41, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6534},
-	{0x2F42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6587},
-	{0x2F43, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6597},
-	{0x2F44, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65A4},
-	{0x2F45, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65B9},
-	{0x2F46, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65E0},
-	{0x2F47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65E5},
-	{0x2F48, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x66F0},
-	{0x2F49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6708},
-	{0x2F4A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6728},
-	{0x2F4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B20},
-	{0x2F4C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B62},
-	{0x2F4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B79},
-	{0x2F4E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BB3},
-	{0x2F4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BCB},
-	{0x2F50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BD4},
-	{0x2F51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BDB},
-	{0x2F52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C0F},
-	{0x2F53, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C14},
-	{0x2F54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C34},
-	{0x2F55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x706B},
-	{0x2F56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x722A},
-	{0x2F57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7236},
-	{0x2F58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x723B},
-	{0x2F59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x723F},
-	{0x2F5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7247},
-	{0x2F5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7259},
-	{0x2F5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x725B},
-	{0x2F5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x72AC},
-	{0x2F5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7384},
-	{0x2F5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7389},
-	{0x2F60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x74DC},
-	{0x2F61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x74E6},
-	{0x2F62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7518},
-	{0x2F63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x751F},
-	{0x2F64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7528},
-	{0x2F65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7530},
-	{0x2F66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x758B},
-	{0x2F67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7592},
-	{0x2F68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7676},
-	{0x2F69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x767D},
-	{0x2F6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76AE},
-	{0x2F6B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76BF},
-	{0x2F6C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76EE},
-	{0x2F6D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77DB},
-	{0x2F6E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77E2},
-	{0x2F6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77F3},
-	{0x2F70, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x793A},
-	{0x2F71, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79B8},
-	{0x2F72, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79BE},
-	{0x2F73, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7A74},
-	{0x2F74, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7ACB},
-	{0x2F75, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7AF9},
-	{0x2F76, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7C73},
-	{0x2F77, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7CF8},
-	{0x2F78, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F36},
-	{0x2F79, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F51},
-	{0x2F7A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F8A},
-	{0x2F7B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7FBD},
-	{0x2F7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8001},
-	{0x2F7D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x800C},
-	{0x2F7E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8012},
-	{0x2F7F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8033},
-	{0x2F80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x807F},
-	{0x2F81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8089},
-	{0x2F82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81E3},
-	{0x2F83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81EA},
-	{0x2F84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81F3},
-	{0x2F85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81FC},
-	{0x2F86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x820C},
-	{0x2F87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x821B},
-	{0x2F88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x821F},
-	{0x2F89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x826E},
-	{0x2F8A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8272},
-	{0x2F8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8278},
-	{0x2F8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x864D},
-	{0x2F8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x866B},
-	{0x2F8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8840},
-	{0x2F8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x884C},
-	{0x2F90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8863},
-	{0x2F91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x897E},
-	{0x2F92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x898B},
-	{0x2F93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x89D2},
-	{0x2F94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8A00},
-	{0x2F95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C37},
-	{0x2F96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C46},
-	{0x2F97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C55},
-	{0x2F98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C78},
-	{0x2F99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C9D},
-	{0x2F9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8D64},
-	{0x2F9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8D70},
-	{0x2F9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8DB3},
-	{0x2F9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8EAB},
-	{0x2F9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8ECA},
-	{0x2F9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8F9B},
-	{0x2FA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8FB0},
-	{0x2FA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8FB5},
-	{0x2FA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9091},
-	{0x2FA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9149},
-	{0x2FA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91C6},
-	{0x2FA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91CC},
-	{0x2FA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91D1},
-	{0x2FA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9577},
-	{0x2FA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9580},
-	{0x2FA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x961C},
-	{0x2FAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96B6},
-	{0x2FAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96B9},
-	{0x2FAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96E8},
-	{0x2FAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9751},
-	{0x2FAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x975E},
-	{0x2FAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9762},
-	{0x2FB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9769},
-	{0x2FB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97CB},
-	{0x2FB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97ED},
-	{0x2FB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97F3},
-	{0x2FB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9801},
-	{0x2FB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98A8},
-	{0x2FB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98DB},
-	{0x2FB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98DF},
-	{0x2FB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9996},
-	{0x2FB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9999},
-	{0x2FBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x99AC},
-	{0x2FBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9AA8},
-	{0x2FBC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9AD8},
-	{0x2FBD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ADF},
-	{0x2FBE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B25},
-	{0x2FBF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B2F},
-	{0x2FC0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B32},
-	{0x2FC1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B3C},
-	{0x2FC2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B5A},
-	{0x2FC3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9CE5},
-	{0x2FC4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9E75},
-	{0x2FC5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9E7F},
-	{0x2FC6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EA5},
-	{0x2FC7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EBB},
-	{0x2FC8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EC3},
-	{0x2FC9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ECD},
-	{0x2FCA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ED1},
-	{0x2FCB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EF9},
-	{0x2FCC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EFD},
-	{0x2FCD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F0E},
-	{0x2FCE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F13},
-	{0x2FCF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F20},
-	{0x2FD0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F3B},
-	{0x2FD1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F4A},
-	{0x2FD2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F52},
-	{0x2FD3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F8D},
-	{0x2FD4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F9C},
-	{0x2FD5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9FA0},
-	{0x3000, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
-	{0x302A, 218, 0, 0},
-	{0x302B, 228, 0, 0},
-	{0x302C, 232, 0, 0},
-	{0x302D, 222, 0, 0},
-	{0x302E, 224, 0, 0},
-	{0x302F, 224, 0, 0},
-	{0x3036, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3012},
-	{0x3038, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5341},
-	{0x3039, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5344},
-	{0x303A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5345},
-	{0x304C, 0, 2, 2317},
-	{0x304E, 0, 2, 2319},
-	{0x3050, 0, 2, 2321},
-	{0x3052, 0, 2, 2323},
-	{0x3054, 0, 2, 2325},
-	{0x3056, 0, 2, 2327},
-	{0x3058, 0, 2, 2329},
-	{0x305A, 0, 2, 2331},
-	{0x305C, 0, 2, 2333},
-	{0x305E, 0, 2, 2335},
-	{0x3060, 0, 2, 2337},
-	{0x3062, 0, 2, 2339},
-	{0x3065, 0, 2, 2341},
-	{0x3067, 0, 2, 2343},
-	{0x3069, 0, 2, 2345},
-	{0x3070, 0, 2, 2347},
-	{0x3071, 0, 2, 2349},
-	{0x3073, 0, 2, 2351},
-	{0x3074, 0, 2, 2353},
-	{0x3076, 0, 2, 2355},
-	{0x3077, 0, 2, 2357},
-	{0x3079, 0, 2, 2359},
-	{0x307A, 0, 2, 2361},
-	{0x307C, 0, 2, 2363},
-	{0x307D, 0, 2, 2365},
-	{0x3094, 0, 2, 2367},
-	{0x3099, 8, 0, 0},
-	{0x309A, 8, 0, 0},
-	{0x309B, 0, 2 | DECOMP_COMPAT, 2369},
-	{0x309C, 0, 2 | DECOMP_COMPAT, 2371},
-	{0x309E, 0, 2, 2373},
-	{0x309F, 0, 2 | DECOMP_COMPAT, 2375},
-	{0x30AC, 0, 2, 2377},
-	{0x30AE, 0, 2, 2379},
-	{0x30B0, 0, 2, 2381},
-	{0x30B2, 0, 2, 2383},
-	{0x30B4, 0, 2, 2385},
-	{0x30B6, 0, 2, 2387},
-	{0x30B8, 0, 2, 2389},
-	{0x30BA, 0, 2, 2391},
-	{0x30BC, 0, 2, 2393},
-	{0x30BE, 0, 2, 2395},
-	{0x30C0, 0, 2, 2397},
-	{0x30C2, 0, 2, 2399},
-	{0x30C5, 0, 2, 2401},
-	{0x30C7, 0, 2, 2403},
-	{0x30C9, 0, 2, 2405},
-	{0x30D0, 0, 2, 2407},
-	{0x30D1, 0, 2, 2409},
-	{0x30D3, 0, 2, 2411},
-	{0x30D4, 0, 2, 2413},
-	{0x30D6, 0, 2, 2415},
-	{0x30D7, 0, 2, 2417},
-	{0x30D9, 0, 2, 2419},
-	{0x30DA, 0, 2, 2421},
-	{0x30DC, 0, 2, 2423},
-	{0x30DD, 0, 2, 2425},
-	{0x30F4, 0, 2, 2427},
-	{0x30F7, 0, 2, 2429},
-	{0x30F8, 0, 2, 2431},
-	{0x30F9, 0, 2, 2433},
-	{0x30FA, 0, 2, 2435},
-	{0x30FE, 0, 2, 2437},
-	{0x30FF, 0, 2 | DECOMP_COMPAT, 2439},
-	{0x3131, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1100},
-	{0x3132, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1101},
-	{0x3133, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AA},
-	{0x3134, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1102},
-	{0x3135, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AC},
-	{0x3136, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AD},
-	{0x3137, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1103},
-	{0x3138, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1104},
-	{0x3139, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1105},
-	{0x313A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B0},
-	{0x313B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B1},
-	{0x313C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B2},
-	{0x313D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B3},
-	{0x313E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B4},
-	{0x313F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B5},
-	{0x3140, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111A},
-	{0x3141, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1106},
-	{0x3142, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1107},
-	{0x3143, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1108},
-	{0x3144, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1121},
-	{0x3145, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1109},
-	{0x3146, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110A},
-	{0x3147, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110B},
-	{0x3148, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110C},
-	{0x3149, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110D},
-	{0x314A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110E},
-	{0x314B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110F},
-	{0x314C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1110},
-	{0x314D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1111},
-	{0x314E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1112},
-	{0x314F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1161},
-	{0x3150, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1162},
-	{0x3151, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1163},
-	{0x3152, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1164},
-	{0x3153, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1165},
-	{0x3154, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1166},
-	{0x3155, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1167},
-	{0x3156, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1168},
-	{0x3157, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1169},
-	{0x3158, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116A},
-	{0x3159, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116B},
-	{0x315A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116C},
-	{0x315B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116D},
-	{0x315C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116E},
-	{0x315D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116F},
-	{0x315E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1170},
-	{0x315F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1171},
-	{0x3160, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1172},
-	{0x3161, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1173},
-	{0x3162, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1174},
-	{0x3163, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1175},
-	{0x3164, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1160},
-	{0x3165, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1114},
-	{0x3166, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1115},
-	{0x3167, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11C7},
-	{0x3168, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11C8},
-	{0x3169, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11CC},
-	{0x316A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11CE},
-	{0x316B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D3},
-	{0x316C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D7},
-	{0x316D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D9},
-	{0x316E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111C},
-	{0x316F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11DD},
-	{0x3170, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11DF},
-	{0x3171, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111D},
-	{0x3172, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111E},
-	{0x3173, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1120},
-	{0x3174, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1122},
-	{0x3175, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1123},
-	{0x3176, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1127},
-	{0x3177, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1129},
-	{0x3178, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112B},
-	{0x3179, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112C},
-	{0x317A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112D},
-	{0x317B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112E},
-	{0x317C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112F},
-	{0x317D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1132},
-	{0x317E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1136},
-	{0x317F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1140},
-	{0x3180, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1147},
-	{0x3181, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x114C},
-	{0x3182, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11F1},
-	{0x3183, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11F2},
-	{0x3184, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1157},
-	{0x3185, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1158},
-	{0x3186, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1159},
-	{0x3187, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1184},
-	{0x3188, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1185},
-	{0x3189, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1188},
-	{0x318A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1191},
-	{0x318B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1192},
-	{0x318C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1194},
-	{0x318D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x119E},
-	{0x318E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11A1},
-	{0x3192, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
-	{0x3193, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
-	{0x3194, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E09},
-	{0x3195, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x56DB},
-	{0x3196, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0A},
-	{0x3197, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E2D},
-	{0x3198, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0B},
-	{0x3199, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7532},
-	{0x319A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E59},
-	{0x319B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E19},
-	{0x319C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E01},
-	{0x319D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5929},
-	{0x319E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5730},
-	{0x319F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EBA},
-	{0x3200, 0, 3 | DECOMP_COMPAT, 2441},
-	{0x3201, 0, 3 | DECOMP_COMPAT, 2444},
-	{0x3202, 0, 3 | DECOMP_COMPAT, 2447},
-	{0x3203, 0, 3 | DECOMP_COMPAT, 2450},
-	{0x3204, 0, 3 | DECOMP_COMPAT, 2453},
-	{0x3205, 0, 3 | DECOMP_COMPAT, 2456},
-	{0x3206, 0, 3 | DECOMP_COMPAT, 2459},
-	{0x3207, 0, 3 | DECOMP_COMPAT, 2462},
-	{0x3208, 0, 3 | DECOMP_COMPAT, 2465},
-	{0x3209, 0, 3 | DECOMP_COMPAT, 2468},
-	{0x320A, 0, 3 | DECOMP_COMPAT, 2471},
-	{0x320B, 0, 3 | DECOMP_COMPAT, 2474},
-	{0x320C, 0, 3 | DECOMP_COMPAT, 2477},
-	{0x320D, 0, 3 | DECOMP_COMPAT, 2480},
-	{0x320E, 0, 4 | DECOMP_COMPAT, 2483},
-	{0x320F, 0, 4 | DECOMP_COMPAT, 2487},
-	{0x3210, 0, 4 | DECOMP_COMPAT, 2491},
-	{0x3211, 0, 4 | DECOMP_COMPAT, 2495},
-	{0x3212, 0, 4 | DECOMP_COMPAT, 2499},
-	{0x3213, 0, 4 | DECOMP_COMPAT, 2503},
-	{0x3214, 0, 4 | DECOMP_COMPAT, 2507},
-	{0x3215, 0, 4 | DECOMP_COMPAT, 2511},
-	{0x3216, 0, 4 | DECOMP_COMPAT, 2515},
-	{0x3217, 0, 4 | DECOMP_COMPAT, 2519},
-	{0x3218, 0, 4 | DECOMP_COMPAT, 2523},
-	{0x3219, 0, 4 | DECOMP_COMPAT, 2527},
-	{0x321A, 0, 4 | DECOMP_COMPAT, 2531},
-	{0x321B, 0, 4 | DECOMP_COMPAT, 2535},
-	{0x321C, 0, 4 | DECOMP_COMPAT, 2539},
-	{0x321D, 0, 7 | DECOMP_COMPAT, 2543},
-	{0x321E, 0, 6 | DECOMP_COMPAT, 2550},
-	{0x3220, 0, 3 | DECOMP_COMPAT, 2556},
-	{0x3221, 0, 3 | DECOMP_COMPAT, 2559},
-	{0x3222, 0, 3 | DECOMP_COMPAT, 2562},
-	{0x3223, 0, 3 | DECOMP_COMPAT, 2565},
-	{0x3224, 0, 3 | DECOMP_COMPAT, 2568},
-	{0x3225, 0, 3 | DECOMP_COMPAT, 2571},
-	{0x3226, 0, 3 | DECOMP_COMPAT, 2574},
-	{0x3227, 0, 3 | DECOMP_COMPAT, 2577},
-	{0x3228, 0, 3 | DECOMP_COMPAT, 2580},
-	{0x3229, 0, 3 | DECOMP_COMPAT, 2583},
-	{0x322A, 0, 3 | DECOMP_COMPAT, 2586},
-	{0x322B, 0, 3 | DECOMP_COMPAT, 2589},
-	{0x322C, 0, 3 | DECOMP_COMPAT, 2592},
-	{0x322D, 0, 3 | DECOMP_COMPAT, 2595},
-	{0x322E, 0, 3 | DECOMP_COMPAT, 2598},
-	{0x322F, 0, 3 | DECOMP_COMPAT, 2601},
-	{0x3230, 0, 3 | DECOMP_COMPAT, 2604},
-	{0x3231, 0, 3 | DECOMP_COMPAT, 2607},
-	{0x3232, 0, 3 | DECOMP_COMPAT, 2610},
-	{0x3233, 0, 3 | DECOMP_COMPAT, 2613},
-	{0x3234, 0, 3 | DECOMP_COMPAT, 2616},
-	{0x3235, 0, 3 | DECOMP_COMPAT, 2619},
-	{0x3236, 0, 3 | DECOMP_COMPAT, 2622},
-	{0x3237, 0, 3 | DECOMP_COMPAT, 2625},
-	{0x3238, 0, 3 | DECOMP_COMPAT, 2628},
-	{0x3239, 0, 3 | DECOMP_COMPAT, 2631},
-	{0x323A, 0, 3 | DECOMP_COMPAT, 2634},
-	{0x323B, 0, 3 | DECOMP_COMPAT, 2637},
-	{0x323C, 0, 3 | DECOMP_COMPAT, 2640},
-	{0x323D, 0, 3 | DECOMP_COMPAT, 2643},
-	{0x323E, 0, 3 | DECOMP_COMPAT, 2646},
-	{0x323F, 0, 3 | DECOMP_COMPAT, 2649},
-	{0x3240, 0, 3 | DECOMP_COMPAT, 2652},
-	{0x3241, 0, 3 | DECOMP_COMPAT, 2655},
-	{0x3242, 0, 3 | DECOMP_COMPAT, 2658},
-	{0x3243, 0, 3 | DECOMP_COMPAT, 2661},
-	{0x3244, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x554F},
-	{0x3245, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7C},
-	{0x3246, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6587},
-	{0x3247, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7B8F},
-	{0x3250, 0, 3 | DECOMP_COMPAT, 2664},
-	{0x3251, 0, 2 | DECOMP_COMPAT, 2667},
-	{0x3252, 0, 2 | DECOMP_COMPAT, 2669},
-	{0x3253, 0, 2 | DECOMP_COMPAT, 2671},
-	{0x3254, 0, 2 | DECOMP_COMPAT, 2673},
-	{0x3255, 0, 2 | DECOMP_COMPAT, 2675},
-	{0x3256, 0, 2 | DECOMP_COMPAT, 2677},
-	{0x3257, 0, 2 | DECOMP_COMPAT, 2679},
-	{0x3258, 0, 2 | DECOMP_COMPAT, 2681},
-	{0x3259, 0, 2 | DECOMP_COMPAT, 2683},
-	{0x325A, 0, 2 | DECOMP_COMPAT, 2685},
-	{0x325B, 0, 2 | DECOMP_COMPAT, 2687},
-	{0x325C, 0, 2 | DECOMP_COMPAT, 2689},
-	{0x325D, 0, 2 | DECOMP_COMPAT, 2691},
-	{0x325E, 0, 2 | DECOMP_COMPAT, 2693},
-	{0x325F, 0, 2 | DECOMP_COMPAT, 2695},
-	{0x3260, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1100},
-	{0x3261, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1102},
-	{0x3262, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1103},
-	{0x3263, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1105},
-	{0x3264, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1106},
-	{0x3265, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1107},
-	{0x3266, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1109},
-	{0x3267, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110B},
-	{0x3268, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110C},
-	{0x3269, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110E},
-	{0x326A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110F},
-	{0x326B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1110},
-	{0x326C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1111},
-	{0x326D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1112},
-	{0x326E, 0, 2 | DECOMP_COMPAT, 2697},
-	{0x326F, 0, 2 | DECOMP_COMPAT, 2699},
-	{0x3270, 0, 2 | DECOMP_COMPAT, 2701},
-	{0x3271, 0, 2 | DECOMP_COMPAT, 2703},
-	{0x3272, 0, 2 | DECOMP_COMPAT, 2705},
-	{0x3273, 0, 2 | DECOMP_COMPAT, 2707},
-	{0x3274, 0, 2 | DECOMP_COMPAT, 2709},
-	{0x3275, 0, 2 | DECOMP_COMPAT, 2711},
-	{0x3276, 0, 2 | DECOMP_COMPAT, 2713},
-	{0x3277, 0, 2 | DECOMP_COMPAT, 2715},
-	{0x3278, 0, 2 | DECOMP_COMPAT, 2717},
-	{0x3279, 0, 2 | DECOMP_COMPAT, 2719},
-	{0x327A, 0, 2 | DECOMP_COMPAT, 2721},
-	{0x327B, 0, 2 | DECOMP_COMPAT, 2723},
-	{0x327C, 0, 5 | DECOMP_COMPAT, 2725},
-	{0x327D, 0, 4 | DECOMP_COMPAT, 2730},
-	{0x327E, 0, 2 | DECOMP_COMPAT, 2734},
-	{0x3280, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
-	{0x3281, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
-	{0x3282, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E09},
-	{0x3283, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x56DB},
-	{0x3284, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E94},
-	{0x3285, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x516D},
-	{0x3286, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E03},
-	{0x3287, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x516B},
-	{0x3288, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E5D},
-	{0x3289, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5341},
-	{0x328A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6708},
-	{0x328B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x706B},
-	{0x328C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C34},
-	{0x328D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6728},
-	{0x328E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91D1},
-	{0x328F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x571F},
-	{0x3290, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65E5},
-	{0x3291, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x682A},
-	{0x3292, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6709},
-	{0x3293, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x793E},
-	{0x3294, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x540D},
-	{0x3295, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7279},
-	{0x3296, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CA1},
-	{0x3297, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x795D},
-	{0x3298, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x52B4},
-	{0x3299, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79D8},
-	{0x329A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7537},
-	{0x329B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5973},
-	{0x329C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9069},
-	{0x329D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x512A},
-	{0x329E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5370},
-	{0x329F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6CE8},
-	{0x32A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9805},
-	{0x32A1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4F11},
-	{0x32A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5199},
-	{0x32A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B63},
-	{0x32A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0A},
-	{0x32A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E2D},
-	{0x32A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0B},
-	{0x32A7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DE6},
-	{0x32A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53F3},
-	{0x32A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x533B},
-	{0x32AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B97},
-	{0x32AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B66},
-	{0x32AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76E3},
-	{0x32AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4F01},
-	{0x32AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CC7},
-	{0x32AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5354},
-	{0x32B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x591C},
-	{0x32B1, 0, 2 | DECOMP_COMPAT, 2736},
-	{0x32B2, 0, 2 | DECOMP_COMPAT, 2738},
-	{0x32B3, 0, 2 | DECOMP_COMPAT, 2740},
-	{0x32B4, 0, 2 | DECOMP_COMPAT, 2742},
-	{0x32B5, 0, 2 | DECOMP_COMPAT, 2744},
-	{0x32B6, 0, 2 | DECOMP_COMPAT, 2746},
-	{0x32B7, 0, 2 | DECOMP_COMPAT, 2748},
-	{0x32B8, 0, 2 | DECOMP_COMPAT, 2750},
-	{0x32B9, 0, 2 | DECOMP_COMPAT, 2752},
-	{0x32BA, 0, 2 | DECOMP_COMPAT, 2754},
-	{0x32BB, 0, 2 | DECOMP_COMPAT, 2756},
-	{0x32BC, 0, 2 | DECOMP_COMPAT, 2758},
-	{0x32BD, 0, 2 | DECOMP_COMPAT, 2760},
-	{0x32BE, 0, 2 | DECOMP_COMPAT, 2762},
-	{0x32BF, 0, 2 | DECOMP_COMPAT, 2764},
-	{0x32C0, 0, 2 | DECOMP_COMPAT, 2766},
-	{0x32C1, 0, 2 | DECOMP_COMPAT, 2768},
-	{0x32C2, 0, 2 | DECOMP_COMPAT, 2770},
-	{0x32C3, 0, 2 | DECOMP_COMPAT, 2772},
-	{0x32C4, 0, 2 | DECOMP_COMPAT, 2774},
-	{0x32C5, 0, 2 | DECOMP_COMPAT, 2776},
-	{0x32C6, 0, 2 | DECOMP_COMPAT, 2778},
-	{0x32C7, 0, 2 | DECOMP_COMPAT, 2780},
-	{0x32C8, 0, 2 | DECOMP_COMPAT, 2782},
-	{0x32C9, 0, 3 | DECOMP_COMPAT, 2784},
-	{0x32CA, 0, 3 | DECOMP_COMPAT, 2787},
-	{0x32CB, 0, 3 | DECOMP_COMPAT, 2790},
-	{0x32CC, 0, 2 | DECOMP_COMPAT, 2793},
-	{0x32CD, 0, 3 | DECOMP_COMPAT, 2795},
-	{0x32CE, 0, 2 | DECOMP_COMPAT, 2798},
-	{0x32CF, 0, 3 | DECOMP_COMPAT, 2800},
-	{0x32D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A2},
-	{0x32D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A4},
-	{0x32D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A6},
-	{0x32D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A8},
-	{0x32D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AA},
-	{0x32D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AB},
-	{0x32D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AD},
-	{0x32D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AF},
-	{0x32D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B1},
-	{0x32D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B3},
-	{0x32DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B5},
-	{0x32DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B7},
-	{0x32DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B9},
-	{0x32DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BB},
-	{0x32DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BD},
-	{0x32DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BF},
-	{0x32E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C1},
-	{0x32E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C4},
-	{0x32E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C6},
-	{0x32E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C8},
-	{0x32E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CA},
-	{0x32E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CB},
-	{0x32E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CC},
-	{0x32E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CD},
-	{0x32E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CE},
-	{0x32E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CF},
-	{0x32EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D2},
-	{0x32EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D5},
-	{0x32EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D8},
-	{0x32ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DB},
-	{0x32EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DE},
-	{0x32EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DF},
-	{0x32F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E0},
-	{0x32F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E1},
-	{0x32F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E2},
-	{0x32F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E4},
-	{0x32F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E6},
-	{0x32F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E8},
-	{0x32F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E9},
-	{0x32F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EA},
-	{0x32F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EB},
-	{0x32F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EC},
-	{0x32FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30ED},
-	{0x32FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EF},
-	{0x32FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F0},
-	{0x32FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F1},
-	{0x32FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F2},
-	{0x32FF, 0, 2 | DECOMP_COMPAT, 2803},
-	{0x3300, 0, 4 | DECOMP_COMPAT, 2805},
-	{0x3301, 0, 4 | DECOMP_COMPAT, 2809},
-	{0x3302, 0, 4 | DECOMP_COMPAT, 2813},
-	{0x3303, 0, 3 | DECOMP_COMPAT, 2817},
-	{0x3304, 0, 4 | DECOMP_COMPAT, 2820},
-	{0x3305, 0, 3 | DECOMP_COMPAT, 2824},
-	{0x3306, 0, 3 | DECOMP_COMPAT, 2827},
-	{0x3307, 0, 5 | DECOMP_COMPAT, 2830},
-	{0x3308, 0, 4 | DECOMP_COMPAT, 2835},
-	{0x3309, 0, 3 | DECOMP_COMPAT, 2839},
-	{0x330A, 0, 3 | DECOMP_COMPAT, 2842},
-	{0x330B, 0, 3 | DECOMP_COMPAT, 2845},
-	{0x330C, 0, 4 | DECOMP_COMPAT, 2848},
-	{0x330D, 0, 4 | DECOMP_COMPAT, 2852},
-	{0x330E, 0, 3 | DECOMP_COMPAT, 2856},
-	{0x330F, 0, 3 | DECOMP_COMPAT, 2859},
-	{0x3310, 0, 2 | DECOMP_COMPAT, 2862},
-	{0x3311, 0, 3 | DECOMP_COMPAT, 2864},
-	{0x3312, 0, 4 | DECOMP_COMPAT, 2867},
-	{0x3313, 0, 4 | DECOMP_COMPAT, 2871},
-	{0x3314, 0, 2 | DECOMP_COMPAT, 2875},
-	{0x3315, 0, 5 | DECOMP_COMPAT, 2877},
-	{0x3316, 0, 6 | DECOMP_COMPAT, 2882},
-	{0x3317, 0, 5 | DECOMP_COMPAT, 2888},
-	{0x3318, 0, 3 | DECOMP_COMPAT, 2893},
-	{0x3319, 0, 5 | DECOMP_COMPAT, 2896},
-	{0x331A, 0, 5 | DECOMP_COMPAT, 2901},
-	{0x331B, 0, 4 | DECOMP_COMPAT, 2906},
-	{0x331C, 0, 3 | DECOMP_COMPAT, 2910},
-	{0x331D, 0, 3 | DECOMP_COMPAT, 2913},
-	{0x331E, 0, 3 | DECOMP_COMPAT, 2916},
-	{0x331F, 0, 4 | DECOMP_COMPAT, 2919},
-	{0x3320, 0, 5 | DECOMP_COMPAT, 2923},
-	{0x3321, 0, 4 | DECOMP_COMPAT, 2928},
-	{0x3322, 0, 3 | DECOMP_COMPAT, 2932},
-	{0x3323, 0, 3 | DECOMP_COMPAT, 2935},
-	{0x3324, 0, 3 | DECOMP_COMPAT, 2938},
-	{0x3325, 0, 2 | DECOMP_COMPAT, 2941},
-	{0x3326, 0, 2 | DECOMP_COMPAT, 2943},
-	{0x3327, 0, 2 | DECOMP_COMPAT, 2945},
-	{0x3328, 0, 2 | DECOMP_COMPAT, 2947},
-	{0x3329, 0, 3 | DECOMP_COMPAT, 2949},
-	{0x332A, 0, 3 | DECOMP_COMPAT, 2952},
-	{0x332B, 0, 5 | DECOMP_COMPAT, 2955},
-	{0x332C, 0, 3 | DECOMP_COMPAT, 2960},
-	{0x332D, 0, 4 | DECOMP_COMPAT, 2963},
-	{0x332E, 0, 5 | DECOMP_COMPAT, 2967},
-	{0x332F, 0, 3 | DECOMP_COMPAT, 2972},
-	{0x3330, 0, 2 | DECOMP_COMPAT, 2975},
-	{0x3331, 0, 2 | DECOMP_COMPAT, 2977},
-	{0x3332, 0, 5 | DECOMP_COMPAT, 2979},
-	{0x3333, 0, 4 | DECOMP_COMPAT, 2984},
-	{0x3334, 0, 5 | DECOMP_COMPAT, 2988},
-	{0x3335, 0, 3 | DECOMP_COMPAT, 2993},
-	{0x3336, 0, 5 | DECOMP_COMPAT, 2996},
-	{0x3337, 0, 2 | DECOMP_COMPAT, 3001},
-	{0x3338, 0, 3 | DECOMP_COMPAT, 3003},
-	{0x3339, 0, 3 | DECOMP_COMPAT, 3006},
-	{0x333A, 0, 3 | DECOMP_COMPAT, 3009},
-	{0x333B, 0, 3 | DECOMP_COMPAT, 3012},
-	{0x333C, 0, 3 | DECOMP_COMPAT, 3015},
-	{0x333D, 0, 4 | DECOMP_COMPAT, 3018},
-	{0x333E, 0, 3 | DECOMP_COMPAT, 3022},
-	{0x333F, 0, 2 | DECOMP_COMPAT, 3025},
-	{0x3340, 0, 3 | DECOMP_COMPAT, 3027},
-	{0x3341, 0, 3 | DECOMP_COMPAT, 3030},
-	{0x3342, 0, 3 | DECOMP_COMPAT, 3033},
-	{0x3343, 0, 4 | DECOMP_COMPAT, 3036},
-	{0x3344, 0, 3 | DECOMP_COMPAT, 3040},
-	{0x3345, 0, 3 | DECOMP_COMPAT, 3043},
-	{0x3346, 0, 3 | DECOMP_COMPAT, 3046},
-	{0x3347, 0, 5 | DECOMP_COMPAT, 3049},
-	{0x3348, 0, 4 | DECOMP_COMPAT, 3054},
-	{0x3349, 0, 2 | DECOMP_COMPAT, 3058},
-	{0x334A, 0, 5 | DECOMP_COMPAT, 3060},
-	{0x334B, 0, 2 | DECOMP_COMPAT, 3065},
-	{0x334C, 0, 4 | DECOMP_COMPAT, 3067},
-	{0x334D, 0, 4 | DECOMP_COMPAT, 3071},
-	{0x334E, 0, 3 | DECOMP_COMPAT, 3075},
-	{0x334F, 0, 3 | DECOMP_COMPAT, 3078},
-	{0x3350, 0, 3 | DECOMP_COMPAT, 3081},
-	{0x3351, 0, 4 | DECOMP_COMPAT, 3084},
-	{0x3352, 0, 2 | DECOMP_COMPAT, 3088},
-	{0x3353, 0, 3 | DECOMP_COMPAT, 3090},
-	{0x3354, 0, 4 | DECOMP_COMPAT, 3093},
-	{0x3355, 0, 2 | DECOMP_COMPAT, 3097},
-	{0x3356, 0, 5 | DECOMP_COMPAT, 3099},
-	{0x3357, 0, 3 | DECOMP_COMPAT, 3104},
-	{0x3358, 0, 2 | DECOMP_COMPAT, 3107},
-	{0x3359, 0, 2 | DECOMP_COMPAT, 3109},
-	{0x335A, 0, 2 | DECOMP_COMPAT, 3111},
-	{0x335B, 0, 2 | DECOMP_COMPAT, 3113},
-	{0x335C, 0, 2 | DECOMP_COMPAT, 3115},
-	{0x335D, 0, 2 | DECOMP_COMPAT, 3117},
-	{0x335E, 0, 2 | DECOMP_COMPAT, 3119},
-	{0x335F, 0, 2 | DECOMP_COMPAT, 3121},
-	{0x3360, 0, 2 | DECOMP_COMPAT, 3123},
-	{0x3361, 0, 2 | DECOMP_COMPAT, 3125},
-	{0x3362, 0, 3 | DECOMP_COMPAT, 3127},
-	{0x3363, 0, 3 | DECOMP_COMPAT, 3130},
-	{0x3364, 0, 3 | DECOMP_COMPAT, 3133},
-	{0x3365, 0, 3 | DECOMP_COMPAT, 3136},
-	{0x3366, 0, 3 | DECOMP_COMPAT, 3139},
-	{0x3367, 0, 3 | DECOMP_COMPAT, 3142},
-	{0x3368, 0, 3 | DECOMP_COMPAT, 3145},
-	{0x3369, 0, 3 | DECOMP_COMPAT, 3148},
-	{0x336A, 0, 3 | DECOMP_COMPAT, 3151},
-	{0x336B, 0, 3 | DECOMP_COMPAT, 3154},
-	{0x336C, 0, 3 | DECOMP_COMPAT, 3157},
-	{0x336D, 0, 3 | DECOMP_COMPAT, 3160},
-	{0x336E, 0, 3 | DECOMP_COMPAT, 3163},
-	{0x336F, 0, 3 | DECOMP_COMPAT, 3166},
-	{0x3370, 0, 3 | DECOMP_COMPAT, 3169},
-	{0x3371, 0, 3 | DECOMP_COMPAT, 3172},
-	{0x3372, 0, 2 | DECOMP_COMPAT, 3175},
-	{0x3373, 0, 2 | DECOMP_COMPAT, 3177},
-	{0x3374, 0, 3 | DECOMP_COMPAT, 3179},
-	{0x3375, 0, 2 | DECOMP_COMPAT, 3182},
-	{0x3376, 0, 2 | DECOMP_COMPAT, 3184},
-	{0x3377, 0, 2 | DECOMP_COMPAT, 3186},
-	{0x3378, 0, 3 | DECOMP_COMPAT, 3188},
-	{0x3379, 0, 3 | DECOMP_COMPAT, 3191},
-	{0x337A, 0, 2 | DECOMP_COMPAT, 3194},
-	{0x337B, 0, 2 | DECOMP_COMPAT, 3196},
-	{0x337C, 0, 2 | DECOMP_COMPAT, 3198},
-	{0x337D, 0, 2 | DECOMP_COMPAT, 3200},
-	{0x337E, 0, 2 | DECOMP_COMPAT, 3202},
-	{0x337F, 0, 4 | DECOMP_COMPAT, 3204},
-	{0x3380, 0, 2 | DECOMP_COMPAT, 3208},
-	{0x3381, 0, 2 | DECOMP_COMPAT, 3210},
-	{0x3382, 0, 2 | DECOMP_COMPAT, 3212},
-	{0x3383, 0, 2 | DECOMP_COMPAT, 3214},
-	{0x3384, 0, 2 | DECOMP_COMPAT, 3216},
-	{0x3385, 0, 2 | DECOMP_COMPAT, 3218},
-	{0x3386, 0, 2 | DECOMP_COMPAT, 3220},
-	{0x3387, 0, 2 | DECOMP_COMPAT, 3222},
-	{0x3388, 0, 3 | DECOMP_COMPAT, 3224},
-	{0x3389, 0, 4 | DECOMP_COMPAT, 3227},
-	{0x338A, 0, 2 | DECOMP_COMPAT, 3231},
-	{0x338B, 0, 2 | DECOMP_COMPAT, 3233},
-	{0x338C, 0, 2 | DECOMP_COMPAT, 3235},
-	{0x338D, 0, 2 | DECOMP_COMPAT, 3237},
-	{0x338E, 0, 2 | DECOMP_COMPAT, 3239},
-	{0x338F, 0, 2 | DECOMP_COMPAT, 3241},
-	{0x3390, 0, 2 | DECOMP_COMPAT, 3243},
-	{0x3391, 0, 3 | DECOMP_COMPAT, 3245},
-	{0x3392, 0, 3 | DECOMP_COMPAT, 3248},
-	{0x3393, 0, 3 | DECOMP_COMPAT, 3251},
-	{0x3394, 0, 3 | DECOMP_COMPAT, 3254},
-	{0x3395, 0, 2 | DECOMP_COMPAT, 3257},
-	{0x3396, 0, 2 | DECOMP_COMPAT, 3259},
-	{0x3397, 0, 2 | DECOMP_COMPAT, 3261},
-	{0x3398, 0, 2 | DECOMP_COMPAT, 3263},
-	{0x3399, 0, 2 | DECOMP_COMPAT, 3265},
-	{0x339A, 0, 2 | DECOMP_COMPAT, 3267},
-	{0x339B, 0, 2 | DECOMP_COMPAT, 3269},
-	{0x339C, 0, 2 | DECOMP_COMPAT, 3271},
-	{0x339D, 0, 2 | DECOMP_COMPAT, 3273},
-	{0x339E, 0, 2 | DECOMP_COMPAT, 3275},
-	{0x339F, 0, 3 | DECOMP_COMPAT, 3277},
-	{0x33A0, 0, 3 | DECOMP_COMPAT, 3280},
-	{0x33A1, 0, 2 | DECOMP_COMPAT, 3283},
-	{0x33A2, 0, 3 | DECOMP_COMPAT, 3285},
-	{0x33A3, 0, 3 | DECOMP_COMPAT, 3288},
-	{0x33A4, 0, 3 | DECOMP_COMPAT, 3291},
-	{0x33A5, 0, 2 | DECOMP_COMPAT, 3294},
-	{0x33A6, 0, 3 | DECOMP_COMPAT, 3296},
-	{0x33A7, 0, 3 | DECOMP_COMPAT, 3299},
-	{0x33A8, 0, 4 | DECOMP_COMPAT, 3302},
-	{0x33A9, 0, 2 | DECOMP_COMPAT, 3306},
-	{0x33AA, 0, 3 | DECOMP_COMPAT, 3308},
-	{0x33AB, 0, 3 | DECOMP_COMPAT, 3311},
-	{0x33AC, 0, 3 | DECOMP_COMPAT, 3314},
-	{0x33AD, 0, 3 | DECOMP_COMPAT, 3317},
-	{0x33AE, 0, 5 | DECOMP_COMPAT, 3320},
-	{0x33AF, 0, 6 | DECOMP_COMPAT, 3325},
-	{0x33B0, 0, 2 | DECOMP_COMPAT, 3331},
-	{0x33B1, 0, 2 | DECOMP_COMPAT, 3333},
-	{0x33B2, 0, 2 | DECOMP_COMPAT, 3335},
-	{0x33B3, 0, 2 | DECOMP_COMPAT, 3337},
-	{0x33B4, 0, 2 | DECOMP_COMPAT, 3339},
-	{0x33B5, 0, 2 | DECOMP_COMPAT, 3341},
-	{0x33B6, 0, 2 | DECOMP_COMPAT, 3343},
-	{0x33B7, 0, 2 | DECOMP_COMPAT, 3345},
-	{0x33B8, 0, 2 | DECOMP_COMPAT, 3347},
-	{0x33B9, 0, 2 | DECOMP_COMPAT, 3349},
-	{0x33BA, 0, 2 | DECOMP_COMPAT, 3351},
-	{0x33BB, 0, 2 | DECOMP_COMPAT, 3353},
-	{0x33BC, 0, 2 | DECOMP_COMPAT, 3355},
-	{0x33BD, 0, 2 | DECOMP_COMPAT, 3357},
-	{0x33BE, 0, 2 | DECOMP_COMPAT, 3359},
-	{0x33BF, 0, 2 | DECOMP_COMPAT, 3361},
-	{0x33C0, 0, 2 | DECOMP_COMPAT, 3363},
-	{0x33C1, 0, 2 | DECOMP_COMPAT, 3365},
-	{0x33C2, 0, 4 | DECOMP_COMPAT, 3367},
-	{0x33C3, 0, 2 | DECOMP_COMPAT, 3371},
-	{0x33C4, 0, 2 | DECOMP_COMPAT, 3373},
-	{0x33C5, 0, 2 | DECOMP_COMPAT, 3375},
-	{0x33C6, 0, 4 | DECOMP_COMPAT, 3377},
-	{0x33C7, 0, 3 | DECOMP_COMPAT, 3381},
-	{0x33C8, 0, 2 | DECOMP_COMPAT, 3384},
-	{0x33C9, 0, 2 | DECOMP_COMPAT, 3386},
-	{0x33CA, 0, 2 | DECOMP_COMPAT, 3388},
-	{0x33CB, 0, 2 | DECOMP_COMPAT, 3390},
-	{0x33CC, 0, 2 | DECOMP_COMPAT, 3392},
-	{0x33CD, 0, 2 | DECOMP_COMPAT, 3394},
-	{0x33CE, 0, 2 | DECOMP_COMPAT, 3396},
-	{0x33CF, 0, 2 | DECOMP_COMPAT, 3398},
-	{0x33D0, 0, 2 | DECOMP_COMPAT, 3400},
-	{0x33D1, 0, 2 | DECOMP_COMPAT, 3402},
-	{0x33D2, 0, 3 | DECOMP_COMPAT, 3404},
-	{0x33D3, 0, 2 | DECOMP_COMPAT, 3407},
-	{0x33D4, 0, 2 | DECOMP_COMPAT, 3409},
-	{0x33D5, 0, 3 | DECOMP_COMPAT, 3411},
-	{0x33D6, 0, 3 | DECOMP_COMPAT, 3414},
-	{0x33D7, 0, 2 | DECOMP_COMPAT, 3417},
-	{0x33D8, 0, 4 | DECOMP_COMPAT, 3419},
-	{0x33D9, 0, 3 | DECOMP_COMPAT, 3423},
-	{0x33DA, 0, 2 | DECOMP_COMPAT, 3426},
-	{0x33DB, 0, 2 | DECOMP_COMPAT, 3428},
-	{0x33DC, 0, 2 | DECOMP_COMPAT, 3430},
-	{0x33DD, 0, 2 | DECOMP_COMPAT, 3432},
-	{0x33DE, 0, 3 | DECOMP_COMPAT, 3434},
-	{0x33DF, 0, 3 | DECOMP_COMPAT, 3437},
-	{0x33E0, 0, 2 | DECOMP_COMPAT, 3440},
-	{0x33E1, 0, 2 | DECOMP_COMPAT, 3442},
-	{0x33E2, 0, 2 | DECOMP_COMPAT, 3444},
-	{0x33E3, 0, 2 | DECOMP_COMPAT, 3446},
-	{0x33E4, 0, 2 | DECOMP_COMPAT, 3448},
-	{0x33E5, 0, 2 | DECOMP_COMPAT, 3450},
-	{0x33E6, 0, 2 | DECOMP_COMPAT, 3452},
-	{0x33E7, 0, 2 | DECOMP_COMPAT, 3454},
-	{0x33E8, 0, 2 | DECOMP_COMPAT, 3456},
-	{0x33E9, 0, 3 | DECOMP_COMPAT, 3458},
-	{0x33EA, 0, 3 | DECOMP_COMPAT, 3461},
-	{0x33EB, 0, 3 | DECOMP_COMPAT, 3464},
-	{0x33EC, 0, 3 | DECOMP_COMPAT, 3467},
-	{0x33ED, 0, 3 | DECOMP_COMPAT, 3470},
-	{0x33EE, 0, 3 | DECOMP_COMPAT, 3473},
-	{0x33EF, 0, 3 | DECOMP_COMPAT, 3476},
-	{0x33F0, 0, 3 | DECOMP_COMPAT, 3479},
-	{0x33F1, 0, 3 | DECOMP_COMPAT, 3482},
-	{0x33F2, 0, 3 | DECOMP_COMPAT, 3485},
-	{0x33F3, 0, 3 | DECOMP_COMPAT, 3488},
-	{0x33F4, 0, 3 | DECOMP_COMPAT, 3491},
-	{0x33F5, 0, 3 | DECOMP_COMPAT, 3494},
-	{0x33F6, 0, 3 | DECOMP_COMPAT, 3497},
-	{0x33F7, 0, 3 | DECOMP_COMPAT, 3500},
-	{0x33F8, 0, 3 | DECOMP_COMPAT, 3503},
-	{0x33F9, 0, 3 | DECOMP_COMPAT, 3506},
-	{0x33FA, 0, 3 | DECOMP_COMPAT, 3509},
-	{0x33FB, 0, 3 | DECOMP_COMPAT, 3512},
-	{0x33FC, 0, 3 | DECOMP_COMPAT, 3515},
-	{0x33FD, 0, 3 | DECOMP_COMPAT, 3518},
-	{0x33FE, 0, 3 | DECOMP_COMPAT, 3521},
-	{0x33FF, 0, 3 | DECOMP_COMPAT, 3524},
-	{0xA66F, 230, 0, 0},
-	{0xA674, 230, 0, 0},
-	{0xA675, 230, 0, 0},
-	{0xA676, 230, 0, 0},
-	{0xA677, 230, 0, 0},
-	{0xA678, 230, 0, 0},
-	{0xA679, 230, 0, 0},
-	{0xA67A, 230, 0, 0},
-	{0xA67B, 230, 0, 0},
-	{0xA67C, 230, 0, 0},
-	{0xA67D, 230, 0, 0},
-	{0xA69C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044A},
-	{0xA69D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044C},
-	{0xA69E, 230, 0, 0},
-	{0xA69F, 230, 0, 0},
-	{0xA6F0, 230, 0, 0},
-	{0xA6F1, 230, 0, 0},
-	{0xA770, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA76F},
-	{0xA7F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0xA7F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0xA7F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0xA7F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0126},
-	{0xA7F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0153},
-	{0xA806, 9, 0, 0},
-	{0xA82C, 9, 0, 0},
-	{0xA8C4, 9, 0, 0},
-	{0xA8E0, 230, 0, 0},
-	{0xA8E1, 230, 0, 0},
-	{0xA8E2, 230, 0, 0},
-	{0xA8E3, 230, 0, 0},
-	{0xA8E4, 230, 0, 0},
-	{0xA8E5, 230, 0, 0},
-	{0xA8E6, 230, 0, 0},
-	{0xA8E7, 230, 0, 0},
-	{0xA8E8, 230, 0, 0},
-	{0xA8E9, 230, 0, 0},
-	{0xA8EA, 230, 0, 0},
-	{0xA8EB, 230, 0, 0},
-	{0xA8EC, 230, 0, 0},
-	{0xA8ED, 230, 0, 0},
-	{0xA8EE, 230, 0, 0},
-	{0xA8EF, 230, 0, 0},
-	{0xA8F0, 230, 0, 0},
-	{0xA8F1, 230, 0, 0},
-	{0xA92B, 220, 0, 0},
-	{0xA92C, 220, 0, 0},
-	{0xA92D, 220, 0, 0},
-	{0xA953, 9, 0, 0},
-	{0xA9B3, 7, 0, 0},
-	{0xA9C0, 9, 0, 0},
-	{0xAAB0, 230, 0, 0},
-	{0xAAB2, 230, 0, 0},
-	{0xAAB3, 230, 0, 0},
-	{0xAAB4, 220, 0, 0},
-	{0xAAB7, 230, 0, 0},
-	{0xAAB8, 230, 0, 0},
-	{0xAABE, 230, 0, 0},
-	{0xAABF, 230, 0, 0},
-	{0xAAC1, 230, 0, 0},
-	{0xAAF6, 9, 0, 0},
-	{0xAB5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA727},
-	{0xAB5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB37},
-	{0xAB5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026B},
-	{0xAB5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB52},
-	{0xAB69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028D},
-	{0xABED, 9, 0, 0},
-	{0xF900, 0, 1 | DECOMP_INLINE, 0x8C48},
-	{0xF901, 0, 1 | DECOMP_INLINE, 0x66F4},
-	{0xF902, 0, 1 | DECOMP_INLINE, 0x8ECA},
-	{0xF903, 0, 1 | DECOMP_INLINE, 0x8CC8},
-	{0xF904, 0, 1 | DECOMP_INLINE, 0x6ED1},
-	{0xF905, 0, 1 | DECOMP_INLINE, 0x4E32},
-	{0xF906, 0, 1 | DECOMP_INLINE, 0x53E5},
-	{0xF907, 0, 1 | DECOMP_INLINE, 0x9F9C},
-	{0xF908, 0, 1 | DECOMP_INLINE, 0x9F9C},
-	{0xF909, 0, 1 | DECOMP_INLINE, 0x5951},
-	{0xF90A, 0, 1 | DECOMP_INLINE, 0x91D1},
-	{0xF90B, 0, 1 | DECOMP_INLINE, 0x5587},
-	{0xF90C, 0, 1 | DECOMP_INLINE, 0x5948},
-	{0xF90D, 0, 1 | DECOMP_INLINE, 0x61F6},
-	{0xF90E, 0, 1 | DECOMP_INLINE, 0x7669},
-	{0xF90F, 0, 1 | DECOMP_INLINE, 0x7F85},
-	{0xF910, 0, 1 | DECOMP_INLINE, 0x863F},
-	{0xF911, 0, 1 | DECOMP_INLINE, 0x87BA},
-	{0xF912, 0, 1 | DECOMP_INLINE, 0x88F8},
-	{0xF913, 0, 1 | DECOMP_INLINE, 0x908F},
-	{0xF914, 0, 1 | DECOMP_INLINE, 0x6A02},
-	{0xF915, 0, 1 | DECOMP_INLINE, 0x6D1B},
-	{0xF916, 0, 1 | DECOMP_INLINE, 0x70D9},
-	{0xF917, 0, 1 | DECOMP_INLINE, 0x73DE},
-	{0xF918, 0, 1 | DECOMP_INLINE, 0x843D},
-	{0xF919, 0, 1 | DECOMP_INLINE, 0x916A},
-	{0xF91A, 0, 1 | DECOMP_INLINE, 0x99F1},
-	{0xF91B, 0, 1 | DECOMP_INLINE, 0x4E82},
-	{0xF91C, 0, 1 | DECOMP_INLINE, 0x5375},
-	{0xF91D, 0, 1 | DECOMP_INLINE, 0x6B04},
-	{0xF91E, 0, 1 | DECOMP_INLINE, 0x721B},
-	{0xF91F, 0, 1 | DECOMP_INLINE, 0x862D},
-	{0xF920, 0, 1 | DECOMP_INLINE, 0x9E1E},
-	{0xF921, 0, 1 | DECOMP_INLINE, 0x5D50},
-	{0xF922, 0, 1 | DECOMP_INLINE, 0x6FEB},
-	{0xF923, 0, 1 | DECOMP_INLINE, 0x85CD},
-	{0xF924, 0, 1 | DECOMP_INLINE, 0x8964},
-	{0xF925, 0, 1 | DECOMP_INLINE, 0x62C9},
-	{0xF926, 0, 1 | DECOMP_INLINE, 0x81D8},
-	{0xF927, 0, 1 | DECOMP_INLINE, 0x881F},
-	{0xF928, 0, 1 | DECOMP_INLINE, 0x5ECA},
-	{0xF929, 0, 1 | DECOMP_INLINE, 0x6717},
-	{0xF92A, 0, 1 | DECOMP_INLINE, 0x6D6A},
-	{0xF92B, 0, 1 | DECOMP_INLINE, 0x72FC},
-	{0xF92C, 0, 1 | DECOMP_INLINE, 0x90CE},
-	{0xF92D, 0, 1 | DECOMP_INLINE, 0x4F86},
-	{0xF92E, 0, 1 | DECOMP_INLINE, 0x51B7},
-	{0xF92F, 0, 1 | DECOMP_INLINE, 0x52DE},
-	{0xF930, 0, 1 | DECOMP_INLINE, 0x64C4},
-	{0xF931, 0, 1 | DECOMP_INLINE, 0x6AD3},
-	{0xF932, 0, 1 | DECOMP_INLINE, 0x7210},
-	{0xF933, 0, 1 | DECOMP_INLINE, 0x76E7},
-	{0xF934, 0, 1 | DECOMP_INLINE, 0x8001},
-	{0xF935, 0, 1 | DECOMP_INLINE, 0x8606},
-	{0xF936, 0, 1 | DECOMP_INLINE, 0x865C},
-	{0xF937, 0, 1 | DECOMP_INLINE, 0x8DEF},
-	{0xF938, 0, 1 | DECOMP_INLINE, 0x9732},
-	{0xF939, 0, 1 | DECOMP_INLINE, 0x9B6F},
-	{0xF93A, 0, 1 | DECOMP_INLINE, 0x9DFA},
-	{0xF93B, 0, 1 | DECOMP_INLINE, 0x788C},
-	{0xF93C, 0, 1 | DECOMP_INLINE, 0x797F},
-	{0xF93D, 0, 1 | DECOMP_INLINE, 0x7DA0},
-	{0xF93E, 0, 1 | DECOMP_INLINE, 0x83C9},
-	{0xF93F, 0, 1 | DECOMP_INLINE, 0x9304},
-	{0xF940, 0, 1 | DECOMP_INLINE, 0x9E7F},
-	{0xF941, 0, 1 | DECOMP_INLINE, 0x8AD6},
-	{0xF942, 0, 1 | DECOMP_INLINE, 0x58DF},
-	{0xF943, 0, 1 | DECOMP_INLINE, 0x5F04},
-	{0xF944, 0, 1 | DECOMP_INLINE, 0x7C60},
-	{0xF945, 0, 1 | DECOMP_INLINE, 0x807E},
-	{0xF946, 0, 1 | DECOMP_INLINE, 0x7262},
-	{0xF947, 0, 1 | DECOMP_INLINE, 0x78CA},
-	{0xF948, 0, 1 | DECOMP_INLINE, 0x8CC2},
-	{0xF949, 0, 1 | DECOMP_INLINE, 0x96F7},
-	{0xF94A, 0, 1 | DECOMP_INLINE, 0x58D8},
-	{0xF94B, 0, 1 | DECOMP_INLINE, 0x5C62},
-	{0xF94C, 0, 1 | DECOMP_INLINE, 0x6A13},
-	{0xF94D, 0, 1 | DECOMP_INLINE, 0x6DDA},
-	{0xF94E, 0, 1 | DECOMP_INLINE, 0x6F0F},
-	{0xF94F, 0, 1 | DECOMP_INLINE, 0x7D2F},
-	{0xF950, 0, 1 | DECOMP_INLINE, 0x7E37},
-	{0xF951, 0, 1 | DECOMP_INLINE, 0x964B},
-	{0xF952, 0, 1 | DECOMP_INLINE, 0x52D2},
-	{0xF953, 0, 1 | DECOMP_INLINE, 0x808B},
-	{0xF954, 0, 1 | DECOMP_INLINE, 0x51DC},
-	{0xF955, 0, 1 | DECOMP_INLINE, 0x51CC},
-	{0xF956, 0, 1 | DECOMP_INLINE, 0x7A1C},
-	{0xF957, 0, 1 | DECOMP_INLINE, 0x7DBE},
-	{0xF958, 0, 1 | DECOMP_INLINE, 0x83F1},
-	{0xF959, 0, 1 | DECOMP_INLINE, 0x9675},
-	{0xF95A, 0, 1 | DECOMP_INLINE, 0x8B80},
-	{0xF95B, 0, 1 | DECOMP_INLINE, 0x62CF},
-	{0xF95C, 0, 1 | DECOMP_INLINE, 0x6A02},
-	{0xF95D, 0, 1 | DECOMP_INLINE, 0x8AFE},
-	{0xF95E, 0, 1 | DECOMP_INLINE, 0x4E39},
-	{0xF95F, 0, 1 | DECOMP_INLINE, 0x5BE7},
-	{0xF960, 0, 1 | DECOMP_INLINE, 0x6012},
-	{0xF961, 0, 1 | DECOMP_INLINE, 0x7387},
-	{0xF962, 0, 1 | DECOMP_INLINE, 0x7570},
-	{0xF963, 0, 1 | DECOMP_INLINE, 0x5317},
-	{0xF964, 0, 1 | DECOMP_INLINE, 0x78FB},
-	{0xF965, 0, 1 | DECOMP_INLINE, 0x4FBF},
-	{0xF966, 0, 1 | DECOMP_INLINE, 0x5FA9},
-	{0xF967, 0, 1 | DECOMP_INLINE, 0x4E0D},
-	{0xF968, 0, 1 | DECOMP_INLINE, 0x6CCC},
-	{0xF969, 0, 1 | DECOMP_INLINE, 0x6578},
-	{0xF96A, 0, 1 | DECOMP_INLINE, 0x7D22},
-	{0xF96B, 0, 1 | DECOMP_INLINE, 0x53C3},
-	{0xF96C, 0, 1 | DECOMP_INLINE, 0x585E},
-	{0xF96D, 0, 1 | DECOMP_INLINE, 0x7701},
-	{0xF96E, 0, 1 | DECOMP_INLINE, 0x8449},
-	{0xF96F, 0, 1 | DECOMP_INLINE, 0x8AAA},
-	{0xF970, 0, 1 | DECOMP_INLINE, 0x6BBA},
-	{0xF971, 0, 1 | DECOMP_INLINE, 0x8FB0},
-	{0xF972, 0, 1 | DECOMP_INLINE, 0x6C88},
-	{0xF973, 0, 1 | DECOMP_INLINE, 0x62FE},
-	{0xF974, 0, 1 | DECOMP_INLINE, 0x82E5},
-	{0xF975, 0, 1 | DECOMP_INLINE, 0x63A0},
-	{0xF976, 0, 1 | DECOMP_INLINE, 0x7565},
-	{0xF977, 0, 1 | DECOMP_INLINE, 0x4EAE},
-	{0xF978, 0, 1 | DECOMP_INLINE, 0x5169},
-	{0xF979, 0, 1 | DECOMP_INLINE, 0x51C9},
-	{0xF97A, 0, 1 | DECOMP_INLINE, 0x6881},
-	{0xF97B, 0, 1 | DECOMP_INLINE, 0x7CE7},
-	{0xF97C, 0, 1 | DECOMP_INLINE, 0x826F},
-	{0xF97D, 0, 1 | DECOMP_INLINE, 0x8AD2},
-	{0xF97E, 0, 1 | DECOMP_INLINE, 0x91CF},
-	{0xF97F, 0, 1 | DECOMP_INLINE, 0x52F5},
-	{0xF980, 0, 1 | DECOMP_INLINE, 0x5442},
-	{0xF981, 0, 1 | DECOMP_INLINE, 0x5973},
-	{0xF982, 0, 1 | DECOMP_INLINE, 0x5EEC},
-	{0xF983, 0, 1 | DECOMP_INLINE, 0x65C5},
-	{0xF984, 0, 1 | DECOMP_INLINE, 0x6FFE},
-	{0xF985, 0, 1 | DECOMP_INLINE, 0x792A},
-	{0xF986, 0, 1 | DECOMP_INLINE, 0x95AD},
-	{0xF987, 0, 1 | DECOMP_INLINE, 0x9A6A},
-	{0xF988, 0, 1 | DECOMP_INLINE, 0x9E97},
-	{0xF989, 0, 1 | DECOMP_INLINE, 0x9ECE},
-	{0xF98A, 0, 1 | DECOMP_INLINE, 0x529B},
-	{0xF98B, 0, 1 | DECOMP_INLINE, 0x66C6},
-	{0xF98C, 0, 1 | DECOMP_INLINE, 0x6B77},
-	{0xF98D, 0, 1 | DECOMP_INLINE, 0x8F62},
-	{0xF98E, 0, 1 | DECOMP_INLINE, 0x5E74},
-	{0xF98F, 0, 1 | DECOMP_INLINE, 0x6190},
-	{0xF990, 0, 1 | DECOMP_INLINE, 0x6200},
-	{0xF991, 0, 1 | DECOMP_INLINE, 0x649A},
-	{0xF992, 0, 1 | DECOMP_INLINE, 0x6F23},
-	{0xF993, 0, 1 | DECOMP_INLINE, 0x7149},
-	{0xF994, 0, 1 | DECOMP_INLINE, 0x7489},
-	{0xF995, 0, 1 | DECOMP_INLINE, 0x79CA},
-	{0xF996, 0, 1 | DECOMP_INLINE, 0x7DF4},
-	{0xF997, 0, 1 | DECOMP_INLINE, 0x806F},
-	{0xF998, 0, 1 | DECOMP_INLINE, 0x8F26},
-	{0xF999, 0, 1 | DECOMP_INLINE, 0x84EE},
-	{0xF99A, 0, 1 | DECOMP_INLINE, 0x9023},
-	{0xF99B, 0, 1 | DECOMP_INLINE, 0x934A},
-	{0xF99C, 0, 1 | DECOMP_INLINE, 0x5217},
-	{0xF99D, 0, 1 | DECOMP_INLINE, 0x52A3},
-	{0xF99E, 0, 1 | DECOMP_INLINE, 0x54BD},
-	{0xF99F, 0, 1 | DECOMP_INLINE, 0x70C8},
-	{0xF9A0, 0, 1 | DECOMP_INLINE, 0x88C2},
-	{0xF9A1, 0, 1 | DECOMP_INLINE, 0x8AAA},
-	{0xF9A2, 0, 1 | DECOMP_INLINE, 0x5EC9},
-	{0xF9A3, 0, 1 | DECOMP_INLINE, 0x5FF5},
-	{0xF9A4, 0, 1 | DECOMP_INLINE, 0x637B},
-	{0xF9A5, 0, 1 | DECOMP_INLINE, 0x6BAE},
-	{0xF9A6, 0, 1 | DECOMP_INLINE, 0x7C3E},
-	{0xF9A7, 0, 1 | DECOMP_INLINE, 0x7375},
-	{0xF9A8, 0, 1 | DECOMP_INLINE, 0x4EE4},
-	{0xF9A9, 0, 1 | DECOMP_INLINE, 0x56F9},
-	{0xF9AA, 0, 1 | DECOMP_INLINE, 0x5BE7},
-	{0xF9AB, 0, 1 | DECOMP_INLINE, 0x5DBA},
-	{0xF9AC, 0, 1 | DECOMP_INLINE, 0x601C},
-	{0xF9AD, 0, 1 | DECOMP_INLINE, 0x73B2},
-	{0xF9AE, 0, 1 | DECOMP_INLINE, 0x7469},
-	{0xF9AF, 0, 1 | DECOMP_INLINE, 0x7F9A},
-	{0xF9B0, 0, 1 | DECOMP_INLINE, 0x8046},
-	{0xF9B1, 0, 1 | DECOMP_INLINE, 0x9234},
-	{0xF9B2, 0, 1 | DECOMP_INLINE, 0x96F6},
-	{0xF9B3, 0, 1 | DECOMP_INLINE, 0x9748},
-	{0xF9B4, 0, 1 | DECOMP_INLINE, 0x9818},
-	{0xF9B5, 0, 1 | DECOMP_INLINE, 0x4F8B},
-	{0xF9B6, 0, 1 | DECOMP_INLINE, 0x79AE},
-	{0xF9B7, 0, 1 | DECOMP_INLINE, 0x91B4},
-	{0xF9B8, 0, 1 | DECOMP_INLINE, 0x96B8},
-	{0xF9B9, 0, 1 | DECOMP_INLINE, 0x60E1},
-	{0xF9BA, 0, 1 | DECOMP_INLINE, 0x4E86},
-	{0xF9BB, 0, 1 | DECOMP_INLINE, 0x50DA},
-	{0xF9BC, 0, 1 | DECOMP_INLINE, 0x5BEE},
-	{0xF9BD, 0, 1 | DECOMP_INLINE, 0x5C3F},
-	{0xF9BE, 0, 1 | DECOMP_INLINE, 0x6599},
-	{0xF9BF, 0, 1 | DECOMP_INLINE, 0x6A02},
-	{0xF9C0, 0, 1 | DECOMP_INLINE, 0x71CE},
-	{0xF9C1, 0, 1 | DECOMP_INLINE, 0x7642},
-	{0xF9C2, 0, 1 | DECOMP_INLINE, 0x84FC},
-	{0xF9C3, 0, 1 | DECOMP_INLINE, 0x907C},
-	{0xF9C4, 0, 1 | DECOMP_INLINE, 0x9F8D},
-	{0xF9C5, 0, 1 | DECOMP_INLINE, 0x6688},
-	{0xF9C6, 0, 1 | DECOMP_INLINE, 0x962E},
-	{0xF9C7, 0, 1 | DECOMP_INLINE, 0x5289},
-	{0xF9C8, 0, 1 | DECOMP_INLINE, 0x677B},
-	{0xF9C9, 0, 1 | DECOMP_INLINE, 0x67F3},
-	{0xF9CA, 0, 1 | DECOMP_INLINE, 0x6D41},
-	{0xF9CB, 0, 1 | DECOMP_INLINE, 0x6E9C},
-	{0xF9CC, 0, 1 | DECOMP_INLINE, 0x7409},
-	{0xF9CD, 0, 1 | DECOMP_INLINE, 0x7559},
-	{0xF9CE, 0, 1 | DECOMP_INLINE, 0x786B},
-	{0xF9CF, 0, 1 | DECOMP_INLINE, 0x7D10},
-	{0xF9D0, 0, 1 | DECOMP_INLINE, 0x985E},
-	{0xF9D1, 0, 1 | DECOMP_INLINE, 0x516D},
-	{0xF9D2, 0, 1 | DECOMP_INLINE, 0x622E},
-	{0xF9D3, 0, 1 | DECOMP_INLINE, 0x9678},
-	{0xF9D4, 0, 1 | DECOMP_INLINE, 0x502B},
-	{0xF9D5, 0, 1 | DECOMP_INLINE, 0x5D19},
-	{0xF9D6, 0, 1 | DECOMP_INLINE, 0x6DEA},
-	{0xF9D7, 0, 1 | DECOMP_INLINE, 0x8F2A},
-	{0xF9D8, 0, 1 | DECOMP_INLINE, 0x5F8B},
-	{0xF9D9, 0, 1 | DECOMP_INLINE, 0x6144},
-	{0xF9DA, 0, 1 | DECOMP_INLINE, 0x6817},
-	{0xF9DB, 0, 1 | DECOMP_INLINE, 0x7387},
-	{0xF9DC, 0, 1 | DECOMP_INLINE, 0x9686},
-	{0xF9DD, 0, 1 | DECOMP_INLINE, 0x5229},
-	{0xF9DE, 0, 1 | DECOMP_INLINE, 0x540F},
-	{0xF9DF, 0, 1 | DECOMP_INLINE, 0x5C65},
-	{0xF9E0, 0, 1 | DECOMP_INLINE, 0x6613},
-	{0xF9E1, 0, 1 | DECOMP_INLINE, 0x674E},
-	{0xF9E2, 0, 1 | DECOMP_INLINE, 0x68A8},
-	{0xF9E3, 0, 1 | DECOMP_INLINE, 0x6CE5},
-	{0xF9E4, 0, 1 | DECOMP_INLINE, 0x7406},
-	{0xF9E5, 0, 1 | DECOMP_INLINE, 0x75E2},
-	{0xF9E6, 0, 1 | DECOMP_INLINE, 0x7F79},
-	{0xF9E7, 0, 1 | DECOMP_INLINE, 0x88CF},
-	{0xF9E8, 0, 1 | DECOMP_INLINE, 0x88E1},
-	{0xF9E9, 0, 1 | DECOMP_INLINE, 0x91CC},
-	{0xF9EA, 0, 1 | DECOMP_INLINE, 0x96E2},
-	{0xF9EB, 0, 1 | DECOMP_INLINE, 0x533F},
-	{0xF9EC, 0, 1 | DECOMP_INLINE, 0x6EBA},
-	{0xF9ED, 0, 1 | DECOMP_INLINE, 0x541D},
-	{0xF9EE, 0, 1 | DECOMP_INLINE, 0x71D0},
-	{0xF9EF, 0, 1 | DECOMP_INLINE, 0x7498},
-	{0xF9F0, 0, 1 | DECOMP_INLINE, 0x85FA},
-	{0xF9F1, 0, 1 | DECOMP_INLINE, 0x96A3},
-	{0xF9F2, 0, 1 | DECOMP_INLINE, 0x9C57},
-	{0xF9F3, 0, 1 | DECOMP_INLINE, 0x9E9F},
-	{0xF9F4, 0, 1 | DECOMP_INLINE, 0x6797},
-	{0xF9F5, 0, 1 | DECOMP_INLINE, 0x6DCB},
-	{0xF9F6, 0, 1 | DECOMP_INLINE, 0x81E8},
-	{0xF9F7, 0, 1 | DECOMP_INLINE, 0x7ACB},
-	{0xF9F8, 0, 1 | DECOMP_INLINE, 0x7B20},
-	{0xF9F9, 0, 1 | DECOMP_INLINE, 0x7C92},
-	{0xF9FA, 0, 1 | DECOMP_INLINE, 0x72C0},
-	{0xF9FB, 0, 1 | DECOMP_INLINE, 0x7099},
-	{0xF9FC, 0, 1 | DECOMP_INLINE, 0x8B58},
-	{0xF9FD, 0, 1 | DECOMP_INLINE, 0x4EC0},
-	{0xF9FE, 0, 1 | DECOMP_INLINE, 0x8336},
-	{0xF9FF, 0, 1 | DECOMP_INLINE, 0x523A},
-	{0xFA00, 0, 1 | DECOMP_INLINE, 0x5207},
-	{0xFA01, 0, 1 | DECOMP_INLINE, 0x5EA6},
-	{0xFA02, 0, 1 | DECOMP_INLINE, 0x62D3},
-	{0xFA03, 0, 1 | DECOMP_INLINE, 0x7CD6},
-	{0xFA04, 0, 1 | DECOMP_INLINE, 0x5B85},
-	{0xFA05, 0, 1 | DECOMP_INLINE, 0x6D1E},
-	{0xFA06, 0, 1 | DECOMP_INLINE, 0x66B4},
-	{0xFA07, 0, 1 | DECOMP_INLINE, 0x8F3B},
-	{0xFA08, 0, 1 | DECOMP_INLINE, 0x884C},
-	{0xFA09, 0, 1 | DECOMP_INLINE, 0x964D},
-	{0xFA0A, 0, 1 | DECOMP_INLINE, 0x898B},
-	{0xFA0B, 0, 1 | DECOMP_INLINE, 0x5ED3},
-	{0xFA0C, 0, 1 | DECOMP_INLINE, 0x5140},
-	{0xFA0D, 0, 1 | DECOMP_INLINE, 0x55C0},
-	{0xFA10, 0, 1 | DECOMP_INLINE, 0x585A},
-	{0xFA12, 0, 1 | DECOMP_INLINE, 0x6674},
-	{0xFA15, 0, 1 | DECOMP_INLINE, 0x51DE},
-	{0xFA16, 0, 1 | DECOMP_INLINE, 0x732A},
-	{0xFA17, 0, 1 | DECOMP_INLINE, 0x76CA},
-	{0xFA18, 0, 1 | DECOMP_INLINE, 0x793C},
-	{0xFA19, 0, 1 | DECOMP_INLINE, 0x795E},
-	{0xFA1A, 0, 1 | DECOMP_INLINE, 0x7965},
-	{0xFA1B, 0, 1 | DECOMP_INLINE, 0x798F},
-	{0xFA1C, 0, 1 | DECOMP_INLINE, 0x9756},
-	{0xFA1D, 0, 1 | DECOMP_INLINE, 0x7CBE},
-	{0xFA1E, 0, 1 | DECOMP_INLINE, 0x7FBD},
-	{0xFA20, 0, 1 | DECOMP_INLINE, 0x8612},
-	{0xFA22, 0, 1 | DECOMP_INLINE, 0x8AF8},
-	{0xFA25, 0, 1 | DECOMP_INLINE, 0x9038},
-	{0xFA26, 0, 1 | DECOMP_INLINE, 0x90FD},
-	{0xFA2A, 0, 1 | DECOMP_INLINE, 0x98EF},
-	{0xFA2B, 0, 1 | DECOMP_INLINE, 0x98FC},
-	{0xFA2C, 0, 1 | DECOMP_INLINE, 0x9928},
-	{0xFA2D, 0, 1 | DECOMP_INLINE, 0x9DB4},
-	{0xFA2E, 0, 1 | DECOMP_INLINE, 0x90DE},
-	{0xFA2F, 0, 1 | DECOMP_INLINE, 0x96B7},
-	{0xFA30, 0, 1 | DECOMP_INLINE, 0x4FAE},
-	{0xFA31, 0, 1 | DECOMP_INLINE, 0x50E7},
-	{0xFA32, 0, 1 | DECOMP_INLINE, 0x514D},
-	{0xFA33, 0, 1 | DECOMP_INLINE, 0x52C9},
-	{0xFA34, 0, 1 | DECOMP_INLINE, 0x52E4},
-	{0xFA35, 0, 1 | DECOMP_INLINE, 0x5351},
-	{0xFA36, 0, 1 | DECOMP_INLINE, 0x559D},
-	{0xFA37, 0, 1 | DECOMP_INLINE, 0x5606},
-	{0xFA38, 0, 1 | DECOMP_INLINE, 0x5668},
-	{0xFA39, 0, 1 | DECOMP_INLINE, 0x5840},
-	{0xFA3A, 0, 1 | DECOMP_INLINE, 0x58A8},
-	{0xFA3B, 0, 1 | DECOMP_INLINE, 0x5C64},
-	{0xFA3C, 0, 1 | DECOMP_INLINE, 0x5C6E},
-	{0xFA3D, 0, 1 | DECOMP_INLINE, 0x6094},
-	{0xFA3E, 0, 1 | DECOMP_INLINE, 0x6168},
-	{0xFA3F, 0, 1 | DECOMP_INLINE, 0x618E},
-	{0xFA40, 0, 1 | DECOMP_INLINE, 0x61F2},
-	{0xFA41, 0, 1 | DECOMP_INLINE, 0x654F},
-	{0xFA42, 0, 1 | DECOMP_INLINE, 0x65E2},
-	{0xFA43, 0, 1 | DECOMP_INLINE, 0x6691},
-	{0xFA44, 0, 1 | DECOMP_INLINE, 0x6885},
-	{0xFA45, 0, 1 | DECOMP_INLINE, 0x6D77},
-	{0xFA46, 0, 1 | DECOMP_INLINE, 0x6E1A},
-	{0xFA47, 0, 1 | DECOMP_INLINE, 0x6F22},
-	{0xFA48, 0, 1 | DECOMP_INLINE, 0x716E},
-	{0xFA49, 0, 1 | DECOMP_INLINE, 0x722B},
-	{0xFA4A, 0, 1 | DECOMP_INLINE, 0x7422},
-	{0xFA4B, 0, 1 | DECOMP_INLINE, 0x7891},
-	{0xFA4C, 0, 1 | DECOMP_INLINE, 0x793E},
-	{0xFA4D, 0, 1 | DECOMP_INLINE, 0x7949},
-	{0xFA4E, 0, 1 | DECOMP_INLINE, 0x7948},
-	{0xFA4F, 0, 1 | DECOMP_INLINE, 0x7950},
-	{0xFA50, 0, 1 | DECOMP_INLINE, 0x7956},
-	{0xFA51, 0, 1 | DECOMP_INLINE, 0x795D},
-	{0xFA52, 0, 1 | DECOMP_INLINE, 0x798D},
-	{0xFA53, 0, 1 | DECOMP_INLINE, 0x798E},
-	{0xFA54, 0, 1 | DECOMP_INLINE, 0x7A40},
-	{0xFA55, 0, 1 | DECOMP_INLINE, 0x7A81},
-	{0xFA56, 0, 1 | DECOMP_INLINE, 0x7BC0},
-	{0xFA57, 0, 1 | DECOMP_INLINE, 0x7DF4},
-	{0xFA58, 0, 1 | DECOMP_INLINE, 0x7E09},
-	{0xFA59, 0, 1 | DECOMP_INLINE, 0x7E41},
-	{0xFA5A, 0, 1 | DECOMP_INLINE, 0x7F72},
-	{0xFA5B, 0, 1 | DECOMP_INLINE, 0x8005},
-	{0xFA5C, 0, 1 | DECOMP_INLINE, 0x81ED},
-	{0xFA5D, 0, 1 | DECOMP_INLINE, 0x8279},
-	{0xFA5E, 0, 1 | DECOMP_INLINE, 0x8279},
-	{0xFA5F, 0, 1 | DECOMP_INLINE, 0x8457},
-	{0xFA60, 0, 1 | DECOMP_INLINE, 0x8910},
-	{0xFA61, 0, 1 | DECOMP_INLINE, 0x8996},
-	{0xFA62, 0, 1 | DECOMP_INLINE, 0x8B01},
-	{0xFA63, 0, 1 | DECOMP_INLINE, 0x8B39},
-	{0xFA64, 0, 1 | DECOMP_INLINE, 0x8CD3},
-	{0xFA65, 0, 1 | DECOMP_INLINE, 0x8D08},
-	{0xFA66, 0, 1 | DECOMP_INLINE, 0x8FB6},
-	{0xFA67, 0, 1 | DECOMP_INLINE, 0x9038},
-	{0xFA68, 0, 1 | DECOMP_INLINE, 0x96E3},
-	{0xFA69, 0, 1 | DECOMP_INLINE, 0x97FF},
-	{0xFA6A, 0, 1 | DECOMP_INLINE, 0x983B},
-	{0xFA6B, 0, 1 | DECOMP_INLINE, 0x6075},
-	{0xFA6C, 0, 1, 3527},
-	{0xFA6D, 0, 1 | DECOMP_INLINE, 0x8218},
-	{0xFA70, 0, 1 | DECOMP_INLINE, 0x4E26},
-	{0xFA71, 0, 1 | DECOMP_INLINE, 0x51B5},
-	{0xFA72, 0, 1 | DECOMP_INLINE, 0x5168},
-	{0xFA73, 0, 1 | DECOMP_INLINE, 0x4F80},
-	{0xFA74, 0, 1 | DECOMP_INLINE, 0x5145},
-	{0xFA75, 0, 1 | DECOMP_INLINE, 0x5180},
-	{0xFA76, 0, 1 | DECOMP_INLINE, 0x52C7},
-	{0xFA77, 0, 1 | DECOMP_INLINE, 0x52FA},
-	{0xFA78, 0, 1 | DECOMP_INLINE, 0x559D},
-	{0xFA79, 0, 1 | DECOMP_INLINE, 0x5555},
-	{0xFA7A, 0, 1 | DECOMP_INLINE, 0x5599},
-	{0xFA7B, 0, 1 | DECOMP_INLINE, 0x55E2},
-	{0xFA7C, 0, 1 | DECOMP_INLINE, 0x585A},
-	{0xFA7D, 0, 1 | DECOMP_INLINE, 0x58B3},
-	{0xFA7E, 0, 1 | DECOMP_INLINE, 0x5944},
-	{0xFA7F, 0, 1 | DECOMP_INLINE, 0x5954},
-	{0xFA80, 0, 1 | DECOMP_INLINE, 0x5A62},
-	{0xFA81, 0, 1 | DECOMP_INLINE, 0x5B28},
-	{0xFA82, 0, 1 | DECOMP_INLINE, 0x5ED2},
-	{0xFA83, 0, 1 | DECOMP_INLINE, 0x5ED9},
-	{0xFA84, 0, 1 | DECOMP_INLINE, 0x5F69},
-	{0xFA85, 0, 1 | DECOMP_INLINE, 0x5FAD},
-	{0xFA86, 0, 1 | DECOMP_INLINE, 0x60D8},
-	{0xFA87, 0, 1 | DECOMP_INLINE, 0x614E},
-	{0xFA88, 0, 1 | DECOMP_INLINE, 0x6108},
-	{0xFA89, 0, 1 | DECOMP_INLINE, 0x618E},
-	{0xFA8A, 0, 1 | DECOMP_INLINE, 0x6160},
-	{0xFA8B, 0, 1 | DECOMP_INLINE, 0x61F2},
-	{0xFA8C, 0, 1 | DECOMP_INLINE, 0x6234},
-	{0xFA8D, 0, 1 | DECOMP_INLINE, 0x63C4},
-	{0xFA8E, 0, 1 | DECOMP_INLINE, 0x641C},
-	{0xFA8F, 0, 1 | DECOMP_INLINE, 0x6452},
-	{0xFA90, 0, 1 | DECOMP_INLINE, 0x6556},
-	{0xFA91, 0, 1 | DECOMP_INLINE, 0x6674},
-	{0xFA92, 0, 1 | DECOMP_INLINE, 0x6717},
-	{0xFA93, 0, 1 | DECOMP_INLINE, 0x671B},
-	{0xFA94, 0, 1 | DECOMP_INLINE, 0x6756},
-	{0xFA95, 0, 1 | DECOMP_INLINE, 0x6B79},
-	{0xFA96, 0, 1 | DECOMP_INLINE, 0x6BBA},
-	{0xFA97, 0, 1 | DECOMP_INLINE, 0x6D41},
-	{0xFA98, 0, 1 | DECOMP_INLINE, 0x6EDB},
-	{0xFA99, 0, 1 | DECOMP_INLINE, 0x6ECB},
-	{0xFA9A, 0, 1 | DECOMP_INLINE, 0x6F22},
-	{0xFA9B, 0, 1 | DECOMP_INLINE, 0x701E},
-	{0xFA9C, 0, 1 | DECOMP_INLINE, 0x716E},
-	{0xFA9D, 0, 1 | DECOMP_INLINE, 0x77A7},
-	{0xFA9E, 0, 1 | DECOMP_INLINE, 0x7235},
-	{0xFA9F, 0, 1 | DECOMP_INLINE, 0x72AF},
-	{0xFAA0, 0, 1 | DECOMP_INLINE, 0x732A},
-	{0xFAA1, 0, 1 | DECOMP_INLINE, 0x7471},
-	{0xFAA2, 0, 1 | DECOMP_INLINE, 0x7506},
-	{0xFAA3, 0, 1 | DECOMP_INLINE, 0x753B},
-	{0xFAA4, 0, 1 | DECOMP_INLINE, 0x761D},
-	{0xFAA5, 0, 1 | DECOMP_INLINE, 0x761F},
-	{0xFAA6, 0, 1 | DECOMP_INLINE, 0x76CA},
-	{0xFAA7, 0, 1 | DECOMP_INLINE, 0x76DB},
-	{0xFAA8, 0, 1 | DECOMP_INLINE, 0x76F4},
-	{0xFAA9, 0, 1 | DECOMP_INLINE, 0x774A},
-	{0xFAAA, 0, 1 | DECOMP_INLINE, 0x7740},
-	{0xFAAB, 0, 1 | DECOMP_INLINE, 0x78CC},
-	{0xFAAC, 0, 1 | DECOMP_INLINE, 0x7AB1},
-	{0xFAAD, 0, 1 | DECOMP_INLINE, 0x7BC0},
-	{0xFAAE, 0, 1 | DECOMP_INLINE, 0x7C7B},
-	{0xFAAF, 0, 1 | DECOMP_INLINE, 0x7D5B},
-	{0xFAB0, 0, 1 | DECOMP_INLINE, 0x7DF4},
-	{0xFAB1, 0, 1 | DECOMP_INLINE, 0x7F3E},
-	{0xFAB2, 0, 1 | DECOMP_INLINE, 0x8005},
-	{0xFAB3, 0, 1 | DECOMP_INLINE, 0x8352},
-	{0xFAB4, 0, 1 | DECOMP_INLINE, 0x83EF},
-	{0xFAB5, 0, 1 | DECOMP_INLINE, 0x8779},
-	{0xFAB6, 0, 1 | DECOMP_INLINE, 0x8941},
-	{0xFAB7, 0, 1 | DECOMP_INLINE, 0x8986},
-	{0xFAB8, 0, 1 | DECOMP_INLINE, 0x8996},
-	{0xFAB9, 0, 1 | DECOMP_INLINE, 0x8ABF},
-	{0xFABA, 0, 1 | DECOMP_INLINE, 0x8AF8},
-	{0xFABB, 0, 1 | DECOMP_INLINE, 0x8ACB},
-	{0xFABC, 0, 1 | DECOMP_INLINE, 0x8B01},
-	{0xFABD, 0, 1 | DECOMP_INLINE, 0x8AFE},
-	{0xFABE, 0, 1 | DECOMP_INLINE, 0x8AED},
-	{0xFABF, 0, 1 | DECOMP_INLINE, 0x8B39},
-	{0xFAC0, 0, 1 | DECOMP_INLINE, 0x8B8A},
-	{0xFAC1, 0, 1 | DECOMP_INLINE, 0x8D08},
-	{0xFAC2, 0, 1 | DECOMP_INLINE, 0x8F38},
-	{0xFAC3, 0, 1 | DECOMP_INLINE, 0x9072},
-	{0xFAC4, 0, 1 | DECOMP_INLINE, 0x9199},
-	{0xFAC5, 0, 1 | DECOMP_INLINE, 0x9276},
-	{0xFAC6, 0, 1 | DECOMP_INLINE, 0x967C},
-	{0xFAC7, 0, 1 | DECOMP_INLINE, 0x96E3},
-	{0xFAC8, 0, 1 | DECOMP_INLINE, 0x9756},
-	{0xFAC9, 0, 1 | DECOMP_INLINE, 0x97DB},
-	{0xFACA, 0, 1 | DECOMP_INLINE, 0x97FF},
-	{0xFACB, 0, 1 | DECOMP_INLINE, 0x980B},
-	{0xFACC, 0, 1 | DECOMP_INLINE, 0x983B},
-	{0xFACD, 0, 1 | DECOMP_INLINE, 0x9B12},
-	{0xFACE, 0, 1 | DECOMP_INLINE, 0x9F9C},
-	{0xFACF, 0, 1, 3528},
-	{0xFAD0, 0, 1, 3529},
-	{0xFAD1, 0, 1, 3530},
-	{0xFAD2, 0, 1 | DECOMP_INLINE, 0x3B9D},
-	{0xFAD3, 0, 1 | DECOMP_INLINE, 0x4018},
-	{0xFAD4, 0, 1 | DECOMP_INLINE, 0x4039},
-	{0xFAD5, 0, 1, 3531},
-	{0xFAD6, 0, 1, 3532},
-	{0xFAD7, 0, 1, 3533},
-	{0xFAD8, 0, 1 | DECOMP_INLINE, 0x9F43},
-	{0xFAD9, 0, 1 | DECOMP_INLINE, 0x9F8E},
-	{0xFB00, 0, 2 | DECOMP_COMPAT, 3534},
-	{0xFB01, 0, 2 | DECOMP_COMPAT, 3536},
-	{0xFB02, 0, 2 | DECOMP_COMPAT, 3538},
-	{0xFB03, 0, 3 | DECOMP_COMPAT, 3540},
-	{0xFB04, 0, 3 | DECOMP_COMPAT, 3543},
-	{0xFB05, 0, 2 | DECOMP_COMPAT, 3546},
-	{0xFB06, 0, 2 | DECOMP_COMPAT, 3548},
-	{0xFB13, 0, 2 | DECOMP_COMPAT, 3550},
-	{0xFB14, 0, 2 | DECOMP_COMPAT, 3552},
-	{0xFB15, 0, 2 | DECOMP_COMPAT, 3554},
-	{0xFB16, 0, 2 | DECOMP_COMPAT, 3556},
-	{0xFB17, 0, 2 | DECOMP_COMPAT, 3558},
-	{0xFB1D, 0, 2 | DECOMP_NO_COMPOSE, 3560},	/* in exclusion list */
-	{0xFB1E, 26, 0, 0},
-	{0xFB1F, 0, 2 | DECOMP_NO_COMPOSE, 3562},	/* in exclusion list */
-	{0xFB20, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05E2},
-	{0xFB21, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D0},
-	{0xFB22, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D3},
-	{0xFB23, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D4},
-	{0xFB24, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DB},
-	{0xFB25, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DC},
-	{0xFB26, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DD},
-	{0xFB27, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05E8},
-	{0xFB28, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05EA},
-	{0xFB29, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
-	{0xFB2A, 0, 2 | DECOMP_NO_COMPOSE, 3564},	/* in exclusion list */
-	{0xFB2B, 0, 2 | DECOMP_NO_COMPOSE, 3566},	/* in exclusion list */
-	{0xFB2C, 0, 2 | DECOMP_NO_COMPOSE, 3568},	/* in exclusion list */
-	{0xFB2D, 0, 2 | DECOMP_NO_COMPOSE, 3570},	/* in exclusion list */
-	{0xFB2E, 0, 2 | DECOMP_NO_COMPOSE, 3572},	/* in exclusion list */
-	{0xFB2F, 0, 2 | DECOMP_NO_COMPOSE, 3574},	/* in exclusion list */
-	{0xFB30, 0, 2 | DECOMP_NO_COMPOSE, 3576},	/* in exclusion list */
-	{0xFB31, 0, 2 | DECOMP_NO_COMPOSE, 3578},	/* in exclusion list */
-	{0xFB32, 0, 2 | DECOMP_NO_COMPOSE, 3580},	/* in exclusion list */
-	{0xFB33, 0, 2 | DECOMP_NO_COMPOSE, 3582},	/* in exclusion list */
-	{0xFB34, 0, 2 | DECOMP_NO_COMPOSE, 3584},	/* in exclusion list */
-	{0xFB35, 0, 2 | DECOMP_NO_COMPOSE, 3586},	/* in exclusion list */
-	{0xFB36, 0, 2 | DECOMP_NO_COMPOSE, 3588},	/* in exclusion list */
-	{0xFB38, 0, 2 | DECOMP_NO_COMPOSE, 3590},	/* in exclusion list */
-	{0xFB39, 0, 2 | DECOMP_NO_COMPOSE, 3592},	/* in exclusion list */
-	{0xFB3A, 0, 2 | DECOMP_NO_COMPOSE, 3594},	/* in exclusion list */
-	{0xFB3B, 0, 2 | DECOMP_NO_COMPOSE, 3596},	/* in exclusion list */
-	{0xFB3C, 0, 2 | DECOMP_NO_COMPOSE, 3598},	/* in exclusion list */
-	{0xFB3E, 0, 2 | DECOMP_NO_COMPOSE, 3600},	/* in exclusion list */
-	{0xFB40, 0, 2 | DECOMP_NO_COMPOSE, 3602},	/* in exclusion list */
-	{0xFB41, 0, 2 | DECOMP_NO_COMPOSE, 3604},	/* in exclusion list */
-	{0xFB43, 0, 2 | DECOMP_NO_COMPOSE, 3606},	/* in exclusion list */
-	{0xFB44, 0, 2 | DECOMP_NO_COMPOSE, 3608},	/* in exclusion list */
-	{0xFB46, 0, 2 | DECOMP_NO_COMPOSE, 3610},	/* in exclusion list */
-	{0xFB47, 0, 2 | DECOMP_NO_COMPOSE, 3612},	/* in exclusion list */
-	{0xFB48, 0, 2 | DECOMP_NO_COMPOSE, 3614},	/* in exclusion list */
-	{0xFB49, 0, 2 | DECOMP_NO_COMPOSE, 3616},	/* in exclusion list */
-	{0xFB4A, 0, 2 | DECOMP_NO_COMPOSE, 3618},	/* in exclusion list */
-	{0xFB4B, 0, 2 | DECOMP_NO_COMPOSE, 3620},	/* in exclusion list */
-	{0xFB4C, 0, 2 | DECOMP_NO_COMPOSE, 3622},	/* in exclusion list */
-	{0xFB4D, 0, 2 | DECOMP_NO_COMPOSE, 3624},	/* in exclusion list */
-	{0xFB4E, 0, 2 | DECOMP_NO_COMPOSE, 3626},	/* in exclusion list */
-	{0xFB4F, 0, 2 | DECOMP_COMPAT, 3628},
-	{0xFB50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0671},
-	{0xFB51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0671},
-	{0xFB52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
-	{0xFB53, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
-	{0xFB54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
-	{0xFB55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
-	{0xFB56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
-	{0xFB57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
-	{0xFB58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
-	{0xFB59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
-	{0xFB5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
-	{0xFB5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
-	{0xFB5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
-	{0xFB5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
-	{0xFB5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
-	{0xFB5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
-	{0xFB60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
-	{0xFB61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
-	{0xFB62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
-	{0xFB63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
-	{0xFB64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
-	{0xFB65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
-	{0xFB66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
-	{0xFB67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
-	{0xFB68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
-	{0xFB69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
-	{0xFB6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
-	{0xFB6B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
-	{0xFB6C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
-	{0xFB6D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
-	{0xFB6E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
-	{0xFB6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
-	{0xFB70, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
-	{0xFB71, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
-	{0xFB72, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
-	{0xFB73, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
-	{0xFB74, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
-	{0xFB75, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
-	{0xFB76, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
-	{0xFB77, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
-	{0xFB78, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
-	{0xFB79, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
-	{0xFB7A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
-	{0xFB7B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
-	{0xFB7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
-	{0xFB7D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
-	{0xFB7E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
-	{0xFB7F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
-	{0xFB80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
-	{0xFB81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
-	{0xFB82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068D},
-	{0xFB83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068D},
-	{0xFB84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068C},
-	{0xFB85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068C},
-	{0xFB86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068E},
-	{0xFB87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068E},
-	{0xFB88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0688},
-	{0xFB89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0688},
-	{0xFB8A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0698},
-	{0xFB8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0698},
-	{0xFB8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0691},
-	{0xFB8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0691},
-	{0xFB8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
-	{0xFB8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
-	{0xFB90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
-	{0xFB91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
-	{0xFB92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
-	{0xFB93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
-	{0xFB94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
-	{0xFB95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
-	{0xFB96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
-	{0xFB97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
-	{0xFB98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
-	{0xFB99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
-	{0xFB9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
-	{0xFB9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
-	{0xFB9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
-	{0xFB9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
-	{0xFB9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
-	{0xFB9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
-	{0xFBA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
-	{0xFBA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
-	{0xFBA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
-	{0xFBA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
-	{0xFBA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C0},
-	{0xFBA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C0},
-	{0xFBA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
-	{0xFBA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
-	{0xFBA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
-	{0xFBA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
-	{0xFBAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
-	{0xFBAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
-	{0xFBAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
-	{0xFBAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
-	{0xFBAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D2},
-	{0xFBAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D2},
-	{0xFBB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D3},
-	{0xFBB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D3},
-	{0xFBD3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
-	{0xFBD4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
-	{0xFBD5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
-	{0xFBD6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
-	{0xFBD7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C7},
-	{0xFBD8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C7},
-	{0xFBD9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C6},
-	{0xFBDA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C6},
-	{0xFBDB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C8},
-	{0xFBDC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C8},
-	{0xFBDD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0677},
-	{0xFBDE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CB},
-	{0xFBDF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CB},
-	{0xFBE0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C5},
-	{0xFBE1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C5},
-	{0xFBE2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C9},
-	{0xFBE3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C9},
-	{0xFBE4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
-	{0xFBE5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
-	{0xFBE6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
-	{0xFBE7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
-	{0xFBE8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
-	{0xFBE9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
-	{0xFBEA, 0, 2 | DECOMP_COMPAT, 3630},
-	{0xFBEB, 0, 2 | DECOMP_COMPAT, 3632},
-	{0xFBEC, 0, 2 | DECOMP_COMPAT, 3634},
-	{0xFBED, 0, 2 | DECOMP_COMPAT, 3636},
-	{0xFBEE, 0, 2 | DECOMP_COMPAT, 3638},
-	{0xFBEF, 0, 2 | DECOMP_COMPAT, 3640},
-	{0xFBF0, 0, 2 | DECOMP_COMPAT, 3642},
-	{0xFBF1, 0, 2 | DECOMP_COMPAT, 3644},
-	{0xFBF2, 0, 2 | DECOMP_COMPAT, 3646},
-	{0xFBF3, 0, 2 | DECOMP_COMPAT, 3648},
-	{0xFBF4, 0, 2 | DECOMP_COMPAT, 3650},
-	{0xFBF5, 0, 2 | DECOMP_COMPAT, 3652},
-	{0xFBF6, 0, 2 | DECOMP_COMPAT, 3654},
-	{0xFBF7, 0, 2 | DECOMP_COMPAT, 3656},
-	{0xFBF8, 0, 2 | DECOMP_COMPAT, 3658},
-	{0xFBF9, 0, 2 | DECOMP_COMPAT, 3660},
-	{0xFBFA, 0, 2 | DECOMP_COMPAT, 3662},
-	{0xFBFB, 0, 2 | DECOMP_COMPAT, 3664},
-	{0xFBFC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
-	{0xFBFD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
-	{0xFBFE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
-	{0xFBFF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
-	{0xFC00, 0, 2 | DECOMP_COMPAT, 3666},
-	{0xFC01, 0, 2 | DECOMP_COMPAT, 3668},
-	{0xFC02, 0, 2 | DECOMP_COMPAT, 3670},
-	{0xFC03, 0, 2 | DECOMP_COMPAT, 3672},
-	{0xFC04, 0, 2 | DECOMP_COMPAT, 3674},
-	{0xFC05, 0, 2 | DECOMP_COMPAT, 3676},
-	{0xFC06, 0, 2 | DECOMP_COMPAT, 3678},
-	{0xFC07, 0, 2 | DECOMP_COMPAT, 3680},
-	{0xFC08, 0, 2 | DECOMP_COMPAT, 3682},
-	{0xFC09, 0, 2 | DECOMP_COMPAT, 3684},
-	{0xFC0A, 0, 2 | DECOMP_COMPAT, 3686},
-	{0xFC0B, 0, 2 | DECOMP_COMPAT, 3688},
-	{0xFC0C, 0, 2 | DECOMP_COMPAT, 3690},
-	{0xFC0D, 0, 2 | DECOMP_COMPAT, 3692},
-	{0xFC0E, 0, 2 | DECOMP_COMPAT, 3694},
-	{0xFC0F, 0, 2 | DECOMP_COMPAT, 3696},
-	{0xFC10, 0, 2 | DECOMP_COMPAT, 3698},
-	{0xFC11, 0, 2 | DECOMP_COMPAT, 3700},
-	{0xFC12, 0, 2 | DECOMP_COMPAT, 3702},
-	{0xFC13, 0, 2 | DECOMP_COMPAT, 3704},
-	{0xFC14, 0, 2 | DECOMP_COMPAT, 3706},
-	{0xFC15, 0, 2 | DECOMP_COMPAT, 3708},
-	{0xFC16, 0, 2 | DECOMP_COMPAT, 3710},
-	{0xFC17, 0, 2 | DECOMP_COMPAT, 3712},
-	{0xFC18, 0, 2 | DECOMP_COMPAT, 3714},
-	{0xFC19, 0, 2 | DECOMP_COMPAT, 3716},
-	{0xFC1A, 0, 2 | DECOMP_COMPAT, 3718},
-	{0xFC1B, 0, 2 | DECOMP_COMPAT, 3720},
-	{0xFC1C, 0, 2 | DECOMP_COMPAT, 3722},
-	{0xFC1D, 0, 2 | DECOMP_COMPAT, 3724},
-	{0xFC1E, 0, 2 | DECOMP_COMPAT, 3726},
-	{0xFC1F, 0, 2 | DECOMP_COMPAT, 3728},
-	{0xFC20, 0, 2 | DECOMP_COMPAT, 3730},
-	{0xFC21, 0, 2 | DECOMP_COMPAT, 3732},
-	{0xFC22, 0, 2 | DECOMP_COMPAT, 3734},
-	{0xFC23, 0, 2 | DECOMP_COMPAT, 3736},
-	{0xFC24, 0, 2 | DECOMP_COMPAT, 3738},
-	{0xFC25, 0, 2 | DECOMP_COMPAT, 3740},
-	{0xFC26, 0, 2 | DECOMP_COMPAT, 3742},
-	{0xFC27, 0, 2 | DECOMP_COMPAT, 3744},
-	{0xFC28, 0, 2 | DECOMP_COMPAT, 3746},
-	{0xFC29, 0, 2 | DECOMP_COMPAT, 3748},
-	{0xFC2A, 0, 2 | DECOMP_COMPAT, 3750},
-	{0xFC2B, 0, 2 | DECOMP_COMPAT, 3752},
-	{0xFC2C, 0, 2 | DECOMP_COMPAT, 3754},
-	{0xFC2D, 0, 2 | DECOMP_COMPAT, 3756},
-	{0xFC2E, 0, 2 | DECOMP_COMPAT, 3758},
-	{0xFC2F, 0, 2 | DECOMP_COMPAT, 3760},
-	{0xFC30, 0, 2 | DECOMP_COMPAT, 3762},
-	{0xFC31, 0, 2 | DECOMP_COMPAT, 3764},
-	{0xFC32, 0, 2 | DECOMP_COMPAT, 3766},
-	{0xFC33, 0, 2 | DECOMP_COMPAT, 3768},
-	{0xFC34, 0, 2 | DECOMP_COMPAT, 3770},
-	{0xFC35, 0, 2 | DECOMP_COMPAT, 3772},
-	{0xFC36, 0, 2 | DECOMP_COMPAT, 3774},
-	{0xFC37, 0, 2 | DECOMP_COMPAT, 3776},
-	{0xFC38, 0, 2 | DECOMP_COMPAT, 3778},
-	{0xFC39, 0, 2 | DECOMP_COMPAT, 3780},
-	{0xFC3A, 0, 2 | DECOMP_COMPAT, 3782},
-	{0xFC3B, 0, 2 | DECOMP_COMPAT, 3784},
-	{0xFC3C, 0, 2 | DECOMP_COMPAT, 3786},
-	{0xFC3D, 0, 2 | DECOMP_COMPAT, 3788},
-	{0xFC3E, 0, 2 | DECOMP_COMPAT, 3790},
-	{0xFC3F, 0, 2 | DECOMP_COMPAT, 3792},
-	{0xFC40, 0, 2 | DECOMP_COMPAT, 3794},
-	{0xFC41, 0, 2 | DECOMP_COMPAT, 3796},
-	{0xFC42, 0, 2 | DECOMP_COMPAT, 3798},
-	{0xFC43, 0, 2 | DECOMP_COMPAT, 3800},
-	{0xFC44, 0, 2 | DECOMP_COMPAT, 3802},
-	{0xFC45, 0, 2 | DECOMP_COMPAT, 3804},
-	{0xFC46, 0, 2 | DECOMP_COMPAT, 3806},
-	{0xFC47, 0, 2 | DECOMP_COMPAT, 3808},
-	{0xFC48, 0, 2 | DECOMP_COMPAT, 3810},
-	{0xFC49, 0, 2 | DECOMP_COMPAT, 3812},
-	{0xFC4A, 0, 2 | DECOMP_COMPAT, 3814},
-	{0xFC4B, 0, 2 | DECOMP_COMPAT, 3816},
-	{0xFC4C, 0, 2 | DECOMP_COMPAT, 3818},
-	{0xFC4D, 0, 2 | DECOMP_COMPAT, 3820},
-	{0xFC4E, 0, 2 | DECOMP_COMPAT, 3822},
-	{0xFC4F, 0, 2 | DECOMP_COMPAT, 3824},
-	{0xFC50, 0, 2 | DECOMP_COMPAT, 3826},
-	{0xFC51, 0, 2 | DECOMP_COMPAT, 3828},
-	{0xFC52, 0, 2 | DECOMP_COMPAT, 3830},
-	{0xFC53, 0, 2 | DECOMP_COMPAT, 3832},
-	{0xFC54, 0, 2 | DECOMP_COMPAT, 3834},
-	{0xFC55, 0, 2 | DECOMP_COMPAT, 3836},
-	{0xFC56, 0, 2 | DECOMP_COMPAT, 3838},
-	{0xFC57, 0, 2 | DECOMP_COMPAT, 3840},
-	{0xFC58, 0, 2 | DECOMP_COMPAT, 3842},
-	{0xFC59, 0, 2 | DECOMP_COMPAT, 3844},
-	{0xFC5A, 0, 2 | DECOMP_COMPAT, 3846},
-	{0xFC5B, 0, 2 | DECOMP_COMPAT, 3848},
-	{0xFC5C, 0, 2 | DECOMP_COMPAT, 3850},
-	{0xFC5D, 0, 2 | DECOMP_COMPAT, 3852},
-	{0xFC5E, 0, 3 | DECOMP_COMPAT, 3854},
-	{0xFC5F, 0, 3 | DECOMP_COMPAT, 3857},
-	{0xFC60, 0, 3 | DECOMP_COMPAT, 3860},
-	{0xFC61, 0, 3 | DECOMP_COMPAT, 3863},
-	{0xFC62, 0, 3 | DECOMP_COMPAT, 3866},
-	{0xFC63, 0, 3 | DECOMP_COMPAT, 3869},
-	{0xFC64, 0, 2 | DECOMP_COMPAT, 3872},
-	{0xFC65, 0, 2 | DECOMP_COMPAT, 3874},
-	{0xFC66, 0, 2 | DECOMP_COMPAT, 3876},
-	{0xFC67, 0, 2 | DECOMP_COMPAT, 3878},
-	{0xFC68, 0, 2 | DECOMP_COMPAT, 3880},
-	{0xFC69, 0, 2 | DECOMP_COMPAT, 3882},
-	{0xFC6A, 0, 2 | DECOMP_COMPAT, 3884},
-	{0xFC6B, 0, 2 | DECOMP_COMPAT, 3886},
-	{0xFC6C, 0, 2 | DECOMP_COMPAT, 3888},
-	{0xFC6D, 0, 2 | DECOMP_COMPAT, 3890},
-	{0xFC6E, 0, 2 | DECOMP_COMPAT, 3892},
-	{0xFC6F, 0, 2 | DECOMP_COMPAT, 3894},
-	{0xFC70, 0, 2 | DECOMP_COMPAT, 3896},
-	{0xFC71, 0, 2 | DECOMP_COMPAT, 3898},
-	{0xFC72, 0, 2 | DECOMP_COMPAT, 3900},
-	{0xFC73, 0, 2 | DECOMP_COMPAT, 3902},
-	{0xFC74, 0, 2 | DECOMP_COMPAT, 3904},
-	{0xFC75, 0, 2 | DECOMP_COMPAT, 3906},
-	{0xFC76, 0, 2 | DECOMP_COMPAT, 3908},
-	{0xFC77, 0, 2 | DECOMP_COMPAT, 3910},
-	{0xFC78, 0, 2 | DECOMP_COMPAT, 3912},
-	{0xFC79, 0, 2 | DECOMP_COMPAT, 3914},
-	{0xFC7A, 0, 2 | DECOMP_COMPAT, 3916},
-	{0xFC7B, 0, 2 | DECOMP_COMPAT, 3918},
-	{0xFC7C, 0, 2 | DECOMP_COMPAT, 3920},
-	{0xFC7D, 0, 2 | DECOMP_COMPAT, 3922},
-	{0xFC7E, 0, 2 | DECOMP_COMPAT, 3924},
-	{0xFC7F, 0, 2 | DECOMP_COMPAT, 3926},
-	{0xFC80, 0, 2 | DECOMP_COMPAT, 3928},
-	{0xFC81, 0, 2 | DECOMP_COMPAT, 3930},
-	{0xFC82, 0, 2 | DECOMP_COMPAT, 3932},
-	{0xFC83, 0, 2 | DECOMP_COMPAT, 3934},
-	{0xFC84, 0, 2 | DECOMP_COMPAT, 3936},
-	{0xFC85, 0, 2 | DECOMP_COMPAT, 3938},
-	{0xFC86, 0, 2 | DECOMP_COMPAT, 3940},
-	{0xFC87, 0, 2 | DECOMP_COMPAT, 3942},
-	{0xFC88, 0, 2 | DECOMP_COMPAT, 3944},
-	{0xFC89, 0, 2 | DECOMP_COMPAT, 3946},
-	{0xFC8A, 0, 2 | DECOMP_COMPAT, 3948},
-	{0xFC8B, 0, 2 | DECOMP_COMPAT, 3950},
-	{0xFC8C, 0, 2 | DECOMP_COMPAT, 3952},
-	{0xFC8D, 0, 2 | DECOMP_COMPAT, 3954},
-	{0xFC8E, 0, 2 | DECOMP_COMPAT, 3956},
-	{0xFC8F, 0, 2 | DECOMP_COMPAT, 3958},
-	{0xFC90, 0, 2 | DECOMP_COMPAT, 3960},
-	{0xFC91, 0, 2 | DECOMP_COMPAT, 3962},
-	{0xFC92, 0, 2 | DECOMP_COMPAT, 3964},
-	{0xFC93, 0, 2 | DECOMP_COMPAT, 3966},
-	{0xFC94, 0, 2 | DECOMP_COMPAT, 3968},
-	{0xFC95, 0, 2 | DECOMP_COMPAT, 3970},
-	{0xFC96, 0, 2 | DECOMP_COMPAT, 3972},
-	{0xFC97, 0, 2 | DECOMP_COMPAT, 3974},
-	{0xFC98, 0, 2 | DECOMP_COMPAT, 3976},
-	{0xFC99, 0, 2 | DECOMP_COMPAT, 3978},
-	{0xFC9A, 0, 2 | DECOMP_COMPAT, 3980},
-	{0xFC9B, 0, 2 | DECOMP_COMPAT, 3982},
-	{0xFC9C, 0, 2 | DECOMP_COMPAT, 3984},
-	{0xFC9D, 0, 2 | DECOMP_COMPAT, 3986},
-	{0xFC9E, 0, 2 | DECOMP_COMPAT, 3988},
-	{0xFC9F, 0, 2 | DECOMP_COMPAT, 3990},
-	{0xFCA0, 0, 2 | DECOMP_COMPAT, 3992},
-	{0xFCA1, 0, 2 | DECOMP_COMPAT, 3994},
-	{0xFCA2, 0, 2 | DECOMP_COMPAT, 3996},
-	{0xFCA3, 0, 2 | DECOMP_COMPAT, 3998},
-	{0xFCA4, 0, 2 | DECOMP_COMPAT, 4000},
-	{0xFCA5, 0, 2 | DECOMP_COMPAT, 4002},
-	{0xFCA6, 0, 2 | DECOMP_COMPAT, 4004},
-	{0xFCA7, 0, 2 | DECOMP_COMPAT, 4006},
-	{0xFCA8, 0, 2 | DECOMP_COMPAT, 4008},
-	{0xFCA9, 0, 2 | DECOMP_COMPAT, 4010},
-	{0xFCAA, 0, 2 | DECOMP_COMPAT, 4012},
-	{0xFCAB, 0, 2 | DECOMP_COMPAT, 4014},
-	{0xFCAC, 0, 2 | DECOMP_COMPAT, 4016},
-	{0xFCAD, 0, 2 | DECOMP_COMPAT, 4018},
-	{0xFCAE, 0, 2 | DECOMP_COMPAT, 4020},
-	{0xFCAF, 0, 2 | DECOMP_COMPAT, 4022},
-	{0xFCB0, 0, 2 | DECOMP_COMPAT, 4024},
-	{0xFCB1, 0, 2 | DECOMP_COMPAT, 4026},
-	{0xFCB2, 0, 2 | DECOMP_COMPAT, 4028},
-	{0xFCB3, 0, 2 | DECOMP_COMPAT, 4030},
-	{0xFCB4, 0, 2 | DECOMP_COMPAT, 4032},
-	{0xFCB5, 0, 2 | DECOMP_COMPAT, 4034},
-	{0xFCB6, 0, 2 | DECOMP_COMPAT, 4036},
-	{0xFCB7, 0, 2 | DECOMP_COMPAT, 4038},
-	{0xFCB8, 0, 2 | DECOMP_COMPAT, 4040},
-	{0xFCB9, 0, 2 | DECOMP_COMPAT, 4042},
-	{0xFCBA, 0, 2 | DECOMP_COMPAT, 4044},
-	{0xFCBB, 0, 2 | DECOMP_COMPAT, 4046},
-	{0xFCBC, 0, 2 | DECOMP_COMPAT, 4048},
-	{0xFCBD, 0, 2 | DECOMP_COMPAT, 4050},
-	{0xFCBE, 0, 2 | DECOMP_COMPAT, 4052},
-	{0xFCBF, 0, 2 | DECOMP_COMPAT, 4054},
-	{0xFCC0, 0, 2 | DECOMP_COMPAT, 4056},
-	{0xFCC1, 0, 2 | DECOMP_COMPAT, 4058},
-	{0xFCC2, 0, 2 | DECOMP_COMPAT, 4060},
-	{0xFCC3, 0, 2 | DECOMP_COMPAT, 4062},
-	{0xFCC4, 0, 2 | DECOMP_COMPAT, 4064},
-	{0xFCC5, 0, 2 | DECOMP_COMPAT, 4066},
-	{0xFCC6, 0, 2 | DECOMP_COMPAT, 4068},
-	{0xFCC7, 0, 2 | DECOMP_COMPAT, 4070},
-	{0xFCC8, 0, 2 | DECOMP_COMPAT, 4072},
-	{0xFCC9, 0, 2 | DECOMP_COMPAT, 4074},
-	{0xFCCA, 0, 2 | DECOMP_COMPAT, 4076},
-	{0xFCCB, 0, 2 | DECOMP_COMPAT, 4078},
-	{0xFCCC, 0, 2 | DECOMP_COMPAT, 4080},
-	{0xFCCD, 0, 2 | DECOMP_COMPAT, 4082},
-	{0xFCCE, 0, 2 | DECOMP_COMPAT, 4084},
-	{0xFCCF, 0, 2 | DECOMP_COMPAT, 4086},
-	{0xFCD0, 0, 2 | DECOMP_COMPAT, 4088},
-	{0xFCD1, 0, 2 | DECOMP_COMPAT, 4090},
-	{0xFCD2, 0, 2 | DECOMP_COMPAT, 4092},
-	{0xFCD3, 0, 2 | DECOMP_COMPAT, 4094},
-	{0xFCD4, 0, 2 | DECOMP_COMPAT, 4096},
-	{0xFCD5, 0, 2 | DECOMP_COMPAT, 4098},
-	{0xFCD6, 0, 2 | DECOMP_COMPAT, 4100},
-	{0xFCD7, 0, 2 | DECOMP_COMPAT, 4102},
-	{0xFCD8, 0, 2 | DECOMP_COMPAT, 4104},
-	{0xFCD9, 0, 2 | DECOMP_COMPAT, 4106},
-	{0xFCDA, 0, 2 | DECOMP_COMPAT, 4108},
-	{0xFCDB, 0, 2 | DECOMP_COMPAT, 4110},
-	{0xFCDC, 0, 2 | DECOMP_COMPAT, 4112},
-	{0xFCDD, 0, 2 | DECOMP_COMPAT, 4114},
-	{0xFCDE, 0, 2 | DECOMP_COMPAT, 4116},
-	{0xFCDF, 0, 2 | DECOMP_COMPAT, 4118},
-	{0xFCE0, 0, 2 | DECOMP_COMPAT, 4120},
-	{0xFCE1, 0, 2 | DECOMP_COMPAT, 4122},
-	{0xFCE2, 0, 2 | DECOMP_COMPAT, 4124},
-	{0xFCE3, 0, 2 | DECOMP_COMPAT, 4126},
-	{0xFCE4, 0, 2 | DECOMP_COMPAT, 4128},
-	{0xFCE5, 0, 2 | DECOMP_COMPAT, 4130},
-	{0xFCE6, 0, 2 | DECOMP_COMPAT, 4132},
-	{0xFCE7, 0, 2 | DECOMP_COMPAT, 4134},
-	{0xFCE8, 0, 2 | DECOMP_COMPAT, 4136},
-	{0xFCE9, 0, 2 | DECOMP_COMPAT, 4138},
-	{0xFCEA, 0, 2 | DECOMP_COMPAT, 4140},
-	{0xFCEB, 0, 2 | DECOMP_COMPAT, 4142},
-	{0xFCEC, 0, 2 | DECOMP_COMPAT, 4144},
-	{0xFCED, 0, 2 | DECOMP_COMPAT, 4146},
-	{0xFCEE, 0, 2 | DECOMP_COMPAT, 4148},
-	{0xFCEF, 0, 2 | DECOMP_COMPAT, 4150},
-	{0xFCF0, 0, 2 | DECOMP_COMPAT, 4152},
-	{0xFCF1, 0, 2 | DECOMP_COMPAT, 4154},
-	{0xFCF2, 0, 3 | DECOMP_COMPAT, 4156},
-	{0xFCF3, 0, 3 | DECOMP_COMPAT, 4159},
-	{0xFCF4, 0, 3 | DECOMP_COMPAT, 4162},
-	{0xFCF5, 0, 2 | DECOMP_COMPAT, 4165},
-	{0xFCF6, 0, 2 | DECOMP_COMPAT, 4167},
-	{0xFCF7, 0, 2 | DECOMP_COMPAT, 4169},
-	{0xFCF8, 0, 2 | DECOMP_COMPAT, 4171},
-	{0xFCF9, 0, 2 | DECOMP_COMPAT, 4173},
-	{0xFCFA, 0, 2 | DECOMP_COMPAT, 4175},
-	{0xFCFB, 0, 2 | DECOMP_COMPAT, 4177},
-	{0xFCFC, 0, 2 | DECOMP_COMPAT, 4179},
-	{0xFCFD, 0, 2 | DECOMP_COMPAT, 4181},
-	{0xFCFE, 0, 2 | DECOMP_COMPAT, 4183},
-	{0xFCFF, 0, 2 | DECOMP_COMPAT, 4185},
-	{0xFD00, 0, 2 | DECOMP_COMPAT, 4187},
-	{0xFD01, 0, 2 | DECOMP_COMPAT, 4189},
-	{0xFD02, 0, 2 | DECOMP_COMPAT, 4191},
-	{0xFD03, 0, 2 | DECOMP_COMPAT, 4193},
-	{0xFD04, 0, 2 | DECOMP_COMPAT, 4195},
-	{0xFD05, 0, 2 | DECOMP_COMPAT, 4197},
-	{0xFD06, 0, 2 | DECOMP_COMPAT, 4199},
-	{0xFD07, 0, 2 | DECOMP_COMPAT, 4201},
-	{0xFD08, 0, 2 | DECOMP_COMPAT, 4203},
-	{0xFD09, 0, 2 | DECOMP_COMPAT, 4205},
-	{0xFD0A, 0, 2 | DECOMP_COMPAT, 4207},
-	{0xFD0B, 0, 2 | DECOMP_COMPAT, 4209},
-	{0xFD0C, 0, 2 | DECOMP_COMPAT, 4211},
-	{0xFD0D, 0, 2 | DECOMP_COMPAT, 4213},
-	{0xFD0E, 0, 2 | DECOMP_COMPAT, 4215},
-	{0xFD0F, 0, 2 | DECOMP_COMPAT, 4217},
-	{0xFD10, 0, 2 | DECOMP_COMPAT, 4219},
-	{0xFD11, 0, 2 | DECOMP_COMPAT, 4221},
-	{0xFD12, 0, 2 | DECOMP_COMPAT, 4223},
-	{0xFD13, 0, 2 | DECOMP_COMPAT, 4225},
-	{0xFD14, 0, 2 | DECOMP_COMPAT, 4227},
-	{0xFD15, 0, 2 | DECOMP_COMPAT, 4229},
-	{0xFD16, 0, 2 | DECOMP_COMPAT, 4231},
-	{0xFD17, 0, 2 | DECOMP_COMPAT, 4233},
-	{0xFD18, 0, 2 | DECOMP_COMPAT, 4235},
-	{0xFD19, 0, 2 | DECOMP_COMPAT, 4237},
-	{0xFD1A, 0, 2 | DECOMP_COMPAT, 4239},
-	{0xFD1B, 0, 2 | DECOMP_COMPAT, 4241},
-	{0xFD1C, 0, 2 | DECOMP_COMPAT, 4243},
-	{0xFD1D, 0, 2 | DECOMP_COMPAT, 4245},
-	{0xFD1E, 0, 2 | DECOMP_COMPAT, 4247},
-	{0xFD1F, 0, 2 | DECOMP_COMPAT, 4249},
-	{0xFD20, 0, 2 | DECOMP_COMPAT, 4251},
-	{0xFD21, 0, 2 | DECOMP_COMPAT, 4253},
-	{0xFD22, 0, 2 | DECOMP_COMPAT, 4255},
-	{0xFD23, 0, 2 | DECOMP_COMPAT, 4257},
-	{0xFD24, 0, 2 | DECOMP_COMPAT, 4259},
-	{0xFD25, 0, 2 | DECOMP_COMPAT, 4261},
-	{0xFD26, 0, 2 | DECOMP_COMPAT, 4263},
-	{0xFD27, 0, 2 | DECOMP_COMPAT, 4265},
-	{0xFD28, 0, 2 | DECOMP_COMPAT, 4267},
-	{0xFD29, 0, 2 | DECOMP_COMPAT, 4269},
-	{0xFD2A, 0, 2 | DECOMP_COMPAT, 4271},
-	{0xFD2B, 0, 2 | DECOMP_COMPAT, 4273},
-	{0xFD2C, 0, 2 | DECOMP_COMPAT, 4275},
-	{0xFD2D, 0, 2 | DECOMP_COMPAT, 4277},
-	{0xFD2E, 0, 2 | DECOMP_COMPAT, 4279},
-	{0xFD2F, 0, 2 | DECOMP_COMPAT, 4281},
-	{0xFD30, 0, 2 | DECOMP_COMPAT, 4283},
-	{0xFD31, 0, 2 | DECOMP_COMPAT, 4285},
-	{0xFD32, 0, 2 | DECOMP_COMPAT, 4287},
-	{0xFD33, 0, 2 | DECOMP_COMPAT, 4289},
-	{0xFD34, 0, 2 | DECOMP_COMPAT, 4291},
-	{0xFD35, 0, 2 | DECOMP_COMPAT, 4293},
-	{0xFD36, 0, 2 | DECOMP_COMPAT, 4295},
-	{0xFD37, 0, 2 | DECOMP_COMPAT, 4297},
-	{0xFD38, 0, 2 | DECOMP_COMPAT, 4299},
-	{0xFD39, 0, 2 | DECOMP_COMPAT, 4301},
-	{0xFD3A, 0, 2 | DECOMP_COMPAT, 4303},
-	{0xFD3B, 0, 2 | DECOMP_COMPAT, 4305},
-	{0xFD3C, 0, 2 | DECOMP_COMPAT, 4307},
-	{0xFD3D, 0, 2 | DECOMP_COMPAT, 4309},
-	{0xFD50, 0, 3 | DECOMP_COMPAT, 4311},
-	{0xFD51, 0, 3 | DECOMP_COMPAT, 4314},
-	{0xFD52, 0, 3 | DECOMP_COMPAT, 4317},
-	{0xFD53, 0, 3 | DECOMP_COMPAT, 4320},
-	{0xFD54, 0, 3 | DECOMP_COMPAT, 4323},
-	{0xFD55, 0, 3 | DECOMP_COMPAT, 4326},
-	{0xFD56, 0, 3 | DECOMP_COMPAT, 4329},
-	{0xFD57, 0, 3 | DECOMP_COMPAT, 4332},
-	{0xFD58, 0, 3 | DECOMP_COMPAT, 4335},
-	{0xFD59, 0, 3 | DECOMP_COMPAT, 4338},
-	{0xFD5A, 0, 3 | DECOMP_COMPAT, 4341},
-	{0xFD5B, 0, 3 | DECOMP_COMPAT, 4344},
-	{0xFD5C, 0, 3 | DECOMP_COMPAT, 4347},
-	{0xFD5D, 0, 3 | DECOMP_COMPAT, 4350},
-	{0xFD5E, 0, 3 | DECOMP_COMPAT, 4353},
-	{0xFD5F, 0, 3 | DECOMP_COMPAT, 4356},
-	{0xFD60, 0, 3 | DECOMP_COMPAT, 4359},
-	{0xFD61, 0, 3 | DECOMP_COMPAT, 4362},
-	{0xFD62, 0, 3 | DECOMP_COMPAT, 4365},
-	{0xFD63, 0, 3 | DECOMP_COMPAT, 4368},
-	{0xFD64, 0, 3 | DECOMP_COMPAT, 4371},
-	{0xFD65, 0, 3 | DECOMP_COMPAT, 4374},
-	{0xFD66, 0, 3 | DECOMP_COMPAT, 4377},
-	{0xFD67, 0, 3 | DECOMP_COMPAT, 4380},
-	{0xFD68, 0, 3 | DECOMP_COMPAT, 4383},
-	{0xFD69, 0, 3 | DECOMP_COMPAT, 4386},
-	{0xFD6A, 0, 3 | DECOMP_COMPAT, 4389},
-	{0xFD6B, 0, 3 | DECOMP_COMPAT, 4392},
-	{0xFD6C, 0, 3 | DECOMP_COMPAT, 4395},
-	{0xFD6D, 0, 3 | DECOMP_COMPAT, 4398},
-	{0xFD6E, 0, 3 | DECOMP_COMPAT, 4401},
-	{0xFD6F, 0, 3 | DECOMP_COMPAT, 4404},
-	{0xFD70, 0, 3 | DECOMP_COMPAT, 4407},
-	{0xFD71, 0, 3 | DECOMP_COMPAT, 4410},
-	{0xFD72, 0, 3 | DECOMP_COMPAT, 4413},
-	{0xFD73, 0, 3 | DECOMP_COMPAT, 4416},
-	{0xFD74, 0, 3 | DECOMP_COMPAT, 4419},
-	{0xFD75, 0, 3 | DECOMP_COMPAT, 4422},
-	{0xFD76, 0, 3 | DECOMP_COMPAT, 4425},
-	{0xFD77, 0, 3 | DECOMP_COMPAT, 4428},
-	{0xFD78, 0, 3 | DECOMP_COMPAT, 4431},
-	{0xFD79, 0, 3 | DECOMP_COMPAT, 4434},
-	{0xFD7A, 0, 3 | DECOMP_COMPAT, 4437},
-	{0xFD7B, 0, 3 | DECOMP_COMPAT, 4440},
-	{0xFD7C, 0, 3 | DECOMP_COMPAT, 4443},
-	{0xFD7D, 0, 3 | DECOMP_COMPAT, 4446},
-	{0xFD7E, 0, 3 | DECOMP_COMPAT, 4449},
-	{0xFD7F, 0, 3 | DECOMP_COMPAT, 4452},
-	{0xFD80, 0, 3 | DECOMP_COMPAT, 4455},
-	{0xFD81, 0, 3 | DECOMP_COMPAT, 4458},
-	{0xFD82, 0, 3 | DECOMP_COMPAT, 4461},
-	{0xFD83, 0, 3 | DECOMP_COMPAT, 4464},
-	{0xFD84, 0, 3 | DECOMP_COMPAT, 4467},
-	{0xFD85, 0, 3 | DECOMP_COMPAT, 4470},
-	{0xFD86, 0, 3 | DECOMP_COMPAT, 4473},
-	{0xFD87, 0, 3 | DECOMP_COMPAT, 4476},
-	{0xFD88, 0, 3 | DECOMP_COMPAT, 4479},
-	{0xFD89, 0, 3 | DECOMP_COMPAT, 4482},
-	{0xFD8A, 0, 3 | DECOMP_COMPAT, 4485},
-	{0xFD8B, 0, 3 | DECOMP_COMPAT, 4488},
-	{0xFD8C, 0, 3 | DECOMP_COMPAT, 4491},
-	{0xFD8D, 0, 3 | DECOMP_COMPAT, 4494},
-	{0xFD8E, 0, 3 | DECOMP_COMPAT, 4497},
-	{0xFD8F, 0, 3 | DECOMP_COMPAT, 4500},
-	{0xFD92, 0, 3 | DECOMP_COMPAT, 4503},
-	{0xFD93, 0, 3 | DECOMP_COMPAT, 4506},
-	{0xFD94, 0, 3 | DECOMP_COMPAT, 4509},
-	{0xFD95, 0, 3 | DECOMP_COMPAT, 4512},
-	{0xFD96, 0, 3 | DECOMP_COMPAT, 4515},
-	{0xFD97, 0, 3 | DECOMP_COMPAT, 4518},
-	{0xFD98, 0, 3 | DECOMP_COMPAT, 4521},
-	{0xFD99, 0, 3 | DECOMP_COMPAT, 4524},
-	{0xFD9A, 0, 3 | DECOMP_COMPAT, 4527},
-	{0xFD9B, 0, 3 | DECOMP_COMPAT, 4530},
-	{0xFD9C, 0, 3 | DECOMP_COMPAT, 4533},
-	{0xFD9D, 0, 3 | DECOMP_COMPAT, 4536},
-	{0xFD9E, 0, 3 | DECOMP_COMPAT, 4539},
-	{0xFD9F, 0, 3 | DECOMP_COMPAT, 4542},
-	{0xFDA0, 0, 3 | DECOMP_COMPAT, 4545},
-	{0xFDA1, 0, 3 | DECOMP_COMPAT, 4548},
-	{0xFDA2, 0, 3 | DECOMP_COMPAT, 4551},
-	{0xFDA3, 0, 3 | DECOMP_COMPAT, 4554},
-	{0xFDA4, 0, 3 | DECOMP_COMPAT, 4557},
-	{0xFDA5, 0, 3 | DECOMP_COMPAT, 4560},
-	{0xFDA6, 0, 3 | DECOMP_COMPAT, 4563},
-	{0xFDA7, 0, 3 | DECOMP_COMPAT, 4566},
-	{0xFDA8, 0, 3 | DECOMP_COMPAT, 4569},
-	{0xFDA9, 0, 3 | DECOMP_COMPAT, 4572},
-	{0xFDAA, 0, 3 | DECOMP_COMPAT, 4575},
-	{0xFDAB, 0, 3 | DECOMP_COMPAT, 4578},
-	{0xFDAC, 0, 3 | DECOMP_COMPAT, 4581},
-	{0xFDAD, 0, 3 | DECOMP_COMPAT, 4584},
-	{0xFDAE, 0, 3 | DECOMP_COMPAT, 4587},
-	{0xFDAF, 0, 3 | DECOMP_COMPAT, 4590},
-	{0xFDB0, 0, 3 | DECOMP_COMPAT, 4593},
-	{0xFDB1, 0, 3 | DECOMP_COMPAT, 4596},
-	{0xFDB2, 0, 3 | DECOMP_COMPAT, 4599},
-	{0xFDB3, 0, 3 | DECOMP_COMPAT, 4602},
-	{0xFDB4, 0, 3 | DECOMP_COMPAT, 4605},
-	{0xFDB5, 0, 3 | DECOMP_COMPAT, 4608},
-	{0xFDB6, 0, 3 | DECOMP_COMPAT, 4611},
-	{0xFDB7, 0, 3 | DECOMP_COMPAT, 4614},
-	{0xFDB8, 0, 3 | DECOMP_COMPAT, 4617},
-	{0xFDB9, 0, 3 | DECOMP_COMPAT, 4620},
-	{0xFDBA, 0, 3 | DECOMP_COMPAT, 4623},
-	{0xFDBB, 0, 3 | DECOMP_COMPAT, 4626},
-	{0xFDBC, 0, 3 | DECOMP_COMPAT, 4629},
-	{0xFDBD, 0, 3 | DECOMP_COMPAT, 4632},
-	{0xFDBE, 0, 3 | DECOMP_COMPAT, 4635},
-	{0xFDBF, 0, 3 | DECOMP_COMPAT, 4638},
-	{0xFDC0, 0, 3 | DECOMP_COMPAT, 4641},
-	{0xFDC1, 0, 3 | DECOMP_COMPAT, 4644},
-	{0xFDC2, 0, 3 | DECOMP_COMPAT, 4647},
-	{0xFDC3, 0, 3 | DECOMP_COMPAT, 4650},
-	{0xFDC4, 0, 3 | DECOMP_COMPAT, 4653},
-	{0xFDC5, 0, 3 | DECOMP_COMPAT, 4656},
-	{0xFDC6, 0, 3 | DECOMP_COMPAT, 4659},
-	{0xFDC7, 0, 3 | DECOMP_COMPAT, 4662},
-	{0xFDF0, 0, 3 | DECOMP_COMPAT, 4665},
-	{0xFDF1, 0, 3 | DECOMP_COMPAT, 4668},
-	{0xFDF2, 0, 4 | DECOMP_COMPAT, 4671},
-	{0xFDF3, 0, 4 | DECOMP_COMPAT, 4675},
-	{0xFDF4, 0, 4 | DECOMP_COMPAT, 4679},
-	{0xFDF5, 0, 4 | DECOMP_COMPAT, 4683},
-	{0xFDF6, 0, 4 | DECOMP_COMPAT, 4687},
-	{0xFDF7, 0, 4 | DECOMP_COMPAT, 4691},
-	{0xFDF8, 0, 4 | DECOMP_COMPAT, 4695},
-	{0xFDF9, 0, 3 | DECOMP_COMPAT, 4699},
-	{0xFDFA, 0, 18 | DECOMP_COMPAT, 4702},
-	{0xFDFB, 0, 8 | DECOMP_COMPAT, 4720},
-	{0xFDFC, 0, 4 | DECOMP_COMPAT, 4728},
-	{0xFE10, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002C},
-	{0xFE11, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3001},
-	{0xFE12, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3002},
-	{0xFE13, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003A},
-	{0xFE14, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003B},
-	{0xFE15, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0021},
-	{0xFE16, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003F},
-	{0xFE17, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3016},
-	{0xFE18, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3017},
-	{0xFE19, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2026},
-	{0xFE20, 230, 0, 0},
-	{0xFE21, 230, 0, 0},
-	{0xFE22, 230, 0, 0},
-	{0xFE23, 230, 0, 0},
-	{0xFE24, 230, 0, 0},
-	{0xFE25, 230, 0, 0},
-	{0xFE26, 230, 0, 0},
-	{0xFE27, 220, 0, 0},
-	{0xFE28, 220, 0, 0},
-	{0xFE29, 220, 0, 0},
-	{0xFE2A, 220, 0, 0},
-	{0xFE2B, 220, 0, 0},
-	{0xFE2C, 220, 0, 0},
-	{0xFE2D, 220, 0, 0},
-	{0xFE2E, 230, 0, 0},
-	{0xFE2F, 230, 0, 0},
-	{0xFE30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2025},
-	{0xFE31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2014},
-	{0xFE32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2013},
-	{0xFE33, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
-	{0xFE34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
-	{0xFE35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
-	{0xFE36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
-	{0xFE37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007B},
-	{0xFE38, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007D},
-	{0xFE39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3014},
-	{0xFE3A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3015},
-	{0xFE3B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3010},
-	{0xFE3C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3011},
-	{0xFE3D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300A},
-	{0xFE3E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300B},
-	{0xFE3F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3008},
-	{0xFE40, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3009},
-	{0xFE41, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300C},
-	{0xFE42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300D},
-	{0xFE43, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300E},
-	{0xFE44, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300F},
-	{0xFE47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005B},
-	{0xFE48, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005D},
-	{0xFE49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
-	{0xFE4A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
-	{0xFE4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
-	{0xFE4C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
-	{0xFE4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
-	{0xFE4E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
-	{0xFE4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
-	{0xFE50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002C},
-	{0xFE51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3001},
-	{0xFE52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002E},
-	{0xFE54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003B},
-	{0xFE55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003A},
-	{0xFE56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003F},
-	{0xFE57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0021},
-	{0xFE58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2014},
-	{0xFE59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
-	{0xFE5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
-	{0xFE5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007B},
-	{0xFE5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007D},
-	{0xFE5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3014},
-	{0xFE5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3015},
-	{0xFE5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0023},
-	{0xFE60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0026},
-	{0xFE61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002A},
-	{0xFE62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
-	{0xFE63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002D},
-	{0xFE64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003C},
-	{0xFE65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003E},
-	{0xFE66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
-	{0xFE68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005C},
-	{0xFE69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0024},
-	{0xFE6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0025},
-	{0xFE6B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0040},
-	{0xFE70, 0, 2 | DECOMP_COMPAT, 4732},
-	{0xFE71, 0, 2 | DECOMP_COMPAT, 4734},
-	{0xFE72, 0, 2 | DECOMP_COMPAT, 4736},
-	{0xFE74, 0, 2 | DECOMP_COMPAT, 4738},
-	{0xFE76, 0, 2 | DECOMP_COMPAT, 4740},
-	{0xFE77, 0, 2 | DECOMP_COMPAT, 4742},
-	{0xFE78, 0, 2 | DECOMP_COMPAT, 4744},
-	{0xFE79, 0, 2 | DECOMP_COMPAT, 4746},
-	{0xFE7A, 0, 2 | DECOMP_COMPAT, 4748},
-	{0xFE7B, 0, 2 | DECOMP_COMPAT, 4750},
-	{0xFE7C, 0, 2 | DECOMP_COMPAT, 4752},
-	{0xFE7D, 0, 2 | DECOMP_COMPAT, 4754},
-	{0xFE7E, 0, 2 | DECOMP_COMPAT, 4756},
-	{0xFE7F, 0, 2 | DECOMP_COMPAT, 4758},
-	{0xFE80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0621},
-	{0xFE81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0622},
-	{0xFE82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0622},
-	{0xFE83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0623},
-	{0xFE84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0623},
-	{0xFE85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0624},
-	{0xFE86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0624},
-	{0xFE87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0625},
-	{0xFE88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0625},
-	{0xFE89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
-	{0xFE8A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
-	{0xFE8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
-	{0xFE8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
-	{0xFE8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
-	{0xFE8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
-	{0xFE8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0xFE90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0xFE91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0xFE92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0xFE93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0629},
-	{0xFE94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0629},
-	{0xFE95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0xFE96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0xFE97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0xFE98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0xFE99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0xFE9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0xFE9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0xFE9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0xFE9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0xFE9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0xFE9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0xFEA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0xFEA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0xFEA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0xFEA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0xFEA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0xFEA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0xFEA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0xFEA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0xFEA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0xFEA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
-	{0xFEAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
-	{0xFEAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
-	{0xFEAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
-	{0xFEAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
-	{0xFEAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
-	{0xFEAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
-	{0xFEB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
-	{0xFEB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0xFEB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0xFEB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0xFEB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0xFEB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0xFEB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0xFEB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0xFEB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0xFEB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0xFEBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0xFEBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0xFEBC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0xFEBD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0xFEBE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0xFEBF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0xFEC0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0xFEC1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
-	{0xFEC2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
-	{0xFEC3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
-	{0xFEC4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
-	{0xFEC5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
-	{0xFEC6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
-	{0xFEC7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
-	{0xFEC8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
-	{0xFEC9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0xFECA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0xFECB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0xFECC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0xFECD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0xFECE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0xFECF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0xFED0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0xFED1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0xFED2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0xFED3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0xFED4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0xFED5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0xFED6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0xFED7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0xFED8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0xFED9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
-	{0xFEDA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
-	{0xFEDB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
-	{0xFEDC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
-	{0xFEDD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0xFEDE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0xFEDF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0xFEE0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0xFEE1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0xFEE2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0xFEE3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0xFEE4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0xFEE5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0xFEE6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0xFEE7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0xFEE8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0xFEE9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
-	{0xFEEA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
-	{0xFEEB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
-	{0xFEEC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
-	{0xFEED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
-	{0xFEEE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
-	{0xFEEF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
-	{0xFEF0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
-	{0xFEF1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0xFEF2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0xFEF3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0xFEF4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0xFEF5, 0, 2 | DECOMP_COMPAT, 4760},
-	{0xFEF6, 0, 2 | DECOMP_COMPAT, 4762},
-	{0xFEF7, 0, 2 | DECOMP_COMPAT, 4764},
-	{0xFEF8, 0, 2 | DECOMP_COMPAT, 4766},
-	{0xFEF9, 0, 2 | DECOMP_COMPAT, 4768},
-	{0xFEFA, 0, 2 | DECOMP_COMPAT, 4770},
-	{0xFEFB, 0, 2 | DECOMP_COMPAT, 4772},
-	{0xFEFC, 0, 2 | DECOMP_COMPAT, 4774},
-	{0xFF01, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0021},
-	{0xFF02, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0022},
-	{0xFF03, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0023},
-	{0xFF04, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0024},
-	{0xFF05, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0025},
-	{0xFF06, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0026},
-	{0xFF07, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0027},
-	{0xFF08, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
-	{0xFF09, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
-	{0xFF0A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002A},
-	{0xFF0B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
-	{0xFF0C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002C},
-	{0xFF0D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002D},
-	{0xFF0E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002E},
-	{0xFF0F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002F},
-	{0xFF10, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0xFF11, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0xFF12, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0xFF13, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0xFF14, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0xFF15, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0xFF16, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0xFF17, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0xFF18, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0xFF19, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0xFF1A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003A},
-	{0xFF1B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003B},
-	{0xFF1C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003C},
-	{0xFF1D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
-	{0xFF1E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003E},
-	{0xFF1F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003F},
-	{0xFF20, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0040},
-	{0xFF21, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0xFF22, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0xFF23, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0xFF24, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0xFF25, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0xFF26, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0xFF27, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0xFF28, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0xFF29, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0xFF2A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0xFF2B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0xFF2C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0xFF2D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0xFF2E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0xFF2F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0xFF30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0xFF31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0xFF32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0xFF33, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0xFF34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0xFF35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0xFF36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0xFF37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0xFF38, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0xFF39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0xFF3A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0xFF3B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005B},
-	{0xFF3C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005C},
-	{0xFF3D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005D},
-	{0xFF3E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005E},
-	{0xFF3F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
-	{0xFF40, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0060},
-	{0xFF41, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0xFF42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0xFF43, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0xFF44, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0xFF45, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0xFF46, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0xFF47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0xFF48, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0xFF49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0xFF4A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0xFF4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0xFF4C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0xFF4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0xFF4E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0xFF4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0xFF50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0xFF51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0xFF52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0xFF53, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0xFF54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0xFF55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0xFF56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0xFF57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0xFF58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0xFF59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0xFF5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0xFF5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007B},
-	{0xFF5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007C},
-	{0xFF5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007D},
-	{0xFF5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007E},
-	{0xFF5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2985},
-	{0xFF60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2986},
-	{0xFF61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3002},
-	{0xFF62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300C},
-	{0xFF63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300D},
-	{0xFF64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3001},
-	{0xFF65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30FB},
-	{0xFF66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F2},
-	{0xFF67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A1},
-	{0xFF68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A3},
-	{0xFF69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A5},
-	{0xFF6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A7},
-	{0xFF6B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A9},
-	{0xFF6C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E3},
-	{0xFF6D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E5},
-	{0xFF6E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E7},
-	{0xFF6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C3},
-	{0xFF70, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30FC},
-	{0xFF71, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A2},
-	{0xFF72, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A4},
-	{0xFF73, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A6},
-	{0xFF74, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A8},
-	{0xFF75, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AA},
-	{0xFF76, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AB},
-	{0xFF77, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AD},
-	{0xFF78, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AF},
-	{0xFF79, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B1},
-	{0xFF7A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B3},
-	{0xFF7B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B5},
-	{0xFF7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B7},
-	{0xFF7D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B9},
-	{0xFF7E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BB},
-	{0xFF7F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BD},
-	{0xFF80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BF},
-	{0xFF81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C1},
-	{0xFF82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C4},
-	{0xFF83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C6},
-	{0xFF84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C8},
-	{0xFF85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CA},
-	{0xFF86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CB},
-	{0xFF87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CC},
-	{0xFF88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CD},
-	{0xFF89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CE},
-	{0xFF8A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CF},
-	{0xFF8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D2},
-	{0xFF8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D5},
-	{0xFF8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D8},
-	{0xFF8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DB},
-	{0xFF8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DE},
-	{0xFF90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DF},
-	{0xFF91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E0},
-	{0xFF92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E1},
-	{0xFF93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E2},
-	{0xFF94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E4},
-	{0xFF95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E6},
-	{0xFF96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E8},
-	{0xFF97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E9},
-	{0xFF98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EA},
-	{0xFF99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EB},
-	{0xFF9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EC},
-	{0xFF9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30ED},
-	{0xFF9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EF},
-	{0xFF9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F3},
-	{0xFF9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3099},
-	{0xFF9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x309A},
-	{0xFFA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3164},
-	{0xFFA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3131},
-	{0xFFA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3132},
-	{0xFFA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3133},
-	{0xFFA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3134},
-	{0xFFA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3135},
-	{0xFFA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3136},
-	{0xFFA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3137},
-	{0xFFA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3138},
-	{0xFFA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3139},
-	{0xFFAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313A},
-	{0xFFAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313B},
-	{0xFFAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313C},
-	{0xFFAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313D},
-	{0xFFAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313E},
-	{0xFFAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313F},
-	{0xFFB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3140},
-	{0xFFB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3141},
-	{0xFFB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3142},
-	{0xFFB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3143},
-	{0xFFB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3144},
-	{0xFFB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3145},
-	{0xFFB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3146},
-	{0xFFB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3147},
-	{0xFFB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3148},
-	{0xFFB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3149},
-	{0xFFBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314A},
-	{0xFFBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314B},
-	{0xFFBC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314C},
-	{0xFFBD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314D},
-	{0xFFBE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314E},
-	{0xFFC2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314F},
-	{0xFFC3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3150},
-	{0xFFC4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3151},
-	{0xFFC5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3152},
-	{0xFFC6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3153},
-	{0xFFC7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3154},
-	{0xFFCA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3155},
-	{0xFFCB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3156},
-	{0xFFCC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3157},
-	{0xFFCD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3158},
-	{0xFFCE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3159},
-	{0xFFCF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315A},
-	{0xFFD2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315B},
-	{0xFFD3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315C},
-	{0xFFD4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315D},
-	{0xFFD5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315E},
-	{0xFFD6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315F},
-	{0xFFD7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3160},
-	{0xFFDA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3161},
-	{0xFFDB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3162},
-	{0xFFDC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3163},
-	{0xFFE0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A2},
-	{0xFFE1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A3},
-	{0xFFE2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00AC},
-	{0xFFE3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00AF},
-	{0xFFE4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A6},
-	{0xFFE5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A5},
-	{0xFFE6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x20A9},
-	{0xFFE8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2502},
-	{0xFFE9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2190},
-	{0xFFEA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2191},
-	{0xFFEB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2192},
-	{0xFFEC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2193},
-	{0xFFED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x25A0},
-	{0xFFEE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x25CB},
-	{0x101FD, 220, 0, 0},
-	{0x102E0, 220, 0, 0},
-	{0x10376, 230, 0, 0},
-	{0x10377, 230, 0, 0},
-	{0x10378, 230, 0, 0},
-	{0x10379, 230, 0, 0},
-	{0x1037A, 230, 0, 0},
-	{0x105C9, 0, 2, 4776},
-	{0x105E4, 0, 2, 4778},
-	{0x10781, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02D0},
-	{0x10782, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02D1},
-	{0x10783, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00E6},
-	{0x10784, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0299},
-	{0x10785, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0253},
-	{0x10787, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A3},
-	{0x10788, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB66},
-	{0x10789, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A5},
-	{0x1078A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A4},
-	{0x1078B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0256},
-	{0x1078C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0257},
-	{0x1078D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D91},
-	{0x1078E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0258},
-	{0x1078F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025E},
-	{0x10790, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A9},
-	{0x10791, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0264},
-	{0x10792, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0262},
-	{0x10793, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0260},
-	{0x10794, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029B},
-	{0x10795, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0127},
-	{0x10796, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029C},
-	{0x10797, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0267},
-	{0x10798, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0284},
-	{0x10799, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02AA},
-	{0x1079A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02AB},
-	{0x1079B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026C},
-	{0x1079C, 0, 1 | DECOMP_COMPAT, 4780},
-	{0x1079D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA78E},
-	{0x1079E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026E},
-	{0x1079F, 0, 1 | DECOMP_COMPAT, 4781},
-	{0x107A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028E},
-	{0x107A1, 0, 1 | DECOMP_COMPAT, 4782},
-	{0x107A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00F8},
-	{0x107A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0276},
-	{0x107A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0277},
-	{0x107A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x107A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027A},
-	{0x107A7, 0, 1 | DECOMP_COMPAT, 4783},
-	{0x107A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027D},
-	{0x107A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027E},
-	{0x107AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0280},
-	{0x107AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A8},
-	{0x107AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A6},
-	{0x107AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB67},
-	{0x107AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A7},
-	{0x107AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0288},
-	{0x107B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2C71},
-	{0x107B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028F},
-	{0x107B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A1},
-	{0x107B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A2},
-	{0x107B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0298},
-	{0x107B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01C0},
-	{0x107B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01C1},
-	{0x107B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01C2},
-	{0x107B9, 0, 1 | DECOMP_COMPAT, 4784},
-	{0x107BA, 0, 1 | DECOMP_COMPAT, 4785},
-	{0x10A0D, 220, 0, 0},
-	{0x10A0F, 230, 0, 0},
-	{0x10A38, 230, 0, 0},
-	{0x10A39, 1, 0, 0},
-	{0x10A3A, 220, 0, 0},
-	{0x10A3F, 9, 0, 0},
-	{0x10AE5, 230, 0, 0},
-	{0x10AE6, 220, 0, 0},
-	{0x10D24, 230, 0, 0},
-	{0x10D25, 230, 0, 0},
-	{0x10D26, 230, 0, 0},
-	{0x10D27, 230, 0, 0},
-	{0x10D69, 230, 0, 0},
-	{0x10D6A, 230, 0, 0},
-	{0x10D6B, 230, 0, 0},
-	{0x10D6C, 230, 0, 0},
-	{0x10D6D, 230, 0, 0},
-	{0x10EAB, 230, 0, 0},
-	{0x10EAC, 230, 0, 0},
-	{0x10EFD, 220, 0, 0},
-	{0x10EFE, 220, 0, 0},
-	{0x10EFF, 220, 0, 0},
-	{0x10F46, 220, 0, 0},
-	{0x10F47, 220, 0, 0},
-	{0x10F48, 230, 0, 0},
-	{0x10F49, 230, 0, 0},
-	{0x10F4A, 230, 0, 0},
-	{0x10F4B, 220, 0, 0},
-	{0x10F4C, 230, 0, 0},
-	{0x10F4D, 220, 0, 0},
-	{0x10F4E, 220, 0, 0},
-	{0x10F4F, 220, 0, 0},
-	{0x10F50, 220, 0, 0},
-	{0x10F82, 230, 0, 0},
-	{0x10F83, 220, 0, 0},
-	{0x10F84, 230, 0, 0},
-	{0x10F85, 220, 0, 0},
-	{0x11046, 9, 0, 0},
-	{0x11070, 9, 0, 0},
-	{0x1107F, 9, 0, 0},
-	{0x1109A, 0, 2, 4786},
-	{0x1109C, 0, 2, 4788},
-	{0x110AB, 0, 2, 4790},
-	{0x110B9, 9, 0, 0},
-	{0x110BA, 7, 0, 0},
-	{0x11100, 230, 0, 0},
-	{0x11101, 230, 0, 0},
-	{0x11102, 230, 0, 0},
-	{0x1112E, 0, 2, 4792},
-	{0x1112F, 0, 2, 4794},
-	{0x11133, 9, 0, 0},
-	{0x11134, 9, 0, 0},
-	{0x11173, 7, 0, 0},
-	{0x111C0, 9, 0, 0},
-	{0x111CA, 7, 0, 0},
-	{0x11235, 9, 0, 0},
-	{0x11236, 7, 0, 0},
-	{0x112E9, 7, 0, 0},
-	{0x112EA, 9, 0, 0},
-	{0x1133B, 7, 0, 0},
-	{0x1133C, 7, 0, 0},
-	{0x1134B, 0, 2, 4796},
-	{0x1134C, 0, 2, 4798},
-	{0x1134D, 9, 0, 0},
-	{0x11366, 230, 0, 0},
-	{0x11367, 230, 0, 0},
-	{0x11368, 230, 0, 0},
-	{0x11369, 230, 0, 0},
-	{0x1136A, 230, 0, 0},
-	{0x1136B, 230, 0, 0},
-	{0x1136C, 230, 0, 0},
-	{0x11370, 230, 0, 0},
-	{0x11371, 230, 0, 0},
-	{0x11372, 230, 0, 0},
-	{0x11373, 230, 0, 0},
-	{0x11374, 230, 0, 0},
-	{0x11383, 0, 2, 4800},
-	{0x11385, 0, 2, 4802},
-	{0x1138E, 0, 2, 4804},
-	{0x11391, 0, 2, 4806},
-	{0x113C5, 0, 2, 4808},
-	{0x113C7, 0, 2, 4810},
-	{0x113C8, 0, 2, 4812},
-	{0x113CE, 9, 0, 0},
-	{0x113CF, 9, 0, 0},
-	{0x113D0, 9, 0, 0},
-	{0x11442, 9, 0, 0},
-	{0x11446, 7, 0, 0},
-	{0x1145E, 230, 0, 0},
-	{0x114BB, 0, 2, 4814},
-	{0x114BC, 0, 2, 4816},
-	{0x114BE, 0, 2, 4818},
-	{0x114C2, 9, 0, 0},
-	{0x114C3, 7, 0, 0},
-	{0x115BA, 0, 2, 4820},
-	{0x115BB, 0, 2, 4822},
-	{0x115BF, 9, 0, 0},
-	{0x115C0, 7, 0, 0},
-	{0x1163F, 9, 0, 0},
-	{0x116B6, 9, 0, 0},
-	{0x116B7, 7, 0, 0},
-	{0x1172B, 9, 0, 0},
-	{0x11839, 9, 0, 0},
-	{0x1183A, 7, 0, 0},
-	{0x11938, 0, 2, 4824},
-	{0x1193D, 9, 0, 0},
-	{0x1193E, 9, 0, 0},
-	{0x11943, 7, 0, 0},
-	{0x119E0, 9, 0, 0},
-	{0x11A34, 9, 0, 0},
-	{0x11A47, 9, 0, 0},
-	{0x11A99, 9, 0, 0},
-	{0x11C3F, 9, 0, 0},
-	{0x11D42, 7, 0, 0},
-	{0x11D44, 9, 0, 0},
-	{0x11D45, 9, 0, 0},
-	{0x11D97, 9, 0, 0},
-	{0x11F41, 9, 0, 0},
-	{0x11F42, 9, 0, 0},
-	{0x16121, 0, 2, 4826},
-	{0x16122, 0, 2, 4828},
-	{0x16123, 0, 2, 4830},
-	{0x16124, 0, 2, 4832},
-	{0x16125, 0, 2, 4834},
-	{0x16126, 0, 2, 4836},
-	{0x16127, 0, 2, 4838},
-	{0x16128, 0, 2, 4840},
-	{0x1612F, 9, 0, 0},
-	{0x16AF0, 1, 0, 0},
-	{0x16AF1, 1, 0, 0},
-	{0x16AF2, 1, 0, 0},
-	{0x16AF3, 1, 0, 0},
-	{0x16AF4, 1, 0, 0},
-	{0x16B30, 230, 0, 0},
-	{0x16B31, 230, 0, 0},
-	{0x16B32, 230, 0, 0},
-	{0x16B33, 230, 0, 0},
-	{0x16B34, 230, 0, 0},
-	{0x16B35, 230, 0, 0},
-	{0x16B36, 230, 0, 0},
-	{0x16D68, 0, 2, 4842},
-	{0x16D69, 0, 2, 4844},
-	{0x16D6A, 0, 2, 4846},
-	{0x16FF0, 6, 0, 0},
-	{0x16FF1, 6, 0, 0},
-	{0x1BC9E, 1, 0, 0},
-	{0x1CCD6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1CCD7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1CCD8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1CCD9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1CCDA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1CCDB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1CCDC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1CCDD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1CCDE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1CCDF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1CCE0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1CCE1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1CCE2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1CCE3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1CCE4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1CCE5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1CCE6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1CCE7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1CCE8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1CCE9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1CCEA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1CCEB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1CCEC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1CCED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1CCEE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1CCEF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1CCF0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x1CCF1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x1CCF2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x1CCF3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x1CCF4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x1CCF5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x1CCF6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x1CCF7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x1CCF8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x1CCF9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x1D15E, 0, 2 | DECOMP_NO_COMPOSE, 4848},	/* in exclusion list */
-	{0x1D15F, 0, 2 | DECOMP_NO_COMPOSE, 4850},	/* in exclusion list */
-	{0x1D160, 0, 2 | DECOMP_NO_COMPOSE, 4852},	/* in exclusion list */
-	{0x1D161, 0, 2 | DECOMP_NO_COMPOSE, 4854},	/* in exclusion list */
-	{0x1D162, 0, 2 | DECOMP_NO_COMPOSE, 4856},	/* in exclusion list */
-	{0x1D163, 0, 2 | DECOMP_NO_COMPOSE, 4858},	/* in exclusion list */
-	{0x1D164, 0, 2 | DECOMP_NO_COMPOSE, 4860},	/* in exclusion list */
-	{0x1D165, 216, 0, 0},
-	{0x1D166, 216, 0, 0},
-	{0x1D167, 1, 0, 0},
-	{0x1D168, 1, 0, 0},
-	{0x1D169, 1, 0, 0},
-	{0x1D16D, 226, 0, 0},
-	{0x1D16E, 216, 0, 0},
-	{0x1D16F, 216, 0, 0},
-	{0x1D170, 216, 0, 0},
-	{0x1D171, 216, 0, 0},
-	{0x1D172, 216, 0, 0},
-	{0x1D17B, 220, 0, 0},
-	{0x1D17C, 220, 0, 0},
-	{0x1D17D, 220, 0, 0},
-	{0x1D17E, 220, 0, 0},
-	{0x1D17F, 220, 0, 0},
-	{0x1D180, 220, 0, 0},
-	{0x1D181, 220, 0, 0},
-	{0x1D182, 220, 0, 0},
-	{0x1D185, 230, 0, 0},
-	{0x1D186, 230, 0, 0},
-	{0x1D187, 230, 0, 0},
-	{0x1D188, 230, 0, 0},
-	{0x1D189, 230, 0, 0},
-	{0x1D18A, 220, 0, 0},
-	{0x1D18B, 220, 0, 0},
-	{0x1D1AA, 230, 0, 0},
-	{0x1D1AB, 230, 0, 0},
-	{0x1D1AC, 230, 0, 0},
-	{0x1D1AD, 230, 0, 0},
-	{0x1D1BB, 0, 2 | DECOMP_NO_COMPOSE, 4862},	/* in exclusion list */
-	{0x1D1BC, 0, 2 | DECOMP_NO_COMPOSE, 4864},	/* in exclusion list */
-	{0x1D1BD, 0, 2 | DECOMP_NO_COMPOSE, 4866},	/* in exclusion list */
-	{0x1D1BE, 0, 2 | DECOMP_NO_COMPOSE, 4868},	/* in exclusion list */
-	{0x1D1BF, 0, 2 | DECOMP_NO_COMPOSE, 4870},	/* in exclusion list */
-	{0x1D1C0, 0, 2 | DECOMP_NO_COMPOSE, 4872},	/* in exclusion list */
-	{0x1D242, 230, 0, 0},
-	{0x1D243, 230, 0, 0},
-	{0x1D244, 230, 0, 0},
-	{0x1D400, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D401, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D402, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D403, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D404, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D405, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D406, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D407, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D408, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D409, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D40A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D40B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D40C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D40D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D40E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D40F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D410, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D411, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D412, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D413, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D414, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D415, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D416, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D417, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D418, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D419, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D41A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D41B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D41C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D41D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D41E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D41F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D420, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D421, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D422, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D423, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D424, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D425, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D426, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D427, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D428, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D429, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D42A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D42B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D42C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D42D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D42E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D42F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D430, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D431, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D432, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D433, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D434, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D435, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D436, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D437, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D438, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D439, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D43A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D43B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D43C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D43D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D43E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D43F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D440, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D441, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D442, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D443, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D444, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D445, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D446, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D447, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D448, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D449, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D44A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D44B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D44C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D44D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D44E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D44F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D450, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D451, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D452, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D453, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D454, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D456, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D457, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D458, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D459, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D45A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D45B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D45C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D45D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D45E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D45F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D460, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D461, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D462, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D463, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D464, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D465, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D466, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D467, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D468, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D469, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D46A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D46B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D46C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D46D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D46E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D46F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D470, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D471, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D472, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D473, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D474, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D475, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D476, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D477, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D478, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D479, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D47A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D47B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D47C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D47D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D47E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D47F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D480, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D481, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D482, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D483, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D484, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D485, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D486, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D487, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D488, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D489, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D48A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D48B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D48C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D48D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D48E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D48F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D490, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D491, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D492, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D493, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D494, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D495, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D496, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D497, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D498, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D499, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D49A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D49B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D49C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D49E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D49F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D4A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D4A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D4A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D4A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D4AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D4AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D4AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D4AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D4AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D4B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D4B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D4B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D4B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D4B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D4B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D4B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D4B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D4B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D4B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D4BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D4BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D4BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D4BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D4C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D4C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D4C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D4C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D4C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D4C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D4C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D4C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D4C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D4CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D4CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D4CC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D4CD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D4CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D4CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D4D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D4D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D4D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D4D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D4D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D4D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D4D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D4D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D4D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D4D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D4DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D4DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D4DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D4DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D4DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D4DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D4E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D4E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D4E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D4E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D4E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D4E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D4E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D4E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D4E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D4E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D4EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D4EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D4EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D4ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D4EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D4EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D4F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D4F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D4F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D4F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D4F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D4F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D4F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D4F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D4F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D4F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D4FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D4FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D4FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D4FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D4FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D4FF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D500, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D501, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D502, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D503, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D504, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D505, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D507, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D508, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D509, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D50A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D50D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D50E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D50F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D510, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D511, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D512, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D513, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D514, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D516, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D517, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D518, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D519, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D51A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D51B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D51C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D51E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D51F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D520, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D521, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D522, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D523, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D524, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D525, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D526, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D527, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D528, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D529, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D52A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D52B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D52C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D52D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D52E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D52F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D530, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D531, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D532, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D533, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D534, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D535, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D536, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D537, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D538, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D539, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D53B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D53C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D53D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D53E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D540, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D541, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D542, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D543, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D544, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D546, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D54A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D54B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D54C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D54D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D54E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D54F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D550, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D552, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D553, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D554, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D555, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D556, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D557, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D558, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D559, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D55A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D55B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D55C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D55D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D55E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D55F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D560, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D561, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D562, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D563, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D564, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D565, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D566, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D567, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D568, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D569, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D56A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D56B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D56C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D56D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D56E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D56F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D570, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D571, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D572, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D573, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D574, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D575, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D576, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D577, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D578, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D579, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D57A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D57B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D57C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D57D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D57E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D57F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D580, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D581, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D582, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D583, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D584, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D585, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D586, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D587, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D588, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D589, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D58A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D58B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D58C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D58D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D58E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D58F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D590, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D591, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D592, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D593, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D594, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D595, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D596, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D597, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D598, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D599, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D59A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D59B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D59C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D59D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D59E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D59F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D5A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D5A1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D5A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D5A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D5A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D5A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D5A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D5A7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D5A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D5A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D5AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D5AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D5AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D5AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D5AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D5AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D5B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D5B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D5B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D5B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D5B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D5B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D5B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D5B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D5B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D5B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D5BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D5BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D5BC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D5BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D5BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D5BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D5C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D5C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D5C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D5C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D5C4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D5C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D5C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D5C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D5C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D5C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D5CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D5CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D5CC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D5CD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D5CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D5CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D5D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D5D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D5D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D5D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D5D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D5D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D5D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D5D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D5D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D5D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D5DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D5DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D5DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D5DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D5DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D5DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D5E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D5E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D5E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D5E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D5E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D5E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D5E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D5E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D5E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D5E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D5EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D5EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D5EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D5ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D5EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D5EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D5F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D5F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D5F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D5F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D5F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D5F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D5F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D5F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D5F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D5F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D5FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D5FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D5FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D5FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D5FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D5FF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D600, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D601, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D602, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D603, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D604, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D605, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D606, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D607, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D608, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D609, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D60A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D60B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D60C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D60D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D60E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D60F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D610, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D611, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D612, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D613, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D614, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D615, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D616, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D617, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D618, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D619, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D61A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D61B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D61C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D61D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D61E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D61F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D620, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D621, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D622, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D623, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D624, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D625, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D626, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D627, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D628, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D629, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D62A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D62B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D62C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D62D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D62E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D62F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D630, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D631, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D632, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D633, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D634, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D635, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D636, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D637, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D638, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D639, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D63A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D63B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D63C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D63D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D63E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D63F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D640, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D641, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D642, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D643, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D644, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D645, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D646, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D647, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D648, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D649, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D64A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D64B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D64C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D64D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D64E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D64F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D650, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D651, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D652, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D653, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D654, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D655, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D656, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D657, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D658, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D659, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D65A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D65B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D65C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D65D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D65E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D65F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D660, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D661, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D662, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D663, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D664, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D665, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D666, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D667, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D668, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D669, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D66A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D66B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D66C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D66D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D66E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D66F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D670, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1D671, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1D672, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1D673, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1D674, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1D675, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1D676, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1D677, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1D678, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1D679, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1D67A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1D67B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1D67C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1D67D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1D67E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1D67F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1D680, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1D681, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1D682, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1D683, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1D684, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1D685, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1D686, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1D687, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1D688, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1D689, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1D68A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
-	{0x1D68B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
-	{0x1D68C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
-	{0x1D68D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
-	{0x1D68E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
-	{0x1D68F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
-	{0x1D690, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
-	{0x1D691, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
-	{0x1D692, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
-	{0x1D693, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
-	{0x1D694, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
-	{0x1D695, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
-	{0x1D696, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
-	{0x1D697, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
-	{0x1D698, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
-	{0x1D699, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
-	{0x1D69A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
-	{0x1D69B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
-	{0x1D69C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
-	{0x1D69D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
-	{0x1D69E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
-	{0x1D69F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
-	{0x1D6A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
-	{0x1D6A1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
-	{0x1D6A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
-	{0x1D6A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
-	{0x1D6A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0131},
-	{0x1D6A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0237},
-	{0x1D6A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
-	{0x1D6A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
-	{0x1D6AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
-	{0x1D6AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
-	{0x1D6AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
-	{0x1D6AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
-	{0x1D6AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
-	{0x1D6AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
-	{0x1D6B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
-	{0x1D6B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
-	{0x1D6B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
-	{0x1D6B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
-	{0x1D6B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
-	{0x1D6B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
-	{0x1D6B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
-	{0x1D6B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
-	{0x1D6B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
-	{0x1D6B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
-	{0x1D6BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
-	{0x1D6BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
-	{0x1D6BC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
-	{0x1D6BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
-	{0x1D6BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
-	{0x1D6BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
-	{0x1D6C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
-	{0x1D6C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
-	{0x1D6C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
-	{0x1D6C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
-	{0x1D6C4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
-	{0x1D6C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
-	{0x1D6C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
-	{0x1D6C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
-	{0x1D6C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
-	{0x1D6C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
-	{0x1D6CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
-	{0x1D6CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
-	{0x1D6CC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
-	{0x1D6CD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
-	{0x1D6CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
-	{0x1D6CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
-	{0x1D6D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
-	{0x1D6D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
-	{0x1D6D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
-	{0x1D6D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
-	{0x1D6D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
-	{0x1D6D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
-	{0x1D6D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
-	{0x1D6D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
-	{0x1D6D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
-	{0x1D6D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
-	{0x1D6DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
-	{0x1D6DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
-	{0x1D6DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
-	{0x1D6DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
-	{0x1D6DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
-	{0x1D6DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
-	{0x1D6E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
-	{0x1D6E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
-	{0x1D6E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
-	{0x1D6E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
-	{0x1D6E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
-	{0x1D6E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
-	{0x1D6E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
-	{0x1D6E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
-	{0x1D6E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
-	{0x1D6E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
-	{0x1D6EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
-	{0x1D6EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
-	{0x1D6EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
-	{0x1D6ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
-	{0x1D6EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
-	{0x1D6EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
-	{0x1D6F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
-	{0x1D6F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
-	{0x1D6F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
-	{0x1D6F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
-	{0x1D6F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
-	{0x1D6F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
-	{0x1D6F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
-	{0x1D6F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
-	{0x1D6F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
-	{0x1D6F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
-	{0x1D6FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
-	{0x1D6FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
-	{0x1D6FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
-	{0x1D6FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
-	{0x1D6FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
-	{0x1D6FF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
-	{0x1D700, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
-	{0x1D701, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
-	{0x1D702, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
-	{0x1D703, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
-	{0x1D704, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
-	{0x1D705, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
-	{0x1D706, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
-	{0x1D707, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
-	{0x1D708, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
-	{0x1D709, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
-	{0x1D70A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
-	{0x1D70B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
-	{0x1D70C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
-	{0x1D70D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
-	{0x1D70E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
-	{0x1D70F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
-	{0x1D710, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
-	{0x1D711, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
-	{0x1D712, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
-	{0x1D713, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
-	{0x1D714, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
-	{0x1D715, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
-	{0x1D716, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
-	{0x1D717, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
-	{0x1D718, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
-	{0x1D719, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
-	{0x1D71A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
-	{0x1D71B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
-	{0x1D71C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
-	{0x1D71D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
-	{0x1D71E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
-	{0x1D71F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
-	{0x1D720, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
-	{0x1D721, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
-	{0x1D722, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
-	{0x1D723, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
-	{0x1D724, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
-	{0x1D725, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
-	{0x1D726, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
-	{0x1D727, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
-	{0x1D728, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
-	{0x1D729, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
-	{0x1D72A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
-	{0x1D72B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
-	{0x1D72C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
-	{0x1D72D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
-	{0x1D72E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
-	{0x1D72F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
-	{0x1D730, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
-	{0x1D731, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
-	{0x1D732, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
-	{0x1D733, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
-	{0x1D734, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
-	{0x1D735, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
-	{0x1D736, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
-	{0x1D737, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
-	{0x1D738, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
-	{0x1D739, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
-	{0x1D73A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
-	{0x1D73B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
-	{0x1D73C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
-	{0x1D73D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
-	{0x1D73E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
-	{0x1D73F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
-	{0x1D740, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
-	{0x1D741, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
-	{0x1D742, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
-	{0x1D743, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
-	{0x1D744, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
-	{0x1D745, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
-	{0x1D746, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
-	{0x1D747, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
-	{0x1D748, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
-	{0x1D749, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
-	{0x1D74A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
-	{0x1D74B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
-	{0x1D74C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
-	{0x1D74D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
-	{0x1D74E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
-	{0x1D74F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
-	{0x1D750, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
-	{0x1D751, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
-	{0x1D752, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
-	{0x1D753, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
-	{0x1D754, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
-	{0x1D755, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
-	{0x1D756, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
-	{0x1D757, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
-	{0x1D758, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
-	{0x1D759, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
-	{0x1D75A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
-	{0x1D75B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
-	{0x1D75C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
-	{0x1D75D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
-	{0x1D75E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
-	{0x1D75F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
-	{0x1D760, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
-	{0x1D761, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
-	{0x1D762, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
-	{0x1D763, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
-	{0x1D764, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
-	{0x1D765, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
-	{0x1D766, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
-	{0x1D767, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
-	{0x1D768, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
-	{0x1D769, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
-	{0x1D76A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
-	{0x1D76B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
-	{0x1D76C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
-	{0x1D76D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
-	{0x1D76E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
-	{0x1D76F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
-	{0x1D770, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
-	{0x1D771, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
-	{0x1D772, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
-	{0x1D773, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
-	{0x1D774, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
-	{0x1D775, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
-	{0x1D776, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
-	{0x1D777, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
-	{0x1D778, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
-	{0x1D779, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
-	{0x1D77A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
-	{0x1D77B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
-	{0x1D77C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
-	{0x1D77D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
-	{0x1D77E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
-	{0x1D77F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
-	{0x1D780, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
-	{0x1D781, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
-	{0x1D782, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
-	{0x1D783, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
-	{0x1D784, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
-	{0x1D785, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
-	{0x1D786, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
-	{0x1D787, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
-	{0x1D788, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
-	{0x1D789, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
-	{0x1D78A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
-	{0x1D78B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
-	{0x1D78C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
-	{0x1D78D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
-	{0x1D78E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
-	{0x1D78F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
-	{0x1D790, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
-	{0x1D791, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
-	{0x1D792, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
-	{0x1D793, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
-	{0x1D794, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
-	{0x1D795, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
-	{0x1D796, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
-	{0x1D797, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
-	{0x1D798, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
-	{0x1D799, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
-	{0x1D79A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
-	{0x1D79B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
-	{0x1D79C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
-	{0x1D79D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
-	{0x1D79E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
-	{0x1D79F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
-	{0x1D7A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
-	{0x1D7A1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
-	{0x1D7A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
-	{0x1D7A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
-	{0x1D7A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
-	{0x1D7A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
-	{0x1D7A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
-	{0x1D7A7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
-	{0x1D7A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
-	{0x1D7A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
-	{0x1D7AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
-	{0x1D7AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
-	{0x1D7AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
-	{0x1D7AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
-	{0x1D7AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
-	{0x1D7AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
-	{0x1D7B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
-	{0x1D7B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
-	{0x1D7B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
-	{0x1D7B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
-	{0x1D7B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
-	{0x1D7B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
-	{0x1D7B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
-	{0x1D7B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
-	{0x1D7B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
-	{0x1D7B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
-	{0x1D7BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
-	{0x1D7BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
-	{0x1D7BC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
-	{0x1D7BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
-	{0x1D7BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
-	{0x1D7BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
-	{0x1D7C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
-	{0x1D7C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
-	{0x1D7C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
-	{0x1D7C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
-	{0x1D7C4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
-	{0x1D7C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
-	{0x1D7C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
-	{0x1D7C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
-	{0x1D7C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
-	{0x1D7C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
-	{0x1D7CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03DC},
-	{0x1D7CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03DD},
-	{0x1D7CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x1D7CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x1D7D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x1D7D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x1D7D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x1D7D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x1D7D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x1D7D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x1D7D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x1D7D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x1D7D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x1D7D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x1D7DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x1D7DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x1D7DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x1D7DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x1D7DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x1D7DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x1D7E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x1D7E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x1D7E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x1D7E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x1D7E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x1D7E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x1D7E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x1D7E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x1D7E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x1D7E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x1D7EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x1D7EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x1D7EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x1D7ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x1D7EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x1D7EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x1D7F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x1D7F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x1D7F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x1D7F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x1D7F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x1D7F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x1D7F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x1D7F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x1D7F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x1D7F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x1D7FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x1D7FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x1D7FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x1D7FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x1D7FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x1D7FF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x1E000, 230, 0, 0},
-	{0x1E001, 230, 0, 0},
-	{0x1E002, 230, 0, 0},
-	{0x1E003, 230, 0, 0},
-	{0x1E004, 230, 0, 0},
-	{0x1E005, 230, 0, 0},
-	{0x1E006, 230, 0, 0},
-	{0x1E008, 230, 0, 0},
-	{0x1E009, 230, 0, 0},
-	{0x1E00A, 230, 0, 0},
-	{0x1E00B, 230, 0, 0},
-	{0x1E00C, 230, 0, 0},
-	{0x1E00D, 230, 0, 0},
-	{0x1E00E, 230, 0, 0},
-	{0x1E00F, 230, 0, 0},
-	{0x1E010, 230, 0, 0},
-	{0x1E011, 230, 0, 0},
-	{0x1E012, 230, 0, 0},
-	{0x1E013, 230, 0, 0},
-	{0x1E014, 230, 0, 0},
-	{0x1E015, 230, 0, 0},
-	{0x1E016, 230, 0, 0},
-	{0x1E017, 230, 0, 0},
-	{0x1E018, 230, 0, 0},
-	{0x1E01B, 230, 0, 0},
-	{0x1E01C, 230, 0, 0},
-	{0x1E01D, 230, 0, 0},
-	{0x1E01E, 230, 0, 0},
-	{0x1E01F, 230, 0, 0},
-	{0x1E020, 230, 0, 0},
-	{0x1E021, 230, 0, 0},
-	{0x1E023, 230, 0, 0},
-	{0x1E024, 230, 0, 0},
-	{0x1E026, 230, 0, 0},
-	{0x1E027, 230, 0, 0},
-	{0x1E028, 230, 0, 0},
-	{0x1E029, 230, 0, 0},
-	{0x1E02A, 230, 0, 0},
-	{0x1E030, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0430},
-	{0x1E031, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0431},
-	{0x1E032, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0432},
-	{0x1E033, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0433},
-	{0x1E034, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0434},
-	{0x1E035, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0435},
-	{0x1E036, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0436},
-	{0x1E037, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0437},
-	{0x1E038, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0438},
-	{0x1E039, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043A},
-	{0x1E03A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043B},
-	{0x1E03B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043C},
-	{0x1E03C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043E},
-	{0x1E03D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043F},
-	{0x1E03E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0440},
-	{0x1E03F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0441},
-	{0x1E040, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0442},
-	{0x1E041, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0443},
-	{0x1E042, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0444},
-	{0x1E043, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0445},
-	{0x1E044, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0446},
-	{0x1E045, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0447},
-	{0x1E046, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0448},
-	{0x1E047, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044B},
-	{0x1E048, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044D},
-	{0x1E049, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044E},
-	{0x1E04A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA689},
-	{0x1E04B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04D9},
-	{0x1E04C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0456},
-	{0x1E04D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0458},
-	{0x1E04E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04E9},
-	{0x1E04F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04AF},
-	{0x1E050, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04CF},
-	{0x1E051, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0430},
-	{0x1E052, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0431},
-	{0x1E053, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0432},
-	{0x1E054, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0433},
-	{0x1E055, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0434},
-	{0x1E056, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0435},
-	{0x1E057, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0436},
-	{0x1E058, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0437},
-	{0x1E059, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0438},
-	{0x1E05A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043A},
-	{0x1E05B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043B},
-	{0x1E05C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043E},
-	{0x1E05D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043F},
-	{0x1E05E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0441},
-	{0x1E05F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0443},
-	{0x1E060, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0444},
-	{0x1E061, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0445},
-	{0x1E062, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0446},
-	{0x1E063, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0447},
-	{0x1E064, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0448},
-	{0x1E065, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044A},
-	{0x1E066, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044B},
-	{0x1E067, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0491},
-	{0x1E068, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0456},
-	{0x1E069, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0455},
-	{0x1E06A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x045F},
-	{0x1E06B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04AB},
-	{0x1E06C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA651},
-	{0x1E06D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04B1},
-	{0x1E08F, 230, 0, 0},
-	{0x1E130, 230, 0, 0},
-	{0x1E131, 230, 0, 0},
-	{0x1E132, 230, 0, 0},
-	{0x1E133, 230, 0, 0},
-	{0x1E134, 230, 0, 0},
-	{0x1E135, 230, 0, 0},
-	{0x1E136, 230, 0, 0},
-	{0x1E2AE, 230, 0, 0},
-	{0x1E2EC, 230, 0, 0},
-	{0x1E2ED, 230, 0, 0},
-	{0x1E2EE, 230, 0, 0},
-	{0x1E2EF, 230, 0, 0},
-	{0x1E4EC, 232, 0, 0},
-	{0x1E4ED, 232, 0, 0},
-	{0x1E4EE, 220, 0, 0},
-	{0x1E4EF, 230, 0, 0},
-	{0x1E5EE, 230, 0, 0},
-	{0x1E5EF, 220, 0, 0},
-	{0x1E8D0, 220, 0, 0},
-	{0x1E8D1, 220, 0, 0},
-	{0x1E8D2, 220, 0, 0},
-	{0x1E8D3, 220, 0, 0},
-	{0x1E8D4, 220, 0, 0},
-	{0x1E8D5, 220, 0, 0},
-	{0x1E8D6, 220, 0, 0},
-	{0x1E944, 230, 0, 0},
-	{0x1E945, 230, 0, 0},
-	{0x1E946, 230, 0, 0},
-	{0x1E947, 230, 0, 0},
-	{0x1E948, 230, 0, 0},
-	{0x1E949, 230, 0, 0},
-	{0x1E94A, 7, 0, 0},
-	{0x1EE00, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
-	{0x1EE01, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0x1EE02, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0x1EE03, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
-	{0x1EE05, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
-	{0x1EE06, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
-	{0x1EE07, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0x1EE08, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
-	{0x1EE09, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0x1EE0A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
-	{0x1EE0B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0x1EE0C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0x1EE0D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0x1EE0E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0x1EE0F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0x1EE10, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0x1EE11, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0x1EE12, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0x1EE13, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
-	{0x1EE14, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0x1EE15, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0x1EE16, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0x1EE17, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0x1EE18, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
-	{0x1EE19, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0x1EE1A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
-	{0x1EE1B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0x1EE1C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066E},
-	{0x1EE1D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
-	{0x1EE1E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A1},
-	{0x1EE1F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066F},
-	{0x1EE21, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0x1EE22, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0x1EE24, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
-	{0x1EE27, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0x1EE29, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0x1EE2A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
-	{0x1EE2B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0x1EE2C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0x1EE2D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0x1EE2E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0x1EE2F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0x1EE30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0x1EE31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0x1EE32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0x1EE34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0x1EE35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0x1EE36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0x1EE37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0x1EE39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0x1EE3B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0x1EE42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0x1EE47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0x1EE49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0x1EE4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0x1EE4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0x1EE4E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0x1EE4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0x1EE51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0x1EE52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0x1EE54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0x1EE57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0x1EE59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0x1EE5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0x1EE5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
-	{0x1EE5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066F},
-	{0x1EE61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0x1EE62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0x1EE64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
-	{0x1EE67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0x1EE68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
-	{0x1EE69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0x1EE6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
-	{0x1EE6C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0x1EE6D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0x1EE6E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0x1EE6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0x1EE70, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0x1EE71, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0x1EE72, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0x1EE74, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0x1EE75, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0x1EE76, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0x1EE77, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0x1EE79, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0x1EE7A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
-	{0x1EE7B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0x1EE7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066E},
-	{0x1EE7E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A1},
-	{0x1EE80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
-	{0x1EE81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0x1EE82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0x1EE83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
-	{0x1EE84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
-	{0x1EE85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
-	{0x1EE86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
-	{0x1EE87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0x1EE88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
-	{0x1EE89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0x1EE8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0x1EE8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0x1EE8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0x1EE8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0x1EE8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0x1EE90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0x1EE91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0x1EE92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0x1EE93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
-	{0x1EE94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0x1EE95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0x1EE96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0x1EE97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0x1EE98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
-	{0x1EE99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0x1EE9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
-	{0x1EE9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0x1EEA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
-	{0x1EEA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
-	{0x1EEA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
-	{0x1EEA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
-	{0x1EEA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
-	{0x1EEA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
-	{0x1EEA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
-	{0x1EEA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
-	{0x1EEAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
-	{0x1EEAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
-	{0x1EEAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
-	{0x1EEAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
-	{0x1EEAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
-	{0x1EEB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
-	{0x1EEB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
-	{0x1EEB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
-	{0x1EEB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
-	{0x1EEB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
-	{0x1EEB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
-	{0x1EEB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
-	{0x1EEB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
-	{0x1EEB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
-	{0x1EEB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
-	{0x1EEBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
-	{0x1EEBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
-	{0x1F100, 0, 2 | DECOMP_COMPAT, 4874},
-	{0x1F101, 0, 2 | DECOMP_COMPAT, 4876},
-	{0x1F102, 0, 2 | DECOMP_COMPAT, 4878},
-	{0x1F103, 0, 2 | DECOMP_COMPAT, 4880},
-	{0x1F104, 0, 2 | DECOMP_COMPAT, 4882},
-	{0x1F105, 0, 2 | DECOMP_COMPAT, 4884},
-	{0x1F106, 0, 2 | DECOMP_COMPAT, 4886},
-	{0x1F107, 0, 2 | DECOMP_COMPAT, 4888},
-	{0x1F108, 0, 2 | DECOMP_COMPAT, 4890},
-	{0x1F109, 0, 2 | DECOMP_COMPAT, 4892},
-	{0x1F10A, 0, 2 | DECOMP_COMPAT, 4894},
-	{0x1F110, 0, 3 | DECOMP_COMPAT, 4896},
-	{0x1F111, 0, 3 | DECOMP_COMPAT, 4899},
-	{0x1F112, 0, 3 | DECOMP_COMPAT, 4902},
-	{0x1F113, 0, 3 | DECOMP_COMPAT, 4905},
-	{0x1F114, 0, 3 | DECOMP_COMPAT, 4908},
-	{0x1F115, 0, 3 | DECOMP_COMPAT, 4911},
-	{0x1F116, 0, 3 | DECOMP_COMPAT, 4914},
-	{0x1F117, 0, 3 | DECOMP_COMPAT, 4917},
-	{0x1F118, 0, 3 | DECOMP_COMPAT, 4920},
-	{0x1F119, 0, 3 | DECOMP_COMPAT, 4923},
-	{0x1F11A, 0, 3 | DECOMP_COMPAT, 4926},
-	{0x1F11B, 0, 3 | DECOMP_COMPAT, 4929},
-	{0x1F11C, 0, 3 | DECOMP_COMPAT, 4932},
-	{0x1F11D, 0, 3 | DECOMP_COMPAT, 4935},
-	{0x1F11E, 0, 3 | DECOMP_COMPAT, 4938},
-	{0x1F11F, 0, 3 | DECOMP_COMPAT, 4941},
-	{0x1F120, 0, 3 | DECOMP_COMPAT, 4944},
-	{0x1F121, 0, 3 | DECOMP_COMPAT, 4947},
-	{0x1F122, 0, 3 | DECOMP_COMPAT, 4950},
-	{0x1F123, 0, 3 | DECOMP_COMPAT, 4953},
-	{0x1F124, 0, 3 | DECOMP_COMPAT, 4956},
-	{0x1F125, 0, 3 | DECOMP_COMPAT, 4959},
-	{0x1F126, 0, 3 | DECOMP_COMPAT, 4962},
-	{0x1F127, 0, 3 | DECOMP_COMPAT, 4965},
-	{0x1F128, 0, 3 | DECOMP_COMPAT, 4968},
-	{0x1F129, 0, 3 | DECOMP_COMPAT, 4971},
-	{0x1F12A, 0, 3 | DECOMP_COMPAT, 4974},
-	{0x1F12B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1F12C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1F12D, 0, 2 | DECOMP_COMPAT, 4977},
-	{0x1F12E, 0, 2 | DECOMP_COMPAT, 4979},
-	{0x1F130, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
-	{0x1F131, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
-	{0x1F132, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
-	{0x1F133, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
-	{0x1F134, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
-	{0x1F135, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
-	{0x1F136, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
-	{0x1F137, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
-	{0x1F138, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
-	{0x1F139, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
-	{0x1F13A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
-	{0x1F13B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
-	{0x1F13C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
-	{0x1F13D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
-	{0x1F13E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
-	{0x1F13F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
-	{0x1F140, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
-	{0x1F141, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
-	{0x1F142, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
-	{0x1F143, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
-	{0x1F144, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
-	{0x1F145, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
-	{0x1F146, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
-	{0x1F147, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
-	{0x1F148, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
-	{0x1F149, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
-	{0x1F14A, 0, 2 | DECOMP_COMPAT, 4981},
-	{0x1F14B, 0, 2 | DECOMP_COMPAT, 4983},
-	{0x1F14C, 0, 2 | DECOMP_COMPAT, 4985},
-	{0x1F14D, 0, 2 | DECOMP_COMPAT, 4987},
-	{0x1F14E, 0, 3 | DECOMP_COMPAT, 4989},
-	{0x1F14F, 0, 2 | DECOMP_COMPAT, 4992},
-	{0x1F16A, 0, 2 | DECOMP_COMPAT, 4994},
-	{0x1F16B, 0, 2 | DECOMP_COMPAT, 4996},
-	{0x1F16C, 0, 2 | DECOMP_COMPAT, 4998},
-	{0x1F190, 0, 2 | DECOMP_COMPAT, 5000},
-	{0x1F200, 0, 2 | DECOMP_COMPAT, 5002},
-	{0x1F201, 0, 2 | DECOMP_COMPAT, 5004},
-	{0x1F202, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B5},
-	{0x1F210, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x624B},
-	{0x1F211, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B57},
-	{0x1F212, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53CC},
-	{0x1F213, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C7},
-	{0x1F214, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
-	{0x1F215, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x591A},
-	{0x1F216, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x89E3},
-	{0x1F217, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5929},
-	{0x1F218, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EA4},
-	{0x1F219, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6620},
-	{0x1F21A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7121},
-	{0x1F21B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6599},
-	{0x1F21C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x524D},
-	{0x1F21D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F8C},
-	{0x1F21E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x518D},
-	{0x1F21F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65B0},
-	{0x1F220, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x521D},
-	{0x1F221, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7D42},
-	{0x1F222, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x751F},
-	{0x1F223, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CA9},
-	{0x1F224, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x58F0},
-	{0x1F225, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5439},
-	{0x1F226, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6F14},
-	{0x1F227, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6295},
-	{0x1F228, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6355},
-	{0x1F229, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
-	{0x1F22A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E09},
-	{0x1F22B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x904A},
-	{0x1F22C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DE6},
-	{0x1F22D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E2D},
-	{0x1F22E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53F3},
-	{0x1F22F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6307},
-	{0x1F230, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8D70},
-	{0x1F231, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6253},
-	{0x1F232, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7981},
-	{0x1F233, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7A7A},
-	{0x1F234, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5408},
-	{0x1F235, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6E80},
-	{0x1F236, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6709},
-	{0x1F237, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6708},
-	{0x1F238, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7533},
-	{0x1F239, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5272},
-	{0x1F23A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x55B6},
-	{0x1F23B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x914D},
-	{0x1F240, 0, 3 | DECOMP_COMPAT, 5006},
-	{0x1F241, 0, 3 | DECOMP_COMPAT, 5009},
-	{0x1F242, 0, 3 | DECOMP_COMPAT, 5012},
-	{0x1F243, 0, 3 | DECOMP_COMPAT, 5015},
-	{0x1F244, 0, 3 | DECOMP_COMPAT, 5018},
-	{0x1F245, 0, 3 | DECOMP_COMPAT, 5021},
-	{0x1F246, 0, 3 | DECOMP_COMPAT, 5024},
-	{0x1F247, 0, 3 | DECOMP_COMPAT, 5027},
-	{0x1F248, 0, 3 | DECOMP_COMPAT, 5030},
-	{0x1F250, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F97},
-	{0x1F251, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53EF},
-	{0x1FBF0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
-	{0x1FBF1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
-	{0x1FBF2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
-	{0x1FBF3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
-	{0x1FBF4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
-	{0x1FBF5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
-	{0x1FBF6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
-	{0x1FBF7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
-	{0x1FBF8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
-	{0x1FBF9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
-	{0x2F800, 0, 1 | DECOMP_INLINE, 0x4E3D},
-	{0x2F801, 0, 1 | DECOMP_INLINE, 0x4E38},
-	{0x2F802, 0, 1 | DECOMP_INLINE, 0x4E41},
-	{0x2F803, 0, 1, 5033},
-	{0x2F804, 0, 1 | DECOMP_INLINE, 0x4F60},
-	{0x2F805, 0, 1 | DECOMP_INLINE, 0x4FAE},
-	{0x2F806, 0, 1 | DECOMP_INLINE, 0x4FBB},
-	{0x2F807, 0, 1 | DECOMP_INLINE, 0x5002},
-	{0x2F808, 0, 1 | DECOMP_INLINE, 0x507A},
-	{0x2F809, 0, 1 | DECOMP_INLINE, 0x5099},
-	{0x2F80A, 0, 1 | DECOMP_INLINE, 0x50E7},
-	{0x2F80B, 0, 1 | DECOMP_INLINE, 0x50CF},
-	{0x2F80C, 0, 1 | DECOMP_INLINE, 0x349E},
-	{0x2F80D, 0, 1, 5034},
-	{0x2F80E, 0, 1 | DECOMP_INLINE, 0x514D},
-	{0x2F80F, 0, 1 | DECOMP_INLINE, 0x5154},
-	{0x2F810, 0, 1 | DECOMP_INLINE, 0x5164},
-	{0x2F811, 0, 1 | DECOMP_INLINE, 0x5177},
-	{0x2F812, 0, 1, 5035},
-	{0x2F813, 0, 1 | DECOMP_INLINE, 0x34B9},
-	{0x2F814, 0, 1 | DECOMP_INLINE, 0x5167},
-	{0x2F815, 0, 1 | DECOMP_INLINE, 0x518D},
-	{0x2F816, 0, 1, 5036},
-	{0x2F817, 0, 1 | DECOMP_INLINE, 0x5197},
-	{0x2F818, 0, 1 | DECOMP_INLINE, 0x51A4},
-	{0x2F819, 0, 1 | DECOMP_INLINE, 0x4ECC},
-	{0x2F81A, 0, 1 | DECOMP_INLINE, 0x51AC},
-	{0x2F81B, 0, 1 | DECOMP_INLINE, 0x51B5},
-	{0x2F81C, 0, 1, 5037},
-	{0x2F81D, 0, 1 | DECOMP_INLINE, 0x51F5},
-	{0x2F81E, 0, 1 | DECOMP_INLINE, 0x5203},
-	{0x2F81F, 0, 1 | DECOMP_INLINE, 0x34DF},
-	{0x2F820, 0, 1 | DECOMP_INLINE, 0x523B},
-	{0x2F821, 0, 1 | DECOMP_INLINE, 0x5246},
-	{0x2F822, 0, 1 | DECOMP_INLINE, 0x5272},
-	{0x2F823, 0, 1 | DECOMP_INLINE, 0x5277},
-	{0x2F824, 0, 1 | DECOMP_INLINE, 0x3515},
-	{0x2F825, 0, 1 | DECOMP_INLINE, 0x52C7},
-	{0x2F826, 0, 1 | DECOMP_INLINE, 0x52C9},
-	{0x2F827, 0, 1 | DECOMP_INLINE, 0x52E4},
-	{0x2F828, 0, 1 | DECOMP_INLINE, 0x52FA},
-	{0x2F829, 0, 1 | DECOMP_INLINE, 0x5305},
-	{0x2F82A, 0, 1 | DECOMP_INLINE, 0x5306},
-	{0x2F82B, 0, 1 | DECOMP_INLINE, 0x5317},
-	{0x2F82C, 0, 1 | DECOMP_INLINE, 0x5349},
-	{0x2F82D, 0, 1 | DECOMP_INLINE, 0x5351},
-	{0x2F82E, 0, 1 | DECOMP_INLINE, 0x535A},
-	{0x2F82F, 0, 1 | DECOMP_INLINE, 0x5373},
-	{0x2F830, 0, 1 | DECOMP_INLINE, 0x537D},
-	{0x2F831, 0, 1 | DECOMP_INLINE, 0x537F},
-	{0x2F832, 0, 1 | DECOMP_INLINE, 0x537F},
-	{0x2F833, 0, 1 | DECOMP_INLINE, 0x537F},
-	{0x2F834, 0, 1, 5038},
-	{0x2F835, 0, 1 | DECOMP_INLINE, 0x7070},
-	{0x2F836, 0, 1 | DECOMP_INLINE, 0x53CA},
-	{0x2F837, 0, 1 | DECOMP_INLINE, 0x53DF},
-	{0x2F838, 0, 1, 5039},
-	{0x2F839, 0, 1 | DECOMP_INLINE, 0x53EB},
-	{0x2F83A, 0, 1 | DECOMP_INLINE, 0x53F1},
-	{0x2F83B, 0, 1 | DECOMP_INLINE, 0x5406},
-	{0x2F83C, 0, 1 | DECOMP_INLINE, 0x549E},
-	{0x2F83D, 0, 1 | DECOMP_INLINE, 0x5438},
-	{0x2F83E, 0, 1 | DECOMP_INLINE, 0x5448},
-	{0x2F83F, 0, 1 | DECOMP_INLINE, 0x5468},
-	{0x2F840, 0, 1 | DECOMP_INLINE, 0x54A2},
-	{0x2F841, 0, 1 | DECOMP_INLINE, 0x54F6},
-	{0x2F842, 0, 1 | DECOMP_INLINE, 0x5510},
-	{0x2F843, 0, 1 | DECOMP_INLINE, 0x5553},
-	{0x2F844, 0, 1 | DECOMP_INLINE, 0x5563},
-	{0x2F845, 0, 1 | DECOMP_INLINE, 0x5584},
-	{0x2F846, 0, 1 | DECOMP_INLINE, 0x5584},
-	{0x2F847, 0, 1 | DECOMP_INLINE, 0x5599},
-	{0x2F848, 0, 1 | DECOMP_INLINE, 0x55AB},
-	{0x2F849, 0, 1 | DECOMP_INLINE, 0x55B3},
-	{0x2F84A, 0, 1 | DECOMP_INLINE, 0x55C2},
-	{0x2F84B, 0, 1 | DECOMP_INLINE, 0x5716},
-	{0x2F84C, 0, 1 | DECOMP_INLINE, 0x5606},
-	{0x2F84D, 0, 1 | DECOMP_INLINE, 0x5717},
-	{0x2F84E, 0, 1 | DECOMP_INLINE, 0x5651},
-	{0x2F84F, 0, 1 | DECOMP_INLINE, 0x5674},
-	{0x2F850, 0, 1 | DECOMP_INLINE, 0x5207},
-	{0x2F851, 0, 1 | DECOMP_INLINE, 0x58EE},
-	{0x2F852, 0, 1 | DECOMP_INLINE, 0x57CE},
-	{0x2F853, 0, 1 | DECOMP_INLINE, 0x57F4},
-	{0x2F854, 0, 1 | DECOMP_INLINE, 0x580D},
-	{0x2F855, 0, 1 | DECOMP_INLINE, 0x578B},
-	{0x2F856, 0, 1 | DECOMP_INLINE, 0x5832},
-	{0x2F857, 0, 1 | DECOMP_INLINE, 0x5831},
-	{0x2F858, 0, 1 | DECOMP_INLINE, 0x58AC},
-	{0x2F859, 0, 1, 5040},
-	{0x2F85A, 0, 1 | DECOMP_INLINE, 0x58F2},
-	{0x2F85B, 0, 1 | DECOMP_INLINE, 0x58F7},
-	{0x2F85C, 0, 1 | DECOMP_INLINE, 0x5906},
-	{0x2F85D, 0, 1 | DECOMP_INLINE, 0x591A},
-	{0x2F85E, 0, 1 | DECOMP_INLINE, 0x5922},
-	{0x2F85F, 0, 1 | DECOMP_INLINE, 0x5962},
-	{0x2F860, 0, 1, 5041},
-	{0x2F861, 0, 1, 5042},
-	{0x2F862, 0, 1 | DECOMP_INLINE, 0x59EC},
-	{0x2F863, 0, 1 | DECOMP_INLINE, 0x5A1B},
-	{0x2F864, 0, 1 | DECOMP_INLINE, 0x5A27},
-	{0x2F865, 0, 1 | DECOMP_INLINE, 0x59D8},
-	{0x2F866, 0, 1 | DECOMP_INLINE, 0x5A66},
-	{0x2F867, 0, 1 | DECOMP_INLINE, 0x36EE},
-	{0x2F868, 0, 1 | DECOMP_INLINE, 0x36FC},
-	{0x2F869, 0, 1 | DECOMP_INLINE, 0x5B08},
-	{0x2F86A, 0, 1 | DECOMP_INLINE, 0x5B3E},
-	{0x2F86B, 0, 1 | DECOMP_INLINE, 0x5B3E},
-	{0x2F86C, 0, 1, 5043},
-	{0x2F86D, 0, 1 | DECOMP_INLINE, 0x5BC3},
-	{0x2F86E, 0, 1 | DECOMP_INLINE, 0x5BD8},
-	{0x2F86F, 0, 1 | DECOMP_INLINE, 0x5BE7},
-	{0x2F870, 0, 1 | DECOMP_INLINE, 0x5BF3},
-	{0x2F871, 0, 1, 5044},
-	{0x2F872, 0, 1 | DECOMP_INLINE, 0x5BFF},
-	{0x2F873, 0, 1 | DECOMP_INLINE, 0x5C06},
-	{0x2F874, 0, 1 | DECOMP_INLINE, 0x5F53},
-	{0x2F875, 0, 1 | DECOMP_INLINE, 0x5C22},
-	{0x2F876, 0, 1 | DECOMP_INLINE, 0x3781},
-	{0x2F877, 0, 1 | DECOMP_INLINE, 0x5C60},
-	{0x2F878, 0, 1 | DECOMP_INLINE, 0x5C6E},
-	{0x2F879, 0, 1 | DECOMP_INLINE, 0x5CC0},
-	{0x2F87A, 0, 1 | DECOMP_INLINE, 0x5C8D},
-	{0x2F87B, 0, 1, 5045},
-	{0x2F87C, 0, 1 | DECOMP_INLINE, 0x5D43},
-	{0x2F87D, 0, 1, 5046},
-	{0x2F87E, 0, 1 | DECOMP_INLINE, 0x5D6E},
-	{0x2F87F, 0, 1 | DECOMP_INLINE, 0x5D6B},
-	{0x2F880, 0, 1 | DECOMP_INLINE, 0x5D7C},
-	{0x2F881, 0, 1 | DECOMP_INLINE, 0x5DE1},
-	{0x2F882, 0, 1 | DECOMP_INLINE, 0x5DE2},
-	{0x2F883, 0, 1 | DECOMP_INLINE, 0x382F},
-	{0x2F884, 0, 1 | DECOMP_INLINE, 0x5DFD},
-	{0x2F885, 0, 1 | DECOMP_INLINE, 0x5E28},
-	{0x2F886, 0, 1 | DECOMP_INLINE, 0x5E3D},
-	{0x2F887, 0, 1 | DECOMP_INLINE, 0x5E69},
-	{0x2F888, 0, 1 | DECOMP_INLINE, 0x3862},
-	{0x2F889, 0, 1, 5047},
-	{0x2F88A, 0, 1 | DECOMP_INLINE, 0x387C},
-	{0x2F88B, 0, 1 | DECOMP_INLINE, 0x5EB0},
-	{0x2F88C, 0, 1 | DECOMP_INLINE, 0x5EB3},
-	{0x2F88D, 0, 1 | DECOMP_INLINE, 0x5EB6},
-	{0x2F88E, 0, 1 | DECOMP_INLINE, 0x5ECA},
-	{0x2F88F, 0, 1, 5048},
-	{0x2F890, 0, 1 | DECOMP_INLINE, 0x5EFE},
-	{0x2F891, 0, 1, 5049},
-	{0x2F892, 0, 1, 5050},
-	{0x2F893, 0, 1 | DECOMP_INLINE, 0x8201},
-	{0x2F894, 0, 1 | DECOMP_INLINE, 0x5F22},
-	{0x2F895, 0, 1 | DECOMP_INLINE, 0x5F22},
-	{0x2F896, 0, 1 | DECOMP_INLINE, 0x38C7},
-	{0x2F897, 0, 1, 5051},
-	{0x2F898, 0, 1, 5052},
-	{0x2F899, 0, 1 | DECOMP_INLINE, 0x5F62},
-	{0x2F89A, 0, 1 | DECOMP_INLINE, 0x5F6B},
-	{0x2F89B, 0, 1 | DECOMP_INLINE, 0x38E3},
-	{0x2F89C, 0, 1 | DECOMP_INLINE, 0x5F9A},
-	{0x2F89D, 0, 1 | DECOMP_INLINE, 0x5FCD},
-	{0x2F89E, 0, 1 | DECOMP_INLINE, 0x5FD7},
-	{0x2F89F, 0, 1 | DECOMP_INLINE, 0x5FF9},
-	{0x2F8A0, 0, 1 | DECOMP_INLINE, 0x6081},
-	{0x2F8A1, 0, 1 | DECOMP_INLINE, 0x393A},
-	{0x2F8A2, 0, 1 | DECOMP_INLINE, 0x391C},
-	{0x2F8A3, 0, 1 | DECOMP_INLINE, 0x6094},
-	{0x2F8A4, 0, 1, 5053},
-	{0x2F8A5, 0, 1 | DECOMP_INLINE, 0x60C7},
-	{0x2F8A6, 0, 1 | DECOMP_INLINE, 0x6148},
-	{0x2F8A7, 0, 1 | DECOMP_INLINE, 0x614C},
-	{0x2F8A8, 0, 1 | DECOMP_INLINE, 0x614E},
-	{0x2F8A9, 0, 1 | DECOMP_INLINE, 0x614C},
-	{0x2F8AA, 0, 1 | DECOMP_INLINE, 0x617A},
-	{0x2F8AB, 0, 1 | DECOMP_INLINE, 0x618E},
-	{0x2F8AC, 0, 1 | DECOMP_INLINE, 0x61B2},
-	{0x2F8AD, 0, 1 | DECOMP_INLINE, 0x61A4},
-	{0x2F8AE, 0, 1 | DECOMP_INLINE, 0x61AF},
-	{0x2F8AF, 0, 1 | DECOMP_INLINE, 0x61DE},
-	{0x2F8B0, 0, 1 | DECOMP_INLINE, 0x61F2},
-	{0x2F8B1, 0, 1 | DECOMP_INLINE, 0x61F6},
-	{0x2F8B2, 0, 1 | DECOMP_INLINE, 0x6210},
-	{0x2F8B3, 0, 1 | DECOMP_INLINE, 0x621B},
-	{0x2F8B4, 0, 1 | DECOMP_INLINE, 0x625D},
-	{0x2F8B5, 0, 1 | DECOMP_INLINE, 0x62B1},
-	{0x2F8B6, 0, 1 | DECOMP_INLINE, 0x62D4},
-	{0x2F8B7, 0, 1 | DECOMP_INLINE, 0x6350},
-	{0x2F8B8, 0, 1, 5054},
-	{0x2F8B9, 0, 1 | DECOMP_INLINE, 0x633D},
-	{0x2F8BA, 0, 1 | DECOMP_INLINE, 0x62FC},
-	{0x2F8BB, 0, 1 | DECOMP_INLINE, 0x6368},
-	{0x2F8BC, 0, 1 | DECOMP_INLINE, 0x6383},
-	{0x2F8BD, 0, 1 | DECOMP_INLINE, 0x63E4},
-	{0x2F8BE, 0, 1, 5055},
-	{0x2F8BF, 0, 1 | DECOMP_INLINE, 0x6422},
-	{0x2F8C0, 0, 1 | DECOMP_INLINE, 0x63C5},
-	{0x2F8C1, 0, 1 | DECOMP_INLINE, 0x63A9},
-	{0x2F8C2, 0, 1 | DECOMP_INLINE, 0x3A2E},
-	{0x2F8C3, 0, 1 | DECOMP_INLINE, 0x6469},
-	{0x2F8C4, 0, 1 | DECOMP_INLINE, 0x647E},
-	{0x2F8C5, 0, 1 | DECOMP_INLINE, 0x649D},
-	{0x2F8C6, 0, 1 | DECOMP_INLINE, 0x6477},
-	{0x2F8C7, 0, 1 | DECOMP_INLINE, 0x3A6C},
-	{0x2F8C8, 0, 1 | DECOMP_INLINE, 0x654F},
-	{0x2F8C9, 0, 1 | DECOMP_INLINE, 0x656C},
-	{0x2F8CA, 0, 1, 5056},
-	{0x2F8CB, 0, 1 | DECOMP_INLINE, 0x65E3},
-	{0x2F8CC, 0, 1 | DECOMP_INLINE, 0x66F8},
-	{0x2F8CD, 0, 1 | DECOMP_INLINE, 0x6649},
-	{0x2F8CE, 0, 1 | DECOMP_INLINE, 0x3B19},
-	{0x2F8CF, 0, 1 | DECOMP_INLINE, 0x6691},
-	{0x2F8D0, 0, 1 | DECOMP_INLINE, 0x3B08},
-	{0x2F8D1, 0, 1 | DECOMP_INLINE, 0x3AE4},
-	{0x2F8D2, 0, 1 | DECOMP_INLINE, 0x5192},
-	{0x2F8D3, 0, 1 | DECOMP_INLINE, 0x5195},
-	{0x2F8D4, 0, 1 | DECOMP_INLINE, 0x6700},
-	{0x2F8D5, 0, 1 | DECOMP_INLINE, 0x669C},
-	{0x2F8D6, 0, 1 | DECOMP_INLINE, 0x80AD},
-	{0x2F8D7, 0, 1 | DECOMP_INLINE, 0x43D9},
-	{0x2F8D8, 0, 1 | DECOMP_INLINE, 0x6717},
-	{0x2F8D9, 0, 1 | DECOMP_INLINE, 0x671B},
-	{0x2F8DA, 0, 1 | DECOMP_INLINE, 0x6721},
-	{0x2F8DB, 0, 1 | DECOMP_INLINE, 0x675E},
-	{0x2F8DC, 0, 1 | DECOMP_INLINE, 0x6753},
-	{0x2F8DD, 0, 1, 5057},
-	{0x2F8DE, 0, 1 | DECOMP_INLINE, 0x3B49},
-	{0x2F8DF, 0, 1 | DECOMP_INLINE, 0x67FA},
-	{0x2F8E0, 0, 1 | DECOMP_INLINE, 0x6785},
-	{0x2F8E1, 0, 1 | DECOMP_INLINE, 0x6852},
-	{0x2F8E2, 0, 1 | DECOMP_INLINE, 0x6885},
-	{0x2F8E3, 0, 1, 5058},
-	{0x2F8E4, 0, 1 | DECOMP_INLINE, 0x688E},
-	{0x2F8E5, 0, 1 | DECOMP_INLINE, 0x681F},
-	{0x2F8E6, 0, 1 | DECOMP_INLINE, 0x6914},
-	{0x2F8E7, 0, 1 | DECOMP_INLINE, 0x3B9D},
-	{0x2F8E8, 0, 1 | DECOMP_INLINE, 0x6942},
-	{0x2F8E9, 0, 1 | DECOMP_INLINE, 0x69A3},
-	{0x2F8EA, 0, 1 | DECOMP_INLINE, 0x69EA},
-	{0x2F8EB, 0, 1 | DECOMP_INLINE, 0x6AA8},
-	{0x2F8EC, 0, 1, 5059},
-	{0x2F8ED, 0, 1 | DECOMP_INLINE, 0x6ADB},
-	{0x2F8EE, 0, 1 | DECOMP_INLINE, 0x3C18},
-	{0x2F8EF, 0, 1 | DECOMP_INLINE, 0x6B21},
-	{0x2F8F0, 0, 1, 5060},
-	{0x2F8F1, 0, 1 | DECOMP_INLINE, 0x6B54},
-	{0x2F8F2, 0, 1 | DECOMP_INLINE, 0x3C4E},
-	{0x2F8F3, 0, 1 | DECOMP_INLINE, 0x6B72},
-	{0x2F8F4, 0, 1 | DECOMP_INLINE, 0x6B9F},
-	{0x2F8F5, 0, 1 | DECOMP_INLINE, 0x6BBA},
-	{0x2F8F6, 0, 1 | DECOMP_INLINE, 0x6BBB},
-	{0x2F8F7, 0, 1, 5061},
-	{0x2F8F8, 0, 1, 5062},
-	{0x2F8F9, 0, 1, 5063},
-	{0x2F8FA, 0, 1 | DECOMP_INLINE, 0x6C4E},
-	{0x2F8FB, 0, 1, 5064},
-	{0x2F8FC, 0, 1 | DECOMP_INLINE, 0x6CBF},
-	{0x2F8FD, 0, 1 | DECOMP_INLINE, 0x6CCD},
-	{0x2F8FE, 0, 1 | DECOMP_INLINE, 0x6C67},
-	{0x2F8FF, 0, 1 | DECOMP_INLINE, 0x6D16},
-	{0x2F900, 0, 1 | DECOMP_INLINE, 0x6D3E},
-	{0x2F901, 0, 1 | DECOMP_INLINE, 0x6D77},
-	{0x2F902, 0, 1 | DECOMP_INLINE, 0x6D41},
-	{0x2F903, 0, 1 | DECOMP_INLINE, 0x6D69},
-	{0x2F904, 0, 1 | DECOMP_INLINE, 0x6D78},
-	{0x2F905, 0, 1 | DECOMP_INLINE, 0x6D85},
-	{0x2F906, 0, 1, 5065},
-	{0x2F907, 0, 1 | DECOMP_INLINE, 0x6D34},
-	{0x2F908, 0, 1 | DECOMP_INLINE, 0x6E2F},
-	{0x2F909, 0, 1 | DECOMP_INLINE, 0x6E6E},
-	{0x2F90A, 0, 1 | DECOMP_INLINE, 0x3D33},
-	{0x2F90B, 0, 1 | DECOMP_INLINE, 0x6ECB},
-	{0x2F90C, 0, 1 | DECOMP_INLINE, 0x6EC7},
-	{0x2F90D, 0, 1, 5066},
-	{0x2F90E, 0, 1 | DECOMP_INLINE, 0x6DF9},
-	{0x2F90F, 0, 1 | DECOMP_INLINE, 0x6F6E},
-	{0x2F910, 0, 1, 5067},
-	{0x2F911, 0, 1, 5068},
-	{0x2F912, 0, 1 | DECOMP_INLINE, 0x6FC6},
-	{0x2F913, 0, 1 | DECOMP_INLINE, 0x7039},
-	{0x2F914, 0, 1 | DECOMP_INLINE, 0x701E},
-	{0x2F915, 0, 1 | DECOMP_INLINE, 0x701B},
-	{0x2F916, 0, 1 | DECOMP_INLINE, 0x3D96},
-	{0x2F917, 0, 1 | DECOMP_INLINE, 0x704A},
-	{0x2F918, 0, 1 | DECOMP_INLINE, 0x707D},
-	{0x2F919, 0, 1 | DECOMP_INLINE, 0x7077},
-	{0x2F91A, 0, 1 | DECOMP_INLINE, 0x70AD},
-	{0x2F91B, 0, 1, 5069},
-	{0x2F91C, 0, 1 | DECOMP_INLINE, 0x7145},
-	{0x2F91D, 0, 1, 5070},
-	{0x2F91E, 0, 1 | DECOMP_INLINE, 0x719C},
-	{0x2F91F, 0, 1, 5071},
-	{0x2F920, 0, 1 | DECOMP_INLINE, 0x7228},
-	{0x2F921, 0, 1 | DECOMP_INLINE, 0x7235},
-	{0x2F922, 0, 1 | DECOMP_INLINE, 0x7250},
-	{0x2F923, 0, 1, 5072},
-	{0x2F924, 0, 1 | DECOMP_INLINE, 0x7280},
-	{0x2F925, 0, 1 | DECOMP_INLINE, 0x7295},
-	{0x2F926, 0, 1, 5073},
-	{0x2F927, 0, 1, 5074},
-	{0x2F928, 0, 1 | DECOMP_INLINE, 0x737A},
-	{0x2F929, 0, 1 | DECOMP_INLINE, 0x738B},
-	{0x2F92A, 0, 1 | DECOMP_INLINE, 0x3EAC},
-	{0x2F92B, 0, 1 | DECOMP_INLINE, 0x73A5},
-	{0x2F92C, 0, 1 | DECOMP_INLINE, 0x3EB8},
-	{0x2F92D, 0, 1 | DECOMP_INLINE, 0x3EB8},
-	{0x2F92E, 0, 1 | DECOMP_INLINE, 0x7447},
-	{0x2F92F, 0, 1 | DECOMP_INLINE, 0x745C},
-	{0x2F930, 0, 1 | DECOMP_INLINE, 0x7471},
-	{0x2F931, 0, 1 | DECOMP_INLINE, 0x7485},
-	{0x2F932, 0, 1 | DECOMP_INLINE, 0x74CA},
-	{0x2F933, 0, 1 | DECOMP_INLINE, 0x3F1B},
-	{0x2F934, 0, 1 | DECOMP_INLINE, 0x7524},
-	{0x2F935, 0, 1, 5075},
-	{0x2F936, 0, 1 | DECOMP_INLINE, 0x753E},
-	{0x2F937, 0, 1, 5076},
-	{0x2F938, 0, 1 | DECOMP_INLINE, 0x7570},
-	{0x2F939, 0, 1, 5077},
-	{0x2F93A, 0, 1 | DECOMP_INLINE, 0x7610},
-	{0x2F93B, 0, 1, 5078},
-	{0x2F93C, 0, 1, 5079},
-	{0x2F93D, 0, 1, 5080},
-	{0x2F93E, 0, 1 | DECOMP_INLINE, 0x3FFC},
-	{0x2F93F, 0, 1 | DECOMP_INLINE, 0x4008},
-	{0x2F940, 0, 1 | DECOMP_INLINE, 0x76F4},
-	{0x2F941, 0, 1, 5081},
-	{0x2F942, 0, 1, 5082},
-	{0x2F943, 0, 1, 5083},
-	{0x2F944, 0, 1, 5084},
-	{0x2F945, 0, 1 | DECOMP_INLINE, 0x771E},
-	{0x2F946, 0, 1 | DECOMP_INLINE, 0x771F},
-	{0x2F947, 0, 1 | DECOMP_INLINE, 0x771F},
-	{0x2F948, 0, 1 | DECOMP_INLINE, 0x774A},
-	{0x2F949, 0, 1 | DECOMP_INLINE, 0x4039},
-	{0x2F94A, 0, 1 | DECOMP_INLINE, 0x778B},
-	{0x2F94B, 0, 1 | DECOMP_INLINE, 0x4046},
-	{0x2F94C, 0, 1 | DECOMP_INLINE, 0x4096},
-	{0x2F94D, 0, 1, 5085},
-	{0x2F94E, 0, 1 | DECOMP_INLINE, 0x784E},
-	{0x2F94F, 0, 1 | DECOMP_INLINE, 0x788C},
-	{0x2F950, 0, 1 | DECOMP_INLINE, 0x78CC},
-	{0x2F951, 0, 1 | DECOMP_INLINE, 0x40E3},
-	{0x2F952, 0, 1, 5086},
-	{0x2F953, 0, 1 | DECOMP_INLINE, 0x7956},
-	{0x2F954, 0, 1, 5087},
-	{0x2F955, 0, 1, 5088},
-	{0x2F956, 0, 1 | DECOMP_INLINE, 0x798F},
-	{0x2F957, 0, 1 | DECOMP_INLINE, 0x79EB},
-	{0x2F958, 0, 1 | DECOMP_INLINE, 0x412F},
-	{0x2F959, 0, 1 | DECOMP_INLINE, 0x7A40},
-	{0x2F95A, 0, 1 | DECOMP_INLINE, 0x7A4A},
-	{0x2F95B, 0, 1 | DECOMP_INLINE, 0x7A4F},
-	{0x2F95C, 0, 1, 5089},
-	{0x2F95D, 0, 1, 5090},
-	{0x2F95E, 0, 1, 5091},
-	{0x2F95F, 0, 1 | DECOMP_INLINE, 0x7AEE},
-	{0x2F960, 0, 1 | DECOMP_INLINE, 0x4202},
-	{0x2F961, 0, 1, 5092},
-	{0x2F962, 0, 1 | DECOMP_INLINE, 0x7BC6},
-	{0x2F963, 0, 1 | DECOMP_INLINE, 0x7BC9},
-	{0x2F964, 0, 1 | DECOMP_INLINE, 0x4227},
-	{0x2F965, 0, 1, 5093},
-	{0x2F966, 0, 1 | DECOMP_INLINE, 0x7CD2},
-	{0x2F967, 0, 1 | DECOMP_INLINE, 0x42A0},
-	{0x2F968, 0, 1 | DECOMP_INLINE, 0x7CE8},
-	{0x2F969, 0, 1 | DECOMP_INLINE, 0x7CE3},
-	{0x2F96A, 0, 1 | DECOMP_INLINE, 0x7D00},
-	{0x2F96B, 0, 1, 5094},
-	{0x2F96C, 0, 1 | DECOMP_INLINE, 0x7D63},
-	{0x2F96D, 0, 1 | DECOMP_INLINE, 0x4301},
-	{0x2F96E, 0, 1 | DECOMP_INLINE, 0x7DC7},
-	{0x2F96F, 0, 1 | DECOMP_INLINE, 0x7E02},
-	{0x2F970, 0, 1 | DECOMP_INLINE, 0x7E45},
-	{0x2F971, 0, 1 | DECOMP_INLINE, 0x4334},
-	{0x2F972, 0, 1, 5095},
-	{0x2F973, 0, 1, 5096},
-	{0x2F974, 0, 1 | DECOMP_INLINE, 0x4359},
-	{0x2F975, 0, 1, 5097},
-	{0x2F976, 0, 1 | DECOMP_INLINE, 0x7F7A},
-	{0x2F977, 0, 1, 5098},
-	{0x2F978, 0, 1 | DECOMP_INLINE, 0x7F95},
-	{0x2F979, 0, 1 | DECOMP_INLINE, 0x7FFA},
-	{0x2F97A, 0, 1 | DECOMP_INLINE, 0x8005},
-	{0x2F97B, 0, 1, 5099},
-	{0x2F97C, 0, 1, 5100},
-	{0x2F97D, 0, 1 | DECOMP_INLINE, 0x8060},
-	{0x2F97E, 0, 1, 5101},
-	{0x2F97F, 0, 1 | DECOMP_INLINE, 0x8070},
-	{0x2F980, 0, 1, 5102},
-	{0x2F981, 0, 1 | DECOMP_INLINE, 0x43D5},
-	{0x2F982, 0, 1 | DECOMP_INLINE, 0x80B2},
-	{0x2F983, 0, 1 | DECOMP_INLINE, 0x8103},
-	{0x2F984, 0, 1 | DECOMP_INLINE, 0x440B},
-	{0x2F985, 0, 1 | DECOMP_INLINE, 0x813E},
-	{0x2F986, 0, 1 | DECOMP_INLINE, 0x5AB5},
-	{0x2F987, 0, 1, 5103},
-	{0x2F988, 0, 1, 5104},
-	{0x2F989, 0, 1, 5105},
-	{0x2F98A, 0, 1, 5106},
-	{0x2F98B, 0, 1 | DECOMP_INLINE, 0x8201},
-	{0x2F98C, 0, 1 | DECOMP_INLINE, 0x8204},
-	{0x2F98D, 0, 1 | DECOMP_INLINE, 0x8F9E},
-	{0x2F98E, 0, 1 | DECOMP_INLINE, 0x446B},
-	{0x2F98F, 0, 1 | DECOMP_INLINE, 0x8291},
-	{0x2F990, 0, 1 | DECOMP_INLINE, 0x828B},
-	{0x2F991, 0, 1 | DECOMP_INLINE, 0x829D},
-	{0x2F992, 0, 1 | DECOMP_INLINE, 0x52B3},
-	{0x2F993, 0, 1 | DECOMP_INLINE, 0x82B1},
-	{0x2F994, 0, 1 | DECOMP_INLINE, 0x82B3},
-	{0x2F995, 0, 1 | DECOMP_INLINE, 0x82BD},
-	{0x2F996, 0, 1 | DECOMP_INLINE, 0x82E6},
-	{0x2F997, 0, 1, 5107},
-	{0x2F998, 0, 1 | DECOMP_INLINE, 0x82E5},
-	{0x2F999, 0, 1 | DECOMP_INLINE, 0x831D},
-	{0x2F99A, 0, 1 | DECOMP_INLINE, 0x8363},
-	{0x2F99B, 0, 1 | DECOMP_INLINE, 0x83AD},
-	{0x2F99C, 0, 1 | DECOMP_INLINE, 0x8323},
-	{0x2F99D, 0, 1 | DECOMP_INLINE, 0x83BD},
-	{0x2F99E, 0, 1 | DECOMP_INLINE, 0x83E7},
-	{0x2F99F, 0, 1 | DECOMP_INLINE, 0x8457},
-	{0x2F9A0, 0, 1 | DECOMP_INLINE, 0x8353},
-	{0x2F9A1, 0, 1 | DECOMP_INLINE, 0x83CA},
-	{0x2F9A2, 0, 1 | DECOMP_INLINE, 0x83CC},
-	{0x2F9A3, 0, 1 | DECOMP_INLINE, 0x83DC},
-	{0x2F9A4, 0, 1, 5108},
-	{0x2F9A5, 0, 1, 5109},
-	{0x2F9A6, 0, 1, 5110},
-	{0x2F9A7, 0, 1 | DECOMP_INLINE, 0x452B},
-	{0x2F9A8, 0, 1 | DECOMP_INLINE, 0x84F1},
-	{0x2F9A9, 0, 1 | DECOMP_INLINE, 0x84F3},
-	{0x2F9AA, 0, 1 | DECOMP_INLINE, 0x8516},
-	{0x2F9AB, 0, 1, 5111},
-	{0x2F9AC, 0, 1 | DECOMP_INLINE, 0x8564},
-	{0x2F9AD, 0, 1, 5112},
-	{0x2F9AE, 0, 1 | DECOMP_INLINE, 0x455D},
-	{0x2F9AF, 0, 1 | DECOMP_INLINE, 0x4561},
-	{0x2F9B0, 0, 1, 5113},
-	{0x2F9B1, 0, 1, 5114},
-	{0x2F9B2, 0, 1 | DECOMP_INLINE, 0x456B},
-	{0x2F9B3, 0, 1 | DECOMP_INLINE, 0x8650},
-	{0x2F9B4, 0, 1 | DECOMP_INLINE, 0x865C},
-	{0x2F9B5, 0, 1 | DECOMP_INLINE, 0x8667},
-	{0x2F9B6, 0, 1 | DECOMP_INLINE, 0x8669},
-	{0x2F9B7, 0, 1 | DECOMP_INLINE, 0x86A9},
-	{0x2F9B8, 0, 1 | DECOMP_INLINE, 0x8688},
-	{0x2F9B9, 0, 1 | DECOMP_INLINE, 0x870E},
-	{0x2F9BA, 0, 1 | DECOMP_INLINE, 0x86E2},
-	{0x2F9BB, 0, 1 | DECOMP_INLINE, 0x8779},
-	{0x2F9BC, 0, 1 | DECOMP_INLINE, 0x8728},
-	{0x2F9BD, 0, 1 | DECOMP_INLINE, 0x876B},
-	{0x2F9BE, 0, 1 | DECOMP_INLINE, 0x8786},
-	{0x2F9BF, 0, 1 | DECOMP_INLINE, 0x45D7},
-	{0x2F9C0, 0, 1 | DECOMP_INLINE, 0x87E1},
-	{0x2F9C1, 0, 1 | DECOMP_INLINE, 0x8801},
-	{0x2F9C2, 0, 1 | DECOMP_INLINE, 0x45F9},
-	{0x2F9C3, 0, 1 | DECOMP_INLINE, 0x8860},
-	{0x2F9C4, 0, 1 | DECOMP_INLINE, 0x8863},
-	{0x2F9C5, 0, 1, 5115},
-	{0x2F9C6, 0, 1 | DECOMP_INLINE, 0x88D7},
-	{0x2F9C7, 0, 1 | DECOMP_INLINE, 0x88DE},
-	{0x2F9C8, 0, 1 | DECOMP_INLINE, 0x4635},
-	{0x2F9C9, 0, 1 | DECOMP_INLINE, 0x88FA},
-	{0x2F9CA, 0, 1 | DECOMP_INLINE, 0x34BB},
-	{0x2F9CB, 0, 1, 5116},
-	{0x2F9CC, 0, 1, 5117},
-	{0x2F9CD, 0, 1 | DECOMP_INLINE, 0x46BE},
-	{0x2F9CE, 0, 1 | DECOMP_INLINE, 0x46C7},
-	{0x2F9CF, 0, 1 | DECOMP_INLINE, 0x8AA0},
-	{0x2F9D0, 0, 1 | DECOMP_INLINE, 0x8AED},
-	{0x2F9D1, 0, 1 | DECOMP_INLINE, 0x8B8A},
-	{0x2F9D2, 0, 1 | DECOMP_INLINE, 0x8C55},
-	{0x2F9D3, 0, 1, 5118},
-	{0x2F9D4, 0, 1 | DECOMP_INLINE, 0x8CAB},
-	{0x2F9D5, 0, 1 | DECOMP_INLINE, 0x8CC1},
-	{0x2F9D6, 0, 1 | DECOMP_INLINE, 0x8D1B},
-	{0x2F9D7, 0, 1 | DECOMP_INLINE, 0x8D77},
-	{0x2F9D8, 0, 1, 5119},
-	{0x2F9D9, 0, 1, 5120},
-	{0x2F9DA, 0, 1 | DECOMP_INLINE, 0x8DCB},
-	{0x2F9DB, 0, 1 | DECOMP_INLINE, 0x8DBC},
-	{0x2F9DC, 0, 1 | DECOMP_INLINE, 0x8DF0},
-	{0x2F9DD, 0, 1, 5121},
-	{0x2F9DE, 0, 1 | DECOMP_INLINE, 0x8ED4},
-	{0x2F9DF, 0, 1 | DECOMP_INLINE, 0x8F38},
-	{0x2F9E0, 0, 1, 5122},
-	{0x2F9E1, 0, 1, 5123},
-	{0x2F9E2, 0, 1 | DECOMP_INLINE, 0x9094},
-	{0x2F9E3, 0, 1 | DECOMP_INLINE, 0x90F1},
-	{0x2F9E4, 0, 1 | DECOMP_INLINE, 0x9111},
-	{0x2F9E5, 0, 1, 5124},
-	{0x2F9E6, 0, 1 | DECOMP_INLINE, 0x911B},
-	{0x2F9E7, 0, 1 | DECOMP_INLINE, 0x9238},
-	{0x2F9E8, 0, 1 | DECOMP_INLINE, 0x92D7},
-	{0x2F9E9, 0, 1 | DECOMP_INLINE, 0x92D8},
-	{0x2F9EA, 0, 1 | DECOMP_INLINE, 0x927C},
-	{0x2F9EB, 0, 1 | DECOMP_INLINE, 0x93F9},
-	{0x2F9EC, 0, 1 | DECOMP_INLINE, 0x9415},
-	{0x2F9ED, 0, 1, 5125},
-	{0x2F9EE, 0, 1 | DECOMP_INLINE, 0x958B},
-	{0x2F9EF, 0, 1 | DECOMP_INLINE, 0x4995},
-	{0x2F9F0, 0, 1 | DECOMP_INLINE, 0x95B7},
-	{0x2F9F1, 0, 1, 5126},
-	{0x2F9F2, 0, 1 | DECOMP_INLINE, 0x49E6},
-	{0x2F9F3, 0, 1 | DECOMP_INLINE, 0x96C3},
-	{0x2F9F4, 0, 1 | DECOMP_INLINE, 0x5DB2},
-	{0x2F9F5, 0, 1 | DECOMP_INLINE, 0x9723},
-	{0x2F9F6, 0, 1, 5127},
-	{0x2F9F7, 0, 1, 5128},
-	{0x2F9F8, 0, 1 | DECOMP_INLINE, 0x4A6E},
-	{0x2F9F9, 0, 1 | DECOMP_INLINE, 0x4A76},
-	{0x2F9FA, 0, 1 | DECOMP_INLINE, 0x97E0},
-	{0x2F9FB, 0, 1, 5129},
-	{0x2F9FC, 0, 1 | DECOMP_INLINE, 0x4AB2},
-	{0x2F9FD, 0, 1, 5130},
-	{0x2F9FE, 0, 1 | DECOMP_INLINE, 0x980B},
-	{0x2F9FF, 0, 1 | DECOMP_INLINE, 0x980B},
-	{0x2FA00, 0, 1 | DECOMP_INLINE, 0x9829},
-	{0x2FA01, 0, 1, 5131},
-	{0x2FA02, 0, 1 | DECOMP_INLINE, 0x98E2},
-	{0x2FA03, 0, 1 | DECOMP_INLINE, 0x4B33},
-	{0x2FA04, 0, 1 | DECOMP_INLINE, 0x9929},
-	{0x2FA05, 0, 1 | DECOMP_INLINE, 0x99A7},
-	{0x2FA06, 0, 1 | DECOMP_INLINE, 0x99C2},
-	{0x2FA07, 0, 1 | DECOMP_INLINE, 0x99FE},
-	{0x2FA08, 0, 1 | DECOMP_INLINE, 0x4BCE},
-	{0x2FA09, 0, 1, 5132},
-	{0x2FA0A, 0, 1 | DECOMP_INLINE, 0x9B12},
-	{0x2FA0B, 0, 1 | DECOMP_INLINE, 0x9C40},
-	{0x2FA0C, 0, 1 | DECOMP_INLINE, 0x9CFD},
-	{0x2FA0D, 0, 1 | DECOMP_INLINE, 0x4CCE},
-	{0x2FA0E, 0, 1 | DECOMP_INLINE, 0x4CED},
-	{0x2FA0F, 0, 1 | DECOMP_INLINE, 0x9D67},
-	{0x2FA10, 0, 1, 5133},
-	{0x2FA11, 0, 1 | DECOMP_INLINE, 0x4CF8},
-	{0x2FA12, 0, 1, 5134},
-	{0x2FA13, 0, 1, 5135},
-	{0x2FA14, 0, 1, 5136},
-	{0x2FA15, 0, 1 | DECOMP_INLINE, 0x9EBB},
-	{0x2FA16, 0, 1 | DECOMP_INLINE, 0x4D56},
-	{0x2FA17, 0, 1 | DECOMP_INLINE, 0x9EF9},
-	{0x2FA18, 0, 1 | DECOMP_INLINE, 0x9EFE},
-	{0x2FA19, 0, 1 | DECOMP_INLINE, 0x9F05},
-	{0x2FA1A, 0, 1 | DECOMP_INLINE, 0x9F0F},
-	{0x2FA1B, 0, 1 | DECOMP_INLINE, 0x9F16},
-	{0x2FA1C, 0, 1 | DECOMP_INLINE, 0x9F3B},
-	{0x2FA1D, 0, 1, 5137}
+	{0, 0, 0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0, 2 | DECOMP_COMPAT, 1494},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0, 2 | DECOMP_COMPAT, 1496},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0, 2 | DECOMP_COMPAT, 1498},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
+	{0, 2 | DECOMP_COMPAT, 1500},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0, 3 | DECOMP_COMPAT, 378},
+	{0, 3 | DECOMP_COMPAT, 381},
+	{0, 3 | DECOMP_COMPAT, 384},
+	{0, 2, 1502},
+	{0, 2, 1504},
+	{0, 2, 1506},
+	{0, 2, 1508},
+	{0, 2, 1510},
+	{0, 2, 1512},
+	{0, 2, 1514},
+	{0, 2, 1516},
+	{0, 2, 1518},
+	{0, 2, 1520},
+	{0, 2, 1522},
+	{0, 2, 1524},
+	{0, 2, 1526},
+	{0, 2, 1528},
+	{0, 2, 1530},
+	{0, 2, 1532},
+	{0, 2, 1534},
+	{0, 2, 1536},
+	{0, 2, 1538},
+	{0, 2, 1540},
+	{0, 2, 1542},
+	{0, 2, 1544},
+	{0, 2, 1546},
+	{0, 2, 1548},
+	{0, 2, 1550},
+	{0, 2, 1552},
+	{0, 2, 1554},
+	{0, 2, 1556},
+	{0, 2, 1558},
+	{0, 2, 1560},
+	{0, 2, 1562},
+	{0, 2, 1564},
+	{0, 2, 1566},
+	{0, 2, 1568},
+	{0, 2, 1570},
+	{0, 2, 1572},
+	{0, 2, 1574},
+	{0, 2, 1576},
+	{0, 2, 1578},
+	{0, 2, 1580},
+	{0, 2, 1582},
+	{0, 2, 1584},
+	{0, 2, 1586},
+	{0, 2, 1588},
+	{0, 2, 1590},
+	{0, 2, 1592},
+	{0, 2, 1594},
+	{0, 2, 1596},
+	{0, 2, 1598},
+	{0, 2, 1600},
+	{0, 2, 1602},
+	{0, 2, 1604},
+	{0, 2, 1606},
+	{0, 2, 1608},
+	{0, 2, 1610},
+	{0, 2, 1612},
+	{0, 2, 1614},
+	{0, 2, 1616},
+	{0, 2, 1618},
+	{0, 2, 1620},
+	{0, 2, 1622},
+	{0, 2, 1624},
+	{0, 2, 1626},
+	{0, 2, 1628},
+	{0, 2, 1630},
+	{0, 2, 1632},
+	{0, 2, 1634},
+	{0, 2, 1636},
+	{0, 2, 1638},
+	{0, 2, 1640},
+	{0, 2, 1642},
+	{0, 2, 1644},
+	{0, 2, 1646},
+	{0, 2, 1648},
+	{0, 2, 1650},
+	{0, 2, 1652},
+	{0, 2, 1654},
+	{0, 2, 1656},
+	{0, 2, 1658},
+	{0, 2, 1660},
+	{0, 2, 1662},
+	{0, 2, 1664},
+	{0, 2, 1666},
+	{0, 2, 1668},
+	{0, 2, 1670},
+	{0, 2, 1672},
+	{0, 2, 1674},
+	{0, 2, 1676},
+	{0, 2, 1678},
+	{0, 2, 1680},
+	{0, 2, 1682},
+	{0, 2, 1684},
+	{0, 2, 1686},
+	{0, 2, 1688},
+	{0, 2, 1690},
+	{0, 2, 1692},
+	{0, 2, 1694},
+	{0, 2, 1696},
+	{0, 2 | DECOMP_COMPAT, 1698},
+	{0, 2 | DECOMP_COMPAT, 1700},
+	{0, 2, 1702},
+	{0, 2, 1704},
+	{0, 2, 1706},
+	{0, 2, 1708},
+	{0, 2, 1710},
+	{0, 2, 1712},
+	{0, 2, 1714},
+	{0, 2, 1716},
+	{0, 2, 1718},
+	{0, 2, 1720},
+	{0, 2 | DECOMP_COMPAT, 1722},
+	{0, 2 | DECOMP_COMPAT, 1724},
+	{0, 2, 1726},
+	{0, 2, 1728},
+	{0, 2, 1730},
+	{0, 2, 1732},
+	{0, 2, 1734},
+	{0, 2, 1736},
+	{0, 2 | DECOMP_COMPAT, 1738},
+	{0, 2, 1740},
+	{0, 2, 1742},
+	{0, 2, 1744},
+	{0, 2, 1746},
+	{0, 2, 1748},
+	{0, 2, 1750},
+	{0, 2, 1752},
+	{0, 2, 1754},
+	{0, 2, 1756},
+	{0, 2, 1758},
+	{0, 2, 1760},
+	{0, 2, 1762},
+	{0, 2, 1764},
+	{0, 2, 1766},
+	{0, 2, 1768},
+	{0, 2, 1770},
+	{0, 2, 1772},
+	{0, 2, 1774},
+	{0, 2, 1776},
+	{0, 2, 1778},
+	{0, 2, 1780},
+	{0, 2, 1782},
+	{0, 2, 1784},
+	{0, 2, 1786},
+	{0, 2, 1788},
+	{0, 2, 1790},
+	{0, 2, 1792},
+	{0, 2, 1794},
+	{0, 2, 1796},
+	{0, 2, 1798},
+	{0, 2, 1800},
+	{0, 2, 1802},
+	{0, 2, 1804},
+	{0, 2, 1806},
+	{0, 2, 1808},
+	{0, 2, 1810},
+	{0, 2, 1812},
+	{0, 2, 1814},
+	{0, 2, 1816},
+	{0, 2, 1818},
+	{0, 2, 1820},
+	{0, 2, 1822},
+	{0, 2, 1824},
+	{0, 2, 1826},
+	{0, 2, 1828},
+	{0, 2, 1830},
+	{0, 2, 1832},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0, 2, 1834},
+	{0, 2, 1836},
+	{0, 2, 1838},
+	{0, 2, 1840},
+	{0, 2 | DECOMP_COMPAT, 1842},
+	{0, 2 | DECOMP_COMPAT, 1844},
+	{0, 2 | DECOMP_COMPAT, 1846},
+	{0, 2 | DECOMP_COMPAT, 1848},
+	{0, 2 | DECOMP_COMPAT, 1850},
+	{0, 2 | DECOMP_COMPAT, 1852},
+	{0, 2 | DECOMP_COMPAT, 1854},
+	{0, 2 | DECOMP_COMPAT, 1856},
+	{0, 2 | DECOMP_COMPAT, 1858},
+	{0, 2, 1860},
+	{0, 2, 1862},
+	{0, 2, 1864},
+	{0, 2, 1866},
+	{0, 2, 1868},
+	{0, 2, 1870},
+	{0, 2, 1872},
+	{0, 2, 1874},
+	{0, 2, 1876},
+	{0, 2, 1878},
+	{0, 2, 1880},
+	{0, 2, 1882},
+	{0, 2, 1884},
+	{0, 2, 1886},
+	{0, 2, 1888},
+	{0, 2, 1890},
+	{0, 2, 1892},
+	{0, 2, 1894},
+	{0, 2, 1896},
+	{0, 2, 1898},
+	{0, 2, 1900},
+	{0, 2, 1902},
+	{0, 2, 1904},
+	{0, 2, 1906},
+	{0, 2, 1908},
+	{0, 2, 1910},
+	{0, 2, 1912},
+	{0, 2, 1914},
+	{0, 2, 1916},
+	{0, 2, 1918},
+	{0, 2, 1920},
+	{0, 2, 1922},
+	{0, 2, 1924},
+	{0, 2 | DECOMP_COMPAT, 1926},
+	{0, 2 | DECOMP_COMPAT, 1928},
+	{0, 2 | DECOMP_COMPAT, 1930},
+	{0, 2, 1932},
+	{0, 2, 1934},
+	{0, 2, 1936},
+	{0, 2, 1938},
+	{0, 2, 1940},
+	{0, 2, 1942},
+	{0, 2, 1944},
+	{0, 2, 1946},
+	{0, 2, 1948},
+	{0, 2, 1950},
+	{0, 2, 1952},
+	{0, 2, 1954},
+	{0, 2, 1956},
+	{0, 2, 1958},
+	{0, 2, 1960},
+	{0, 2, 1962},
+	{0, 2, 1964},
+	{0, 2, 1966},
+	{0, 2, 1968},
+	{0, 2, 1970},
+	{0, 2, 1972},
+	{0, 2, 1974},
+	{0, 2, 1976},
+	{0, 2, 1978},
+	{0, 2, 1980},
+	{0, 2, 1982},
+	{0, 2, 1984},
+	{0, 2, 1986},
+	{0, 2, 1988},
+	{0, 2, 1990},
+	{0, 2, 1992},
+	{0, 2, 1994},
+	{0, 2, 1996},
+	{0, 2, 1998},
+	{0, 2, 2000},
+	{0, 2, 2002},
+	{0, 2, 2004},
+	{0, 2, 2006},
+	{0, 2, 2008},
+	{0, 2, 2010},
+	{0, 2, 2012},
+	{0, 2, 2014},
+	{0, 2, 2016},
+	{0, 2, 2018},
+	{0, 2, 2020},
+	{0, 2, 2022},
+	{0, 2, 2024},
+	{0, 2, 2026},
+	{0, 2, 2028},
+	{0, 2, 2030},
+	{0, 2, 2032},
+	{0, 2, 2034},
+	{0, 2, 2036},
+	{0, 2, 2038},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0266},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0279},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0281},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0, 2 | DECOMP_COMPAT, 2040},
+	{0, 2 | DECOMP_COMPAT, 2042},
+	{0, 2 | DECOMP_COMPAT, 2044},
+	{0, 2 | DECOMP_COMPAT, 2046},
+	{0, 2 | DECOMP_COMPAT, 2048},
+	{0, 2 | DECOMP_COMPAT, 2050},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0263},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0295},
+	{230, 0, 0},
+	{232, 0, 0},
+	{220, 0, 0},
+	{216, 0, 0},
+	{202, 0, 0},
+	{1, 0, 0},
+	{230, 1 | DECOMP_INLINE, 0x0300},
+	{230, 1 | DECOMP_INLINE, 0x0301},
+	{230, 1 | DECOMP_INLINE, 0x0313},
+	{230, 2 | DECOMP_NO_COMPOSE, 2052},	/* non-starter decomposition */
+	{240, 0, 0},
+	{233, 0, 0},
+	{234, 0, 0},
+	{0, 1 | DECOMP_INLINE, 0x02B9},
+	{0, 2 | DECOMP_COMPAT, 2054},
+	{0, 1 | DECOMP_INLINE, 0x003B},
+	{0, 2, 2056},
+	{0, 2, 2058},
+	{0, 1 | DECOMP_INLINE, 0x00B7},
+	{0, 2, 2060},
+	{0, 2, 2062},
+	{0, 2, 2064},
+	{0, 2, 2066},
+	{0, 2, 2068},
+	{0, 2, 2070},
+	{0, 2, 2072},
+	{0, 2, 2074},
+	{0, 2, 2076},
+	{0, 2, 2078},
+	{0, 2, 2080},
+	{0, 2, 2082},
+	{0, 2, 2084},
+	{0, 2, 2086},
+	{0, 2, 2088},
+	{0, 2, 2090},
+	{0, 2, 2092},
+	{0, 2, 2094},
+	{0, 2, 2096},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
+	{0, 2, 2098},
+	{0, 2, 2100},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
+	{0, 2, 2102},
+	{0, 2, 2104},
+	{0, 2, 2106},
+	{0, 2, 2108},
+	{0, 2, 2110},
+	{0, 2, 2112},
+	{0, 2, 2114},
+	{0, 2, 2116},
+	{0, 2, 2118},
+	{0, 2, 2120},
+	{0, 2, 2122},
+	{0, 2, 2124},
+	{0, 2, 2126},
+	{0, 2, 2128},
+	{0, 2, 2130},
+	{0, 2, 2132},
+	{0, 2, 2134},
+	{0, 2, 2136},
+	{0, 2, 2138},
+	{0, 2, 2140},
+	{0, 2, 2142},
+	{0, 2, 2144},
+	{0, 2, 2146},
+	{0, 2, 2148},
+	{0, 2, 2150},
+	{0, 2, 2152},
+	{0, 2, 2154},
+	{0, 2, 2156},
+	{0, 2, 2158},
+	{0, 2, 2160},
+	{0, 2, 2162},
+	{0, 2, 2164},
+	{0, 2, 2166},
+	{0, 2, 2168},
+	{0, 2, 2170},
+	{0, 2, 2172},
+	{0, 2, 2174},
+	{0, 2, 2176},
+	{0, 2, 2178},
+	{0, 2, 2180},
+	{0, 2, 2182},
+	{0, 2, 2184},
+	{0, 2, 2186},
+	{0, 2, 2188},
+	{0, 2, 2190},
+	{0, 2, 2192},
+	{0, 2, 2194},
+	{0, 2, 2196},
+	{0, 2, 2198},
+	{0, 2, 2200},
+	{0, 2, 2202},
+	{0, 2, 2204},
+	{0, 2 | DECOMP_COMPAT, 2206},
+	{222, 0, 0},
+	{228, 0, 0},
+	{10, 0, 0},
+	{11, 0, 0},
+	{12, 0, 0},
+	{13, 0, 0},
+	{14, 0, 0},
+	{15, 0, 0},
+	{16, 0, 0},
+	{17, 0, 0},
+	{18, 0, 0},
+	{19, 0, 0},
+	{20, 0, 0},
+	{21, 0, 0},
+	{22, 0, 0},
+	{23, 0, 0},
+	{24, 0, 0},
+	{25, 0, 0},
+	{30, 0, 0},
+	{31, 0, 0},
+	{32, 0, 0},
+	{0, 2, 2208},
+	{0, 2, 2210},
+	{0, 2, 2212},
+	{0, 2, 2214},
+	{0, 2, 2216},
+	{27, 0, 0},
+	{28, 0, 0},
+	{29, 0, 0},
+	{33, 0, 0},
+	{34, 0, 0},
+	{35, 0, 0},
+	{0, 2 | DECOMP_COMPAT, 2218},
+	{0, 2 | DECOMP_COMPAT, 2220},
+	{0, 2 | DECOMP_COMPAT, 2222},
+	{0, 2 | DECOMP_COMPAT, 2224},
+	{0, 2, 2226},
+	{0, 2, 2228},
+	{0, 2, 2230},
+	{36, 0, 0},
+	{0, 2, 2232},
+	{0, 2, 2234},
+	{0, 2, 2236},
+	{7, 0, 0},
+	{9, 0, 0},
+	{0, 2 | DECOMP_NO_COMPOSE, 2238},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2240},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2242},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2244},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2246},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2248},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2250},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2252},	/* in exclusion list */
+	{0, 2, 2254},
+	{0, 2, 2256},
+	{0, 2 | DECOMP_NO_COMPOSE, 2258},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2260},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2262},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2264},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2266},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2268},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2270},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2272},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2274},	/* in exclusion list */
+	{0, 2, 2276},
+	{0, 2, 2278},
+	{0, 2, 2280},
+	{0, 2 | DECOMP_NO_COMPOSE, 2282},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2284},	/* in exclusion list */
+	{0, 2, 2286},
+	{0, 2, 2288},
+	{0, 2, 2290},
+	{0, 2, 2292},
+	{0, 2, 2294},
+	{84, 0, 0},
+	{91, 0, 0},
+	{0, 2, 2296},
+	{0, 2, 2298},
+	{0, 2, 2300},
+	{0, 2, 2302},
+	{0, 2, 2304},
+	{0, 2, 2306},
+	{0, 2, 2308},
+	{0, 2, 2310},
+	{0, 2, 2312},
+	{0, 2, 2314},
+	{0, 2, 2316},
+	{0, 2, 2318},
+	{0, 2 | DECOMP_COMPAT, 2320},
+	{103, 0, 0},
+	{107, 0, 0},
+	{0, 2 | DECOMP_COMPAT, 2322},
+	{118, 0, 0},
+	{122, 0, 0},
+	{0, 2 | DECOMP_COMPAT, 2324},
+	{0, 2 | DECOMP_COMPAT, 2326},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0F0B},
+	{0, 2 | DECOMP_NO_COMPOSE, 2328},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2330},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2332},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2334},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2336},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2338},	/* in exclusion list */
+	{129, 0, 0},
+	{130, 0, 0},
+	{0, 2 | DECOMP_NO_COMPOSE, 2340},	/* non-starter decomposition */
+	{132, 0, 0},
+	{0, 2 | DECOMP_NO_COMPOSE, 2342},	/* non-starter decomposition */
+	{0, 2 | DECOMP_NO_COMPOSE, 2344},	/* in exclusion list */
+	{0, 2 | DECOMP_COMPAT, 2346},
+	{0, 2 | DECOMP_NO_COMPOSE, 2348},	/* in exclusion list */
+	{0, 2 | DECOMP_COMPAT, 2350},
+	{0, 2 | DECOMP_NO_COMPOSE, 2352},	/* non-starter decomposition */
+	{0, 2 | DECOMP_NO_COMPOSE, 2354},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2356},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2358},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2360},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2362},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 2364},	/* in exclusion list */
+	{0, 2, 2366},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x10DC},
+	{0, 2, 2368},
+	{0, 2, 2370},
+	{0, 2, 2372},
+	{0, 2, 2374},
+	{0, 2, 2376},
+	{0, 2, 2378},
+	{0, 2, 2380},
+	{0, 2, 2382},
+	{0, 2, 2384},
+	{0, 2, 2386},
+	{0, 2, 2388},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00C6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x018E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0222},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0250},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0251},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D02},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0259},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x014B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0254},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D16},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D17},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D1D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D25},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0252},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0255},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00F0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0261},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0265},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0268},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0269},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D7B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D85},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0271},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0270},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0272},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0273},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0274},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0275},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0278},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0282},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0283},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01AB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0289},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D1C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0290},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0291},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0292},
+	{214, 0, 0},
+	{218, 0, 0},
+	{0, 2, 2390},
+	{0, 2, 2392},
+	{0, 2, 2394},
+	{0, 2, 2396},
+	{0, 2, 2398},
+	{0, 2, 2400},
+	{0, 2, 2402},
+	{0, 2, 2404},
+	{0, 2, 2406},
+	{0, 2, 2408},
+	{0, 2, 2410},
+	{0, 2, 2412},
+	{0, 2, 2414},
+	{0, 2, 2416},
+	{0, 2, 2418},
+	{0, 2, 2420},
+	{0, 2, 2422},
+	{0, 2, 2424},
+	{0, 2, 2426},
+	{0, 2, 2428},
+	{0, 2, 2430},
+	{0, 2, 2432},
+	{0, 2, 2434},
+	{0, 2, 2436},
+	{0, 2, 2438},
+	{0, 2, 2440},
+	{0, 2, 2442},
+	{0, 2, 2444},
+	{0, 2, 2446},
+	{0, 2, 2448},
+	{0, 2, 2450},
+	{0, 2, 2452},
+	{0, 2, 2454},
+	{0, 2, 2456},
+	{0, 2, 2458},
+	{0, 2, 2460},
+	{0, 2, 2462},
+	{0, 2, 2464},
+	{0, 2, 2466},
+	{0, 2, 2468},
+	{0, 2, 2470},
+	{0, 2, 2472},
+	{0, 2, 2474},
+	{0, 2, 2476},
+	{0, 2, 2478},
+	{0, 2, 2480},
+	{0, 2, 2482},
+	{0, 2, 2484},
+	{0, 2, 2486},
+	{0, 2, 2488},
+	{0, 2, 2490},
+	{0, 2, 2492},
+	{0, 2, 2494},
+	{0, 2, 2496},
+	{0, 2, 2498},
+	{0, 2, 2500},
+	{0, 2, 2502},
+	{0, 2, 2504},
+	{0, 2, 2506},
+	{0, 2, 2508},
+	{0, 2, 2510},
+	{0, 2, 2512},
+	{0, 2, 2514},
+	{0, 2, 2516},
+	{0, 2, 2518},
+	{0, 2, 2520},
+	{0, 2, 2522},
+	{0, 2, 2524},
+	{0, 2, 2526},
+	{0, 2, 2528},
+	{0, 2, 2530},
+	{0, 2, 2532},
+	{0, 2, 2534},
+	{0, 2, 2536},
+	{0, 2, 2538},
+	{0, 2, 2540},
+	{0, 2, 2542},
+	{0, 2, 2544},
+	{0, 2, 2546},
+	{0, 2, 2548},
+	{0, 2, 2550},
+	{0, 2, 2552},
+	{0, 2, 2554},
+	{0, 2, 2556},
+	{0, 2, 2558},
+	{0, 2, 2560},
+	{0, 2, 2562},
+	{0, 2, 2564},
+	{0, 2, 2566},
+	{0, 2, 2568},
+	{0, 2, 2570},
+	{0, 2, 2572},
+	{0, 2, 2574},
+	{0, 2, 2576},
+	{0, 2, 2578},
+	{0, 2, 2580},
+	{0, 2, 2582},
+	{0, 2, 2584},
+	{0, 2, 2586},
+	{0, 2, 2588},
+	{0, 2, 2590},
+	{0, 2, 2592},
+	{0, 2, 2594},
+	{0, 2, 2596},
+	{0, 2, 2598},
+	{0, 2, 2600},
+	{0, 2, 2602},
+	{0, 2, 2604},
+	{0, 2, 2606},
+	{0, 2, 2608},
+	{0, 2, 2610},
+	{0, 2, 2612},
+	{0, 2, 2614},
+	{0, 2, 2616},
+	{0, 2, 2618},
+	{0, 2, 2620},
+	{0, 2, 2622},
+	{0, 2, 2624},
+	{0, 2, 2626},
+	{0, 2, 2628},
+	{0, 2, 2630},
+	{0, 2, 2632},
+	{0, 2, 2634},
+	{0, 2, 2636},
+	{0, 2, 2638},
+	{0, 2, 2640},
+	{0, 2, 2642},
+	{0, 2, 2644},
+	{0, 2, 2646},
+	{0, 2, 2648},
+	{0, 2, 2650},
+	{0, 2, 2652},
+	{0, 2, 2654},
+	{0, 2, 2656},
+	{0, 2, 2658},
+	{0, 2, 2660},
+	{0, 2, 2662},
+	{0, 2, 2664},
+	{0, 2, 2666},
+	{0, 2, 2668},
+	{0, 2, 2670},
+	{0, 2, 2672},
+	{0, 2, 2674},
+	{0, 2, 2676},
+	{0, 2, 2678},
+	{0, 2, 2680},
+	{0, 2, 2682},
+	{0, 2, 2684},
+	{0, 2, 2686},
+	{0, 2, 2688},
+	{0, 2, 2690},
+	{0, 2, 2692},
+	{0, 2, 2694},
+	{0, 2, 2696},
+	{0, 2 | DECOMP_COMPAT, 2698},
+	{0, 2, 2700},
+	{0, 2, 2702},
+	{0, 2, 2704},
+	{0, 2, 2706},
+	{0, 2, 2708},
+	{0, 2, 2710},
+	{0, 2, 2712},
+	{0, 2, 2714},
+	{0, 2, 2716},
+	{0, 2, 2718},
+	{0, 2, 2720},
+	{0, 2, 2722},
+	{0, 2, 2724},
+	{0, 2, 2726},
+	{0, 2, 2728},
+	{0, 2, 2730},
+	{0, 2, 2732},
+	{0, 2, 2734},
+	{0, 2, 2736},
+	{0, 2, 2738},
+	{0, 2, 2740},
+	{0, 2, 2742},
+	{0, 2, 2744},
+	{0, 2, 2746},
+	{0, 2, 2748},
+	{0, 2, 2750},
+	{0, 2, 2752},
+	{0, 2, 2754},
+	{0, 2, 2756},
+	{0, 2, 2758},
+	{0, 2, 2760},
+	{0, 2, 2762},
+	{0, 2, 2764},
+	{0, 2, 2766},
+	{0, 2, 2768},
+	{0, 2, 2770},
+	{0, 2, 2772},
+	{0, 2, 2774},
+	{0, 2, 2776},
+	{0, 2, 2778},
+	{0, 2, 2780},
+	{0, 2, 2782},
+	{0, 2, 2784},
+	{0, 2, 2786},
+	{0, 2, 2788},
+	{0, 2, 2790},
+	{0, 2, 2792},
+	{0, 2, 2794},
+	{0, 2, 2796},
+	{0, 2, 2798},
+	{0, 2, 2800},
+	{0, 2, 2802},
+	{0, 2, 2804},
+	{0, 2, 2806},
+	{0, 2, 2808},
+	{0, 2, 2810},
+	{0, 2, 2812},
+	{0, 2, 2814},
+	{0, 2, 2816},
+	{0, 2, 2818},
+	{0, 2, 2820},
+	{0, 2, 2822},
+	{0, 2, 2824},
+	{0, 2, 2826},
+	{0, 2, 2828},
+	{0, 2, 2830},
+	{0, 2, 2832},
+	{0, 2, 2834},
+	{0, 2, 2836},
+	{0, 2, 2838},
+	{0, 2, 2840},
+	{0, 2, 2842},
+	{0, 2, 2844},
+	{0, 2, 2846},
+	{0, 2, 2848},
+	{0, 2, 2850},
+	{0, 2, 2852},
+	{0, 2, 2854},
+	{0, 2, 2856},
+	{0, 2, 2858},
+	{0, 2, 2860},
+	{0, 2, 2862},
+	{0, 2, 2864},
+	{0, 2, 2866},
+	{0, 2, 2868},
+	{0, 2, 2870},
+	{0, 2, 2872},
+	{0, 2, 2874},
+	{0, 2, 2876},
+	{0, 2, 2878},
+	{0, 2, 2880},
+	{0, 2, 2882},
+	{0, 2, 2884},
+	{0, 2, 2886},
+	{0, 2, 2888},
+	{0, 2, 2890},
+	{0, 2, 2892},
+	{0, 2, 2894},
+	{0, 2, 2896},
+	{0, 2, 2898},
+	{0, 2, 2900},
+	{0, 2, 2902},
+	{0, 2, 2904},
+	{0, 2, 2906},
+	{0, 2, 2908},
+	{0, 2, 2910},
+	{0, 2, 2912},
+	{0, 2, 2914},
+	{0, 2, 2916},
+	{0, 2, 2918},
+	{0, 2, 2920},
+	{0, 2, 2922},
+	{0, 2, 2924},
+	{0, 2, 2926},
+	{0, 2, 2928},
+	{0, 2, 2930},
+	{0, 2, 2932},
+	{0, 2, 2934},
+	{0, 2, 2936},
+	{0, 2, 2938},
+	{0, 2, 2940},
+	{0, 2, 2942},
+	{0, 2, 2944},
+	{0, 2, 2946},
+	{0, 2, 2948},
+	{0, 2, 2950},
+	{0, 2, 2952},
+	{0, 2, 2954},
+	{0, 2, 2956},
+	{0, 2, 2958},
+	{0, 2, 2960},
+	{0, 2, 2962},
+	{0, 2, 2964},
+	{0, 2, 2966},
+	{0, 2, 2968},
+	{0, 2, 2970},
+	{0, 2, 2972},
+	{0, 2, 2974},
+	{0, 2, 2976},
+	{0, 2, 2978},
+	{0, 2, 2980},
+	{0, 2, 2982},
+	{0, 2, 2984},
+	{0, 2, 2986},
+	{0, 2, 2988},
+	{0, 2, 2990},
+	{0, 2, 2992},
+	{0, 2, 2994},
+	{0, 2, 2996},
+	{0, 2, 2998},
+	{0, 2, 3000},
+	{0, 2, 3002},
+	{0, 2, 3004},
+	{0, 2, 3006},
+	{0, 2, 3008},
+	{0, 2, 3010},
+	{0, 2, 3012},
+	{0, 2, 3014},
+	{0, 2, 3016},
+	{0, 2, 3018},
+	{0, 2, 3020},
+	{0, 2, 3022},
+	{0, 2, 3024},
+	{0, 2, 3026},
+	{0, 2, 3028},
+	{0, 2, 3030},
+	{0, 2, 3032},
+	{0, 2, 3034},
+	{0, 2, 3036},
+	{0, 2, 3038},
+	{0, 2, 3040},
+	{0, 2, 3042},
+	{0, 2, 3044},
+	{0, 2, 3046},
+	{0, 2, 3048},
+	{0, 2, 3050},
+	{0, 2, 3052},
+	{0, 2, 3054},
+	{0, 2, 3056},
+	{0, 2, 3058},
+	{0, 2, 3060},
+	{0, 2, 3062},
+	{0, 2, 3064},
+	{0, 2, 3066},
+	{0, 2, 3068},
+	{0, 2, 3070},
+	{0, 2, 3072},
+	{0, 2, 3074},
+	{0, 2, 3076},
+	{0, 2, 3078},
+	{0, 2, 3080},
+	{0, 2, 3082},
+	{0, 1 | DECOMP_INLINE, 0x03AC},
+	{0, 2, 3084},
+	{0, 1 | DECOMP_INLINE, 0x03AD},
+	{0, 2, 3086},
+	{0, 1 | DECOMP_INLINE, 0x03AE},
+	{0, 2, 3088},
+	{0, 1 | DECOMP_INLINE, 0x03AF},
+	{0, 2, 3090},
+	{0, 1 | DECOMP_INLINE, 0x03CC},
+	{0, 2, 3092},
+	{0, 1 | DECOMP_INLINE, 0x03CD},
+	{0, 2, 3094},
+	{0, 1 | DECOMP_INLINE, 0x03CE},
+	{0, 2, 3096},
+	{0, 2, 3098},
+	{0, 2, 3100},
+	{0, 2, 3102},
+	{0, 2, 3104},
+	{0, 2, 3106},
+	{0, 2, 3108},
+	{0, 2, 3110},
+	{0, 2, 3112},
+	{0, 2, 3114},
+	{0, 2, 3116},
+	{0, 2, 3118},
+	{0, 2, 3120},
+	{0, 2, 3122},
+	{0, 2, 3124},
+	{0, 2, 3126},
+	{0, 2, 3128},
+	{0, 2, 3130},
+	{0, 2, 3132},
+	{0, 2, 3134},
+	{0, 2, 3136},
+	{0, 2, 3138},
+	{0, 2, 3140},
+	{0, 2, 3142},
+	{0, 2, 3144},
+	{0, 2, 3146},
+	{0, 2, 3148},
+	{0, 2, 3150},
+	{0, 2, 3152},
+	{0, 2, 3154},
+	{0, 2, 3156},
+	{0, 2, 3158},
+	{0, 2, 3160},
+	{0, 2, 3162},
+	{0, 2, 3164},
+	{0, 2, 3166},
+	{0, 2, 3168},
+	{0, 2, 3170},
+	{0, 2, 3172},
+	{0, 2, 3174},
+	{0, 2, 3176},
+	{0, 2, 3178},
+	{0, 2, 3180},
+	{0, 2, 3182},
+	{0, 2, 3184},
+	{0, 2, 3186},
+	{0, 2, 3188},
+	{0, 2, 3190},
+	{0, 2, 3192},
+	{0, 2, 3194},
+	{0, 2, 3196},
+	{0, 2, 3198},
+	{0, 2, 3200},
+	{0, 2, 3202},
+	{0, 2, 3204},
+	{0, 2, 3206},
+	{0, 2, 3208},
+	{0, 2, 3210},
+	{0, 1 | DECOMP_INLINE, 0x0386},
+	{0, 2, 3212},
+	{0, 2 | DECOMP_COMPAT, 3214},
+	{0, 1 | DECOMP_INLINE, 0x03B9},
+	{0, 2 | DECOMP_COMPAT, 3216},
+	{0, 2, 3218},
+	{0, 2, 3220},
+	{0, 2, 3222},
+	{0, 2, 3224},
+	{0, 2, 3226},
+	{0, 2, 3228},
+	{0, 2, 3230},
+	{0, 1 | DECOMP_INLINE, 0x0388},
+	{0, 2, 3232},
+	{0, 1 | DECOMP_INLINE, 0x0389},
+	{0, 2, 3234},
+	{0, 2, 3236},
+	{0, 2, 3238},
+	{0, 2, 3240},
+	{0, 2, 3242},
+	{0, 2, 3244},
+	{0, 2, 3246},
+	{0, 1 | DECOMP_INLINE, 0x0390},
+	{0, 2, 3248},
+	{0, 2, 3250},
+	{0, 2, 3252},
+	{0, 2, 3254},
+	{0, 2, 3256},
+	{0, 1 | DECOMP_INLINE, 0x038A},
+	{0, 2, 3258},
+	{0, 2, 3260},
+	{0, 2, 3262},
+	{0, 2, 3264},
+	{0, 2, 3266},
+	{0, 2, 3268},
+	{0, 1 | DECOMP_INLINE, 0x03B0},
+	{0, 2, 3270},
+	{0, 2, 3272},
+	{0, 2, 3274},
+	{0, 2, 3276},
+	{0, 2, 3278},
+	{0, 2, 3280},
+	{0, 2, 3282},
+	{0, 1 | DECOMP_INLINE, 0x038E},
+	{0, 2, 3284},
+	{0, 2, 3286},
+	{0, 1 | DECOMP_INLINE, 0x0385},
+	{0, 1 | DECOMP_INLINE, 0x0060},
+	{0, 2, 3288},
+	{0, 2, 3290},
+	{0, 2, 3292},
+	{0, 2, 3294},
+	{0, 2, 3296},
+	{0, 2, 3298},
+	{0, 1 | DECOMP_INLINE, 0x038C},
+	{0, 2, 3300},
+	{0, 1 | DECOMP_INLINE, 0x038F},
+	{0, 2, 3302},
+	{0, 1 | DECOMP_INLINE, 0x00B4},
+	{0, 2 | DECOMP_COMPAT, 3304},
+	{0, 1 | DECOMP_INLINE, 0x2002},
+	{0, 1 | DECOMP_INLINE, 0x2003},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2010},
+	{0, 2 | DECOMP_COMPAT, 3306},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002E},
+	{0, 2 | DECOMP_COMPAT, 387},
+	{0, 3 | DECOMP_COMPAT, 387},
+	{0, 2 | DECOMP_COMPAT, 126},
+	{0, 3 | DECOMP_COMPAT, 126},
+	{0, 2 | DECOMP_COMPAT, 390},
+	{0, 3 | DECOMP_COMPAT, 390},
+	{0, 2 | DECOMP_COMPAT, 3308},
+	{0, 2 | DECOMP_COMPAT, 3310},
+	{0, 2 | DECOMP_COMPAT, 3312},
+	{0, 2 | DECOMP_COMPAT, 3314},
+	{0, 2 | DECOMP_COMPAT, 3316},
+	{0, 4 | DECOMP_COMPAT, 126},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2212},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0, 2 | DECOMP_COMPAT, 3318},
+	{0, 3 | DECOMP_COMPAT, 393},
+	{0, 3 | DECOMP_COMPAT, 396},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0, 2 | DECOMP_COMPAT, 3320},
+	{0, 3 | DECOMP_COMPAT, 399},
+	{0, 3 | DECOMP_COMPAT, 402},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0190},
+	{0, 2 | DECOMP_COMPAT, 3322},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0127},
+	{0, 2 | DECOMP_COMPAT, 3324},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0, 2 | DECOMP_COMPAT, 3326},
+	{0, 3 | DECOMP_COMPAT, 405},
+	{0, 2 | DECOMP_COMPAT, 3328},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0, 1 | DECOMP_INLINE, 0x03A9},
+	{0, 1 | DECOMP_INLINE, 0x004B},
+	{0, 1 | DECOMP_INLINE, 0x00C5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D3},
+	{0, 3 | DECOMP_COMPAT, 408},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2211},
+	{0, 3 | DECOMP_COMPAT, 411},
+	{0, 3 | DECOMP_COMPAT, 414},
+	{0, 4 | DECOMP_COMPAT, 130},
+	{0, 3 | DECOMP_COMPAT, 417},
+	{0, 3 | DECOMP_COMPAT, 420},
+	{0, 3 | DECOMP_COMPAT, 423},
+	{0, 3 | DECOMP_COMPAT, 426},
+	{0, 3 | DECOMP_COMPAT, 429},
+	{0, 3 | DECOMP_COMPAT, 432},
+	{0, 3 | DECOMP_COMPAT, 435},
+	{0, 3 | DECOMP_COMPAT, 438},
+	{0, 3 | DECOMP_COMPAT, 441},
+	{0, 3 | DECOMP_COMPAT, 444},
+	{0, 3 | DECOMP_COMPAT, 447},
+	{0, 3 | DECOMP_COMPAT, 450},
+	{0, 2 | DECOMP_COMPAT, 130},
+	{0, 2 | DECOMP_COMPAT, 135},
+	{0, 3 | DECOMP_COMPAT, 135},
+	{0, 2 | DECOMP_COMPAT, 3330},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0, 2 | DECOMP_COMPAT, 134},
+	{0, 3 | DECOMP_COMPAT, 134},
+	{0, 4 | DECOMP_COMPAT, 134},
+	{0, 2 | DECOMP_COMPAT, 3332},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0, 2 | DECOMP_COMPAT, 453},
+	{0, 3 | DECOMP_COMPAT, 453},
+	{0, 2 | DECOMP_COMPAT, 139},
+	{0, 3 | DECOMP_COMPAT, 139},
+	{0, 2 | DECOMP_COMPAT, 3334},
+	{0, 2 | DECOMP_COMPAT, 138},
+	{0, 3 | DECOMP_COMPAT, 138},
+	{0, 4 | DECOMP_COMPAT, 138},
+	{0, 2 | DECOMP_COMPAT, 3336},
+	{0, 2 | DECOMP_COMPAT, 456},
+	{0, 3 | DECOMP_COMPAT, 456},
+	{0, 3 | DECOMP_COMPAT, 459},
+	{0, 2, 3338},
+	{0, 2, 3340},
+	{0, 2, 3342},
+	{0, 2, 3344},
+	{0, 2, 3346},
+	{0, 2, 3348},
+	{0, 2, 3350},
+	{0, 2, 3352},
+	{0, 2, 3354},
+	{0, 2, 3356},
+	{0, 2, 3358},
+	{0, 2 | DECOMP_COMPAT, 186},
+	{0, 3 | DECOMP_COMPAT, 186},
+	{0, 2 | DECOMP_COMPAT, 462},
+	{0, 3 | DECOMP_COMPAT, 462},
+	{0, 2, 3360},
+	{0, 2, 3362},
+	{0, 2, 3364},
+	{0, 2, 3366},
+	{0, 2, 3368},
+	{0, 2, 3370},
+	{0, 2, 3372},
+	{0, 2, 3374},
+	{0, 2, 3376},
+	{0, 2, 3378},
+	{0, 2, 3380},
+	{0, 2, 3382},
+	{0, 2, 3384},
+	{0, 2, 3386},
+	{0, 2, 3388},
+	{0, 2, 3390},
+	{0, 2, 3392},
+	{0, 2, 3394},
+	{0, 2, 3396},
+	{0, 2, 3398},
+	{0, 2, 3400},
+	{0, 2, 3402},
+	{0, 2, 3404},
+	{0, 2, 3406},
+	{0, 2, 3408},
+	{0, 2, 3410},
+	{0, 2, 3412},
+	{0, 2, 3414},
+	{0, 2, 3416},
+	{0, 2, 3418},
+	{0, 2, 3420},
+	{0, 2, 3422},
+	{0, 2, 3424},
+	{0, 1 | DECOMP_INLINE, 0x3008},
+	{0, 1 | DECOMP_INLINE, 0x3009},
+	{0, 2 | DECOMP_COMPAT, 132},
+	{0, 2 | DECOMP_COMPAT, 147},
+	{0, 2 | DECOMP_COMPAT, 151},
+	{0, 2 | DECOMP_COMPAT, 155},
+	{0, 2 | DECOMP_COMPAT, 159},
+	{0, 2 | DECOMP_COMPAT, 163},
+	{0, 2 | DECOMP_COMPAT, 167},
+	{0, 2 | DECOMP_COMPAT, 171},
+	{0, 2 | DECOMP_COMPAT, 175},
+	{0, 2 | DECOMP_COMPAT, 179},
+	{0, 2 | DECOMP_COMPAT, 183},
+	{0, 3 | DECOMP_COMPAT, 465},
+	{0, 3 | DECOMP_COMPAT, 468},
+	{0, 3 | DECOMP_COMPAT, 471},
+	{0, 3 | DECOMP_COMPAT, 474},
+	{0, 3 | DECOMP_COMPAT, 477},
+	{0, 3 | DECOMP_COMPAT, 480},
+	{0, 3 | DECOMP_COMPAT, 483},
+	{0, 3 | DECOMP_COMPAT, 486},
+	{0, 3 | DECOMP_COMPAT, 489},
+	{0, 4 | DECOMP_COMPAT, 142},
+	{0, 4 | DECOMP_COMPAT, 146},
+	{0, 4 | DECOMP_COMPAT, 150},
+	{0, 4 | DECOMP_COMPAT, 154},
+	{0, 4 | DECOMP_COMPAT, 158},
+	{0, 4 | DECOMP_COMPAT, 162},
+	{0, 4 | DECOMP_COMPAT, 166},
+	{0, 4 | DECOMP_COMPAT, 170},
+	{0, 4 | DECOMP_COMPAT, 174},
+	{0, 4 | DECOMP_COMPAT, 178},
+	{0, 4 | DECOMP_COMPAT, 182},
+	{0, 2 | DECOMP_COMPAT, 496},
+	{0, 2 | DECOMP_COMPAT, 499},
+	{0, 2 | DECOMP_COMPAT, 502},
+	{0, 2 | DECOMP_COMPAT, 386},
+	{0, 2 | DECOMP_COMPAT, 508},
+	{0, 2 | DECOMP_COMPAT, 511},
+	{0, 2 | DECOMP_COMPAT, 514},
+	{0, 2 | DECOMP_COMPAT, 517},
+	{0, 2 | DECOMP_COMPAT, 520},
+	{0, 3 | DECOMP_COMPAT, 492},
+	{0, 3 | DECOMP_COMPAT, 495},
+	{0, 3 | DECOMP_COMPAT, 498},
+	{0, 3 | DECOMP_COMPAT, 501},
+	{0, 3 | DECOMP_COMPAT, 504},
+	{0, 3 | DECOMP_COMPAT, 507},
+	{0, 3 | DECOMP_COMPAT, 510},
+	{0, 3 | DECOMP_COMPAT, 513},
+	{0, 3 | DECOMP_COMPAT, 516},
+	{0, 3 | DECOMP_COMPAT, 519},
+	{0, 3 | DECOMP_COMPAT, 522},
+	{0, 3 | DECOMP_COMPAT, 525},
+	{0, 3 | DECOMP_COMPAT, 528},
+	{0, 3 | DECOMP_COMPAT, 531},
+	{0, 3 | DECOMP_COMPAT, 534},
+	{0, 3 | DECOMP_COMPAT, 537},
+	{0, 3 | DECOMP_COMPAT, 540},
+	{0, 3 | DECOMP_COMPAT, 543},
+	{0, 3 | DECOMP_COMPAT, 546},
+	{0, 3 | DECOMP_COMPAT, 549},
+	{0, 3 | DECOMP_COMPAT, 552},
+	{0, 3 | DECOMP_COMPAT, 555},
+	{0, 3 | DECOMP_COMPAT, 558},
+	{0, 3 | DECOMP_COMPAT, 561},
+	{0, 3 | DECOMP_COMPAT, 564},
+	{0, 3 | DECOMP_COMPAT, 567},
+	{0, 3 | DECOMP_COMPAT, 570},
+	{0, 3 | DECOMP_COMPAT, 573},
+	{0, 3 | DECOMP_COMPAT, 576},
+	{0, 3 | DECOMP_COMPAT, 579},
+	{0, 3 | DECOMP_COMPAT, 582},
+	{0, 3 | DECOMP_COMPAT, 585},
+	{0, 3 | DECOMP_COMPAT, 588},
+	{0, 3 | DECOMP_COMPAT, 591},
+	{0, 3 | DECOMP_COMPAT, 594},
+	{0, 3 | DECOMP_COMPAT, 597},
+	{0, 3 | DECOMP_COMPAT, 600},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0, 4 | DECOMP_COMPAT, 186},
+	{0, 3 | DECOMP_COMPAT, 603},
+	{0, 2 | DECOMP_COMPAT, 605},
+	{0, 3 | DECOMP_COMPAT, 606},
+	{0, 2 | DECOMP_NO_COMPOSE, 3426},	/* in exclusion list */
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2D61},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BCD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F9F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E28},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E36},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E3F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E59},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E85},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EA0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EBA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x513F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5165},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x516B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5182},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5196},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51AB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51E0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51F5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5200},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x529B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x52F9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5315},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x531A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5338},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5341},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x535C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5369},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5382},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53B6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53C8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53E3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x56D7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x571F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x58EB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5902},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x590A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5915},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5927},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5973},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B50},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B80},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5BF8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C0F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C22},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C38},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C6E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C71},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DDB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DE5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DF1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DFE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E72},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5EF4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5EFE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F0B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F13},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F50},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F61},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F73},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5FC3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6208},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6236},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x624B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x652F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6534},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6587},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6597},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65A4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65B9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65E0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65E5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x66F0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6708},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6728},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B20},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B62},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B79},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BB3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BCB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BD4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BDB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C0F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C14},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C34},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x706B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x722A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7236},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x723B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x723F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7247},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7259},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x725B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x72AC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7384},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7389},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x74DC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x74E6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7518},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x751F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7528},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7530},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x758B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7592},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7676},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x767D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76AE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76BF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76EE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77DB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77E2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77F3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x793A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79B8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79BE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7A74},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7ACB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7AF9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7C73},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7CF8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F36},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F51},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F8A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7FBD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8001},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x800C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8012},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8033},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x807F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8089},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81E3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81EA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81F3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81FC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x820C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x821B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x821F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x826E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8272},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8278},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x864D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x866B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8840},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x884C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8863},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x897E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x898B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x89D2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8A00},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C37},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C46},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C55},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C78},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C9D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8D64},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8D70},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8DB3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8EAB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8ECA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8F9B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8FB0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8FB5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9091},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9149},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91C6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91CC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91D1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9577},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9580},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x961C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96B6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96B9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96E8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9751},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x975E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9762},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9769},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97CB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97ED},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97F3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9801},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98A8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98DB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98DF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9996},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9999},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x99AC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9AA8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9AD8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ADF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B25},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B2F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B32},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B3C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B5A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9CE5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9E75},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9E7F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EA5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EBB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EC3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ECD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ED1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EF9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EFD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F0E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F13},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F20},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F3B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F4A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F52},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F8D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F9C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9FA0},
+	{224, 0, 0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3012},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5344},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5345},
+	{0, 2, 3428},
+	{0, 2, 3430},
+	{0, 2, 3432},
+	{0, 2, 3434},
+	{0, 2, 3436},
+	{0, 2, 3438},
+	{0, 2, 3440},
+	{0, 2, 3442},
+	{0, 2, 3444},
+	{0, 2, 3446},
+	{0, 2, 3448},
+	{0, 2, 3450},
+	{0, 2, 3452},
+	{0, 2, 3454},
+	{0, 2, 3456},
+	{0, 2, 3458},
+	{0, 2, 3460},
+	{0, 2, 3462},
+	{0, 2, 3464},
+	{0, 2, 3466},
+	{0, 2, 3468},
+	{0, 2, 3470},
+	{0, 2, 3472},
+	{0, 2, 3474},
+	{0, 2, 3476},
+	{0, 2, 3478},
+	{8, 0, 0},
+	{0, 2 | DECOMP_COMPAT, 3480},
+	{0, 2 | DECOMP_COMPAT, 3482},
+	{0, 2, 3484},
+	{0, 2 | DECOMP_COMPAT, 3486},
+	{0, 2, 3488},
+	{0, 2, 3490},
+	{0, 2, 3492},
+	{0, 2, 3494},
+	{0, 2, 3496},
+	{0, 2, 3498},
+	{0, 2, 3500},
+	{0, 2, 3502},
+	{0, 2, 3504},
+	{0, 2, 3506},
+	{0, 2, 3508},
+	{0, 2, 3510},
+	{0, 2, 3512},
+	{0, 2, 3514},
+	{0, 2, 3516},
+	{0, 2, 3518},
+	{0, 2, 3520},
+	{0, 2, 3522},
+	{0, 2, 3524},
+	{0, 2, 3526},
+	{0, 2, 3528},
+	{0, 2, 3530},
+	{0, 2, 3532},
+	{0, 2, 3534},
+	{0, 2, 3536},
+	{0, 2, 3538},
+	{0, 2, 3540},
+	{0, 2, 3542},
+	{0, 2, 3544},
+	{0, 2, 3546},
+	{0, 2, 3548},
+	{0, 2 | DECOMP_COMPAT, 3550},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1100},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1101},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1102},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1103},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1104},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1105},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1106},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1107},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1108},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1121},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1109},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1110},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1111},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1112},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1161},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1162},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1163},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1164},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1165},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1166},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1167},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1168},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1169},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1170},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1171},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1172},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1173},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1174},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1175},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1160},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1114},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1115},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11C7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11C8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11CC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11CE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11DD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11DF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1120},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1122},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1123},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1127},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1129},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1132},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1136},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1140},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1147},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x114C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11F1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11F2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1157},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1158},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1159},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1184},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1185},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1188},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1191},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1192},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1194},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x119E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11A1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E09},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x56DB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E2D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7532},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E19},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E01},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5929},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5730},
+	{0, 3 | DECOMP_COMPAT, 609},
+	{0, 3 | DECOMP_COMPAT, 612},
+	{0, 3 | DECOMP_COMPAT, 615},
+	{0, 3 | DECOMP_COMPAT, 618},
+	{0, 3 | DECOMP_COMPAT, 621},
+	{0, 3 | DECOMP_COMPAT, 624},
+	{0, 3 | DECOMP_COMPAT, 627},
+	{0, 3 | DECOMP_COMPAT, 630},
+	{0, 3 | DECOMP_COMPAT, 633},
+	{0, 3 | DECOMP_COMPAT, 636},
+	{0, 3 | DECOMP_COMPAT, 639},
+	{0, 3 | DECOMP_COMPAT, 642},
+	{0, 3 | DECOMP_COMPAT, 645},
+	{0, 3 | DECOMP_COMPAT, 648},
+	{0, 4 | DECOMP_COMPAT, 190},
+	{0, 4 | DECOMP_COMPAT, 194},
+	{0, 4 | DECOMP_COMPAT, 198},
+	{0, 4 | DECOMP_COMPAT, 202},
+	{0, 4 | DECOMP_COMPAT, 206},
+	{0, 4 | DECOMP_COMPAT, 210},
+	{0, 4 | DECOMP_COMPAT, 214},
+	{0, 4 | DECOMP_COMPAT, 218},
+	{0, 4 | DECOMP_COMPAT, 222},
+	{0, 4 | DECOMP_COMPAT, 226},
+	{0, 4 | DECOMP_COMPAT, 230},
+	{0, 4 | DECOMP_COMPAT, 234},
+	{0, 4 | DECOMP_COMPAT, 238},
+	{0, 4 | DECOMP_COMPAT, 242},
+	{0, 4 | DECOMP_COMPAT, 246},
+	{0, 7 | DECOMP_COMPAT, 26},
+	{0, 6 | DECOMP_COMPAT, 33},
+	{0, 3 | DECOMP_COMPAT, 651},
+	{0, 3 | DECOMP_COMPAT, 654},
+	{0, 3 | DECOMP_COMPAT, 657},
+	{0, 3 | DECOMP_COMPAT, 660},
+	{0, 3 | DECOMP_COMPAT, 663},
+	{0, 3 | DECOMP_COMPAT, 666},
+	{0, 3 | DECOMP_COMPAT, 669},
+	{0, 3 | DECOMP_COMPAT, 672},
+	{0, 3 | DECOMP_COMPAT, 675},
+	{0, 3 | DECOMP_COMPAT, 678},
+	{0, 3 | DECOMP_COMPAT, 681},
+	{0, 3 | DECOMP_COMPAT, 684},
+	{0, 3 | DECOMP_COMPAT, 687},
+	{0, 3 | DECOMP_COMPAT, 690},
+	{0, 3 | DECOMP_COMPAT, 693},
+	{0, 3 | DECOMP_COMPAT, 696},
+	{0, 3 | DECOMP_COMPAT, 699},
+	{0, 3 | DECOMP_COMPAT, 702},
+	{0, 3 | DECOMP_COMPAT, 705},
+	{0, 3 | DECOMP_COMPAT, 708},
+	{0, 3 | DECOMP_COMPAT, 711},
+	{0, 3 | DECOMP_COMPAT, 714},
+	{0, 3 | DECOMP_COMPAT, 717},
+	{0, 3 | DECOMP_COMPAT, 720},
+	{0, 3 | DECOMP_COMPAT, 723},
+	{0, 3 | DECOMP_COMPAT, 726},
+	{0, 3 | DECOMP_COMPAT, 729},
+	{0, 3 | DECOMP_COMPAT, 732},
+	{0, 3 | DECOMP_COMPAT, 735},
+	{0, 3 | DECOMP_COMPAT, 738},
+	{0, 3 | DECOMP_COMPAT, 741},
+	{0, 3 | DECOMP_COMPAT, 744},
+	{0, 3 | DECOMP_COMPAT, 747},
+	{0, 3 | DECOMP_COMPAT, 750},
+	{0, 3 | DECOMP_COMPAT, 753},
+	{0, 3 | DECOMP_COMPAT, 756},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x554F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7B8F},
+	{0, 3 | DECOMP_COMPAT, 759},
+	{0, 2 | DECOMP_COMPAT, 915},
+	{0, 2 | DECOMP_COMPAT, 918},
+	{0, 2 | DECOMP_COMPAT, 383},
+	{0, 2 | DECOMP_COMPAT, 924},
+	{0, 2 | DECOMP_COMPAT, 1044},
+	{0, 2 | DECOMP_COMPAT, 1047},
+	{0, 2 | DECOMP_COMPAT, 1050},
+	{0, 2 | DECOMP_COMPAT, 1053},
+	{0, 2 | DECOMP_COMPAT, 1056},
+	{0, 2 | DECOMP_COMPAT, 1059},
+	{0, 2 | DECOMP_COMPAT, 422},
+	{0, 2 | DECOMP_COMPAT, 419},
+	{0, 2 | DECOMP_COMPAT, 3552},
+	{0, 2 | DECOMP_COMPAT, 3554},
+	{0, 2 | DECOMP_COMPAT, 3556},
+	{0, 2 | DECOMP_COMPAT, 191},
+	{0, 2 | DECOMP_COMPAT, 195},
+	{0, 2 | DECOMP_COMPAT, 199},
+	{0, 2 | DECOMP_COMPAT, 203},
+	{0, 2 | DECOMP_COMPAT, 207},
+	{0, 2 | DECOMP_COMPAT, 211},
+	{0, 2 | DECOMP_COMPAT, 215},
+	{0, 2 | DECOMP_COMPAT, 219},
+	{0, 2 | DECOMP_COMPAT, 223},
+	{0, 2 | DECOMP_COMPAT, 51},
+	{0, 2 | DECOMP_COMPAT, 231},
+	{0, 2 | DECOMP_COMPAT, 235},
+	{0, 2 | DECOMP_COMPAT, 239},
+	{0, 2 | DECOMP_COMPAT, 243},
+	{0, 5 | DECOMP_COMPAT, 51},
+	{0, 4 | DECOMP_COMPAT, 250},
+	{0, 2 | DECOMP_COMPAT, 3558},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E94},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x516D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E03},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E5D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x682A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6709},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x793E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x540D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7279},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CA1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x795D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x52B4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79D8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7537},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9069},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x512A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5370},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6CE8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9805},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4F11},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5199},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B63},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DE6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53F3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x533B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B97},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B66},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76E3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4F01},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CC7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5354},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x591C},
+	{0, 2 | DECOMP_COMPAT, 3560},
+	{0, 2 | DECOMP_COMPAT, 3562},
+	{0, 2 | DECOMP_COMPAT, 3564},
+	{0, 2 | DECOMP_COMPAT, 3566},
+	{0, 2 | DECOMP_COMPAT, 3568},
+	{0, 2 | DECOMP_COMPAT, 380},
+	{0, 2 | DECOMP_COMPAT, 3570},
+	{0, 2 | DECOMP_COMPAT, 3555},
+	{0, 2 | DECOMP_COMPAT, 3572},
+	{0, 2 | DECOMP_COMPAT, 3574},
+	{0, 2 | DECOMP_COMPAT, 3576},
+	{0, 2 | DECOMP_COMPAT, 3578},
+	{0, 2 | DECOMP_COMPAT, 3580},
+	{0, 2 | DECOMP_COMPAT, 3582},
+	{0, 2 | DECOMP_COMPAT, 3584},
+	{0, 2 | DECOMP_COMPAT, 766},
+	{0, 2 | DECOMP_COMPAT, 769},
+	{0, 2 | DECOMP_COMPAT, 3586},
+	{0, 2 | DECOMP_COMPAT, 3588},
+	{0, 2 | DECOMP_COMPAT, 3590},
+	{0, 2 | DECOMP_COMPAT, 3592},
+	{0, 2 | DECOMP_COMPAT, 3594},
+	{0, 2 | DECOMP_COMPAT, 3596},
+	{0, 2 | DECOMP_COMPAT, 3598},
+	{0, 3 | DECOMP_COMPAT, 762},
+	{0, 3 | DECOMP_COMPAT, 765},
+	{0, 3 | DECOMP_COMPAT, 768},
+	{0, 2 | DECOMP_COMPAT, 3600},
+	{0, 3 | DECOMP_COMPAT, 771},
+	{0, 2 | DECOMP_COMPAT, 3602},
+	{0, 3 | DECOMP_COMPAT, 774},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30ED},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F2},
+	{0, 2 | DECOMP_COMPAT, 3604},
+	{0, 4 | DECOMP_COMPAT, 254},
+	{0, 4 | DECOMP_COMPAT, 258},
+	{0, 4 | DECOMP_COMPAT, 262},
+	{0, 3 | DECOMP_COMPAT, 777},
+	{0, 4 | DECOMP_COMPAT, 266},
+	{0, 3 | DECOMP_COMPAT, 780},
+	{0, 3 | DECOMP_COMPAT, 783},
+	{0, 5 | DECOMP_COMPAT, 56},
+	{0, 4 | DECOMP_COMPAT, 270},
+	{0, 3 | DECOMP_COMPAT, 786},
+	{0, 3 | DECOMP_COMPAT, 789},
+	{0, 3 | DECOMP_COMPAT, 792},
+	{0, 4 | DECOMP_COMPAT, 274},
+	{0, 4 | DECOMP_COMPAT, 278},
+	{0, 3 | DECOMP_COMPAT, 795},
+	{0, 3 | DECOMP_COMPAT, 798},
+	{0, 2 | DECOMP_COMPAT, 3606},
+	{0, 3 | DECOMP_COMPAT, 801},
+	{0, 4 | DECOMP_COMPAT, 282},
+	{0, 4 | DECOMP_COMPAT, 286},
+	{0, 2 | DECOMP_COMPAT, 39},
+	{0, 5 | DECOMP_COMPAT, 61},
+	{0, 6 | DECOMP_COMPAT, 39},
+	{0, 5 | DECOMP_COMPAT, 66},
+	{0, 3 | DECOMP_COMPAT, 63},
+	{0, 5 | DECOMP_COMPAT, 71},
+	{0, 5 | DECOMP_COMPAT, 76},
+	{0, 4 | DECOMP_COMPAT, 290},
+	{0, 3 | DECOMP_COMPAT, 804},
+	{0, 3 | DECOMP_COMPAT, 807},
+	{0, 3 | DECOMP_COMPAT, 810},
+	{0, 4 | DECOMP_COMPAT, 294},
+	{0, 5 | DECOMP_COMPAT, 81},
+	{0, 4 | DECOMP_COMPAT, 298},
+	{0, 3 | DECOMP_COMPAT, 813},
+	{0, 3 | DECOMP_COMPAT, 88},
+	{0, 3 | DECOMP_COMPAT, 816},
+	{0, 2 | DECOMP_COMPAT, 3608},
+	{0, 2 | DECOMP_COMPAT, 3610},
+	{0, 2 | DECOMP_COMPAT, 74},
+	{0, 2 | DECOMP_COMPAT, 3612},
+	{0, 3 | DECOMP_COMPAT, 819},
+	{0, 3 | DECOMP_COMPAT, 822},
+	{0, 5 | DECOMP_COMPAT, 86},
+	{0, 3 | DECOMP_COMPAT, 825},
+	{0, 4 | DECOMP_COMPAT, 302},
+	{0, 5 | DECOMP_COMPAT, 91},
+	{0, 3 | DECOMP_COMPAT, 828},
+	{0, 2 | DECOMP_COMPAT, 3614},
+	{0, 2 | DECOMP_COMPAT, 3616},
+	{0, 5 | DECOMP_COMPAT, 96},
+	{0, 4 | DECOMP_COMPAT, 306},
+	{0, 5 | DECOMP_COMPAT, 101},
+	{0, 3 | DECOMP_COMPAT, 831},
+	{0, 5 | DECOMP_COMPAT, 106},
+	{0, 2 | DECOMP_COMPAT, 3618},
+	{0, 3 | DECOMP_COMPAT, 834},
+	{0, 3 | DECOMP_COMPAT, 837},
+	{0, 3 | DECOMP_COMPAT, 840},
+	{0, 3 | DECOMP_COMPAT, 843},
+	{0, 3 | DECOMP_COMPAT, 846},
+	{0, 4 | DECOMP_COMPAT, 310},
+	{0, 3 | DECOMP_COMPAT, 849},
+	{0, 2 | DECOMP_COMPAT, 3620},
+	{0, 3 | DECOMP_COMPAT, 852},
+	{0, 3 | DECOMP_COMPAT, 855},
+	{0, 3 | DECOMP_COMPAT, 858},
+	{0, 4 | DECOMP_COMPAT, 314},
+	{0, 3 | DECOMP_COMPAT, 861},
+	{0, 3 | DECOMP_COMPAT, 864},
+	{0, 3 | DECOMP_COMPAT, 867},
+	{0, 5 | DECOMP_COMPAT, 111},
+	{0, 4 | DECOMP_COMPAT, 318},
+	{0, 2 | DECOMP_COMPAT, 116},
+	{0, 5 | DECOMP_COMPAT, 116},
+	{0, 2 | DECOMP_COMPAT, 322},
+	{0, 4 | DECOMP_COMPAT, 322},
+	{0, 4 | DECOMP_COMPAT, 41},
+	{0, 3 | DECOMP_COMPAT, 870},
+	{0, 3 | DECOMP_COMPAT, 873},
+	{0, 3 | DECOMP_COMPAT, 876},
+	{0, 4 | DECOMP_COMPAT, 326},
+	{0, 2 | DECOMP_COMPAT, 3622},
+	{0, 3 | DECOMP_COMPAT, 879},
+	{0, 4 | DECOMP_COMPAT, 330},
+	{0, 2 | DECOMP_COMPAT, 3624},
+	{0, 5 | DECOMP_COMPAT, 121},
+	{0, 3 | DECOMP_COMPAT, 68},
+	{0, 2 | DECOMP_COMPAT, 883},
+	{0, 2 | DECOMP_COMPAT, 886},
+	{0, 2 | DECOMP_COMPAT, 889},
+	{0, 2 | DECOMP_COMPAT, 892},
+	{0, 2 | DECOMP_COMPAT, 895},
+	{0, 2 | DECOMP_COMPAT, 898},
+	{0, 2 | DECOMP_COMPAT, 901},
+	{0, 2 | DECOMP_COMPAT, 904},
+	{0, 2 | DECOMP_COMPAT, 907},
+	{0, 2 | DECOMP_COMPAT, 910},
+	{0, 3 | DECOMP_COMPAT, 882},
+	{0, 3 | DECOMP_COMPAT, 885},
+	{0, 3 | DECOMP_COMPAT, 888},
+	{0, 3 | DECOMP_COMPAT, 891},
+	{0, 3 | DECOMP_COMPAT, 894},
+	{0, 3 | DECOMP_COMPAT, 897},
+	{0, 3 | DECOMP_COMPAT, 900},
+	{0, 3 | DECOMP_COMPAT, 903},
+	{0, 3 | DECOMP_COMPAT, 906},
+	{0, 3 | DECOMP_COMPAT, 909},
+	{0, 3 | DECOMP_COMPAT, 912},
+	{0, 3 | DECOMP_COMPAT, 915},
+	{0, 3 | DECOMP_COMPAT, 918},
+	{0, 3 | DECOMP_COMPAT, 921},
+	{0, 3 | DECOMP_COMPAT, 924},
+	{0, 3 | DECOMP_COMPAT, 927},
+	{0, 2 | DECOMP_COMPAT, 3626},
+	{0, 2 | DECOMP_COMPAT, 3628},
+	{0, 3 | DECOMP_COMPAT, 930},
+	{0, 2 | DECOMP_COMPAT, 3630},
+	{0, 2 | DECOMP_COMPAT, 3632},
+	{0, 2 | DECOMP_COMPAT, 933},
+	{0, 3 | DECOMP_COMPAT, 933},
+	{0, 3 | DECOMP_COMPAT, 936},
+	{0, 2 | DECOMP_COMPAT, 3634},
+	{0, 2 | DECOMP_COMPAT, 3636},
+	{0, 2 | DECOMP_COMPAT, 3638},
+	{0, 2 | DECOMP_COMPAT, 3640},
+	{0, 2 | DECOMP_COMPAT, 3642},
+	{0, 4 | DECOMP_COMPAT, 334},
+	{0, 2 | DECOMP_COMPAT, 3644},
+	{0, 2 | DECOMP_COMPAT, 3646},
+	{0, 2 | DECOMP_COMPAT, 3648},
+	{0, 2 | DECOMP_COMPAT, 995},
+	{0, 2 | DECOMP_COMPAT, 3650},
+	{0, 2 | DECOMP_COMPAT, 3652},
+	{0, 2 | DECOMP_COMPAT, 3654},
+	{0, 2 | DECOMP_COMPAT, 3656},
+	{0, 3 | DECOMP_COMPAT, 339},
+	{0, 4 | DECOMP_COMPAT, 338},
+	{0, 2 | DECOMP_COMPAT, 3658},
+	{0, 2 | DECOMP_COMPAT, 3660},
+	{0, 2 | DECOMP_COMPAT, 3662},
+	{0, 2 | DECOMP_COMPAT, 3664},
+	{0, 2 | DECOMP_COMPAT, 3666},
+	{0, 2 | DECOMP_COMPAT, 352},
+	{0, 2 | DECOMP_COMPAT, 940},
+	{0, 3 | DECOMP_COMPAT, 939},
+	{0, 3 | DECOMP_COMPAT, 942},
+	{0, 3 | DECOMP_COMPAT, 945},
+	{0, 3 | DECOMP_COMPAT, 948},
+	{0, 2 | DECOMP_COMPAT, 3668},
+	{0, 2 | DECOMP_COMPAT, 3670},
+	{0, 2 | DECOMP_COMPAT, 3672},
+	{0, 2 | DECOMP_COMPAT, 3674},
+	{0, 2 | DECOMP_COMPAT, 3676},
+	{0, 2 | DECOMP_COMPAT, 3678},
+	{0, 2 | DECOMP_COMPAT, 3680},
+	{0, 2 | DECOMP_COMPAT, 951},
+	{0, 2 | DECOMP_COMPAT, 954},
+	{0, 2 | DECOMP_COMPAT, 957},
+	{0, 3 | DECOMP_COMPAT, 951},
+	{0, 3 | DECOMP_COMPAT, 954},
+	{0, 2 | DECOMP_COMPAT, 934},
+	{0, 3 | DECOMP_COMPAT, 957},
+	{0, 3 | DECOMP_COMPAT, 960},
+	{0, 3 | DECOMP_COMPAT, 963},
+	{0, 2 | DECOMP_COMPAT, 937},
+	{0, 3 | DECOMP_COMPAT, 966},
+	{0, 3 | DECOMP_COMPAT, 342},
+	{0, 4 | DECOMP_COMPAT, 342},
+	{0, 2 | DECOMP_COMPAT, 928},
+	{0, 3 | DECOMP_COMPAT, 969},
+	{0, 3 | DECOMP_COMPAT, 972},
+	{0, 3 | DECOMP_COMPAT, 975},
+	{0, 3 | DECOMP_COMPAT, 45},
+	{0, 5 | DECOMP_COMPAT, 45},
+	{0, 6 | DECOMP_COMPAT, 45},
+	{0, 2 | DECOMP_COMPAT, 3682},
+	{0, 2 | DECOMP_COMPAT, 3684},
+	{0, 2 | DECOMP_COMPAT, 3686},
+	{0, 2 | DECOMP_COMPAT, 3688},
+	{0, 2 | DECOMP_COMPAT, 3690},
+	{0, 2 | DECOMP_COMPAT, 3692},
+	{0, 2 | DECOMP_COMPAT, 3694},
+	{0, 2 | DECOMP_COMPAT, 3696},
+	{0, 2 | DECOMP_COMPAT, 3698},
+	{0, 2 | DECOMP_COMPAT, 992},
+	{0, 2 | DECOMP_COMPAT, 3700},
+	{0, 2 | DECOMP_COMPAT, 3702},
+	{0, 2 | DECOMP_COMPAT, 3704},
+	{0, 2 | DECOMP_COMPAT, 3706},
+	{0, 2 | DECOMP_COMPAT, 3708},
+	{0, 2 | DECOMP_COMPAT, 3710},
+	{0, 2 | DECOMP_COMPAT, 3712},
+	{0, 2 | DECOMP_COMPAT, 3714},
+	{0, 4 | DECOMP_COMPAT, 346},
+	{0, 2 | DECOMP_COMPAT, 3716},
+	{0, 2 | DECOMP_COMPAT, 3718},
+	{0, 2 | DECOMP_COMPAT, 3720},
+	{0, 4 | DECOMP_COMPAT, 350},
+	{0, 3 | DECOMP_COMPAT, 978},
+	{0, 2 | DECOMP_COMPAT, 3722},
+	{0, 2 | DECOMP_COMPAT, 3724},
+	{0, 2 | DECOMP_COMPAT, 3726},
+	{0, 2 | DECOMP_COMPAT, 3728},
+	{0, 2 | DECOMP_COMPAT, 3730},
+	{0, 2 | DECOMP_COMPAT, 3732},
+	{0, 2 | DECOMP_COMPAT, 3734},
+	{0, 2 | DECOMP_COMPAT, 3736},
+	{0, 2 | DECOMP_COMPAT, 341},
+	{0, 2 | DECOMP_COMPAT, 3738},
+	{0, 3 | DECOMP_COMPAT, 981},
+	{0, 2 | DECOMP_COMPAT, 3740},
+	{0, 2 | DECOMP_COMPAT, 3742},
+	{0, 3 | DECOMP_COMPAT, 984},
+	{0, 3 | DECOMP_COMPAT, 987},
+	{0, 2 | DECOMP_COMPAT, 3744},
+	{0, 4 | DECOMP_COMPAT, 354},
+	{0, 3 | DECOMP_COMPAT, 990},
+	{0, 2 | DECOMP_COMPAT, 3746},
+	{0, 2 | DECOMP_COMPAT, 3748},
+	{0, 2 | DECOMP_COMPAT, 3750},
+	{0, 2 | DECOMP_COMPAT, 3752},
+	{0, 3 | DECOMP_COMPAT, 993},
+	{0, 3 | DECOMP_COMPAT, 996},
+	{0, 2 | DECOMP_COMPAT, 1003},
+	{0, 2 | DECOMP_COMPAT, 1006},
+	{0, 2 | DECOMP_COMPAT, 1009},
+	{0, 2 | DECOMP_COMPAT, 1012},
+	{0, 2 | DECOMP_COMPAT, 1015},
+	{0, 2 | DECOMP_COMPAT, 1018},
+	{0, 2 | DECOMP_COMPAT, 1021},
+	{0, 2 | DECOMP_COMPAT, 1024},
+	{0, 2 | DECOMP_COMPAT, 1027},
+	{0, 3 | DECOMP_COMPAT, 999},
+	{0, 3 | DECOMP_COMPAT, 1002},
+	{0, 3 | DECOMP_COMPAT, 1005},
+	{0, 3 | DECOMP_COMPAT, 1008},
+	{0, 3 | DECOMP_COMPAT, 1011},
+	{0, 3 | DECOMP_COMPAT, 1014},
+	{0, 3 | DECOMP_COMPAT, 1017},
+	{0, 3 | DECOMP_COMPAT, 1020},
+	{0, 3 | DECOMP_COMPAT, 1023},
+	{0, 3 | DECOMP_COMPAT, 1026},
+	{0, 3 | DECOMP_COMPAT, 1029},
+	{0, 3 | DECOMP_COMPAT, 1032},
+	{0, 3 | DECOMP_COMPAT, 1035},
+	{0, 3 | DECOMP_COMPAT, 1038},
+	{0, 3 | DECOMP_COMPAT, 1041},
+	{0, 3 | DECOMP_COMPAT, 1044},
+	{0, 3 | DECOMP_COMPAT, 1047},
+	{0, 3 | DECOMP_COMPAT, 1050},
+	{0, 3 | DECOMP_COMPAT, 1053},
+	{0, 3 | DECOMP_COMPAT, 1056},
+	{0, 3 | DECOMP_COMPAT, 1059},
+	{0, 3 | DECOMP_COMPAT, 1062},
+	{0, 3 | DECOMP_COMPAT, 1065},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA76F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0126},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0153},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA727},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB37},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB52},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028D},
+	{0, 1 | DECOMP_INLINE, 0x8C48},
+	{0, 1 | DECOMP_INLINE, 0x66F4},
+	{0, 1 | DECOMP_INLINE, 0x8ECA},
+	{0, 1 | DECOMP_INLINE, 0x8CC8},
+	{0, 1 | DECOMP_INLINE, 0x6ED1},
+	{0, 1 | DECOMP_INLINE, 0x4E32},
+	{0, 1 | DECOMP_INLINE, 0x53E5},
+	{0, 1 | DECOMP_INLINE, 0x9F9C},
+	{0, 1 | DECOMP_INLINE, 0x5951},
+	{0, 1 | DECOMP_INLINE, 0x91D1},
+	{0, 1 | DECOMP_INLINE, 0x5587},
+	{0, 1 | DECOMP_INLINE, 0x5948},
+	{0, 1 | DECOMP_INLINE, 0x61F6},
+	{0, 1 | DECOMP_INLINE, 0x7669},
+	{0, 1 | DECOMP_INLINE, 0x7F85},
+	{0, 1 | DECOMP_INLINE, 0x863F},
+	{0, 1 | DECOMP_INLINE, 0x87BA},
+	{0, 1 | DECOMP_INLINE, 0x88F8},
+	{0, 1 | DECOMP_INLINE, 0x908F},
+	{0, 1 | DECOMP_INLINE, 0x6A02},
+	{0, 1 | DECOMP_INLINE, 0x6D1B},
+	{0, 1 | DECOMP_INLINE, 0x70D9},
+	{0, 1 | DECOMP_INLINE, 0x73DE},
+	{0, 1 | DECOMP_INLINE, 0x843D},
+	{0, 1 | DECOMP_INLINE, 0x916A},
+	{0, 1 | DECOMP_INLINE, 0x99F1},
+	{0, 1 | DECOMP_INLINE, 0x4E82},
+	{0, 1 | DECOMP_INLINE, 0x5375},
+	{0, 1 | DECOMP_INLINE, 0x6B04},
+	{0, 1 | DECOMP_INLINE, 0x721B},
+	{0, 1 | DECOMP_INLINE, 0x862D},
+	{0, 1 | DECOMP_INLINE, 0x9E1E},
+	{0, 1 | DECOMP_INLINE, 0x5D50},
+	{0, 1 | DECOMP_INLINE, 0x6FEB},
+	{0, 1 | DECOMP_INLINE, 0x85CD},
+	{0, 1 | DECOMP_INLINE, 0x8964},
+	{0, 1 | DECOMP_INLINE, 0x62C9},
+	{0, 1 | DECOMP_INLINE, 0x81D8},
+	{0, 1 | DECOMP_INLINE, 0x881F},
+	{0, 1 | DECOMP_INLINE, 0x5ECA},
+	{0, 1 | DECOMP_INLINE, 0x6717},
+	{0, 1 | DECOMP_INLINE, 0x6D6A},
+	{0, 1 | DECOMP_INLINE, 0x72FC},
+	{0, 1 | DECOMP_INLINE, 0x90CE},
+	{0, 1 | DECOMP_INLINE, 0x4F86},
+	{0, 1 | DECOMP_INLINE, 0x51B7},
+	{0, 1 | DECOMP_INLINE, 0x52DE},
+	{0, 1 | DECOMP_INLINE, 0x64C4},
+	{0, 1 | DECOMP_INLINE, 0x6AD3},
+	{0, 1 | DECOMP_INLINE, 0x7210},
+	{0, 1 | DECOMP_INLINE, 0x76E7},
+	{0, 1 | DECOMP_INLINE, 0x8001},
+	{0, 1 | DECOMP_INLINE, 0x8606},
+	{0, 1 | DECOMP_INLINE, 0x865C},
+	{0, 1 | DECOMP_INLINE, 0x8DEF},
+	{0, 1 | DECOMP_INLINE, 0x9732},
+	{0, 1 | DECOMP_INLINE, 0x9B6F},
+	{0, 1 | DECOMP_INLINE, 0x9DFA},
+	{0, 1 | DECOMP_INLINE, 0x788C},
+	{0, 1 | DECOMP_INLINE, 0x797F},
+	{0, 1 | DECOMP_INLINE, 0x7DA0},
+	{0, 1 | DECOMP_INLINE, 0x83C9},
+	{0, 1 | DECOMP_INLINE, 0x9304},
+	{0, 1 | DECOMP_INLINE, 0x9E7F},
+	{0, 1 | DECOMP_INLINE, 0x8AD6},
+	{0, 1 | DECOMP_INLINE, 0x58DF},
+	{0, 1 | DECOMP_INLINE, 0x5F04},
+	{0, 1 | DECOMP_INLINE, 0x7C60},
+	{0, 1 | DECOMP_INLINE, 0x807E},
+	{0, 1 | DECOMP_INLINE, 0x7262},
+	{0, 1 | DECOMP_INLINE, 0x78CA},
+	{0, 1 | DECOMP_INLINE, 0x8CC2},
+	{0, 1 | DECOMP_INLINE, 0x96F7},
+	{0, 1 | DECOMP_INLINE, 0x58D8},
+	{0, 1 | DECOMP_INLINE, 0x5C62},
+	{0, 1 | DECOMP_INLINE, 0x6A13},
+	{0, 1 | DECOMP_INLINE, 0x6DDA},
+	{0, 1 | DECOMP_INLINE, 0x6F0F},
+	{0, 1 | DECOMP_INLINE, 0x7D2F},
+	{0, 1 | DECOMP_INLINE, 0x7E37},
+	{0, 1 | DECOMP_INLINE, 0x964B},
+	{0, 1 | DECOMP_INLINE, 0x52D2},
+	{0, 1 | DECOMP_INLINE, 0x808B},
+	{0, 1 | DECOMP_INLINE, 0x51DC},
+	{0, 1 | DECOMP_INLINE, 0x51CC},
+	{0, 1 | DECOMP_INLINE, 0x7A1C},
+	{0, 1 | DECOMP_INLINE, 0x7DBE},
+	{0, 1 | DECOMP_INLINE, 0x83F1},
+	{0, 1 | DECOMP_INLINE, 0x9675},
+	{0, 1 | DECOMP_INLINE, 0x8B80},
+	{0, 1 | DECOMP_INLINE, 0x62CF},
+	{0, 1 | DECOMP_INLINE, 0x8AFE},
+	{0, 1 | DECOMP_INLINE, 0x4E39},
+	{0, 1 | DECOMP_INLINE, 0x5BE7},
+	{0, 1 | DECOMP_INLINE, 0x6012},
+	{0, 1 | DECOMP_INLINE, 0x7387},
+	{0, 1 | DECOMP_INLINE, 0x7570},
+	{0, 1 | DECOMP_INLINE, 0x5317},
+	{0, 1 | DECOMP_INLINE, 0x78FB},
+	{0, 1 | DECOMP_INLINE, 0x4FBF},
+	{0, 1 | DECOMP_INLINE, 0x5FA9},
+	{0, 1 | DECOMP_INLINE, 0x4E0D},
+	{0, 1 | DECOMP_INLINE, 0x6CCC},
+	{0, 1 | DECOMP_INLINE, 0x6578},
+	{0, 1 | DECOMP_INLINE, 0x7D22},
+	{0, 1 | DECOMP_INLINE, 0x53C3},
+	{0, 1 | DECOMP_INLINE, 0x585E},
+	{0, 1 | DECOMP_INLINE, 0x7701},
+	{0, 1 | DECOMP_INLINE, 0x8449},
+	{0, 1 | DECOMP_INLINE, 0x8AAA},
+	{0, 1 | DECOMP_INLINE, 0x6BBA},
+	{0, 1 | DECOMP_INLINE, 0x8FB0},
+	{0, 1 | DECOMP_INLINE, 0x6C88},
+	{0, 1 | DECOMP_INLINE, 0x62FE},
+	{0, 1 | DECOMP_INLINE, 0x82E5},
+	{0, 1 | DECOMP_INLINE, 0x63A0},
+	{0, 1 | DECOMP_INLINE, 0x7565},
+	{0, 1 | DECOMP_INLINE, 0x4EAE},
+	{0, 1 | DECOMP_INLINE, 0x5169},
+	{0, 1 | DECOMP_INLINE, 0x51C9},
+	{0, 1 | DECOMP_INLINE, 0x6881},
+	{0, 1 | DECOMP_INLINE, 0x7CE7},
+	{0, 1 | DECOMP_INLINE, 0x826F},
+	{0, 1 | DECOMP_INLINE, 0x8AD2},
+	{0, 1 | DECOMP_INLINE, 0x91CF},
+	{0, 1 | DECOMP_INLINE, 0x52F5},
+	{0, 1 | DECOMP_INLINE, 0x5442},
+	{0, 1 | DECOMP_INLINE, 0x5973},
+	{0, 1 | DECOMP_INLINE, 0x5EEC},
+	{0, 1 | DECOMP_INLINE, 0x65C5},
+	{0, 1 | DECOMP_INLINE, 0x6FFE},
+	{0, 1 | DECOMP_INLINE, 0x792A},
+	{0, 1 | DECOMP_INLINE, 0x95AD},
+	{0, 1 | DECOMP_INLINE, 0x9A6A},
+	{0, 1 | DECOMP_INLINE, 0x9E97},
+	{0, 1 | DECOMP_INLINE, 0x9ECE},
+	{0, 1 | DECOMP_INLINE, 0x529B},
+	{0, 1 | DECOMP_INLINE, 0x66C6},
+	{0, 1 | DECOMP_INLINE, 0x6B77},
+	{0, 1 | DECOMP_INLINE, 0x8F62},
+	{0, 1 | DECOMP_INLINE, 0x5E74},
+	{0, 1 | DECOMP_INLINE, 0x6190},
+	{0, 1 | DECOMP_INLINE, 0x6200},
+	{0, 1 | DECOMP_INLINE, 0x649A},
+	{0, 1 | DECOMP_INLINE, 0x6F23},
+	{0, 1 | DECOMP_INLINE, 0x7149},
+	{0, 1 | DECOMP_INLINE, 0x7489},
+	{0, 1 | DECOMP_INLINE, 0x79CA},
+	{0, 1 | DECOMP_INLINE, 0x7DF4},
+	{0, 1 | DECOMP_INLINE, 0x806F},
+	{0, 1 | DECOMP_INLINE, 0x8F26},
+	{0, 1 | DECOMP_INLINE, 0x84EE},
+	{0, 1 | DECOMP_INLINE, 0x9023},
+	{0, 1 | DECOMP_INLINE, 0x934A},
+	{0, 1 | DECOMP_INLINE, 0x5217},
+	{0, 1 | DECOMP_INLINE, 0x52A3},
+	{0, 1 | DECOMP_INLINE, 0x54BD},
+	{0, 1 | DECOMP_INLINE, 0x70C8},
+	{0, 1 | DECOMP_INLINE, 0x88C2},
+	{0, 1 | DECOMP_INLINE, 0x5EC9},
+	{0, 1 | DECOMP_INLINE, 0x5FF5},
+	{0, 1 | DECOMP_INLINE, 0x637B},
+	{0, 1 | DECOMP_INLINE, 0x6BAE},
+	{0, 1 | DECOMP_INLINE, 0x7C3E},
+	{0, 1 | DECOMP_INLINE, 0x7375},
+	{0, 1 | DECOMP_INLINE, 0x4EE4},
+	{0, 1 | DECOMP_INLINE, 0x56F9},
+	{0, 1 | DECOMP_INLINE, 0x5DBA},
+	{0, 1 | DECOMP_INLINE, 0x601C},
+	{0, 1 | DECOMP_INLINE, 0x73B2},
+	{0, 1 | DECOMP_INLINE, 0x7469},
+	{0, 1 | DECOMP_INLINE, 0x7F9A},
+	{0, 1 | DECOMP_INLINE, 0x8046},
+	{0, 1 | DECOMP_INLINE, 0x9234},
+	{0, 1 | DECOMP_INLINE, 0x96F6},
+	{0, 1 | DECOMP_INLINE, 0x9748},
+	{0, 1 | DECOMP_INLINE, 0x9818},
+	{0, 1 | DECOMP_INLINE, 0x4F8B},
+	{0, 1 | DECOMP_INLINE, 0x79AE},
+	{0, 1 | DECOMP_INLINE, 0x91B4},
+	{0, 1 | DECOMP_INLINE, 0x96B8},
+	{0, 1 | DECOMP_INLINE, 0x60E1},
+	{0, 1 | DECOMP_INLINE, 0x4E86},
+	{0, 1 | DECOMP_INLINE, 0x50DA},
+	{0, 1 | DECOMP_INLINE, 0x5BEE},
+	{0, 1 | DECOMP_INLINE, 0x5C3F},
+	{0, 1 | DECOMP_INLINE, 0x6599},
+	{0, 1 | DECOMP_INLINE, 0x71CE},
+	{0, 1 | DECOMP_INLINE, 0x7642},
+	{0, 1 | DECOMP_INLINE, 0x84FC},
+	{0, 1 | DECOMP_INLINE, 0x907C},
+	{0, 1 | DECOMP_INLINE, 0x9F8D},
+	{0, 1 | DECOMP_INLINE, 0x6688},
+	{0, 1 | DECOMP_INLINE, 0x962E},
+	{0, 1 | DECOMP_INLINE, 0x5289},
+	{0, 1 | DECOMP_INLINE, 0x677B},
+	{0, 1 | DECOMP_INLINE, 0x67F3},
+	{0, 1 | DECOMP_INLINE, 0x6D41},
+	{0, 1 | DECOMP_INLINE, 0x6E9C},
+	{0, 1 | DECOMP_INLINE, 0x7409},
+	{0, 1 | DECOMP_INLINE, 0x7559},
+	{0, 1 | DECOMP_INLINE, 0x786B},
+	{0, 1 | DECOMP_INLINE, 0x7D10},
+	{0, 1 | DECOMP_INLINE, 0x985E},
+	{0, 1 | DECOMP_INLINE, 0x516D},
+	{0, 1 | DECOMP_INLINE, 0x622E},
+	{0, 1 | DECOMP_INLINE, 0x9678},
+	{0, 1 | DECOMP_INLINE, 0x502B},
+	{0, 1 | DECOMP_INLINE, 0x5D19},
+	{0, 1 | DECOMP_INLINE, 0x6DEA},
+	{0, 1 | DECOMP_INLINE, 0x8F2A},
+	{0, 1 | DECOMP_INLINE, 0x5F8B},
+	{0, 1 | DECOMP_INLINE, 0x6144},
+	{0, 1 | DECOMP_INLINE, 0x6817},
+	{0, 1 | DECOMP_INLINE, 0x9686},
+	{0, 1 | DECOMP_INLINE, 0x5229},
+	{0, 1 | DECOMP_INLINE, 0x540F},
+	{0, 1 | DECOMP_INLINE, 0x5C65},
+	{0, 1 | DECOMP_INLINE, 0x6613},
+	{0, 1 | DECOMP_INLINE, 0x674E},
+	{0, 1 | DECOMP_INLINE, 0x68A8},
+	{0, 1 | DECOMP_INLINE, 0x6CE5},
+	{0, 1 | DECOMP_INLINE, 0x7406},
+	{0, 1 | DECOMP_INLINE, 0x75E2},
+	{0, 1 | DECOMP_INLINE, 0x7F79},
+	{0, 1 | DECOMP_INLINE, 0x88CF},
+	{0, 1 | DECOMP_INLINE, 0x88E1},
+	{0, 1 | DECOMP_INLINE, 0x91CC},
+	{0, 1 | DECOMP_INLINE, 0x96E2},
+	{0, 1 | DECOMP_INLINE, 0x533F},
+	{0, 1 | DECOMP_INLINE, 0x6EBA},
+	{0, 1 | DECOMP_INLINE, 0x541D},
+	{0, 1 | DECOMP_INLINE, 0x71D0},
+	{0, 1 | DECOMP_INLINE, 0x7498},
+	{0, 1 | DECOMP_INLINE, 0x85FA},
+	{0, 1 | DECOMP_INLINE, 0x96A3},
+	{0, 1 | DECOMP_INLINE, 0x9C57},
+	{0, 1 | DECOMP_INLINE, 0x9E9F},
+	{0, 1 | DECOMP_INLINE, 0x6797},
+	{0, 1 | DECOMP_INLINE, 0x6DCB},
+	{0, 1 | DECOMP_INLINE, 0x81E8},
+	{0, 1 | DECOMP_INLINE, 0x7ACB},
+	{0, 1 | DECOMP_INLINE, 0x7B20},
+	{0, 1 | DECOMP_INLINE, 0x7C92},
+	{0, 1 | DECOMP_INLINE, 0x72C0},
+	{0, 1 | DECOMP_INLINE, 0x7099},
+	{0, 1 | DECOMP_INLINE, 0x8B58},
+	{0, 1 | DECOMP_INLINE, 0x4EC0},
+	{0, 1 | DECOMP_INLINE, 0x8336},
+	{0, 1 | DECOMP_INLINE, 0x523A},
+	{0, 1 | DECOMP_INLINE, 0x5207},
+	{0, 1 | DECOMP_INLINE, 0x5EA6},
+	{0, 1 | DECOMP_INLINE, 0x62D3},
+	{0, 1 | DECOMP_INLINE, 0x7CD6},
+	{0, 1 | DECOMP_INLINE, 0x5B85},
+	{0, 1 | DECOMP_INLINE, 0x6D1E},
+	{0, 1 | DECOMP_INLINE, 0x66B4},
+	{0, 1 | DECOMP_INLINE, 0x8F3B},
+	{0, 1 | DECOMP_INLINE, 0x884C},
+	{0, 1 | DECOMP_INLINE, 0x964D},
+	{0, 1 | DECOMP_INLINE, 0x898B},
+	{0, 1 | DECOMP_INLINE, 0x5ED3},
+	{0, 1 | DECOMP_INLINE, 0x5140},
+	{0, 1 | DECOMP_INLINE, 0x55C0},
+	{0, 1 | DECOMP_INLINE, 0x585A},
+	{0, 1 | DECOMP_INLINE, 0x6674},
+	{0, 1 | DECOMP_INLINE, 0x51DE},
+	{0, 1 | DECOMP_INLINE, 0x732A},
+	{0, 1 | DECOMP_INLINE, 0x76CA},
+	{0, 1 | DECOMP_INLINE, 0x793C},
+	{0, 1 | DECOMP_INLINE, 0x795E},
+	{0, 1 | DECOMP_INLINE, 0x7965},
+	{0, 1 | DECOMP_INLINE, 0x798F},
+	{0, 1 | DECOMP_INLINE, 0x9756},
+	{0, 1 | DECOMP_INLINE, 0x7CBE},
+	{0, 1 | DECOMP_INLINE, 0x7FBD},
+	{0, 1 | DECOMP_INLINE, 0x8612},
+	{0, 1 | DECOMP_INLINE, 0x8AF8},
+	{0, 1 | DECOMP_INLINE, 0x9038},
+	{0, 1 | DECOMP_INLINE, 0x90FD},
+	{0, 1 | DECOMP_INLINE, 0x98EF},
+	{0, 1 | DECOMP_INLINE, 0x98FC},
+	{0, 1 | DECOMP_INLINE, 0x9928},
+	{0, 1 | DECOMP_INLINE, 0x9DB4},
+	{0, 1 | DECOMP_INLINE, 0x90DE},
+	{0, 1 | DECOMP_INLINE, 0x96B7},
+	{0, 1 | DECOMP_INLINE, 0x4FAE},
+	{0, 1 | DECOMP_INLINE, 0x50E7},
+	{0, 1 | DECOMP_INLINE, 0x514D},
+	{0, 1 | DECOMP_INLINE, 0x52C9},
+	{0, 1 | DECOMP_INLINE, 0x52E4},
+	{0, 1 | DECOMP_INLINE, 0x5351},
+	{0, 1 | DECOMP_INLINE, 0x559D},
+	{0, 1 | DECOMP_INLINE, 0x5606},
+	{0, 1 | DECOMP_INLINE, 0x5668},
+	{0, 1 | DECOMP_INLINE, 0x5840},
+	{0, 1 | DECOMP_INLINE, 0x58A8},
+	{0, 1 | DECOMP_INLINE, 0x5C64},
+	{0, 1 | DECOMP_INLINE, 0x5C6E},
+	{0, 1 | DECOMP_INLINE, 0x6094},
+	{0, 1 | DECOMP_INLINE, 0x6168},
+	{0, 1 | DECOMP_INLINE, 0x618E},
+	{0, 1 | DECOMP_INLINE, 0x61F2},
+	{0, 1 | DECOMP_INLINE, 0x654F},
+	{0, 1 | DECOMP_INLINE, 0x65E2},
+	{0, 1 | DECOMP_INLINE, 0x6691},
+	{0, 1 | DECOMP_INLINE, 0x6885},
+	{0, 1 | DECOMP_INLINE, 0x6D77},
+	{0, 1 | DECOMP_INLINE, 0x6E1A},
+	{0, 1 | DECOMP_INLINE, 0x6F22},
+	{0, 1 | DECOMP_INLINE, 0x716E},
+	{0, 1 | DECOMP_INLINE, 0x722B},
+	{0, 1 | DECOMP_INLINE, 0x7422},
+	{0, 1 | DECOMP_INLINE, 0x7891},
+	{0, 1 | DECOMP_INLINE, 0x793E},
+	{0, 1 | DECOMP_INLINE, 0x7949},
+	{0, 1 | DECOMP_INLINE, 0x7948},
+	{0, 1 | DECOMP_INLINE, 0x7950},
+	{0, 1 | DECOMP_INLINE, 0x7956},
+	{0, 1 | DECOMP_INLINE, 0x795D},
+	{0, 1 | DECOMP_INLINE, 0x798D},
+	{0, 1 | DECOMP_INLINE, 0x798E},
+	{0, 1 | DECOMP_INLINE, 0x7A40},
+	{0, 1 | DECOMP_INLINE, 0x7A81},
+	{0, 1 | DECOMP_INLINE, 0x7BC0},
+	{0, 1 | DECOMP_INLINE, 0x7E09},
+	{0, 1 | DECOMP_INLINE, 0x7E41},
+	{0, 1 | DECOMP_INLINE, 0x7F72},
+	{0, 1 | DECOMP_INLINE, 0x8005},
+	{0, 1 | DECOMP_INLINE, 0x81ED},
+	{0, 1 | DECOMP_INLINE, 0x8279},
+	{0, 1 | DECOMP_INLINE, 0x8457},
+	{0, 1 | DECOMP_INLINE, 0x8910},
+	{0, 1 | DECOMP_INLINE, 0x8996},
+	{0, 1 | DECOMP_INLINE, 0x8B01},
+	{0, 1 | DECOMP_INLINE, 0x8B39},
+	{0, 1 | DECOMP_INLINE, 0x8CD3},
+	{0, 1 | DECOMP_INLINE, 0x8D08},
+	{0, 1 | DECOMP_INLINE, 0x8FB6},
+	{0, 1 | DECOMP_INLINE, 0x96E3},
+	{0, 1 | DECOMP_INLINE, 0x97FF},
+	{0, 1 | DECOMP_INLINE, 0x983B},
+	{0, 1 | DECOMP_INLINE, 0x6075},
+	{0, 1, 4188},
+	{0, 1 | DECOMP_INLINE, 0x8218},
+	{0, 1 | DECOMP_INLINE, 0x4E26},
+	{0, 1 | DECOMP_INLINE, 0x51B5},
+	{0, 1 | DECOMP_INLINE, 0x5168},
+	{0, 1 | DECOMP_INLINE, 0x4F80},
+	{0, 1 | DECOMP_INLINE, 0x5145},
+	{0, 1 | DECOMP_INLINE, 0x5180},
+	{0, 1 | DECOMP_INLINE, 0x52C7},
+	{0, 1 | DECOMP_INLINE, 0x52FA},
+	{0, 1 | DECOMP_INLINE, 0x5555},
+	{0, 1 | DECOMP_INLINE, 0x5599},
+	{0, 1 | DECOMP_INLINE, 0x55E2},
+	{0, 1 | DECOMP_INLINE, 0x58B3},
+	{0, 1 | DECOMP_INLINE, 0x5944},
+	{0, 1 | DECOMP_INLINE, 0x5954},
+	{0, 1 | DECOMP_INLINE, 0x5A62},
+	{0, 1 | DECOMP_INLINE, 0x5B28},
+	{0, 1 | DECOMP_INLINE, 0x5ED2},
+	{0, 1 | DECOMP_INLINE, 0x5ED9},
+	{0, 1 | DECOMP_INLINE, 0x5F69},
+	{0, 1 | DECOMP_INLINE, 0x5FAD},
+	{0, 1 | DECOMP_INLINE, 0x60D8},
+	{0, 1 | DECOMP_INLINE, 0x614E},
+	{0, 1 | DECOMP_INLINE, 0x6108},
+	{0, 1 | DECOMP_INLINE, 0x6160},
+	{0, 1 | DECOMP_INLINE, 0x6234},
+	{0, 1 | DECOMP_INLINE, 0x63C4},
+	{0, 1 | DECOMP_INLINE, 0x641C},
+	{0, 1 | DECOMP_INLINE, 0x6452},
+	{0, 1 | DECOMP_INLINE, 0x6556},
+	{0, 1 | DECOMP_INLINE, 0x671B},
+	{0, 1 | DECOMP_INLINE, 0x6756},
+	{0, 1 | DECOMP_INLINE, 0x6B79},
+	{0, 1 | DECOMP_INLINE, 0x6EDB},
+	{0, 1 | DECOMP_INLINE, 0x6ECB},
+	{0, 1 | DECOMP_INLINE, 0x701E},
+	{0, 1 | DECOMP_INLINE, 0x77A7},
+	{0, 1 | DECOMP_INLINE, 0x7235},
+	{0, 1 | DECOMP_INLINE, 0x72AF},
+	{0, 1 | DECOMP_INLINE, 0x7471},
+	{0, 1 | DECOMP_INLINE, 0x7506},
+	{0, 1 | DECOMP_INLINE, 0x753B},
+	{0, 1 | DECOMP_INLINE, 0x761D},
+	{0, 1 | DECOMP_INLINE, 0x761F},
+	{0, 1 | DECOMP_INLINE, 0x76DB},
+	{0, 1 | DECOMP_INLINE, 0x76F4},
+	{0, 1 | DECOMP_INLINE, 0x774A},
+	{0, 1 | DECOMP_INLINE, 0x7740},
+	{0, 1 | DECOMP_INLINE, 0x78CC},
+	{0, 1 | DECOMP_INLINE, 0x7AB1},
+	{0, 1 | DECOMP_INLINE, 0x7C7B},
+	{0, 1 | DECOMP_INLINE, 0x7D5B},
+	{0, 1 | DECOMP_INLINE, 0x7F3E},
+	{0, 1 | DECOMP_INLINE, 0x8352},
+	{0, 1 | DECOMP_INLINE, 0x83EF},
+	{0, 1 | DECOMP_INLINE, 0x8779},
+	{0, 1 | DECOMP_INLINE, 0x8941},
+	{0, 1 | DECOMP_INLINE, 0x8986},
+	{0, 1 | DECOMP_INLINE, 0x8ABF},
+	{0, 1 | DECOMP_INLINE, 0x8ACB},
+	{0, 1 | DECOMP_INLINE, 0x8AED},
+	{0, 1 | DECOMP_INLINE, 0x8B8A},
+	{0, 1 | DECOMP_INLINE, 0x8F38},
+	{0, 1 | DECOMP_INLINE, 0x9072},
+	{0, 1 | DECOMP_INLINE, 0x9199},
+	{0, 1 | DECOMP_INLINE, 0x9276},
+	{0, 1 | DECOMP_INLINE, 0x967C},
+	{0, 1 | DECOMP_INLINE, 0x97DB},
+	{0, 1 | DECOMP_INLINE, 0x980B},
+	{0, 1 | DECOMP_INLINE, 0x9B12},
+	{0, 1, 4189},
+	{0, 1, 4190},
+	{0, 1, 4191},
+	{0, 1 | DECOMP_INLINE, 0x3B9D},
+	{0, 1 | DECOMP_INLINE, 0x4018},
+	{0, 1 | DECOMP_INLINE, 0x4039},
+	{0, 1, 4192},
+	{0, 1, 4193},
+	{0, 1, 4194},
+	{0, 1 | DECOMP_INLINE, 0x9F43},
+	{0, 1 | DECOMP_INLINE, 0x9F8E},
+	{0, 2 | DECOMP_COMPAT, 1068},
+	{0, 2 | DECOMP_COMPAT, 1069},
+	{0, 2 | DECOMP_COMPAT, 1072},
+	{0, 3 | DECOMP_COMPAT, 1068},
+	{0, 3 | DECOMP_COMPAT, 1071},
+	{0, 2 | DECOMP_COMPAT, 3754},
+	{0, 2 | DECOMP_COMPAT, 3756},
+	{0, 2 | DECOMP_COMPAT, 3758},
+	{0, 2 | DECOMP_COMPAT, 3760},
+	{0, 2 | DECOMP_COMPAT, 3762},
+	{0, 2 | DECOMP_COMPAT, 3764},
+	{0, 2 | DECOMP_COMPAT, 3766},
+	{0, 2 | DECOMP_NO_COMPOSE, 3768},	/* in exclusion list */
+	{26, 0, 0},
+	{0, 2 | DECOMP_NO_COMPOSE, 3770},	/* in exclusion list */
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05E2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05E8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05EA},
+	{0, 2 | DECOMP_NO_COMPOSE, 3772},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3774},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3776},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3778},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3780},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3782},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3784},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3786},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3788},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3790},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3792},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3794},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3796},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3798},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3800},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3802},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3804},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3806},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3808},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3810},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3812},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3814},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3816},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3818},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3820},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3822},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3824},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3826},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3828},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3830},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3832},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 3834},	/* in exclusion list */
+	{0, 2 | DECOMP_COMPAT, 3836},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0671},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0688},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0698},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0691},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0677},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
+	{0, 2 | DECOMP_COMPAT, 3838},
+	{0, 2 | DECOMP_COMPAT, 3840},
+	{0, 2 | DECOMP_COMPAT, 3842},
+	{0, 2 | DECOMP_COMPAT, 3844},
+	{0, 2 | DECOMP_COMPAT, 3846},
+	{0, 2 | DECOMP_COMPAT, 3848},
+	{0, 2 | DECOMP_COMPAT, 3850},
+	{0, 2 | DECOMP_COMPAT, 3852},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
+	{0, 2 | DECOMP_COMPAT, 3854},
+	{0, 2 | DECOMP_COMPAT, 3856},
+	{0, 2 | DECOMP_COMPAT, 3858},
+	{0, 2 | DECOMP_COMPAT, 3860},
+	{0, 2 | DECOMP_COMPAT, 3862},
+	{0, 2 | DECOMP_COMPAT, 1368},
+	{0, 2 | DECOMP_COMPAT, 1272},
+	{0, 2 | DECOMP_COMPAT, 3864},
+	{0, 2 | DECOMP_COMPAT, 3866},
+	{0, 2 | DECOMP_COMPAT, 3868},
+	{0, 2 | DECOMP_COMPAT, 1101},
+	{0, 2 | DECOMP_COMPAT, 1104},
+	{0, 2 | DECOMP_COMPAT, 1110},
+	{0, 2 | DECOMP_COMPAT, 1113},
+	{0, 2 | DECOMP_COMPAT, 3870},
+	{0, 2 | DECOMP_COMPAT, 3872},
+	{0, 2 | DECOMP_COMPAT, 3874},
+	{0, 2 | DECOMP_COMPAT, 3876},
+	{0, 2 | DECOMP_COMPAT, 3878},
+	{0, 2 | DECOMP_COMPAT, 3880},
+	{0, 2 | DECOMP_COMPAT, 1135},
+	{0, 2 | DECOMP_COMPAT, 1102},
+	{0, 2 | DECOMP_COMPAT, 1105},
+	{0, 2 | DECOMP_COMPAT, 363},
+	{0, 2 | DECOMP_COMPAT, 1121},
+	{0, 2 | DECOMP_COMPAT, 3882},
+	{0, 2 | DECOMP_COMPAT, 1111},
+	{0, 2 | DECOMP_COMPAT, 1134},
+	{0, 2 | DECOMP_COMPAT, 1131},
+	{0, 2 | DECOMP_COMPAT, 1302},
+	{0, 2 | DECOMP_COMPAT, 1140},
+	{0, 2 | DECOMP_COMPAT, 1149},
+	{0, 2 | DECOMP_COMPAT, 1152},
+	{0, 2 | DECOMP_COMPAT, 3884},
+	{0, 2 | DECOMP_COMPAT, 1167},
+	{0, 2 | DECOMP_COMPAT, 1170},
+	{0, 2 | DECOMP_COMPAT, 3886},
+	{0, 2 | DECOMP_COMPAT, 3888},
+	{0, 2 | DECOMP_COMPAT, 1173},
+	{0, 2 | DECOMP_COMPAT, 3890},
+	{0, 2 | DECOMP_COMPAT, 1182},
+	{0, 2 | DECOMP_COMPAT, 368},
+	{0, 2 | DECOMP_COMPAT, 3892},
+	{0, 2 | DECOMP_COMPAT, 1191},
+	{0, 2 | DECOMP_COMPAT, 3894},
+	{0, 2 | DECOMP_COMPAT, 3896},
+	{0, 2 | DECOMP_COMPAT, 1200},
+	{0, 2 | DECOMP_COMPAT, 1365},
+	{0, 2 | DECOMP_COMPAT, 3898},
+	{0, 2 | DECOMP_COMPAT, 3900},
+	{0, 2 | DECOMP_COMPAT, 3902},
+	{0, 2 | DECOMP_COMPAT, 1203},
+	{0, 2 | DECOMP_COMPAT, 3904},
+	{0, 2 | DECOMP_COMPAT, 3906},
+	{0, 2 | DECOMP_COMPAT, 3908},
+	{0, 2 | DECOMP_COMPAT, 3910},
+	{0, 2 | DECOMP_COMPAT, 3912},
+	{0, 2 | DECOMP_COMPAT, 3914},
+	{0, 2 | DECOMP_COMPAT, 3916},
+	{0, 2 | DECOMP_COMPAT, 1341},
+	{0, 2 | DECOMP_COMPAT, 3918},
+	{0, 2 | DECOMP_COMPAT, 3920},
+	{0, 2 | DECOMP_COMPAT, 1218},
+	{0, 2 | DECOMP_COMPAT, 1209},
+	{0, 2 | DECOMP_COMPAT, 1221},
+	{0, 2 | DECOMP_COMPAT, 16},
+	{0, 2 | DECOMP_COMPAT, 1},
+	{0, 2 | DECOMP_COMPAT, 10},
+	{0, 2 | DECOMP_COMPAT, 17},
+	{0, 2 | DECOMP_COMPAT, 362},
+	{0, 2 | DECOMP_COMPAT, 1120},
+	{0, 2 | DECOMP_COMPAT, 1147},
+	{0, 2 | DECOMP_COMPAT, 1129},
+	{0, 2 | DECOMP_COMPAT, 1126},
+	{0, 2 | DECOMP_COMPAT, 1257},
+	{0, 2 | DECOMP_COMPAT, 1251},
+	{0, 2 | DECOMP_COMPAT, 3922},
+	{0, 2 | DECOMP_COMPAT, 1263},
+	{0, 2 | DECOMP_COMPAT, 3924},
+	{0, 2 | DECOMP_COMPAT, 3926},
+	{0, 2 | DECOMP_COMPAT, 3928},
+	{0, 2 | DECOMP_COMPAT, 1245},
+	{0, 2 | DECOMP_COMPAT, 3930},
+	{0, 2 | DECOMP_COMPAT, 3932},
+	{0, 2 | DECOMP_COMPAT, 1295},
+	{0, 2 | DECOMP_COMPAT, 1127},
+	{0, 2 | DECOMP_COMPAT, 3881},
+	{0, 2 | DECOMP_COMPAT, 1232},
+	{0, 2 | DECOMP_COMPAT, 3934},
+	{0, 2 | DECOMP_COMPAT, 1319},
+	{0, 2 | DECOMP_COMPAT, 3936},
+	{0, 2 | DECOMP_COMPAT, 3938},
+	{0, 2 | DECOMP_COMPAT, 3940},
+	{0, 3 | DECOMP_COMPAT, 1074},
+	{0, 3 | DECOMP_COMPAT, 1077},
+	{0, 3 | DECOMP_COMPAT, 1080},
+	{0, 3 | DECOMP_COMPAT, 1083},
+	{0, 3 | DECOMP_COMPAT, 1086},
+	{0, 3 | DECOMP_COMPAT, 1089},
+	{0, 2 | DECOMP_COMPAT, 3942},
+	{0, 2 | DECOMP_COMPAT, 3944},
+	{0, 2 | DECOMP_COMPAT, 3946},
+	{0, 2 | DECOMP_COMPAT, 360},
+	{0, 2 | DECOMP_COMPAT, 3948},
+	{0, 2 | DECOMP_COMPAT, 3950},
+	{0, 2 | DECOMP_COMPAT, 3952},
+	{0, 2 | DECOMP_COMPAT, 3954},
+	{0, 2 | DECOMP_COMPAT, 3956},
+	{0, 2 | DECOMP_COMPAT, 3958},
+	{0, 2 | DECOMP_COMPAT, 3960},
+	{0, 2 | DECOMP_COMPAT, 3962},
+	{0, 2 | DECOMP_COMPAT, 3964},
+	{0, 2 | DECOMP_COMPAT, 3966},
+	{0, 2 | DECOMP_COMPAT, 3968},
+	{0, 2 | DECOMP_COMPAT, 3970},
+	{0, 2 | DECOMP_COMPAT, 3972},
+	{0, 2 | DECOMP_COMPAT, 3974},
+	{0, 2 | DECOMP_COMPAT, 1265},
+	{0, 2 | DECOMP_COMPAT, 3976},
+	{0, 2 | DECOMP_COMPAT, 3978},
+	{0, 2 | DECOMP_COMPAT, 3980},
+	{0, 2 | DECOMP_COMPAT, 3982},
+	{0, 2 | DECOMP_COMPAT, 3984},
+	{0, 2 | DECOMP_COMPAT, 6},
+	{0, 2 | DECOMP_COMPAT, 3986},
+	{0, 2 | DECOMP_COMPAT, 3988},
+	{0, 2 | DECOMP_COMPAT, 11},
+	{0, 2 | DECOMP_COMPAT, 3990},
+	{0, 2 | DECOMP_COMPAT, 3992},
+	{0, 2 | DECOMP_COMPAT, 1161},
+	{0, 2 | DECOMP_COMPAT, 3994},
+	{0, 3 | DECOMP_COMPAT, 1092},
+	{0, 3 | DECOMP_COMPAT, 1095},
+	{0, 3 | DECOMP_COMPAT, 1098},
+	{0, 2 | DECOMP_COMPAT, 3996},
+	{0, 2 | DECOMP_COMPAT, 3998},
+	{0, 2 | DECOMP_COMPAT, 4000},
+	{0, 2 | DECOMP_COMPAT, 4002},
+	{0, 2 | DECOMP_COMPAT, 4004},
+	{0, 2 | DECOMP_COMPAT, 4006},
+	{0, 2 | DECOMP_COMPAT, 4008},
+	{0, 2 | DECOMP_COMPAT, 4010},
+	{0, 2 | DECOMP_COMPAT, 4012},
+	{0, 2 | DECOMP_COMPAT, 4014},
+	{0, 2 | DECOMP_COMPAT, 1168},
+	{0, 2 | DECOMP_COMPAT, 1213},
+	{0, 2 | DECOMP_COMPAT, 1138},
+	{0, 2 | DECOMP_COMPAT, 1159},
+	{0, 2 | DECOMP_COMPAT, 1285},
+	{0, 2 | DECOMP_COMPAT, 1273},
+	{0, 2 | DECOMP_COMPAT, 4016},
+	{0, 2 | DECOMP_COMPAT, 4018},
+	{0, 2 | DECOMP_COMPAT, 4020},
+	{0, 2 | DECOMP_COMPAT, 4022},
+	{0, 2 | DECOMP_COMPAT, 1158},
+	{0, 2 | DECOMP_COMPAT, 1155},
+	{0, 2 | DECOMP_COMPAT, 4024},
+	{0, 2 | DECOMP_COMPAT, 4026},
+	{0, 2 | DECOMP_COMPAT, 4028},
+	{0, 2 | DECOMP_COMPAT, 4030},
+	{0, 2 | DECOMP_COMPAT, 4032},
+	{0, 2 | DECOMP_COMPAT, 4034},
+	{0, 3 | DECOMP_COMPAT, 1101},
+	{0, 3 | DECOMP_COMPAT, 1104},
+	{0, 3 | DECOMP_COMPAT, 1107},
+	{0, 3 | DECOMP_COMPAT, 1110},
+	{0, 3 | DECOMP_COMPAT, 1113},
+	{0, 3 | DECOMP_COMPAT, 1116},
+	{0, 3 | DECOMP_COMPAT, 1119},
+	{0, 3 | DECOMP_COMPAT, 1122},
+	{0, 3 | DECOMP_COMPAT, 1125},
+	{0, 3 | DECOMP_COMPAT, 1128},
+	{0, 3 | DECOMP_COMPAT, 1131},
+	{0, 3 | DECOMP_COMPAT, 1134},
+	{0, 3 | DECOMP_COMPAT, 1137},
+	{0, 3 | DECOMP_COMPAT, 1140},
+	{0, 3 | DECOMP_COMPAT, 1143},
+	{0, 3 | DECOMP_COMPAT, 1146},
+	{0, 3 | DECOMP_COMPAT, 1149},
+	{0, 3 | DECOMP_COMPAT, 1152},
+	{0, 3 | DECOMP_COMPAT, 1155},
+	{0, 3 | DECOMP_COMPAT, 1158},
+	{0, 3 | DECOMP_COMPAT, 1161},
+	{0, 3 | DECOMP_COMPAT, 1164},
+	{0, 3 | DECOMP_COMPAT, 1167},
+	{0, 3 | DECOMP_COMPAT, 1170},
+	{0, 3 | DECOMP_COMPAT, 1173},
+	{0, 3 | DECOMP_COMPAT, 1176},
+	{0, 3 | DECOMP_COMPAT, 1179},
+	{0, 3 | DECOMP_COMPAT, 1182},
+	{0, 3 | DECOMP_COMPAT, 1185},
+	{0, 3 | DECOMP_COMPAT, 1188},
+	{0, 3 | DECOMP_COMPAT, 1191},
+	{0, 3 | DECOMP_COMPAT, 1194},
+	{0, 3 | DECOMP_COMPAT, 1197},
+	{0, 3 | DECOMP_COMPAT, 1200},
+	{0, 3 | DECOMP_COMPAT, 1203},
+	{0, 3 | DECOMP_COMPAT, 1206},
+	{0, 3 | DECOMP_COMPAT, 1209},
+	{0, 3 | DECOMP_COMPAT, 1212},
+	{0, 3 | DECOMP_COMPAT, 1215},
+	{0, 3 | DECOMP_COMPAT, 1218},
+	{0, 3 | DECOMP_COMPAT, 1221},
+	{0, 3 | DECOMP_COMPAT, 1224},
+	{0, 3 | DECOMP_COMPAT, 1227},
+	{0, 3 | DECOMP_COMPAT, 362},
+	{0, 3 | DECOMP_COMPAT, 1230},
+	{0, 3 | DECOMP_COMPAT, 1233},
+	{0, 3 | DECOMP_COMPAT, 1236},
+	{0, 3 | DECOMP_COMPAT, 1120},
+	{0, 3 | DECOMP_COMPAT, 1239},
+	{0, 3 | DECOMP_COMPAT, 1242},
+	{0, 3 | DECOMP_COMPAT, 1245},
+	{0, 3 | DECOMP_COMPAT, 1248},
+	{0, 3 | DECOMP_COMPAT, 1251},
+	{0, 3 | DECOMP_COMPAT, 1254},
+	{0, 3 | DECOMP_COMPAT, 1257},
+	{0, 3 | DECOMP_COMPAT, 1260},
+	{0, 3 | DECOMP_COMPAT, 1263},
+	{0, 3 | DECOMP_COMPAT, 1266},
+	{0, 3 | DECOMP_COMPAT, 1269},
+	{0, 3 | DECOMP_COMPAT, 1272},
+	{0, 3 | DECOMP_COMPAT, 1275},
+	{0, 3 | DECOMP_COMPAT, 1278},
+	{0, 3 | DECOMP_COMPAT, 1281},
+	{0, 3 | DECOMP_COMPAT, 1284},
+	{0, 3 | DECOMP_COMPAT, 1287},
+	{0, 3 | DECOMP_COMPAT, 1290},
+	{0, 3 | DECOMP_COMPAT, 1293},
+	{0, 3 | DECOMP_COMPAT, 1296},
+	{0, 3 | DECOMP_COMPAT, 1299},
+	{0, 3 | DECOMP_COMPAT, 1302},
+	{0, 3 | DECOMP_COMPAT, 1305},
+	{0, 3 | DECOMP_COMPAT, 1308},
+	{0, 3 | DECOMP_COMPAT, 1311},
+	{0, 3 | DECOMP_COMPAT, 1314},
+	{0, 3 | DECOMP_COMPAT, 1317},
+	{0, 3 | DECOMP_COMPAT, 1320},
+	{0, 3 | DECOMP_COMPAT, 1323},
+	{0, 3 | DECOMP_COMPAT, 1326},
+	{0, 3 | DECOMP_COMPAT, 1329},
+	{0, 3 | DECOMP_COMPAT, 1332},
+	{0, 3 | DECOMP_COMPAT, 1335},
+	{0, 3 | DECOMP_COMPAT, 1338},
+	{0, 3 | DECOMP_COMPAT, 1341},
+	{0, 3 | DECOMP_COMPAT, 1344},
+	{0, 3 | DECOMP_COMPAT, 1347},
+	{0, 3 | DECOMP_COMPAT, 1350},
+	{0, 3 | DECOMP_COMPAT, 1353},
+	{0, 3 | DECOMP_COMPAT, 1356},
+	{0, 3 | DECOMP_COMPAT, 1359},
+	{0, 3 | DECOMP_COMPAT, 1362},
+	{0, 3 | DECOMP_COMPAT, 1365},
+	{0, 3 | DECOMP_COMPAT, 1368},
+	{0, 3 | DECOMP_COMPAT, 1371},
+	{0, 3 | DECOMP_COMPAT, 1374},
+	{0, 3 | DECOMP_COMPAT, 1377},
+	{0, 3 | DECOMP_COMPAT, 1380},
+	{0, 4 | DECOMP_COMPAT, 4},
+	{0, 4 | DECOMP_COMPAT, 358},
+	{0, 4 | DECOMP_COMPAT, 362},
+	{0, 4 | DECOMP_COMPAT, 366},
+	{0, 4 | DECOMP_COMPAT, 370},
+	{0, 4 | DECOMP_COMPAT, 9},
+	{0, 4 | DECOMP_COMPAT, 14},
+	{0, 3 | DECOMP_COMPAT, 0},
+	{0, 18 | DECOMP_COMPAT, 0},
+	{0, 8 | DECOMP_COMPAT, 18},
+	{0, 4 | DECOMP_COMPAT, 374},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3001},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3002},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0021},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3016},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3017},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2026},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2025},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2014},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2013},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3014},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3015},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3010},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3011},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3008},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3009},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0023},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0026},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0024},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0025},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0040},
+	{0, 2 | DECOMP_COMPAT, 4036},
+	{0, 2 | DECOMP_COMPAT, 4038},
+	{0, 2 | DECOMP_COMPAT, 1074},
+	{0, 2 | DECOMP_COMPAT, 1077},
+	{0, 2 | DECOMP_COMPAT, 1080},
+	{0, 2 | DECOMP_COMPAT, 1092},
+	{0, 2 | DECOMP_COMPAT, 1083},
+	{0, 2 | DECOMP_COMPAT, 1095},
+	{0, 2 | DECOMP_COMPAT, 1086},
+	{0, 2 | DECOMP_COMPAT, 1098},
+	{0, 2 | DECOMP_COMPAT, 1089},
+	{0, 2 | DECOMP_COMPAT, 4040},
+	{0, 2 | DECOMP_COMPAT, 4042},
+	{0, 2 | DECOMP_COMPAT, 4044},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0621},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0622},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0623},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0624},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0625},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0629},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0, 2 | DECOMP_COMPAT, 4046},
+	{0, 2 | DECOMP_COMPAT, 4048},
+	{0, 2 | DECOMP_COMPAT, 4050},
+	{0, 2 | DECOMP_COMPAT, 22},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0022},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0027},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0060},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2985},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2986},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30FB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30FC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3099},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x309A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3164},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3131},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3132},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3133},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3134},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3135},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3136},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3137},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3138},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3139},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3140},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3141},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3142},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3143},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3144},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3145},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3146},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3147},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3148},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3149},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3150},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3151},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3152},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3153},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3154},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3155},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3156},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3157},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3158},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3159},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3160},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3161},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3162},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3163},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00AC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00AF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x20A9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2502},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2190},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2191},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2192},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2193},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x25A0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x25CB},
+	{0, 2, 4052},
+	{0, 2, 4054},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02D0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02D1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00E6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0299},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0253},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB66},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0256},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0257},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D91},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0258},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0264},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0262},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0260},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0267},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0284},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02AA},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02AB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026C},
+	{0, 1 | DECOMP_COMPAT, 4195},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA78E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026E},
+	{0, 1 | DECOMP_COMPAT, 4196},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028E},
+	{0, 1 | DECOMP_COMPAT, 4197},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00F8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0276},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0277},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027A},
+	{0, 1 | DECOMP_COMPAT, 4198},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0280},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB67},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0288},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2C71},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x02A2},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0298},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01C0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01C1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01C2},
+	{0, 1 | DECOMP_COMPAT, 4199},
+	{0, 1 | DECOMP_COMPAT, 4200},
+	{0, 2, 4056},
+	{0, 2, 4058},
+	{0, 2, 4060},
+	{0, 2, 4062},
+	{0, 2, 4064},
+	{0, 2, 4066},
+	{0, 2, 4068},
+	{0, 2, 4070},
+	{0, 2, 4072},
+	{0, 2, 4074},
+	{0, 2, 4076},
+	{0, 2, 4078},
+	{0, 2, 4080},
+	{0, 2, 4082},
+	{0, 2, 4084},
+	{0, 2, 4086},
+	{0, 2, 4088},
+	{0, 2, 4090},
+	{0, 2, 4092},
+	{0, 2, 4094},
+	{0, 2, 4096},
+	{0, 2, 4098},
+	{0, 2, 4100},
+	{0, 2, 4102},
+	{0, 2, 4104},
+	{0, 2, 4106},
+	{0, 2, 4108},
+	{0, 2, 4110},
+	{0, 2, 4112},
+	{0, 2, 4114},
+	{0, 2, 4116},
+	{6, 0, 0},
+	{0, 2 | DECOMP_NO_COMPOSE, 4118},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4120},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4122},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4124},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4126},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4128},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4130},	/* in exclusion list */
+	{226, 0, 0},
+	{0, 2 | DECOMP_NO_COMPOSE, 4132},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4134},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4136},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4138},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4140},	/* in exclusion list */
+	{0, 2 | DECOMP_NO_COMPOSE, 4142},	/* in exclusion list */
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0131},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0237},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03DC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03DD},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0430},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0431},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0432},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0433},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0434},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0435},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0436},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0437},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0438},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0440},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0441},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0442},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0443},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0444},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0445},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0446},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0447},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0448},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044B},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA689},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04D9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0456},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0458},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04E9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04AF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04CF},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0491},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0455},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x045F},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04AB},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA651},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x04B1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066E},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A1},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066F},
+	{0, 2 | DECOMP_COMPAT, 493},
+	{0, 2 | DECOMP_COMPAT, 4144},
+	{0, 2 | DECOMP_COMPAT, 4146},
+	{0, 2 | DECOMP_COMPAT, 4148},
+	{0, 2 | DECOMP_COMPAT, 4150},
+	{0, 2 | DECOMP_COMPAT, 4152},
+	{0, 2 | DECOMP_COMPAT, 4154},
+	{0, 2 | DECOMP_COMPAT, 4156},
+	{0, 2 | DECOMP_COMPAT, 4158},
+	{0, 2 | DECOMP_COMPAT, 4160},
+	{0, 2 | DECOMP_COMPAT, 4162},
+	{0, 3 | DECOMP_COMPAT, 1383},
+	{0, 3 | DECOMP_COMPAT, 1386},
+	{0, 3 | DECOMP_COMPAT, 1389},
+	{0, 3 | DECOMP_COMPAT, 1392},
+	{0, 3 | DECOMP_COMPAT, 1395},
+	{0, 3 | DECOMP_COMPAT, 1398},
+	{0, 3 | DECOMP_COMPAT, 1401},
+	{0, 3 | DECOMP_COMPAT, 1404},
+	{0, 3 | DECOMP_COMPAT, 1407},
+	{0, 3 | DECOMP_COMPAT, 1410},
+	{0, 3 | DECOMP_COMPAT, 1413},
+	{0, 3 | DECOMP_COMPAT, 1416},
+	{0, 3 | DECOMP_COMPAT, 1419},
+	{0, 3 | DECOMP_COMPAT, 1422},
+	{0, 3 | DECOMP_COMPAT, 1425},
+	{0, 3 | DECOMP_COMPAT, 1428},
+	{0, 3 | DECOMP_COMPAT, 1431},
+	{0, 3 | DECOMP_COMPAT, 1434},
+	{0, 3 | DECOMP_COMPAT, 1437},
+	{0, 3 | DECOMP_COMPAT, 1440},
+	{0, 3 | DECOMP_COMPAT, 1443},
+	{0, 3 | DECOMP_COMPAT, 1446},
+	{0, 3 | DECOMP_COMPAT, 1449},
+	{0, 3 | DECOMP_COMPAT, 1452},
+	{0, 3 | DECOMP_COMPAT, 1455},
+	{0, 3 | DECOMP_COMPAT, 1458},
+	{0, 3 | DECOMP_COMPAT, 1461},
+	{0, 2 | DECOMP_COMPAT, 4164},
+	{0, 2 | DECOMP_COMPAT, 4166},
+	{0, 2 | DECOMP_COMPAT, 4168},
+	{0, 2 | DECOMP_COMPAT, 4170},
+	{0, 2 | DECOMP_COMPAT, 4172},
+	{0, 3 | DECOMP_COMPAT, 1464},
+	{0, 2 | DECOMP_COMPAT, 4174},
+	{0, 2 | DECOMP_COMPAT, 4176},
+	{0, 2 | DECOMP_COMPAT, 4178},
+	{0, 2 | DECOMP_COMPAT, 4180},
+	{0, 2 | DECOMP_COMPAT, 4182},
+	{0, 2 | DECOMP_COMPAT, 4184},
+	{0, 2 | DECOMP_COMPAT, 4186},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B57},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53CC},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C7},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x591A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x89E3},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EA4},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6620},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7121},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6599},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x524D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F8C},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x518D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65B0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x521D},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7D42},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CA9},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x58F0},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5439},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6F14},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6295},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6355},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x904A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6307},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6253},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7981},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7A7A},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5408},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6E80},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7533},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5272},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x55B6},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x914D},
+	{0, 3 | DECOMP_COMPAT, 1467},
+	{0, 3 | DECOMP_COMPAT, 1470},
+	{0, 3 | DECOMP_COMPAT, 1473},
+	{0, 3 | DECOMP_COMPAT, 1476},
+	{0, 3 | DECOMP_COMPAT, 1479},
+	{0, 3 | DECOMP_COMPAT, 1482},
+	{0, 3 | DECOMP_COMPAT, 1485},
+	{0, 3 | DECOMP_COMPAT, 1488},
+	{0, 3 | DECOMP_COMPAT, 1491},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F97},
+	{0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53EF},
+	{0, 1 | DECOMP_INLINE, 0x4E3D},
+	{0, 1 | DECOMP_INLINE, 0x4E38},
+	{0, 1 | DECOMP_INLINE, 0x4E41},
+	{0, 1, 4201},
+	{0, 1 | DECOMP_INLINE, 0x4F60},
+	{0, 1 | DECOMP_INLINE, 0x4FBB},
+	{0, 1 | DECOMP_INLINE, 0x5002},
+	{0, 1 | DECOMP_INLINE, 0x507A},
+	{0, 1 | DECOMP_INLINE, 0x5099},
+	{0, 1 | DECOMP_INLINE, 0x50CF},
+	{0, 1 | DECOMP_INLINE, 0x349E},
+	{0, 1, 4202},
+	{0, 1 | DECOMP_INLINE, 0x5154},
+	{0, 1 | DECOMP_INLINE, 0x5164},
+	{0, 1 | DECOMP_INLINE, 0x5177},
+	{0, 1, 4203},
+	{0, 1 | DECOMP_INLINE, 0x34B9},
+	{0, 1 | DECOMP_INLINE, 0x5167},
+	{0, 1 | DECOMP_INLINE, 0x518D},
+	{0, 1, 4204},
+	{0, 1 | DECOMP_INLINE, 0x5197},
+	{0, 1 | DECOMP_INLINE, 0x51A4},
+	{0, 1 | DECOMP_INLINE, 0x4ECC},
+	{0, 1 | DECOMP_INLINE, 0x51AC},
+	{0, 1, 4205},
+	{0, 1 | DECOMP_INLINE, 0x51F5},
+	{0, 1 | DECOMP_INLINE, 0x5203},
+	{0, 1 | DECOMP_INLINE, 0x34DF},
+	{0, 1 | DECOMP_INLINE, 0x523B},
+	{0, 1 | DECOMP_INLINE, 0x5246},
+	{0, 1 | DECOMP_INLINE, 0x5272},
+	{0, 1 | DECOMP_INLINE, 0x5277},
+	{0, 1 | DECOMP_INLINE, 0x3515},
+	{0, 1 | DECOMP_INLINE, 0x5305},
+	{0, 1 | DECOMP_INLINE, 0x5306},
+	{0, 1 | DECOMP_INLINE, 0x5349},
+	{0, 1 | DECOMP_INLINE, 0x535A},
+	{0, 1 | DECOMP_INLINE, 0x5373},
+	{0, 1 | DECOMP_INLINE, 0x537D},
+	{0, 1 | DECOMP_INLINE, 0x537F},
+	{0, 1, 4206},
+	{0, 1 | DECOMP_INLINE, 0x7070},
+	{0, 1 | DECOMP_INLINE, 0x53CA},
+	{0, 1 | DECOMP_INLINE, 0x53DF},
+	{0, 1, 4207},
+	{0, 1 | DECOMP_INLINE, 0x53EB},
+	{0, 1 | DECOMP_INLINE, 0x53F1},
+	{0, 1 | DECOMP_INLINE, 0x5406},
+	{0, 1 | DECOMP_INLINE, 0x549E},
+	{0, 1 | DECOMP_INLINE, 0x5438},
+	{0, 1 | DECOMP_INLINE, 0x5448},
+	{0, 1 | DECOMP_INLINE, 0x5468},
+	{0, 1 | DECOMP_INLINE, 0x54A2},
+	{0, 1 | DECOMP_INLINE, 0x54F6},
+	{0, 1 | DECOMP_INLINE, 0x5510},
+	{0, 1 | DECOMP_INLINE, 0x5553},
+	{0, 1 | DECOMP_INLINE, 0x5563},
+	{0, 1 | DECOMP_INLINE, 0x5584},
+	{0, 1 | DECOMP_INLINE, 0x55AB},
+	{0, 1 | DECOMP_INLINE, 0x55B3},
+	{0, 1 | DECOMP_INLINE, 0x55C2},
+	{0, 1 | DECOMP_INLINE, 0x5716},
+	{0, 1 | DECOMP_INLINE, 0x5717},
+	{0, 1 | DECOMP_INLINE, 0x5651},
+	{0, 1 | DECOMP_INLINE, 0x5674},
+	{0, 1 | DECOMP_INLINE, 0x58EE},
+	{0, 1 | DECOMP_INLINE, 0x57CE},
+	{0, 1 | DECOMP_INLINE, 0x57F4},
+	{0, 1 | DECOMP_INLINE, 0x580D},
+	{0, 1 | DECOMP_INLINE, 0x578B},
+	{0, 1 | DECOMP_INLINE, 0x5832},
+	{0, 1 | DECOMP_INLINE, 0x5831},
+	{0, 1 | DECOMP_INLINE, 0x58AC},
+	{0, 1, 4208},
+	{0, 1 | DECOMP_INLINE, 0x58F2},
+	{0, 1 | DECOMP_INLINE, 0x58F7},
+	{0, 1 | DECOMP_INLINE, 0x5906},
+	{0, 1 | DECOMP_INLINE, 0x591A},
+	{0, 1 | DECOMP_INLINE, 0x5922},
+	{0, 1 | DECOMP_INLINE, 0x5962},
+	{0, 1, 4209},
+	{0, 1, 4210},
+	{0, 1 | DECOMP_INLINE, 0x59EC},
+	{0, 1 | DECOMP_INLINE, 0x5A1B},
+	{0, 1 | DECOMP_INLINE, 0x5A27},
+	{0, 1 | DECOMP_INLINE, 0x59D8},
+	{0, 1 | DECOMP_INLINE, 0x5A66},
+	{0, 1 | DECOMP_INLINE, 0x36EE},
+	{0, 1 | DECOMP_INLINE, 0x36FC},
+	{0, 1 | DECOMP_INLINE, 0x5B08},
+	{0, 1 | DECOMP_INLINE, 0x5B3E},
+	{0, 1, 4211},
+	{0, 1 | DECOMP_INLINE, 0x5BC3},
+	{0, 1 | DECOMP_INLINE, 0x5BD8},
+	{0, 1 | DECOMP_INLINE, 0x5BF3},
+	{0, 1, 4212},
+	{0, 1 | DECOMP_INLINE, 0x5BFF},
+	{0, 1 | DECOMP_INLINE, 0x5C06},
+	{0, 1 | DECOMP_INLINE, 0x5F53},
+	{0, 1 | DECOMP_INLINE, 0x5C22},
+	{0, 1 | DECOMP_INLINE, 0x3781},
+	{0, 1 | DECOMP_INLINE, 0x5C60},
+	{0, 1 | DECOMP_INLINE, 0x5CC0},
+	{0, 1 | DECOMP_INLINE, 0x5C8D},
+	{0, 1, 4213},
+	{0, 1 | DECOMP_INLINE, 0x5D43},
+	{0, 1, 4214},
+	{0, 1 | DECOMP_INLINE, 0x5D6E},
+	{0, 1 | DECOMP_INLINE, 0x5D6B},
+	{0, 1 | DECOMP_INLINE, 0x5D7C},
+	{0, 1 | DECOMP_INLINE, 0x5DE1},
+	{0, 1 | DECOMP_INLINE, 0x5DE2},
+	{0, 1 | DECOMP_INLINE, 0x382F},
+	{0, 1 | DECOMP_INLINE, 0x5DFD},
+	{0, 1 | DECOMP_INLINE, 0x5E28},
+	{0, 1 | DECOMP_INLINE, 0x5E3D},
+	{0, 1 | DECOMP_INLINE, 0x5E69},
+	{0, 1 | DECOMP_INLINE, 0x3862},
+	{0, 1, 4215},
+	{0, 1 | DECOMP_INLINE, 0x387C},
+	{0, 1 | DECOMP_INLINE, 0x5EB0},
+	{0, 1 | DECOMP_INLINE, 0x5EB3},
+	{0, 1 | DECOMP_INLINE, 0x5EB6},
+	{0, 1, 4216},
+	{0, 1 | DECOMP_INLINE, 0x5EFE},
+	{0, 1, 4217},
+	{0, 1 | DECOMP_INLINE, 0x8201},
+	{0, 1 | DECOMP_INLINE, 0x5F22},
+	{0, 1 | DECOMP_INLINE, 0x38C7},
+	{0, 1, 4218},
+	{0, 1, 4219},
+	{0, 1 | DECOMP_INLINE, 0x5F62},
+	{0, 1 | DECOMP_INLINE, 0x5F6B},
+	{0, 1 | DECOMP_INLINE, 0x38E3},
+	{0, 1 | DECOMP_INLINE, 0x5F9A},
+	{0, 1 | DECOMP_INLINE, 0x5FCD},
+	{0, 1 | DECOMP_INLINE, 0x5FD7},
+	{0, 1 | DECOMP_INLINE, 0x5FF9},
+	{0, 1 | DECOMP_INLINE, 0x6081},
+	{0, 1 | DECOMP_INLINE, 0x393A},
+	{0, 1 | DECOMP_INLINE, 0x391C},
+	{0, 1, 4220},
+	{0, 1 | DECOMP_INLINE, 0x60C7},
+	{0, 1 | DECOMP_INLINE, 0x6148},
+	{0, 1 | DECOMP_INLINE, 0x614C},
+	{0, 1 | DECOMP_INLINE, 0x617A},
+	{0, 1 | DECOMP_INLINE, 0x61B2},
+	{0, 1 | DECOMP_INLINE, 0x61A4},
+	{0, 1 | DECOMP_INLINE, 0x61AF},
+	{0, 1 | DECOMP_INLINE, 0x61DE},
+	{0, 1 | DECOMP_INLINE, 0x6210},
+	{0, 1 | DECOMP_INLINE, 0x621B},
+	{0, 1 | DECOMP_INLINE, 0x625D},
+	{0, 1 | DECOMP_INLINE, 0x62B1},
+	{0, 1 | DECOMP_INLINE, 0x62D4},
+	{0, 1 | DECOMP_INLINE, 0x6350},
+	{0, 1, 4221},
+	{0, 1 | DECOMP_INLINE, 0x633D},
+	{0, 1 | DECOMP_INLINE, 0x62FC},
+	{0, 1 | DECOMP_INLINE, 0x6368},
+	{0, 1 | DECOMP_INLINE, 0x6383},
+	{0, 1 | DECOMP_INLINE, 0x63E4},
+	{0, 1, 4222},
+	{0, 1 | DECOMP_INLINE, 0x6422},
+	{0, 1 | DECOMP_INLINE, 0x63C5},
+	{0, 1 | DECOMP_INLINE, 0x63A9},
+	{0, 1 | DECOMP_INLINE, 0x3A2E},
+	{0, 1 | DECOMP_INLINE, 0x6469},
+	{0, 1 | DECOMP_INLINE, 0x647E},
+	{0, 1 | DECOMP_INLINE, 0x649D},
+	{0, 1 | DECOMP_INLINE, 0x6477},
+	{0, 1 | DECOMP_INLINE, 0x3A6C},
+	{0, 1 | DECOMP_INLINE, 0x656C},
+	{0, 1, 4223},
+	{0, 1 | DECOMP_INLINE, 0x65E3},
+	{0, 1 | DECOMP_INLINE, 0x66F8},
+	{0, 1 | DECOMP_INLINE, 0x6649},
+	{0, 1 | DECOMP_INLINE, 0x3B19},
+	{0, 1 | DECOMP_INLINE, 0x3B08},
+	{0, 1 | DECOMP_INLINE, 0x3AE4},
+	{0, 1 | DECOMP_INLINE, 0x5192},
+	{0, 1 | DECOMP_INLINE, 0x5195},
+	{0, 1 | DECOMP_INLINE, 0x6700},
+	{0, 1 | DECOMP_INLINE, 0x669C},
+	{0, 1 | DECOMP_INLINE, 0x80AD},
+	{0, 1 | DECOMP_INLINE, 0x43D9},
+	{0, 1 | DECOMP_INLINE, 0x6721},
+	{0, 1 | DECOMP_INLINE, 0x675E},
+	{0, 1 | DECOMP_INLINE, 0x6753},
+	{0, 1, 4224},
+	{0, 1 | DECOMP_INLINE, 0x3B49},
+	{0, 1 | DECOMP_INLINE, 0x67FA},
+	{0, 1 | DECOMP_INLINE, 0x6785},
+	{0, 1 | DECOMP_INLINE, 0x6852},
+	{0, 1, 4225},
+	{0, 1 | DECOMP_INLINE, 0x688E},
+	{0, 1 | DECOMP_INLINE, 0x681F},
+	{0, 1 | DECOMP_INLINE, 0x6914},
+	{0, 1 | DECOMP_INLINE, 0x6942},
+	{0, 1 | DECOMP_INLINE, 0x69A3},
+	{0, 1 | DECOMP_INLINE, 0x69EA},
+	{0, 1 | DECOMP_INLINE, 0x6AA8},
+	{0, 1, 4226},
+	{0, 1 | DECOMP_INLINE, 0x6ADB},
+	{0, 1 | DECOMP_INLINE, 0x3C18},
+	{0, 1 | DECOMP_INLINE, 0x6B21},
+	{0, 1, 4227},
+	{0, 1 | DECOMP_INLINE, 0x6B54},
+	{0, 1 | DECOMP_INLINE, 0x3C4E},
+	{0, 1 | DECOMP_INLINE, 0x6B72},
+	{0, 1 | DECOMP_INLINE, 0x6B9F},
+	{0, 1 | DECOMP_INLINE, 0x6BBB},
+	{0, 1, 4228},
+	{0, 1, 4229},
+	{0, 1, 4230},
+	{0, 1 | DECOMP_INLINE, 0x6C4E},
+	{0, 1, 4231},
+	{0, 1 | DECOMP_INLINE, 0x6CBF},
+	{0, 1 | DECOMP_INLINE, 0x6CCD},
+	{0, 1 | DECOMP_INLINE, 0x6C67},
+	{0, 1 | DECOMP_INLINE, 0x6D16},
+	{0, 1 | DECOMP_INLINE, 0x6D3E},
+	{0, 1 | DECOMP_INLINE, 0x6D69},
+	{0, 1 | DECOMP_INLINE, 0x6D78},
+	{0, 1 | DECOMP_INLINE, 0x6D85},
+	{0, 1, 4232},
+	{0, 1 | DECOMP_INLINE, 0x6D34},
+	{0, 1 | DECOMP_INLINE, 0x6E2F},
+	{0, 1 | DECOMP_INLINE, 0x6E6E},
+	{0, 1 | DECOMP_INLINE, 0x3D33},
+	{0, 1 | DECOMP_INLINE, 0x6EC7},
+	{0, 1, 4233},
+	{0, 1 | DECOMP_INLINE, 0x6DF9},
+	{0, 1 | DECOMP_INLINE, 0x6F6E},
+	{0, 1, 4234},
+	{0, 1, 4235},
+	{0, 1 | DECOMP_INLINE, 0x6FC6},
+	{0, 1 | DECOMP_INLINE, 0x7039},
+	{0, 1 | DECOMP_INLINE, 0x701B},
+	{0, 1 | DECOMP_INLINE, 0x3D96},
+	{0, 1 | DECOMP_INLINE, 0x704A},
+	{0, 1 | DECOMP_INLINE, 0x707D},
+	{0, 1 | DECOMP_INLINE, 0x7077},
+	{0, 1 | DECOMP_INLINE, 0x70AD},
+	{0, 1, 4236},
+	{0, 1 | DECOMP_INLINE, 0x7145},
+	{0, 1, 4237},
+	{0, 1 | DECOMP_INLINE, 0x719C},
+	{0, 1, 4238},
+	{0, 1 | DECOMP_INLINE, 0x7228},
+	{0, 1 | DECOMP_INLINE, 0x7250},
+	{0, 1, 4239},
+	{0, 1 | DECOMP_INLINE, 0x7280},
+	{0, 1 | DECOMP_INLINE, 0x7295},
+	{0, 1, 4240},
+	{0, 1, 4241},
+	{0, 1 | DECOMP_INLINE, 0x737A},
+	{0, 1 | DECOMP_INLINE, 0x738B},
+	{0, 1 | DECOMP_INLINE, 0x3EAC},
+	{0, 1 | DECOMP_INLINE, 0x73A5},
+	{0, 1 | DECOMP_INLINE, 0x3EB8},
+	{0, 1 | DECOMP_INLINE, 0x7447},
+	{0, 1 | DECOMP_INLINE, 0x745C},
+	{0, 1 | DECOMP_INLINE, 0x7485},
+	{0, 1 | DECOMP_INLINE, 0x74CA},
+	{0, 1 | DECOMP_INLINE, 0x3F1B},
+	{0, 1 | DECOMP_INLINE, 0x7524},
+	{0, 1, 4242},
+	{0, 1 | DECOMP_INLINE, 0x753E},
+	{0, 1, 4243},
+	{0, 1, 4244},
+	{0, 1 | DECOMP_INLINE, 0x7610},
+	{0, 1, 4245},
+	{0, 1, 4246},
+	{0, 1, 4247},
+	{0, 1 | DECOMP_INLINE, 0x3FFC},
+	{0, 1 | DECOMP_INLINE, 0x4008},
+	{0, 1, 4248},
+	{0, 1, 4249},
+	{0, 1, 4250},
+	{0, 1, 4251},
+	{0, 1 | DECOMP_INLINE, 0x771E},
+	{0, 1 | DECOMP_INLINE, 0x771F},
+	{0, 1 | DECOMP_INLINE, 0x778B},
+	{0, 1 | DECOMP_INLINE, 0x4046},
+	{0, 1 | DECOMP_INLINE, 0x4096},
+	{0, 1, 4252},
+	{0, 1 | DECOMP_INLINE, 0x784E},
+	{0, 1 | DECOMP_INLINE, 0x40E3},
+	{0, 1, 4253},
+	{0, 1, 4254},
+	{0, 1, 4255},
+	{0, 1 | DECOMP_INLINE, 0x79EB},
+	{0, 1 | DECOMP_INLINE, 0x412F},
+	{0, 1 | DECOMP_INLINE, 0x7A4A},
+	{0, 1 | DECOMP_INLINE, 0x7A4F},
+	{0, 1, 4256},
+	{0, 1, 4257},
+	{0, 1 | DECOMP_INLINE, 0x7AEE},
+	{0, 1 | DECOMP_INLINE, 0x4202},
+	{0, 1, 4258},
+	{0, 1 | DECOMP_INLINE, 0x7BC6},
+	{0, 1 | DECOMP_INLINE, 0x7BC9},
+	{0, 1 | DECOMP_INLINE, 0x4227},
+	{0, 1, 4259},
+	{0, 1 | DECOMP_INLINE, 0x7CD2},
+	{0, 1 | DECOMP_INLINE, 0x42A0},
+	{0, 1 | DECOMP_INLINE, 0x7CE8},
+	{0, 1 | DECOMP_INLINE, 0x7CE3},
+	{0, 1 | DECOMP_INLINE, 0x7D00},
+	{0, 1, 4260},
+	{0, 1 | DECOMP_INLINE, 0x7D63},
+	{0, 1 | DECOMP_INLINE, 0x4301},
+	{0, 1 | DECOMP_INLINE, 0x7DC7},
+	{0, 1 | DECOMP_INLINE, 0x7E02},
+	{0, 1 | DECOMP_INLINE, 0x7E45},
+	{0, 1 | DECOMP_INLINE, 0x4334},
+	{0, 1, 4261},
+	{0, 1, 4262},
+	{0, 1 | DECOMP_INLINE, 0x4359},
+	{0, 1, 4263},
+	{0, 1 | DECOMP_INLINE, 0x7F7A},
+	{0, 1, 4264},
+	{0, 1 | DECOMP_INLINE, 0x7F95},
+	{0, 1 | DECOMP_INLINE, 0x7FFA},
+	{0, 1, 4265},
+	{0, 1, 4266},
+	{0, 1 | DECOMP_INLINE, 0x8060},
+	{0, 1, 4267},
+	{0, 1 | DECOMP_INLINE, 0x8070},
+	{0, 1, 4268},
+	{0, 1 | DECOMP_INLINE, 0x43D5},
+	{0, 1 | DECOMP_INLINE, 0x80B2},
+	{0, 1 | DECOMP_INLINE, 0x8103},
+	{0, 1 | DECOMP_INLINE, 0x440B},
+	{0, 1 | DECOMP_INLINE, 0x813E},
+	{0, 1 | DECOMP_INLINE, 0x5AB5},
+	{0, 1, 4269},
+	{0, 1, 4270},
+	{0, 1, 4271},
+	{0, 1, 4272},
+	{0, 1 | DECOMP_INLINE, 0x8204},
+	{0, 1 | DECOMP_INLINE, 0x8F9E},
+	{0, 1 | DECOMP_INLINE, 0x446B},
+	{0, 1 | DECOMP_INLINE, 0x8291},
+	{0, 1 | DECOMP_INLINE, 0x828B},
+	{0, 1 | DECOMP_INLINE, 0x829D},
+	{0, 1 | DECOMP_INLINE, 0x52B3},
+	{0, 1 | DECOMP_INLINE, 0x82B1},
+	{0, 1 | DECOMP_INLINE, 0x82B3},
+	{0, 1 | DECOMP_INLINE, 0x82BD},
+	{0, 1 | DECOMP_INLINE, 0x82E6},
+	{0, 1, 4273},
+	{0, 1 | DECOMP_INLINE, 0x831D},
+	{0, 1 | DECOMP_INLINE, 0x8363},
+	{0, 1 | DECOMP_INLINE, 0x83AD},
+	{0, 1 | DECOMP_INLINE, 0x8323},
+	{0, 1 | DECOMP_INLINE, 0x83BD},
+	{0, 1 | DECOMP_INLINE, 0x83E7},
+	{0, 1 | DECOMP_INLINE, 0x8353},
+	{0, 1 | DECOMP_INLINE, 0x83CA},
+	{0, 1 | DECOMP_INLINE, 0x83CC},
+	{0, 1 | DECOMP_INLINE, 0x83DC},
+	{0, 1, 4274},
+	{0, 1, 4275},
+	{0, 1, 4276},
+	{0, 1 | DECOMP_INLINE, 0x452B},
+	{0, 1 | DECOMP_INLINE, 0x84F1},
+	{0, 1 | DECOMP_INLINE, 0x84F3},
+	{0, 1 | DECOMP_INLINE, 0x8516},
+	{0, 1, 4277},
+	{0, 1 | DECOMP_INLINE, 0x8564},
+	{0, 1, 4278},
+	{0, 1 | DECOMP_INLINE, 0x455D},
+	{0, 1 | DECOMP_INLINE, 0x4561},
+	{0, 1, 4279},
+	{0, 1, 4280},
+	{0, 1 | DECOMP_INLINE, 0x456B},
+	{0, 1 | DECOMP_INLINE, 0x8650},
+	{0, 1 | DECOMP_INLINE, 0x8667},
+	{0, 1 | DECOMP_INLINE, 0x8669},
+	{0, 1 | DECOMP_INLINE, 0x86A9},
+	{0, 1 | DECOMP_INLINE, 0x8688},
+	{0, 1 | DECOMP_INLINE, 0x870E},
+	{0, 1 | DECOMP_INLINE, 0x86E2},
+	{0, 1 | DECOMP_INLINE, 0x8728},
+	{0, 1 | DECOMP_INLINE, 0x876B},
+	{0, 1 | DECOMP_INLINE, 0x8786},
+	{0, 1 | DECOMP_INLINE, 0x45D7},
+	{0, 1 | DECOMP_INLINE, 0x87E1},
+	{0, 1 | DECOMP_INLINE, 0x8801},
+	{0, 1 | DECOMP_INLINE, 0x45F9},
+	{0, 1 | DECOMP_INLINE, 0x8860},
+	{0, 1 | DECOMP_INLINE, 0x8863},
+	{0, 1, 4281},
+	{0, 1 | DECOMP_INLINE, 0x88D7},
+	{0, 1 | DECOMP_INLINE, 0x88DE},
+	{0, 1 | DECOMP_INLINE, 0x4635},
+	{0, 1 | DECOMP_INLINE, 0x88FA},
+	{0, 1 | DECOMP_INLINE, 0x34BB},
+	{0, 1, 4282},
+	{0, 1, 4283},
+	{0, 1 | DECOMP_INLINE, 0x46BE},
+	{0, 1 | DECOMP_INLINE, 0x46C7},
+	{0, 1 | DECOMP_INLINE, 0x8AA0},
+	{0, 1 | DECOMP_INLINE, 0x8C55},
+	{0, 1, 4284},
+	{0, 1 | DECOMP_INLINE, 0x8CAB},
+	{0, 1 | DECOMP_INLINE, 0x8CC1},
+	{0, 1 | DECOMP_INLINE, 0x8D1B},
+	{0, 1 | DECOMP_INLINE, 0x8D77},
+	{0, 1, 4285},
+	{0, 1, 4286},
+	{0, 1 | DECOMP_INLINE, 0x8DCB},
+	{0, 1 | DECOMP_INLINE, 0x8DBC},
+	{0, 1 | DECOMP_INLINE, 0x8DF0},
+	{0, 1, 4287},
+	{0, 1 | DECOMP_INLINE, 0x8ED4},
+	{0, 1, 4288},
+	{0, 1, 4289},
+	{0, 1 | DECOMP_INLINE, 0x9094},
+	{0, 1 | DECOMP_INLINE, 0x90F1},
+	{0, 1 | DECOMP_INLINE, 0x9111},
+	{0, 1, 4290},
+	{0, 1 | DECOMP_INLINE, 0x911B},
+	{0, 1 | DECOMP_INLINE, 0x9238},
+	{0, 1 | DECOMP_INLINE, 0x92D7},
+	{0, 1 | DECOMP_INLINE, 0x92D8},
+	{0, 1 | DECOMP_INLINE, 0x927C},
+	{0, 1 | DECOMP_INLINE, 0x93F9},
+	{0, 1 | DECOMP_INLINE, 0x9415},
+	{0, 1, 4291},
+	{0, 1 | DECOMP_INLINE, 0x958B},
+	{0, 1 | DECOMP_INLINE, 0x4995},
+	{0, 1 | DECOMP_INLINE, 0x95B7},
+	{0, 1, 4292},
+	{0, 1 | DECOMP_INLINE, 0x49E6},
+	{0, 1 | DECOMP_INLINE, 0x96C3},
+	{0, 1 | DECOMP_INLINE, 0x5DB2},
+	{0, 1 | DECOMP_INLINE, 0x9723},
+	{0, 1, 4293},
+	{0, 1, 4294},
+	{0, 1 | DECOMP_INLINE, 0x4A6E},
+	{0, 1 | DECOMP_INLINE, 0x4A76},
+	{0, 1 | DECOMP_INLINE, 0x97E0},
+	{0, 1, 4295},
+	{0, 1 | DECOMP_INLINE, 0x4AB2},
+	{0, 1, 4296},
+	{0, 1 | DECOMP_INLINE, 0x9829},
+	{0, 1, 4297},
+	{0, 1 | DECOMP_INLINE, 0x98E2},
+	{0, 1 | DECOMP_INLINE, 0x4B33},
+	{0, 1 | DECOMP_INLINE, 0x9929},
+	{0, 1 | DECOMP_INLINE, 0x99A7},
+	{0, 1 | DECOMP_INLINE, 0x99C2},
+	{0, 1 | DECOMP_INLINE, 0x99FE},
+	{0, 1 | DECOMP_INLINE, 0x4BCE},
+	{0, 1, 4298},
+	{0, 1 | DECOMP_INLINE, 0x9C40},
+	{0, 1 | DECOMP_INLINE, 0x9CFD},
+	{0, 1 | DECOMP_INLINE, 0x4CCE},
+	{0, 1 | DECOMP_INLINE, 0x4CED},
+	{0, 1 | DECOMP_INLINE, 0x9D67},
+	{0, 1, 4299},
+	{0, 1 | DECOMP_INLINE, 0x4CF8},
+	{0, 1, 4300},
+	{0, 1, 4301},
+	{0, 1, 4302},
+	{0, 1 | DECOMP_INLINE, 0x9EBB},
+	{0, 1 | DECOMP_INLINE, 0x4D56},
+	{0, 1 | DECOMP_INLINE, 0x9EF9},
+	{0, 1 | DECOMP_INLINE, 0x9EFE},
+	{0, 1 | DECOMP_INLINE, 0x9F05},
+	{0, 1 | DECOMP_INLINE, 0x9F0F},
+	{0, 1 | DECOMP_INLINE, 0x9F16},
+	{0, 1 | DECOMP_INLINE, 0x9F3B},
+	{0, 1, 4303}
+};
 
+/* Table with sequences of codepoints for decomposition. */
+static const uint32 UnicodeDecompCodepoints[4304] =
+{
+	0x0635, 0x0644, 0x0649, 0x0020, 0x0627, 0x0644, 0x0644, 0x0647,
+	0x0020, 0x0639, 0x0644, 0x064A, 0x0647, 0x0020, 0x0648, 0x0633,
+	0x0644, 0x0645, 0x062C, 0x0644, 0x0020, 0x062C, 0x0644, 0x0627,
+	0x0644, 0x0647, 0x0028, 0x110B, 0x1169, 0x110C, 0x1165, 0x11AB,
+	0x0029, 0x0028, 0x110B, 0x1169, 0x1112, 0x116E, 0x0029, 0x30AD,
+	0x30ED, 0x30E1, 0x30FC, 0x30C8, 0x30EB, 0x0072, 0x0061, 0x0064,
+	0x2215, 0x0073, 0x00B2, 0x110E, 0x1161, 0x11B7, 0x1100, 0x1169,
+	0x30A8, 0x30B9, 0x30AF, 0x30FC, 0x30C9, 0x30AD, 0x30ED, 0x30B0,
+	0x30E9, 0x30E0, 0x30AD, 0x30ED, 0x30EF, 0x30C3, 0x30C8, 0x30B0,
+	0x30E9, 0x30E0, 0x30C8, 0x30F3, 0x30AF, 0x30EB, 0x30BC, 0x30A4,
+	0x30ED, 0x30B5, 0x30F3, 0x30C1, 0x30FC, 0x30E0, 0x30D1, 0x30FC,
+	0x30BB, 0x30F3, 0x30C8, 0x30D4, 0x30A2, 0x30B9, 0x30C8, 0x30EB,
+	0x30D5, 0x30A1, 0x30E9, 0x30C3, 0x30C9, 0x30D6, 0x30C3, 0x30B7,
+	0x30A7, 0x30EB, 0x30D8, 0x30AF, 0x30BF, 0x30FC, 0x30EB, 0x30DE,
+	0x30F3, 0x30B7, 0x30E7, 0x30F3, 0x30DF, 0x30EA, 0x30D0, 0x30FC,
+	0x30EB, 0x30EC, 0x30F3, 0x30C8, 0x30B2, 0x30F3, 0x2032, 0x2032,
+	0x2032, 0x2032, 0x0031, 0x2044, 0x0031, 0x0030, 0x0056, 0x0049,
+	0x0049, 0x0049, 0x0076, 0x0069, 0x0069, 0x0069, 0x0028, 0x0031,
+	0x0030, 0x0029, 0x0028, 0x0031, 0x0031, 0x0029, 0x0028, 0x0031,
+	0x0032, 0x0029, 0x0028, 0x0031, 0x0033, 0x0029, 0x0028, 0x0031,
+	0x0034, 0x0029, 0x0028, 0x0031, 0x0035, 0x0029, 0x0028, 0x0031,
+	0x0036, 0x0029, 0x0028, 0x0031, 0x0037, 0x0029, 0x0028, 0x0031,
+	0x0038, 0x0029, 0x0028, 0x0031, 0x0039, 0x0029, 0x0028, 0x0032,
+	0x0030, 0x0029, 0x222B, 0x222B, 0x222B, 0x222B, 0x0028, 0x1100,
+	0x1161, 0x0029, 0x0028, 0x1102, 0x1161, 0x0029, 0x0028, 0x1103,
+	0x1161, 0x0029, 0x0028, 0x1105, 0x1161, 0x0029, 0x0028, 0x1106,
+	0x1161, 0x0029, 0x0028, 0x1107, 0x1161, 0x0029, 0x0028, 0x1109,
+	0x1161, 0x0029, 0x0028, 0x110B, 0x1161, 0x0029, 0x0028, 0x110C,
+	0x1161, 0x0029, 0x0028, 0x110E, 0x1161, 0x0029, 0x0028, 0x110F,
+	0x1161, 0x0029, 0x0028, 0x1110, 0x1161, 0x0029, 0x0028, 0x1111,
+	0x1161, 0x0029, 0x0028, 0x1112, 0x1161, 0x0029, 0x0028, 0x110C,
+	0x116E, 0x0029, 0x110C, 0x116E, 0x110B, 0x1174, 0x30A2, 0x30D1,
+	0x30FC, 0x30C8, 0x30A2, 0x30EB, 0x30D5, 0x30A1, 0x30A2, 0x30F3,
+	0x30DA, 0x30A2, 0x30A4, 0x30CB, 0x30F3, 0x30B0, 0x30A8, 0x30FC,
+	0x30AB, 0x30FC, 0x30AB, 0x30E9, 0x30C3, 0x30C8, 0x30AB, 0x30ED,
+	0x30EA, 0x30FC, 0x30AD, 0x30E5, 0x30EA, 0x30FC, 0x30AE, 0x30EB,
+	0x30C0, 0x30FC, 0x30AF, 0x30ED, 0x30FC, 0x30CD, 0x30B5, 0x30A4,
+	0x30AF, 0x30EB, 0x30B7, 0x30EA, 0x30F3, 0x30B0, 0x30D0, 0x30FC,
+	0x30EC, 0x30EB, 0x30D5, 0x30A3, 0x30FC, 0x30C8, 0x30DD, 0x30A4,
+	0x30F3, 0x30C8, 0x30DE, 0x30A4, 0x30AF, 0x30ED, 0x30DF, 0x30AF,
+	0x30ED, 0x30F3, 0x30E1, 0x30AC, 0x30C8, 0x30F3, 0x30EA, 0x30C3,
+	0x30C8, 0x30EB, 0x30EB, 0x30FC, 0x30D6, 0x30EB, 0x682A, 0x5F0F,
+	0x4F1A, 0x793E, 0x006B, 0x0063, 0x0061, 0x006C, 0x006D, 0x2215,
+	0x0073, 0x00B2, 0x0061, 0x002E, 0x006D, 0x002E, 0x0043, 0x2215,
+	0x006B, 0x0067, 0x0070, 0x002E, 0x006D, 0x002E, 0x0627, 0x0643,
+	0x0628, 0x0631, 0x0645, 0x062D, 0x0645, 0x062F, 0x0635, 0x0644,
+	0x0639, 0x0645, 0x0631, 0x0633, 0x0648, 0x0644, 0x0631, 0x06CC,
+	0x0627, 0x0644, 0x0031, 0x2044, 0x0034, 0x0031, 0x2044, 0x0032,
+	0x0033, 0x2044, 0x0034, 0x002E, 0x002E, 0x002E, 0x2035, 0x2035,
+	0x2035, 0x0061, 0x002F, 0x0063, 0x0061, 0x002F, 0x0073, 0x0063,
+	0x002F, 0x006F, 0x0063, 0x002F, 0x0075, 0x0054, 0x0045, 0x004C,
+	0x0046, 0x0041, 0x0058, 0x0031, 0x2044, 0x0037, 0x0031, 0x2044,
+	0x0039, 0x0031, 0x2044, 0x0033, 0x0032, 0x2044, 0x0033, 0x0031,
+	0x2044, 0x0035, 0x0032, 0x2044, 0x0035, 0x0033, 0x2044, 0x0035,
+	0x0034, 0x2044, 0x0035, 0x0031, 0x2044, 0x0036, 0x0035, 0x2044,
+	0x0036, 0x0031, 0x2044, 0x0038, 0x0033, 0x2044, 0x0038, 0x0035,
+	0x2044, 0x0038, 0x0037, 0x2044, 0x0038, 0x0058, 0x0049, 0x0049,
+	0x0078, 0x0069, 0x0069, 0x0030, 0x2044, 0x0033, 0x222E, 0x222E,
+	0x222E, 0x0028, 0x0031, 0x0029, 0x0028, 0x0032, 0x0029, 0x0028,
+	0x0033, 0x0029, 0x0028, 0x0034, 0x0029, 0x0028, 0x0035, 0x0029,
+	0x0028, 0x0036, 0x0029, 0x0028, 0x0037, 0x0029, 0x0028, 0x0038,
+	0x0029, 0x0028, 0x0039, 0x0029, 0x0031, 0x0030, 0x002E, 0x0031,
+	0x0031, 0x002E, 0x0031, 0x0032, 0x002E, 0x0031, 0x0033, 0x002E,
+	0x0031, 0x0034, 0x002E, 0x0031, 0x0035, 0x002E, 0x0031, 0x0036,
+	0x002E, 0x0031, 0x0037, 0x002E, 0x0031, 0x0038, 0x002E, 0x0031,
+	0x0039, 0x002E, 0x0032, 0x0030, 0x002E, 0x0028, 0x0061, 0x0029,
+	0x0028, 0x0062, 0x0029, 0x0028, 0x0063, 0x0029, 0x0028, 0x0064,
+	0x0029, 0x0028, 0x0065, 0x0029, 0x0028, 0x0066, 0x0029, 0x0028,
+	0x0067, 0x0029, 0x0028, 0x0068, 0x0029, 0x0028, 0x0069, 0x0029,
+	0x0028, 0x006A, 0x0029, 0x0028, 0x006B, 0x0029, 0x0028, 0x006C,
+	0x0029, 0x0028, 0x006D, 0x0029, 0x0028, 0x006E, 0x0029, 0x0028,
+	0x006F, 0x0029, 0x0028, 0x0070, 0x0029, 0x0028, 0x0071, 0x0029,
+	0x0028, 0x0072, 0x0029, 0x0028, 0x0073, 0x0029, 0x0028, 0x0074,
+	0x0029, 0x0028, 0x0075, 0x0029, 0x0028, 0x0076, 0x0029, 0x0028,
+	0x0077, 0x0029, 0x0028, 0x0078, 0x0029, 0x0028, 0x0079, 0x0029,
+	0x0028, 0x007A, 0x0029, 0x003A, 0x003A, 0x003D, 0x003D, 0x003D,
+	0x003D, 0x0028, 0x1100, 0x0029, 0x0028, 0x1102, 0x0029, 0x0028,
+	0x1103, 0x0029, 0x0028, 0x1105, 0x0029, 0x0028, 0x1106, 0x0029,
+	0x0028, 0x1107, 0x0029, 0x0028, 0x1109, 0x0029, 0x0028, 0x110B,
+	0x0029, 0x0028, 0x110C, 0x0029, 0x0028, 0x110E, 0x0029, 0x0028,
+	0x110F, 0x0029, 0x0028, 0x1110, 0x0029, 0x0028, 0x1111, 0x0029,
+	0x0028, 0x1112, 0x0029, 0x0028, 0x4E00, 0x0029, 0x0028, 0x4E8C,
+	0x0029, 0x0028, 0x4E09, 0x0029, 0x0028, 0x56DB, 0x0029, 0x0028,
+	0x4E94, 0x0029, 0x0028, 0x516D, 0x0029, 0x0028, 0x4E03, 0x0029,
+	0x0028, 0x516B, 0x0029, 0x0028, 0x4E5D, 0x0029, 0x0028, 0x5341,
+	0x0029, 0x0028, 0x6708, 0x0029, 0x0028, 0x706B, 0x0029, 0x0028,
+	0x6C34, 0x0029, 0x0028, 0x6728, 0x0029, 0x0028, 0x91D1, 0x0029,
+	0x0028, 0x571F, 0x0029, 0x0028, 0x65E5, 0x0029, 0x0028, 0x682A,
+	0x0029, 0x0028, 0x6709, 0x0029, 0x0028, 0x793E, 0x0029, 0x0028,
+	0x540D, 0x0029, 0x0028, 0x7279, 0x0029, 0x0028, 0x8CA1, 0x0029,
+	0x0028, 0x795D, 0x0029, 0x0028, 0x52B4, 0x0029, 0x0028, 0x4EE3,
+	0x0029, 0x0028, 0x547C, 0x0029, 0x0028, 0x5B66, 0x0029, 0x0028,
+	0x76E3, 0x0029, 0x0028, 0x4F01, 0x0029, 0x0028, 0x8CC7, 0x0029,
+	0x0028, 0x5354, 0x0029, 0x0028, 0x796D, 0x0029, 0x0028, 0x4F11,
+	0x0029, 0x0028, 0x81EA, 0x0029, 0x0028, 0x81F3, 0x0029, 0x0050,
+	0x0054, 0x0045, 0x0031, 0x0030, 0x6708, 0x0031, 0x0031, 0x6708,
+	0x0031, 0x0032, 0x6708, 0x0065, 0x0072, 0x0067, 0x004C, 0x0054,
+	0x0044, 0x30A2, 0x30FC, 0x30EB, 0x30A4, 0x30F3, 0x30C1, 0x30A6,
+	0x30A9, 0x30F3, 0x30AA, 0x30F3, 0x30B9, 0x30AA, 0x30FC, 0x30E0,
+	0x30AB, 0x30A4, 0x30EA, 0x30AC, 0x30ED, 0x30F3, 0x30AC, 0x30F3,
+	0x30DE, 0x30AE, 0x30CB, 0x30FC, 0x30B1, 0x30FC, 0x30B9, 0x30B3,
+	0x30EB, 0x30CA, 0x30B3, 0x30FC, 0x30DD, 0x30BB, 0x30F3, 0x30C1,
+	0x30C0, 0x30FC, 0x30B9, 0x30CE, 0x30C3, 0x30C8, 0x30CF, 0x30A4,
+	0x30C4, 0x30D1, 0x30FC, 0x30C4, 0x30D4, 0x30AF, 0x30EB, 0x30D5,
+	0x30E9, 0x30F3, 0x30DA, 0x30CB, 0x30D2, 0x30D8, 0x30EB, 0x30C4,
+	0x30DA, 0x30F3, 0x30B9, 0x30DA, 0x30FC, 0x30B8, 0x30D9, 0x30FC,
+	0x30BF, 0x30DC, 0x30EB, 0x30C8, 0x30DD, 0x30F3, 0x30C9, 0x30DB,
+	0x30FC, 0x30EB, 0x30DB, 0x30FC, 0x30F3, 0x30DE, 0x30A4, 0x30EB,
+	0x30DE, 0x30C3, 0x30CF, 0x30DE, 0x30EB, 0x30AF, 0x30E4, 0x30FC,
+	0x30C9, 0x30E4, 0x30FC, 0x30EB, 0x30E6, 0x30A2, 0x30F3, 0x30EB,
+	0x30D4, 0x30FC, 0x0031, 0x0030, 0x70B9, 0x0031, 0x0031, 0x70B9,
+	0x0031, 0x0032, 0x70B9, 0x0031, 0x0033, 0x70B9, 0x0031, 0x0034,
+	0x70B9, 0x0031, 0x0035, 0x70B9, 0x0031, 0x0036, 0x70B9, 0x0031,
+	0x0037, 0x70B9, 0x0031, 0x0038, 0x70B9, 0x0031, 0x0039, 0x70B9,
+	0x0032, 0x0030, 0x70B9, 0x0032, 0x0031, 0x70B9, 0x0032, 0x0032,
+	0x70B9, 0x0032, 0x0033, 0x70B9, 0x0032, 0x0034, 0x70B9, 0x0068,
+	0x0050, 0x0061, 0x0062, 0x0061, 0x0072, 0x0064, 0x006D, 0x00B2,
+	0x0064, 0x006D, 0x00B3, 0x006B, 0x0048, 0x007A, 0x004D, 0x0048,
+	0x007A, 0x0047, 0x0048, 0x007A, 0x0054, 0x0048, 0x007A, 0x006D,
+	0x006D, 0x00B2, 0x0063, 0x006D, 0x00B2, 0x006B, 0x006D, 0x00B2,
+	0x006D, 0x006D, 0x00B3, 0x0063, 0x006D, 0x00B3, 0x006B, 0x006D,
+	0x00B3, 0x006B, 0x0050, 0x0061, 0x004D, 0x0050, 0x0061, 0x0047,
+	0x0050, 0x0061, 0x0043, 0x006F, 0x002E, 0x006C, 0x006F, 0x0067,
+	0x006D, 0x0069, 0x006C, 0x006D, 0x006F, 0x006C, 0x0050, 0x0050,
+	0x004D, 0x0056, 0x2215, 0x006D, 0x0041, 0x2215, 0x006D, 0x0031,
+	0x0030, 0x65E5, 0x0031, 0x0031, 0x65E5, 0x0031, 0x0032, 0x65E5,
+	0x0031, 0x0033, 0x65E5, 0x0031, 0x0034, 0x65E5, 0x0031, 0x0035,
+	0x65E5, 0x0031, 0x0036, 0x65E5, 0x0031, 0x0037, 0x65E5, 0x0031,
+	0x0038, 0x65E5, 0x0031, 0x0039, 0x65E5, 0x0032, 0x0030, 0x65E5,
+	0x0032, 0x0031, 0x65E5, 0x0032, 0x0032, 0x65E5, 0x0032, 0x0033,
+	0x65E5, 0x0032, 0x0034, 0x65E5, 0x0032, 0x0035, 0x65E5, 0x0032,
+	0x0036, 0x65E5, 0x0032, 0x0037, 0x65E5, 0x0032, 0x0038, 0x65E5,
+	0x0032, 0x0039, 0x65E5, 0x0033, 0x0030, 0x65E5, 0x0033, 0x0031,
+	0x65E5, 0x0067, 0x0061, 0x006C, 0x0066, 0x0066, 0x0069, 0x0066,
+	0x0066, 0x006C, 0x0020, 0x064C, 0x0651, 0x0020, 0x064D, 0x0651,
+	0x0020, 0x064E, 0x0651, 0x0020, 0x064F, 0x0651, 0x0020, 0x0650,
+	0x0651, 0x0020, 0x0651, 0x0670, 0x0640, 0x064E, 0x0651, 0x0640,
+	0x064F, 0x0651, 0x0640, 0x0650, 0x0651, 0x062A, 0x062C, 0x0645,
+	0x062A, 0x062D, 0x062C, 0x062A, 0x062D, 0x0645, 0x062A, 0x062E,
+	0x0645, 0x062A, 0x0645, 0x062C, 0x062A, 0x0645, 0x062D, 0x062A,
+	0x0645, 0x062E, 0x062C, 0x0645, 0x062D, 0x062D, 0x0645, 0x064A,
+	0x062D, 0x0645, 0x0649, 0x0633, 0x062D, 0x062C, 0x0633, 0x062C,
+	0x062D, 0x0633, 0x062C, 0x0649, 0x0633, 0x0645, 0x062D, 0x0633,
+	0x0645, 0x062C, 0x0633, 0x0645, 0x0645, 0x0635, 0x062D, 0x062D,
+	0x0635, 0x0645, 0x0645, 0x0634, 0x062D, 0x0645, 0x0634, 0x062C,
+	0x064A, 0x0634, 0x0645, 0x062E, 0x0634, 0x0645, 0x0645, 0x0636,
+	0x062D, 0x0649, 0x0636, 0x062E, 0x0645, 0x0637, 0x0645, 0x062D,
+	0x0637, 0x0645, 0x0645, 0x0637, 0x0645, 0x064A, 0x0639, 0x062C,
+	0x0645, 0x0639, 0x0645, 0x0645, 0x0639, 0x0645, 0x0649, 0x063A,
+	0x0645, 0x0645, 0x063A, 0x0645, 0x064A, 0x063A, 0x0645, 0x0649,
+	0x0641, 0x062E, 0x0645, 0x0642, 0x0645, 0x062D, 0x0642, 0x0645,
+	0x0645, 0x0644, 0x062D, 0x0645, 0x0644, 0x062D, 0x064A, 0x0644,
+	0x062D, 0x0649, 0x0644, 0x062C, 0x062C, 0x0644, 0x062E, 0x0645,
+	0x0644, 0x0645, 0x062D, 0x0645, 0x062D, 0x062C, 0x0645, 0x062D,
+	0x064A, 0x0645, 0x062C, 0x062D, 0x0645, 0x062C, 0x0645, 0x0645,
+	0x062E, 0x0645, 0x0645, 0x062C, 0x062E, 0x0647, 0x0645, 0x062C,
+	0x0647, 0x0645, 0x0645, 0x0646, 0x062D, 0x0645, 0x0646, 0x062D,
+	0x0649, 0x0646, 0x062C, 0x0645, 0x0646, 0x062C, 0x0649, 0x0646,
+	0x0645, 0x064A, 0x0646, 0x0645, 0x0649, 0x064A, 0x0645, 0x0645,
+	0x0628, 0x062E, 0x064A, 0x062A, 0x062C, 0x064A, 0x062A, 0x062C,
+	0x0649, 0x062A, 0x062E, 0x064A, 0x062A, 0x062E, 0x0649, 0x062A,
+	0x0645, 0x064A, 0x062A, 0x0645, 0x0649, 0x062C, 0x0645, 0x064A,
+	0x062C, 0x062D, 0x0649, 0x062C, 0x0645, 0x0649, 0x0633, 0x062E,
+	0x0649, 0x0635, 0x062D, 0x064A, 0x0634, 0x062D, 0x064A, 0x0636,
+	0x062D, 0x064A, 0x0644, 0x062C, 0x064A, 0x0644, 0x0645, 0x064A,
+	0x064A, 0x062D, 0x064A, 0x064A, 0x062C, 0x064A, 0x064A, 0x0645,
+	0x064A, 0x0645, 0x0645, 0x064A, 0x0642, 0x0645, 0x064A, 0x0646,
+	0x062D, 0x064A, 0x0639, 0x0645, 0x064A, 0x0643, 0x0645, 0x064A,
+	0x0646, 0x062C, 0x062D, 0x0645, 0x062E, 0x064A, 0x0644, 0x062C,
+	0x0645, 0x0643, 0x0645, 0x0645, 0x062C, 0x062D, 0x064A, 0x062D,
+	0x062C, 0x064A, 0x0645, 0x062C, 0x064A, 0x0641, 0x0645, 0x064A,
+	0x0628, 0x062D, 0x064A, 0x0633, 0x062E, 0x064A, 0x0646, 0x062C,
+	0x064A, 0x0635, 0x0644, 0x06D2, 0x0642, 0x0644, 0x06D2, 0x0028,
+	0x0041, 0x0029, 0x0028, 0x0042, 0x0029, 0x0028, 0x0043, 0x0029,
+	0x0028, 0x0044, 0x0029, 0x0028, 0x0045, 0x0029, 0x0028, 0x0046,
+	0x0029, 0x0028, 0x0047, 0x0029, 0x0028, 0x0048, 0x0029, 0x0028,
+	0x0049, 0x0029, 0x0028, 0x004A, 0x0029, 0x0028, 0x004B, 0x0029,
+	0x0028, 0x004C, 0x0029, 0x0028, 0x004D, 0x0029, 0x0028, 0x004E,
+	0x0029, 0x0028, 0x004F, 0x0029, 0x0028, 0x0050, 0x0029, 0x0028,
+	0x0051, 0x0029, 0x0028, 0x0052, 0x0029, 0x0028, 0x0053, 0x0029,
+	0x0028, 0x0054, 0x0029, 0x0028, 0x0055, 0x0029, 0x0028, 0x0056,
+	0x0029, 0x0028, 0x0057, 0x0029, 0x0028, 0x0058, 0x0029, 0x0028,
+	0x0059, 0x0029, 0x0028, 0x005A, 0x0029, 0x3014, 0x0053, 0x3015,
+	0x0050, 0x0050, 0x0056, 0x3014, 0x672C, 0x3015, 0x3014, 0x4E09,
+	0x3015, 0x3014, 0x4E8C, 0x3015, 0x3014, 0x5B89, 0x3015, 0x3014,
+	0x70B9, 0x3015, 0x3014, 0x6253, 0x3015, 0x3014, 0x76D7, 0x3015,
+	0x3014, 0x52DD, 0x3015, 0x3014, 0x6557, 0x3015, 0x0020, 0x0308,
+	0x0020, 0x0304, 0x0020, 0x0301, 0x0020, 0x0327, 0x0041, 0x0300,
+	0x0041, 0x0301, 0x0041, 0x0302, 0x0041, 0x0303, 0x0041, 0x0308,
+	0x0041, 0x030A, 0x0043, 0x0327, 0x0045, 0x0300, 0x0045, 0x0301,
+	0x0045, 0x0302, 0x0045, 0x0308, 0x0049, 0x0300, 0x0049, 0x0301,
+	0x0049, 0x0302, 0x0049, 0x0308, 0x004E, 0x0303, 0x004F, 0x0300,
+	0x004F, 0x0301, 0x004F, 0x0302, 0x004F, 0x0303, 0x004F, 0x0308,
+	0x0055, 0x0300, 0x0055, 0x0301, 0x0055, 0x0302, 0x0055, 0x0308,
+	0x0059, 0x0301, 0x0061, 0x0300, 0x0061, 0x0301, 0x0061, 0x0302,
+	0x0061, 0x0303, 0x0061, 0x0308, 0x0061, 0x030A, 0x0063, 0x0327,
+	0x0065, 0x0300, 0x0065, 0x0301, 0x0065, 0x0302, 0x0065, 0x0308,
+	0x0069, 0x0300, 0x0069, 0x0301, 0x0069, 0x0302, 0x0069, 0x0308,
+	0x006E, 0x0303, 0x006F, 0x0300, 0x006F, 0x0301, 0x006F, 0x0302,
+	0x006F, 0x0303, 0x006F, 0x0308, 0x0075, 0x0300, 0x0075, 0x0301,
+	0x0075, 0x0302, 0x0075, 0x0308, 0x0079, 0x0301, 0x0079, 0x0308,
+	0x0041, 0x0304, 0x0061, 0x0304, 0x0041, 0x0306, 0x0061, 0x0306,
+	0x0041, 0x0328, 0x0061, 0x0328, 0x0043, 0x0301, 0x0063, 0x0301,
+	0x0043, 0x0302, 0x0063, 0x0302, 0x0043, 0x0307, 0x0063, 0x0307,
+	0x0043, 0x030C, 0x0063, 0x030C, 0x0044, 0x030C, 0x0064, 0x030C,
+	0x0045, 0x0304, 0x0065, 0x0304, 0x0045, 0x0306, 0x0065, 0x0306,
+	0x0045, 0x0307, 0x0065, 0x0307, 0x0045, 0x0328, 0x0065, 0x0328,
+	0x0045, 0x030C, 0x0065, 0x030C, 0x0047, 0x0302, 0x0067, 0x0302,
+	0x0047, 0x0306, 0x0067, 0x0306, 0x0047, 0x0307, 0x0067, 0x0307,
+	0x0047, 0x0327, 0x0067, 0x0327, 0x0048, 0x0302, 0x0068, 0x0302,
+	0x0049, 0x0303, 0x0069, 0x0303, 0x0049, 0x0304, 0x0069, 0x0304,
+	0x0049, 0x0306, 0x0069, 0x0306, 0x0049, 0x0328, 0x0069, 0x0328,
+	0x0049, 0x0307, 0x0049, 0x004A, 0x0069, 0x006A, 0x004A, 0x0302,
+	0x006A, 0x0302, 0x004B, 0x0327, 0x006B, 0x0327, 0x004C, 0x0301,
+	0x006C, 0x0301, 0x004C, 0x0327, 0x006C, 0x0327, 0x004C, 0x030C,
+	0x006C, 0x030C, 0x004C, 0x00B7, 0x006C, 0x00B7, 0x004E, 0x0301,
+	0x006E, 0x0301, 0x004E, 0x0327, 0x006E, 0x0327, 0x004E, 0x030C,
+	0x006E, 0x030C, 0x02BC, 0x006E, 0x004F, 0x0304, 0x006F, 0x0304,
+	0x004F, 0x0306, 0x006F, 0x0306, 0x004F, 0x030B, 0x006F, 0x030B,
+	0x0052, 0x0301, 0x0072, 0x0301, 0x0052, 0x0327, 0x0072, 0x0327,
+	0x0052, 0x030C, 0x0072, 0x030C, 0x0053, 0x0301, 0x0073, 0x0301,
+	0x0053, 0x0302, 0x0073, 0x0302, 0x0053, 0x0327, 0x0073, 0x0327,
+	0x0053, 0x030C, 0x0073, 0x030C, 0x0054, 0x0327, 0x0074, 0x0327,
+	0x0054, 0x030C, 0x0074, 0x030C, 0x0055, 0x0303, 0x0075, 0x0303,
+	0x0055, 0x0304, 0x0075, 0x0304, 0x0055, 0x0306, 0x0075, 0x0306,
+	0x0055, 0x030A, 0x0075, 0x030A, 0x0055, 0x030B, 0x0075, 0x030B,
+	0x0055, 0x0328, 0x0075, 0x0328, 0x0057, 0x0302, 0x0077, 0x0302,
+	0x0059, 0x0302, 0x0079, 0x0302, 0x0059, 0x0308, 0x005A, 0x0301,
+	0x007A, 0x0301, 0x005A, 0x0307, 0x007A, 0x0307, 0x005A, 0x030C,
+	0x007A, 0x030C, 0x004F, 0x031B, 0x006F, 0x031B, 0x0055, 0x031B,
+	0x0075, 0x031B, 0x0044, 0x017D, 0x0044, 0x017E, 0x0064, 0x017E,
+	0x004C, 0x004A, 0x004C, 0x006A, 0x006C, 0x006A, 0x004E, 0x004A,
+	0x004E, 0x006A, 0x006E, 0x006A, 0x0041, 0x030C, 0x0061, 0x030C,
+	0x0049, 0x030C, 0x0069, 0x030C, 0x004F, 0x030C, 0x006F, 0x030C,
+	0x0055, 0x030C, 0x0075, 0x030C, 0x00DC, 0x0304, 0x00FC, 0x0304,
+	0x00DC, 0x0301, 0x00FC, 0x0301, 0x00DC, 0x030C, 0x00FC, 0x030C,
+	0x00DC, 0x0300, 0x00FC, 0x0300, 0x00C4, 0x0304, 0x00E4, 0x0304,
+	0x0226, 0x0304, 0x0227, 0x0304, 0x00C6, 0x0304, 0x00E6, 0x0304,
+	0x0047, 0x030C, 0x0067, 0x030C, 0x004B, 0x030C, 0x006B, 0x030C,
+	0x004F, 0x0328, 0x006F, 0x0328, 0x01EA, 0x0304, 0x01EB, 0x0304,
+	0x01B7, 0x030C, 0x0292, 0x030C, 0x006A, 0x030C, 0x0044, 0x005A,
+	0x0044, 0x007A, 0x0064, 0x007A, 0x0047, 0x0301, 0x0067, 0x0301,
+	0x004E, 0x0300, 0x006E, 0x0300, 0x00C5, 0x0301, 0x00E5, 0x0301,
+	0x00C6, 0x0301, 0x00E6, 0x0301, 0x00D8, 0x0301, 0x00F8, 0x0301,
+	0x0041, 0x030F, 0x0061, 0x030F, 0x0041, 0x0311, 0x0061, 0x0311,
+	0x0045, 0x030F, 0x0065, 0x030F, 0x0045, 0x0311, 0x0065, 0x0311,
+	0x0049, 0x030F, 0x0069, 0x030F, 0x0049, 0x0311, 0x0069, 0x0311,
+	0x004F, 0x030F, 0x006F, 0x030F, 0x004F, 0x0311, 0x006F, 0x0311,
+	0x0052, 0x030F, 0x0072, 0x030F, 0x0052, 0x0311, 0x0072, 0x0311,
+	0x0055, 0x030F, 0x0075, 0x030F, 0x0055, 0x0311, 0x0075, 0x0311,
+	0x0053, 0x0326, 0x0073, 0x0326, 0x0054, 0x0326, 0x0074, 0x0326,
+	0x0048, 0x030C, 0x0068, 0x030C, 0x0041, 0x0307, 0x0061, 0x0307,
+	0x0045, 0x0327, 0x0065, 0x0327, 0x00D6, 0x0304, 0x00F6, 0x0304,
+	0x00D5, 0x0304, 0x00F5, 0x0304, 0x004F, 0x0307, 0x006F, 0x0307,
+	0x022E, 0x0304, 0x022F, 0x0304, 0x0059, 0x0304, 0x0079, 0x0304,
+	0x0020, 0x0306, 0x0020, 0x0307, 0x0020, 0x030A, 0x0020, 0x0328,
+	0x0020, 0x0303, 0x0020, 0x030B, 0x0308, 0x0301, 0x0020, 0x0345,
+	0x00A8, 0x0301, 0x0391, 0x0301, 0x0395, 0x0301, 0x0397, 0x0301,
+	0x0399, 0x0301, 0x039F, 0x0301, 0x03A5, 0x0301, 0x03A9, 0x0301,
+	0x03CA, 0x0301, 0x0399, 0x0308, 0x03A5, 0x0308, 0x03B1, 0x0301,
+	0x03B5, 0x0301, 0x03B7, 0x0301, 0x03B9, 0x0301, 0x03CB, 0x0301,
+	0x03B9, 0x0308, 0x03C5, 0x0308, 0x03BF, 0x0301, 0x03C5, 0x0301,
+	0x03C9, 0x0301, 0x03D2, 0x0301, 0x03D2, 0x0308, 0x0415, 0x0300,
+	0x0415, 0x0308, 0x0413, 0x0301, 0x0406, 0x0308, 0x041A, 0x0301,
+	0x0418, 0x0300, 0x0423, 0x0306, 0x0418, 0x0306, 0x0438, 0x0306,
+	0x0435, 0x0300, 0x0435, 0x0308, 0x0433, 0x0301, 0x0456, 0x0308,
+	0x043A, 0x0301, 0x0438, 0x0300, 0x0443, 0x0306, 0x0474, 0x030F,
+	0x0475, 0x030F, 0x0416, 0x0306, 0x0436, 0x0306, 0x0410, 0x0306,
+	0x0430, 0x0306, 0x0410, 0x0308, 0x0430, 0x0308, 0x0415, 0x0306,
+	0x0435, 0x0306, 0x04D8, 0x0308, 0x04D9, 0x0308, 0x0416, 0x0308,
+	0x0436, 0x0308, 0x0417, 0x0308, 0x0437, 0x0308, 0x0418, 0x0304,
+	0x0438, 0x0304, 0x0418, 0x0308, 0x0438, 0x0308, 0x041E, 0x0308,
+	0x043E, 0x0308, 0x04E8, 0x0308, 0x04E9, 0x0308, 0x042D, 0x0308,
+	0x044D, 0x0308, 0x0423, 0x0304, 0x0443, 0x0304, 0x0423, 0x0308,
+	0x0443, 0x0308, 0x0423, 0x030B, 0x0443, 0x030B, 0x0427, 0x0308,
+	0x0447, 0x0308, 0x042B, 0x0308, 0x044B, 0x0308, 0x0565, 0x0582,
+	0x0627, 0x0653, 0x0627, 0x0654, 0x0648, 0x0654, 0x0627, 0x0655,
+	0x064A, 0x0654, 0x0627, 0x0674, 0x0648, 0x0674, 0x06C7, 0x0674,
+	0x064A, 0x0674, 0x06D5, 0x0654, 0x06C1, 0x0654, 0x06D2, 0x0654,
+	0x0928, 0x093C, 0x0930, 0x093C, 0x0933, 0x093C, 0x0915, 0x093C,
+	0x0916, 0x093C, 0x0917, 0x093C, 0x091C, 0x093C, 0x0921, 0x093C,
+	0x0922, 0x093C, 0x092B, 0x093C, 0x092F, 0x093C, 0x09C7, 0x09BE,
+	0x09C7, 0x09D7, 0x09A1, 0x09BC, 0x09A2, 0x09BC, 0x09AF, 0x09BC,
+	0x0A32, 0x0A3C, 0x0A38, 0x0A3C, 0x0A16, 0x0A3C, 0x0A17, 0x0A3C,
+	0x0A1C, 0x0A3C, 0x0A2B, 0x0A3C, 0x0B47, 0x0B56, 0x0B47, 0x0B3E,
+	0x0B47, 0x0B57, 0x0B21, 0x0B3C, 0x0B22, 0x0B3C, 0x0B92, 0x0BD7,
+	0x0BC6, 0x0BBE, 0x0BC7, 0x0BBE, 0x0BC6, 0x0BD7, 0x0C46, 0x0C56,
+	0x0CBF, 0x0CD5, 0x0CC6, 0x0CD5, 0x0CC6, 0x0CD6, 0x0CC6, 0x0CC2,
+	0x0CCA, 0x0CD5, 0x0D46, 0x0D3E, 0x0D47, 0x0D3E, 0x0D46, 0x0D57,
+	0x0DD9, 0x0DCA, 0x0DD9, 0x0DCF, 0x0DDC, 0x0DCA, 0x0DD9, 0x0DDF,
+	0x0E4D, 0x0E32, 0x0ECD, 0x0EB2, 0x0EAB, 0x0E99, 0x0EAB, 0x0EA1,
+	0x0F42, 0x0FB7, 0x0F4C, 0x0FB7, 0x0F51, 0x0FB7, 0x0F56, 0x0FB7,
+	0x0F5B, 0x0FB7, 0x0F40, 0x0FB5, 0x0F71, 0x0F72, 0x0F71, 0x0F74,
+	0x0FB2, 0x0F80, 0x0FB2, 0x0F81, 0x0FB3, 0x0F80, 0x0FB3, 0x0F81,
+	0x0F71, 0x0F80, 0x0F92, 0x0FB7, 0x0F9C, 0x0FB7, 0x0FA1, 0x0FB7,
+	0x0FA6, 0x0FB7, 0x0FAB, 0x0FB7, 0x0F90, 0x0FB5, 0x1025, 0x102E,
+	0x1B05, 0x1B35, 0x1B07, 0x1B35, 0x1B09, 0x1B35, 0x1B0B, 0x1B35,
+	0x1B0D, 0x1B35, 0x1B11, 0x1B35, 0x1B3A, 0x1B35, 0x1B3C, 0x1B35,
+	0x1B3E, 0x1B35, 0x1B3F, 0x1B35, 0x1B42, 0x1B35, 0x0041, 0x0325,
+	0x0061, 0x0325, 0x0042, 0x0307, 0x0062, 0x0307, 0x0042, 0x0323,
+	0x0062, 0x0323, 0x0042, 0x0331, 0x0062, 0x0331, 0x00C7, 0x0301,
+	0x00E7, 0x0301, 0x0044, 0x0307, 0x0064, 0x0307, 0x0044, 0x0323,
+	0x0064, 0x0323, 0x0044, 0x0331, 0x0064, 0x0331, 0x0044, 0x0327,
+	0x0064, 0x0327, 0x0044, 0x032D, 0x0064, 0x032D, 0x0112, 0x0300,
+	0x0113, 0x0300, 0x0112, 0x0301, 0x0113, 0x0301, 0x0045, 0x032D,
+	0x0065, 0x032D, 0x0045, 0x0330, 0x0065, 0x0330, 0x0228, 0x0306,
+	0x0229, 0x0306, 0x0046, 0x0307, 0x0066, 0x0307, 0x0047, 0x0304,
+	0x0067, 0x0304, 0x0048, 0x0307, 0x0068, 0x0307, 0x0048, 0x0323,
+	0x0068, 0x0323, 0x0048, 0x0308, 0x0068, 0x0308, 0x0048, 0x0327,
+	0x0068, 0x0327, 0x0048, 0x032E, 0x0068, 0x032E, 0x0049, 0x0330,
+	0x0069, 0x0330, 0x00CF, 0x0301, 0x00EF, 0x0301, 0x004B, 0x0301,
+	0x006B, 0x0301, 0x004B, 0x0323, 0x006B, 0x0323, 0x004B, 0x0331,
+	0x006B, 0x0331, 0x004C, 0x0323, 0x006C, 0x0323, 0x1E36, 0x0304,
+	0x1E37, 0x0304, 0x004C, 0x0331, 0x006C, 0x0331, 0x004C, 0x032D,
+	0x006C, 0x032D, 0x004D, 0x0301, 0x006D, 0x0301, 0x004D, 0x0307,
+	0x006D, 0x0307, 0x004D, 0x0323, 0x006D, 0x0323, 0x004E, 0x0307,
+	0x006E, 0x0307, 0x004E, 0x0323, 0x006E, 0x0323, 0x004E, 0x0331,
+	0x006E, 0x0331, 0x004E, 0x032D, 0x006E, 0x032D, 0x00D5, 0x0301,
+	0x00F5, 0x0301, 0x00D5, 0x0308, 0x00F5, 0x0308, 0x014C, 0x0300,
+	0x014D, 0x0300, 0x014C, 0x0301, 0x014D, 0x0301, 0x0050, 0x0301,
+	0x0070, 0x0301, 0x0050, 0x0307, 0x0070, 0x0307, 0x0052, 0x0307,
+	0x0072, 0x0307, 0x0052, 0x0323, 0x0072, 0x0323, 0x1E5A, 0x0304,
+	0x1E5B, 0x0304, 0x0052, 0x0331, 0x0072, 0x0331, 0x0053, 0x0307,
+	0x0073, 0x0307, 0x0053, 0x0323, 0x0073, 0x0323, 0x015A, 0x0307,
+	0x015B, 0x0307, 0x0160, 0x0307, 0x0161, 0x0307, 0x1E62, 0x0307,
+	0x1E63, 0x0307, 0x0054, 0x0307, 0x0074, 0x0307, 0x0054, 0x0323,
+	0x0074, 0x0323, 0x0054, 0x0331, 0x0074, 0x0331, 0x0054, 0x032D,
+	0x0074, 0x032D, 0x0055, 0x0324, 0x0075, 0x0324, 0x0055, 0x0330,
+	0x0075, 0x0330, 0x0055, 0x032D, 0x0075, 0x032D, 0x0168, 0x0301,
+	0x0169, 0x0301, 0x016A, 0x0308, 0x016B, 0x0308, 0x0056, 0x0303,
+	0x0076, 0x0303, 0x0056, 0x0323, 0x0076, 0x0323, 0x0057, 0x0300,
+	0x0077, 0x0300, 0x0057, 0x0301, 0x0077, 0x0301, 0x0057, 0x0308,
+	0x0077, 0x0308, 0x0057, 0x0307, 0x0077, 0x0307, 0x0057, 0x0323,
+	0x0077, 0x0323, 0x0058, 0x0307, 0x0078, 0x0307, 0x0058, 0x0308,
+	0x0078, 0x0308, 0x0059, 0x0307, 0x0079, 0x0307, 0x005A, 0x0302,
+	0x007A, 0x0302, 0x005A, 0x0323, 0x007A, 0x0323, 0x005A, 0x0331,
+	0x007A, 0x0331, 0x0068, 0x0331, 0x0074, 0x0308, 0x0077, 0x030A,
+	0x0079, 0x030A, 0x0061, 0x02BE, 0x017F, 0x0307, 0x0041, 0x0323,
+	0x0061, 0x0323, 0x0041, 0x0309, 0x0061, 0x0309, 0x00C2, 0x0301,
+	0x00E2, 0x0301, 0x00C2, 0x0300, 0x00E2, 0x0300, 0x00C2, 0x0309,
+	0x00E2, 0x0309, 0x00C2, 0x0303, 0x00E2, 0x0303, 0x1EA0, 0x0302,
+	0x1EA1, 0x0302, 0x0102, 0x0301, 0x0103, 0x0301, 0x0102, 0x0300,
+	0x0103, 0x0300, 0x0102, 0x0309, 0x0103, 0x0309, 0x0102, 0x0303,
+	0x0103, 0x0303, 0x1EA0, 0x0306, 0x1EA1, 0x0306, 0x0045, 0x0323,
+	0x0065, 0x0323, 0x0045, 0x0309, 0x0065, 0x0309, 0x0045, 0x0303,
+	0x0065, 0x0303, 0x00CA, 0x0301, 0x00EA, 0x0301, 0x00CA, 0x0300,
+	0x00EA, 0x0300, 0x00CA, 0x0309, 0x00EA, 0x0309, 0x00CA, 0x0303,
+	0x00EA, 0x0303, 0x1EB8, 0x0302, 0x1EB9, 0x0302, 0x0049, 0x0309,
+	0x0069, 0x0309, 0x0049, 0x0323, 0x0069, 0x0323, 0x004F, 0x0323,
+	0x006F, 0x0323, 0x004F, 0x0309, 0x006F, 0x0309, 0x00D4, 0x0301,
+	0x00F4, 0x0301, 0x00D4, 0x0300, 0x00F4, 0x0300, 0x00D4, 0x0309,
+	0x00F4, 0x0309, 0x00D4, 0x0303, 0x00F4, 0x0303, 0x1ECC, 0x0302,
+	0x1ECD, 0x0302, 0x01A0, 0x0301, 0x01A1, 0x0301, 0x01A0, 0x0300,
+	0x01A1, 0x0300, 0x01A0, 0x0309, 0x01A1, 0x0309, 0x01A0, 0x0303,
+	0x01A1, 0x0303, 0x01A0, 0x0323, 0x01A1, 0x0323, 0x0055, 0x0323,
+	0x0075, 0x0323, 0x0055, 0x0309, 0x0075, 0x0309, 0x01AF, 0x0301,
+	0x01B0, 0x0301, 0x01AF, 0x0300, 0x01B0, 0x0300, 0x01AF, 0x0309,
+	0x01B0, 0x0309, 0x01AF, 0x0303, 0x01B0, 0x0303, 0x01AF, 0x0323,
+	0x01B0, 0x0323, 0x0059, 0x0300, 0x0079, 0x0300, 0x0059, 0x0323,
+	0x0079, 0x0323, 0x0059, 0x0309, 0x0079, 0x0309, 0x0059, 0x0303,
+	0x0079, 0x0303, 0x03B1, 0x0313, 0x03B1, 0x0314, 0x1F00, 0x0300,
+	0x1F01, 0x0300, 0x1F00, 0x0301, 0x1F01, 0x0301, 0x1F00, 0x0342,
+	0x1F01, 0x0342, 0x0391, 0x0313, 0x0391, 0x0314, 0x1F08, 0x0300,
+	0x1F09, 0x0300, 0x1F08, 0x0301, 0x1F09, 0x0301, 0x1F08, 0x0342,
+	0x1F09, 0x0342, 0x03B5, 0x0313, 0x03B5, 0x0314, 0x1F10, 0x0300,
+	0x1F11, 0x0300, 0x1F10, 0x0301, 0x1F11, 0x0301, 0x0395, 0x0313,
+	0x0395, 0x0314, 0x1F18, 0x0300, 0x1F19, 0x0300, 0x1F18, 0x0301,
+	0x1F19, 0x0301, 0x03B7, 0x0313, 0x03B7, 0x0314, 0x1F20, 0x0300,
+	0x1F21, 0x0300, 0x1F20, 0x0301, 0x1F21, 0x0301, 0x1F20, 0x0342,
+	0x1F21, 0x0342, 0x0397, 0x0313, 0x0397, 0x0314, 0x1F28, 0x0300,
+	0x1F29, 0x0300, 0x1F28, 0x0301, 0x1F29, 0x0301, 0x1F28, 0x0342,
+	0x1F29, 0x0342, 0x03B9, 0x0313, 0x03B9, 0x0314, 0x1F30, 0x0300,
+	0x1F31, 0x0300, 0x1F30, 0x0301, 0x1F31, 0x0301, 0x1F30, 0x0342,
+	0x1F31, 0x0342, 0x0399, 0x0313, 0x0399, 0x0314, 0x1F38, 0x0300,
+	0x1F39, 0x0300, 0x1F38, 0x0301, 0x1F39, 0x0301, 0x1F38, 0x0342,
+	0x1F39, 0x0342, 0x03BF, 0x0313, 0x03BF, 0x0314, 0x1F40, 0x0300,
+	0x1F41, 0x0300, 0x1F40, 0x0301, 0x1F41, 0x0301, 0x039F, 0x0313,
+	0x039F, 0x0314, 0x1F48, 0x0300, 0x1F49, 0x0300, 0x1F48, 0x0301,
+	0x1F49, 0x0301, 0x03C5, 0x0313, 0x03C5, 0x0314, 0x1F50, 0x0300,
+	0x1F51, 0x0300, 0x1F50, 0x0301, 0x1F51, 0x0301, 0x1F50, 0x0342,
+	0x1F51, 0x0342, 0x03A5, 0x0314, 0x1F59, 0x0300, 0x1F59, 0x0301,
+	0x1F59, 0x0342, 0x03C9, 0x0313, 0x03C9, 0x0314, 0x1F60, 0x0300,
+	0x1F61, 0x0300, 0x1F60, 0x0301, 0x1F61, 0x0301, 0x1F60, 0x0342,
+	0x1F61, 0x0342, 0x03A9, 0x0313, 0x03A9, 0x0314, 0x1F68, 0x0300,
+	0x1F69, 0x0300, 0x1F68, 0x0301, 0x1F69, 0x0301, 0x1F68, 0x0342,
+	0x1F69, 0x0342, 0x03B1, 0x0300, 0x03B5, 0x0300, 0x03B7, 0x0300,
+	0x03B9, 0x0300, 0x03BF, 0x0300, 0x03C5, 0x0300, 0x03C9, 0x0300,
+	0x1F00, 0x0345, 0x1F01, 0x0345, 0x1F02, 0x0345, 0x1F03, 0x0345,
+	0x1F04, 0x0345, 0x1F05, 0x0345, 0x1F06, 0x0345, 0x1F07, 0x0345,
+	0x1F08, 0x0345, 0x1F09, 0x0345, 0x1F0A, 0x0345, 0x1F0B, 0x0345,
+	0x1F0C, 0x0345, 0x1F0D, 0x0345, 0x1F0E, 0x0345, 0x1F0F, 0x0345,
+	0x1F20, 0x0345, 0x1F21, 0x0345, 0x1F22, 0x0345, 0x1F23, 0x0345,
+	0x1F24, 0x0345, 0x1F25, 0x0345, 0x1F26, 0x0345, 0x1F27, 0x0345,
+	0x1F28, 0x0345, 0x1F29, 0x0345, 0x1F2A, 0x0345, 0x1F2B, 0x0345,
+	0x1F2C, 0x0345, 0x1F2D, 0x0345, 0x1F2E, 0x0345, 0x1F2F, 0x0345,
+	0x1F60, 0x0345, 0x1F61, 0x0345, 0x1F62, 0x0345, 0x1F63, 0x0345,
+	0x1F64, 0x0345, 0x1F65, 0x0345, 0x1F66, 0x0345, 0x1F67, 0x0345,
+	0x1F68, 0x0345, 0x1F69, 0x0345, 0x1F6A, 0x0345, 0x1F6B, 0x0345,
+	0x1F6C, 0x0345, 0x1F6D, 0x0345, 0x1F6E, 0x0345, 0x1F6F, 0x0345,
+	0x03B1, 0x0306, 0x03B1, 0x0304, 0x1F70, 0x0345, 0x03B1, 0x0345,
+	0x03AC, 0x0345, 0x03B1, 0x0342, 0x1FB6, 0x0345, 0x0391, 0x0306,
+	0x0391, 0x0304, 0x0391, 0x0300, 0x0391, 0x0345, 0x0020, 0x0313,
+	0x0020, 0x0342, 0x00A8, 0x0342, 0x1F74, 0x0345, 0x03B7, 0x0345,
+	0x03AE, 0x0345, 0x03B7, 0x0342, 0x1FC6, 0x0345, 0x0395, 0x0300,
+	0x0397, 0x0300, 0x0397, 0x0345, 0x1FBF, 0x0300, 0x1FBF, 0x0301,
+	0x1FBF, 0x0342, 0x03B9, 0x0306, 0x03B9, 0x0304, 0x03CA, 0x0300,
+	0x03B9, 0x0342, 0x03CA, 0x0342, 0x0399, 0x0306, 0x0399, 0x0304,
+	0x0399, 0x0300, 0x1FFE, 0x0300, 0x1FFE, 0x0301, 0x1FFE, 0x0342,
+	0x03C5, 0x0306, 0x03C5, 0x0304, 0x03CB, 0x0300, 0x03C1, 0x0313,
+	0x03C1, 0x0314, 0x03C5, 0x0342, 0x03CB, 0x0342, 0x03A5, 0x0306,
+	0x03A5, 0x0304, 0x03A5, 0x0300, 0x03A1, 0x0314, 0x00A8, 0x0300,
+	0x1F7C, 0x0345, 0x03C9, 0x0345, 0x03CE, 0x0345, 0x03C9, 0x0342,
+	0x1FF6, 0x0345, 0x039F, 0x0300, 0x03A9, 0x0300, 0x03A9, 0x0345,
+	0x0020, 0x0314, 0x0020, 0x0333, 0x0021, 0x0021, 0x0020, 0x0305,
+	0x003F, 0x003F, 0x003F, 0x0021, 0x0021, 0x003F, 0x0052, 0x0073,
+	0x00B0, 0x0043, 0x00B0, 0x0046, 0x004E, 0x006F, 0x0053, 0x004D,
+	0x0054, 0x004D, 0x0049, 0x0056, 0x0049, 0x0058, 0x0069, 0x0076,
+	0x0069, 0x0078, 0x2190, 0x0338, 0x2192, 0x0338, 0x2194, 0x0338,
+	0x21D0, 0x0338, 0x21D4, 0x0338, 0x21D2, 0x0338, 0x2203, 0x0338,
+	0x2208, 0x0338, 0x220B, 0x0338, 0x2223, 0x0338, 0x2225, 0x0338,
+	0x223C, 0x0338, 0x2243, 0x0338, 0x2245, 0x0338, 0x2248, 0x0338,
+	0x003D, 0x0338, 0x2261, 0x0338, 0x224D, 0x0338, 0x003C, 0x0338,
+	0x003E, 0x0338, 0x2264, 0x0338, 0x2265, 0x0338, 0x2272, 0x0338,
+	0x2273, 0x0338, 0x2276, 0x0338, 0x2277, 0x0338, 0x227A, 0x0338,
+	0x227B, 0x0338, 0x2282, 0x0338, 0x2283, 0x0338, 0x2286, 0x0338,
+	0x2287, 0x0338, 0x22A2, 0x0338, 0x22A8, 0x0338, 0x22A9, 0x0338,
+	0x22AB, 0x0338, 0x227C, 0x0338, 0x227D, 0x0338, 0x2291, 0x0338,
+	0x2292, 0x0338, 0x22B2, 0x0338, 0x22B3, 0x0338, 0x22B4, 0x0338,
+	0x22B5, 0x0338, 0x2ADD, 0x0338, 0x304B, 0x3099, 0x304D, 0x3099,
+	0x304F, 0x3099, 0x3051, 0x3099, 0x3053, 0x3099, 0x3055, 0x3099,
+	0x3057, 0x3099, 0x3059, 0x3099, 0x305B, 0x3099, 0x305D, 0x3099,
+	0x305F, 0x3099, 0x3061, 0x3099, 0x3064, 0x3099, 0x3066, 0x3099,
+	0x3068, 0x3099, 0x306F, 0x3099, 0x306F, 0x309A, 0x3072, 0x3099,
+	0x3072, 0x309A, 0x3075, 0x3099, 0x3075, 0x309A, 0x3078, 0x3099,
+	0x3078, 0x309A, 0x307B, 0x3099, 0x307B, 0x309A, 0x3046, 0x3099,
+	0x0020, 0x3099, 0x0020, 0x309A, 0x309D, 0x3099, 0x3088, 0x308A,
+	0x30AB, 0x3099, 0x30AD, 0x3099, 0x30AF, 0x3099, 0x30B1, 0x3099,
+	0x30B3, 0x3099, 0x30B5, 0x3099, 0x30B7, 0x3099, 0x30B9, 0x3099,
+	0x30BB, 0x3099, 0x30BD, 0x3099, 0x30BF, 0x3099, 0x30C1, 0x3099,
+	0x30C4, 0x3099, 0x30C6, 0x3099, 0x30C8, 0x3099, 0x30CF, 0x3099,
+	0x30CF, 0x309A, 0x30D2, 0x3099, 0x30D2, 0x309A, 0x30D5, 0x3099,
+	0x30D5, 0x309A, 0x30D8, 0x3099, 0x30D8, 0x309A, 0x30DB, 0x3099,
+	0x30DB, 0x309A, 0x30A6, 0x3099, 0x30EF, 0x3099, 0x30F0, 0x3099,
+	0x30F1, 0x3099, 0x30F2, 0x3099, 0x30FD, 0x3099, 0x30B3, 0x30C8,
+	0x0033, 0x0033, 0x0033, 0x0034, 0x0033, 0x0035, 0x110B, 0x116E,
+	0x0033, 0x0036, 0x0033, 0x0037, 0x0033, 0x0038, 0x0033, 0x0039,
+	0x0034, 0x0030, 0x0034, 0x0032, 0x0034, 0x0034, 0x0034, 0x0035,
+	0x0034, 0x0036, 0x0034, 0x0037, 0x0034, 0x0038, 0x0034, 0x0039,
+	0x0035, 0x0030, 0x0033, 0x6708, 0x0034, 0x6708, 0x0035, 0x6708,
+	0x0036, 0x6708, 0x0037, 0x6708, 0x0038, 0x6708, 0x0039, 0x6708,
+	0x0048, 0x0067, 0x0065, 0x0056, 0x4EE4, 0x548C, 0x30AE, 0x30AC,
+	0x30C7, 0x30B7, 0x30C9, 0x30EB, 0x30CA, 0x30CE, 0x30D4, 0x30B3,
+	0x30D3, 0x30EB, 0x30DA, 0x30BD, 0x30DB, 0x30F3, 0x30EA, 0x30E9,
+	0x30EC, 0x30E0, 0x0064, 0x0061, 0x0041, 0x0055, 0x006F, 0x0056,
+	0x0070, 0x0063, 0x0049, 0x0055, 0x5E73, 0x6210, 0x662D, 0x548C,
+	0x5927, 0x6B63, 0x660E, 0x6CBB, 0x0070, 0x0041, 0x006E, 0x0041,
+	0x03BC, 0x0041, 0x006B, 0x0041, 0x004B, 0x0042, 0x004D, 0x0042,
+	0x0047, 0x0042, 0x0070, 0x0046, 0x006E, 0x0046, 0x03BC, 0x0046,
+	0x03BC, 0x0067, 0x006D, 0x0067, 0x03BC, 0x2113, 0x006D, 0x2113,
+	0x0064, 0x2113, 0x006B, 0x2113, 0x0066, 0x006D, 0x006E, 0x006D,
+	0x03BC, 0x006D, 0x0070, 0x0073, 0x006E, 0x0073, 0x03BC, 0x0073,
+	0x006D, 0x0073, 0x0070, 0x0056, 0x006E, 0x0056, 0x03BC, 0x0056,
+	0x006D, 0x0056, 0x006B, 0x0056, 0x0070, 0x0057, 0x006E, 0x0057,
+	0x03BC, 0x0057, 0x006D, 0x0057, 0x006B, 0x0057, 0x004D, 0x0057,
+	0x006B, 0x03A9, 0x004D, 0x03A9, 0x0042, 0x0071, 0x0063, 0x0063,
+	0x0063, 0x0064, 0x0064, 0x0042, 0x0047, 0x0079, 0x0068, 0x0061,
+	0x0048, 0x0050, 0x0069, 0x006E, 0x004B, 0x004B, 0x004B, 0x004D,
+	0x006B, 0x0074, 0x006C, 0x006E, 0x006C, 0x0078, 0x006D, 0x0062,
+	0x0050, 0x0048, 0x0050, 0x0052, 0x0073, 0x0072, 0x0053, 0x0076,
+	0x0057, 0x0062, 0x017F, 0x0074, 0x0073, 0x0074, 0x0574, 0x0576,
+	0x0574, 0x0565, 0x0574, 0x056B, 0x057E, 0x0576, 0x0574, 0x056D,
+	0x05D9, 0x05B4, 0x05F2, 0x05B7, 0x05E9, 0x05C1, 0x05E9, 0x05C2,
+	0xFB49, 0x05C1, 0xFB49, 0x05C2, 0x05D0, 0x05B7, 0x05D0, 0x05B8,
+	0x05D0, 0x05BC, 0x05D1, 0x05BC, 0x05D2, 0x05BC, 0x05D3, 0x05BC,
+	0x05D4, 0x05BC, 0x05D5, 0x05BC, 0x05D6, 0x05BC, 0x05D8, 0x05BC,
+	0x05D9, 0x05BC, 0x05DA, 0x05BC, 0x05DB, 0x05BC, 0x05DC, 0x05BC,
+	0x05DE, 0x05BC, 0x05E0, 0x05BC, 0x05E1, 0x05BC, 0x05E3, 0x05BC,
+	0x05E4, 0x05BC, 0x05E6, 0x05BC, 0x05E7, 0x05BC, 0x05E8, 0x05BC,
+	0x05E9, 0x05BC, 0x05EA, 0x05BC, 0x05D5, 0x05B9, 0x05D1, 0x05BF,
+	0x05DB, 0x05BF, 0x05E4, 0x05BF, 0x05D0, 0x05DC, 0x0626, 0x0627,
+	0x0626, 0x06D5, 0x0626, 0x0648, 0x0626, 0x06C7, 0x0626, 0x06C6,
+	0x0626, 0x06C8, 0x0626, 0x06D0, 0x0626, 0x0649, 0x0626, 0x062C,
+	0x0626, 0x062D, 0x0626, 0x0645, 0x0626, 0x064A, 0x0628, 0x062C,
+	0x0628, 0x0645, 0x0628, 0x0649, 0x0628, 0x064A, 0x062A, 0x0649,
+	0x062A, 0x064A, 0x062B, 0x062C, 0x062B, 0x0645, 0x062B, 0x0649,
+	0x062B, 0x064A, 0x062E, 0x062D, 0x0636, 0x062C, 0x0636, 0x0645,
+	0x0637, 0x062D, 0x0638, 0x0645, 0x063A, 0x062C, 0x0641, 0x062C,
+	0x0641, 0x062D, 0x0641, 0x0649, 0x0641, 0x064A, 0x0642, 0x062D,
+	0x0642, 0x0649, 0x0642, 0x064A, 0x0643, 0x0627, 0x0643, 0x062C,
+	0x0643, 0x062D, 0x0643, 0x062E, 0x0643, 0x0644, 0x0643, 0x0649,
+	0x0643, 0x064A, 0x0646, 0x062E, 0x0646, 0x0649, 0x0646, 0x064A,
+	0x0647, 0x062C, 0x0647, 0x0649, 0x0647, 0x064A, 0x064A, 0x0649,
+	0x0630, 0x0670, 0x0631, 0x0670, 0x0649, 0x0670, 0x0626, 0x0631,
+	0x0626, 0x0632, 0x0626, 0x0646, 0x0628, 0x0632, 0x0628, 0x0646,
+	0x062A, 0x0631, 0x062A, 0x0632, 0x062A, 0x0646, 0x062B, 0x0631,
+	0x062B, 0x0632, 0x062B, 0x0646, 0x0645, 0x0627, 0x0646, 0x0631,
+	0x0646, 0x0632, 0x0646, 0x0646, 0x064A, 0x0631, 0x064A, 0x0632,
+	0x0626, 0x062E, 0x0626, 0x0647, 0x0628, 0x0647, 0x062A, 0x0647,
+	0x0635, 0x062E, 0x0646, 0x0647, 0x0647, 0x0670, 0x062B, 0x0647,
+	0x0633, 0x0647, 0x0634, 0x0647, 0x0637, 0x0649, 0x0637, 0x064A,
+	0x0639, 0x0649, 0x0639, 0x064A, 0x063A, 0x0649, 0x063A, 0x064A,
+	0x0633, 0x0649, 0x0633, 0x064A, 0x0634, 0x0649, 0x0634, 0x064A,
+	0x0635, 0x0649, 0x0635, 0x064A, 0x0636, 0x0649, 0x0636, 0x064A,
+	0x0634, 0x062E, 0x0634, 0x0631, 0x0633, 0x0631, 0x0635, 0x0631,
+	0x0636, 0x0631, 0x0627, 0x064B, 0x0020, 0x064B, 0x0640, 0x064B,
+	0x0640, 0x0651, 0x0020, 0x0652, 0x0640, 0x0652, 0x0644, 0x0622,
+	0x0644, 0x0623, 0x0644, 0x0625, 0x105D2, 0x0307, 0x105DA, 0x0307,
+	0x11099, 0x110BA, 0x1109B, 0x110BA, 0x110A5, 0x110BA, 0x11131, 0x11127,
+	0x11132, 0x11127, 0x11347, 0x1133E, 0x11347, 0x11357, 0x11382, 0x113C9,
+	0x11384, 0x113BB, 0x1138B, 0x113C2, 0x11390, 0x113C9, 0x113C2, 0x113C2,
+	0x113C2, 0x113B8, 0x113C2, 0x113C9, 0x114B9, 0x114BA, 0x114B9, 0x114B0,
+	0x114B9, 0x114BD, 0x115B8, 0x115AF, 0x115B9, 0x115AF, 0x11935, 0x11930,
+	0x1611E, 0x1611E, 0x1611E, 0x16129, 0x1611E, 0x1611F, 0x16129, 0x1611F,
+	0x1611E, 0x16120, 0x16121, 0x1611F, 0x16122, 0x1611F, 0x16121, 0x16120,
+	0x16D67, 0x16D67, 0x16D63, 0x16D67, 0x16D69, 0x16D67, 0x1D157, 0x1D165,
+	0x1D158, 0x1D165, 0x1D15F, 0x1D16E, 0x1D15F, 0x1D16F, 0x1D15F, 0x1D170,
+	0x1D15F, 0x1D171, 0x1D15F, 0x1D172, 0x1D1B9, 0x1D165, 0x1D1BA, 0x1D165,
+	0x1D1BB, 0x1D16E, 0x1D1BC, 0x1D16E, 0x1D1BB, 0x1D16F, 0x1D1BC, 0x1D16F,
+	0x0030, 0x002C, 0x0031, 0x002C, 0x0032, 0x002C, 0x0033, 0x002C,
+	0x0034, 0x002C, 0x0035, 0x002C, 0x0036, 0x002C, 0x0037, 0x002C,
+	0x0038, 0x002C, 0x0039, 0x002C, 0x0043, 0x0044, 0x0057, 0x005A,
+	0x0048, 0x0056, 0x0053, 0x0044, 0x0053, 0x0053, 0x0057, 0x0043,
+	0x004D, 0x0043, 0x004D, 0x0044, 0x004D, 0x0052, 0x0044, 0x004A,
+	0x307B, 0x304B, 0x30B3, 0x30B3, 0x242EE, 0x2284A, 0x22844, 0x233D5,
+	0x25249, 0x25CD0, 0x27ED3, 0x1DF04, 0x1DF05, 0x1DF06, 0x1DF08, 0x1DF0A,
+	0x1DF1E, 0x20122, 0x2063A, 0x2051C, 0x2054B, 0x291DF, 0x20A2C, 0x20B63,
+	0x214E4, 0x216A8, 0x216EA, 0x219C8, 0x21B18, 0x21DE4, 0x21DE6, 0x22183,
+	0x2A392, 0x22331, 0x232B8, 0x261DA, 0x226D4, 0x22B0C, 0x22BF1, 0x2300A,
+	0x233C3, 0x2346D, 0x236A3, 0x238A7, 0x23A8D, 0x21D0B, 0x23AFA, 0x23CBC,
+	0x23D1E, 0x23ED1, 0x23F5E, 0x23F8E, 0x20525, 0x24263, 0x243AB, 0x24608,
+	0x24735, 0x24814, 0x24C36, 0x24C92, 0x2219F, 0x24FA1, 0x24FB8, 0x25044,
+	0x250F3, 0x250F2, 0x25119, 0x25133, 0x2541D, 0x25626, 0x2569A, 0x256C5,
+	0x2597C, 0x25AA7, 0x25BAB, 0x25C80, 0x25F86, 0x26228, 0x26247, 0x262D9,
+	0x2633E, 0x264DA, 0x26523, 0x265A8, 0x2335F, 0x267A7, 0x267B5, 0x23393,
+	0x2339C, 0x26B3C, 0x26C36, 0x26D6B, 0x26CD5, 0x273CA, 0x26F2C, 0x26FB1,
+	0x270D2, 0x27667, 0x278AE, 0x27966, 0x27CA8, 0x27F2F, 0x20804, 0x208DE,
+	0x285D2, 0x285ED, 0x2872E, 0x28BFA, 0x28D77, 0x29145, 0x2921A, 0x2940A,
+	0x29496, 0x295B6, 0x29B30, 0x2A0CE, 0x2A105, 0x2A20E, 0x2A291, 0x2A600
 };
 
-/* codepoints array  */
-static const uint32 UnicodeDecomp_codepoints[5138] =
+/*
+ * Table of Unicode codepoints for recomposition of the reordered
+ * Unicode string.
+ */
+static const uint32 UnicodeDecompInverseCodes[962] =
 {
-	 /* 0 */ 0x0020, 0x0308,
-	 /* 2 */ 0x0020, 0x0304,
-	 /* 4 */ 0x0020, 0x0301,
-	 /* 6 */ 0x0020, 0x0327,
-	 /* 8 */ 0x0031, 0x2044, 0x0034,
-	 /* 11 */ 0x0031, 0x2044, 0x0032,
-	 /* 14 */ 0x0033, 0x2044, 0x0034,
-	 /* 17 */ 0x0041, 0x0300,
-	 /* 19 */ 0x0041, 0x0301,
-	 /* 21 */ 0x0041, 0x0302,
-	 /* 23 */ 0x0041, 0x0303,
-	 /* 25 */ 0x0041, 0x0308,
-	 /* 27 */ 0x0041, 0x030A,
-	 /* 29 */ 0x0043, 0x0327,
-	 /* 31 */ 0x0045, 0x0300,
-	 /* 33 */ 0x0045, 0x0301,
-	 /* 35 */ 0x0045, 0x0302,
-	 /* 37 */ 0x0045, 0x0308,
-	 /* 39 */ 0x0049, 0x0300,
-	 /* 41 */ 0x0049, 0x0301,
-	 /* 43 */ 0x0049, 0x0302,
-	 /* 45 */ 0x0049, 0x0308,
-	 /* 47 */ 0x004E, 0x0303,
-	 /* 49 */ 0x004F, 0x0300,
-	 /* 51 */ 0x004F, 0x0301,
-	 /* 53 */ 0x004F, 0x0302,
-	 /* 55 */ 0x004F, 0x0303,
-	 /* 57 */ 0x004F, 0x0308,
-	 /* 59 */ 0x0055, 0x0300,
-	 /* 61 */ 0x0055, 0x0301,
-	 /* 63 */ 0x0055, 0x0302,
-	 /* 65 */ 0x0055, 0x0308,
-	 /* 67 */ 0x0059, 0x0301,
-	 /* 69 */ 0x0061, 0x0300,
-	 /* 71 */ 0x0061, 0x0301,
-	 /* 73 */ 0x0061, 0x0302,
-	 /* 75 */ 0x0061, 0x0303,
-	 /* 77 */ 0x0061, 0x0308,
-	 /* 79 */ 0x0061, 0x030A,
-	 /* 81 */ 0x0063, 0x0327,
-	 /* 83 */ 0x0065, 0x0300,
-	 /* 85 */ 0x0065, 0x0301,
-	 /* 87 */ 0x0065, 0x0302,
-	 /* 89 */ 0x0065, 0x0308,
-	 /* 91 */ 0x0069, 0x0300,
-	 /* 93 */ 0x0069, 0x0301,
-	 /* 95 */ 0x0069, 0x0302,
-	 /* 97 */ 0x0069, 0x0308,
-	 /* 99 */ 0x006E, 0x0303,
-	 /* 101 */ 0x006F, 0x0300,
-	 /* 103 */ 0x006F, 0x0301,
-	 /* 105 */ 0x006F, 0x0302,
-	 /* 107 */ 0x006F, 0x0303,
-	 /* 109 */ 0x006F, 0x0308,
-	 /* 111 */ 0x0075, 0x0300,
-	 /* 113 */ 0x0075, 0x0301,
-	 /* 115 */ 0x0075, 0x0302,
-	 /* 117 */ 0x0075, 0x0308,
-	 /* 119 */ 0x0079, 0x0301,
-	 /* 121 */ 0x0079, 0x0308,
-	 /* 123 */ 0x0041, 0x0304,
-	 /* 125 */ 0x0061, 0x0304,
-	 /* 127 */ 0x0041, 0x0306,
-	 /* 129 */ 0x0061, 0x0306,
-	 /* 131 */ 0x0041, 0x0328,
-	 /* 133 */ 0x0061, 0x0328,
-	 /* 135 */ 0x0043, 0x0301,
-	 /* 137 */ 0x0063, 0x0301,
-	 /* 139 */ 0x0043, 0x0302,
-	 /* 141 */ 0x0063, 0x0302,
-	 /* 143 */ 0x0043, 0x0307,
-	 /* 145 */ 0x0063, 0x0307,
-	 /* 147 */ 0x0043, 0x030C,
-	 /* 149 */ 0x0063, 0x030C,
-	 /* 151 */ 0x0044, 0x030C,
-	 /* 153 */ 0x0064, 0x030C,
-	 /* 155 */ 0x0045, 0x0304,
-	 /* 157 */ 0x0065, 0x0304,
-	 /* 159 */ 0x0045, 0x0306,
-	 /* 161 */ 0x0065, 0x0306,
-	 /* 163 */ 0x0045, 0x0307,
-	 /* 165 */ 0x0065, 0x0307,
-	 /* 167 */ 0x0045, 0x0328,
-	 /* 169 */ 0x0065, 0x0328,
-	 /* 171 */ 0x0045, 0x030C,
-	 /* 173 */ 0x0065, 0x030C,
-	 /* 175 */ 0x0047, 0x0302,
-	 /* 177 */ 0x0067, 0x0302,
-	 /* 179 */ 0x0047, 0x0306,
-	 /* 181 */ 0x0067, 0x0306,
-	 /* 183 */ 0x0047, 0x0307,
-	 /* 185 */ 0x0067, 0x0307,
-	 /* 187 */ 0x0047, 0x0327,
-	 /* 189 */ 0x0067, 0x0327,
-	 /* 191 */ 0x0048, 0x0302,
-	 /* 193 */ 0x0068, 0x0302,
-	 /* 195 */ 0x0049, 0x0303,
-	 /* 197 */ 0x0069, 0x0303,
-	 /* 199 */ 0x0049, 0x0304,
-	 /* 201 */ 0x0069, 0x0304,
-	 /* 203 */ 0x0049, 0x0306,
-	 /* 205 */ 0x0069, 0x0306,
-	 /* 207 */ 0x0049, 0x0328,
-	 /* 209 */ 0x0069, 0x0328,
-	 /* 211 */ 0x0049, 0x0307,
-	 /* 213 */ 0x0049, 0x004A,
-	 /* 215 */ 0x0069, 0x006A,
-	 /* 217 */ 0x004A, 0x0302,
-	 /* 219 */ 0x006A, 0x0302,
-	 /* 221 */ 0x004B, 0x0327,
-	 /* 223 */ 0x006B, 0x0327,
-	 /* 225 */ 0x004C, 0x0301,
-	 /* 227 */ 0x006C, 0x0301,
-	 /* 229 */ 0x004C, 0x0327,
-	 /* 231 */ 0x006C, 0x0327,
-	 /* 233 */ 0x004C, 0x030C,
-	 /* 235 */ 0x006C, 0x030C,
-	 /* 237 */ 0x004C, 0x00B7,
-	 /* 239 */ 0x006C, 0x00B7,
-	 /* 241 */ 0x004E, 0x0301,
-	 /* 243 */ 0x006E, 0x0301,
-	 /* 245 */ 0x004E, 0x0327,
-	 /* 247 */ 0x006E, 0x0327,
-	 /* 249 */ 0x004E, 0x030C,
-	 /* 251 */ 0x006E, 0x030C,
-	 /* 253 */ 0x02BC, 0x006E,
-	 /* 255 */ 0x004F, 0x0304,
-	 /* 257 */ 0x006F, 0x0304,
-	 /* 259 */ 0x004F, 0x0306,
-	 /* 261 */ 0x006F, 0x0306,
-	 /* 263 */ 0x004F, 0x030B,
-	 /* 265 */ 0x006F, 0x030B,
-	 /* 267 */ 0x0052, 0x0301,
-	 /* 269 */ 0x0072, 0x0301,
-	 /* 271 */ 0x0052, 0x0327,
-	 /* 273 */ 0x0072, 0x0327,
-	 /* 275 */ 0x0052, 0x030C,
-	 /* 277 */ 0x0072, 0x030C,
-	 /* 279 */ 0x0053, 0x0301,
-	 /* 281 */ 0x0073, 0x0301,
-	 /* 283 */ 0x0053, 0x0302,
-	 /* 285 */ 0x0073, 0x0302,
-	 /* 287 */ 0x0053, 0x0327,
-	 /* 289 */ 0x0073, 0x0327,
-	 /* 291 */ 0x0053, 0x030C,
-	 /* 293 */ 0x0073, 0x030C,
-	 /* 295 */ 0x0054, 0x0327,
-	 /* 297 */ 0x0074, 0x0327,
-	 /* 299 */ 0x0054, 0x030C,
-	 /* 301 */ 0x0074, 0x030C,
-	 /* 303 */ 0x0055, 0x0303,
-	 /* 305 */ 0x0075, 0x0303,
-	 /* 307 */ 0x0055, 0x0304,
-	 /* 309 */ 0x0075, 0x0304,
-	 /* 311 */ 0x0055, 0x0306,
-	 /* 313 */ 0x0075, 0x0306,
-	 /* 315 */ 0x0055, 0x030A,
-	 /* 317 */ 0x0075, 0x030A,
-	 /* 319 */ 0x0055, 0x030B,
-	 /* 321 */ 0x0075, 0x030B,
-	 /* 323 */ 0x0055, 0x0328,
-	 /* 325 */ 0x0075, 0x0328,
-	 /* 327 */ 0x0057, 0x0302,
-	 /* 329 */ 0x0077, 0x0302,
-	 /* 331 */ 0x0059, 0x0302,
-	 /* 333 */ 0x0079, 0x0302,
-	 /* 335 */ 0x0059, 0x0308,
-	 /* 337 */ 0x005A, 0x0301,
-	 /* 339 */ 0x007A, 0x0301,
-	 /* 341 */ 0x005A, 0x0307,
-	 /* 343 */ 0x007A, 0x0307,
-	 /* 345 */ 0x005A, 0x030C,
-	 /* 347 */ 0x007A, 0x030C,
-	 /* 349 */ 0x004F, 0x031B,
-	 /* 351 */ 0x006F, 0x031B,
-	 /* 353 */ 0x0055, 0x031B,
-	 /* 355 */ 0x0075, 0x031B,
-	 /* 357 */ 0x0044, 0x017D,
-	 /* 359 */ 0x0044, 0x017E,
-	 /* 361 */ 0x0064, 0x017E,
-	 /* 363 */ 0x004C, 0x004A,
-	 /* 365 */ 0x004C, 0x006A,
-	 /* 367 */ 0x006C, 0x006A,
-	 /* 369 */ 0x004E, 0x004A,
-	 /* 371 */ 0x004E, 0x006A,
-	 /* 373 */ 0x006E, 0x006A,
-	 /* 375 */ 0x0041, 0x030C,
-	 /* 377 */ 0x0061, 0x030C,
-	 /* 379 */ 0x0049, 0x030C,
-	 /* 381 */ 0x0069, 0x030C,
-	 /* 383 */ 0x004F, 0x030C,
-	 /* 385 */ 0x006F, 0x030C,
-	 /* 387 */ 0x0055, 0x030C,
-	 /* 389 */ 0x0075, 0x030C,
-	 /* 391 */ 0x00DC, 0x0304,
-	 /* 393 */ 0x00FC, 0x0304,
-	 /* 395 */ 0x00DC, 0x0301,
-	 /* 397 */ 0x00FC, 0x0301,
-	 /* 399 */ 0x00DC, 0x030C,
-	 /* 401 */ 0x00FC, 0x030C,
-	 /* 403 */ 0x00DC, 0x0300,
-	 /* 405 */ 0x00FC, 0x0300,
-	 /* 407 */ 0x00C4, 0x0304,
-	 /* 409 */ 0x00E4, 0x0304,
-	 /* 411 */ 0x0226, 0x0304,
-	 /* 413 */ 0x0227, 0x0304,
-	 /* 415 */ 0x00C6, 0x0304,
-	 /* 417 */ 0x00E6, 0x0304,
-	 /* 419 */ 0x0047, 0x030C,
-	 /* 421 */ 0x0067, 0x030C,
-	 /* 423 */ 0x004B, 0x030C,
-	 /* 425 */ 0x006B, 0x030C,
-	 /* 427 */ 0x004F, 0x0328,
-	 /* 429 */ 0x006F, 0x0328,
-	 /* 431 */ 0x01EA, 0x0304,
-	 /* 433 */ 0x01EB, 0x0304,
-	 /* 435 */ 0x01B7, 0x030C,
-	 /* 437 */ 0x0292, 0x030C,
-	 /* 439 */ 0x006A, 0x030C,
-	 /* 441 */ 0x0044, 0x005A,
-	 /* 443 */ 0x0044, 0x007A,
-	 /* 445 */ 0x0064, 0x007A,
-	 /* 447 */ 0x0047, 0x0301,
-	 /* 449 */ 0x0067, 0x0301,
-	 /* 451 */ 0x004E, 0x0300,
-	 /* 453 */ 0x006E, 0x0300,
-	 /* 455 */ 0x00C5, 0x0301,
-	 /* 457 */ 0x00E5, 0x0301,
-	 /* 459 */ 0x00C6, 0x0301,
-	 /* 461 */ 0x00E6, 0x0301,
-	 /* 463 */ 0x00D8, 0x0301,
-	 /* 465 */ 0x00F8, 0x0301,
-	 /* 467 */ 0x0041, 0x030F,
-	 /* 469 */ 0x0061, 0x030F,
-	 /* 471 */ 0x0041, 0x0311,
-	 /* 473 */ 0x0061, 0x0311,
-	 /* 475 */ 0x0045, 0x030F,
-	 /* 477 */ 0x0065, 0x030F,
-	 /* 479 */ 0x0045, 0x0311,
-	 /* 481 */ 0x0065, 0x0311,
-	 /* 483 */ 0x0049, 0x030F,
-	 /* 485 */ 0x0069, 0x030F,
-	 /* 487 */ 0x0049, 0x0311,
-	 /* 489 */ 0x0069, 0x0311,
-	 /* 491 */ 0x004F, 0x030F,
-	 /* 493 */ 0x006F, 0x030F,
-	 /* 495 */ 0x004F, 0x0311,
-	 /* 497 */ 0x006F, 0x0311,
-	 /* 499 */ 0x0052, 0x030F,
-	 /* 501 */ 0x0072, 0x030F,
-	 /* 503 */ 0x0052, 0x0311,
-	 /* 505 */ 0x0072, 0x0311,
-	 /* 507 */ 0x0055, 0x030F,
-	 /* 509 */ 0x0075, 0x030F,
-	 /* 511 */ 0x0055, 0x0311,
-	 /* 513 */ 0x0075, 0x0311,
-	 /* 515 */ 0x0053, 0x0326,
-	 /* 517 */ 0x0073, 0x0326,
-	 /* 519 */ 0x0054, 0x0326,
-	 /* 521 */ 0x0074, 0x0326,
-	 /* 523 */ 0x0048, 0x030C,
-	 /* 525 */ 0x0068, 0x030C,
-	 /* 527 */ 0x0041, 0x0307,
-	 /* 529 */ 0x0061, 0x0307,
-	 /* 531 */ 0x0045, 0x0327,
-	 /* 533 */ 0x0065, 0x0327,
-	 /* 535 */ 0x00D6, 0x0304,
-	 /* 537 */ 0x00F6, 0x0304,
-	 /* 539 */ 0x00D5, 0x0304,
-	 /* 541 */ 0x00F5, 0x0304,
-	 /* 543 */ 0x004F, 0x0307,
-	 /* 545 */ 0x006F, 0x0307,
-	 /* 547 */ 0x022E, 0x0304,
-	 /* 549 */ 0x022F, 0x0304,
-	 /* 551 */ 0x0059, 0x0304,
-	 /* 553 */ 0x0079, 0x0304,
-	 /* 555 */ 0x0020, 0x0306,
-	 /* 557 */ 0x0020, 0x0307,
-	 /* 559 */ 0x0020, 0x030A,
-	 /* 561 */ 0x0020, 0x0328,
-	 /* 563 */ 0x0020, 0x0303,
-	 /* 565 */ 0x0020, 0x030B,
-	 /* 567 */ 0x0308, 0x0301,
-	 /* 569 */ 0x0020, 0x0345,
-	 /* 571 */ 0x0020, 0x0301,
-	 /* 573 */ 0x00A8, 0x0301,
-	 /* 575 */ 0x0391, 0x0301,
-	 /* 577 */ 0x0395, 0x0301,
-	 /* 579 */ 0x0397, 0x0301,
-	 /* 581 */ 0x0399, 0x0301,
-	 /* 583 */ 0x039F, 0x0301,
-	 /* 585 */ 0x03A5, 0x0301,
-	 /* 587 */ 0x03A9, 0x0301,
-	 /* 589 */ 0x03CA, 0x0301,
-	 /* 591 */ 0x0399, 0x0308,
-	 /* 593 */ 0x03A5, 0x0308,
-	 /* 595 */ 0x03B1, 0x0301,
-	 /* 597 */ 0x03B5, 0x0301,
-	 /* 599 */ 0x03B7, 0x0301,
-	 /* 601 */ 0x03B9, 0x0301,
-	 /* 603 */ 0x03CB, 0x0301,
-	 /* 605 */ 0x03B9, 0x0308,
-	 /* 607 */ 0x03C5, 0x0308,
-	 /* 609 */ 0x03BF, 0x0301,
-	 /* 611 */ 0x03C5, 0x0301,
-	 /* 613 */ 0x03C9, 0x0301,
-	 /* 615 */ 0x03D2, 0x0301,
-	 /* 617 */ 0x03D2, 0x0308,
-	 /* 619 */ 0x0415, 0x0300,
-	 /* 621 */ 0x0415, 0x0308,
-	 /* 623 */ 0x0413, 0x0301,
-	 /* 625 */ 0x0406, 0x0308,
-	 /* 627 */ 0x041A, 0x0301,
-	 /* 629 */ 0x0418, 0x0300,
-	 /* 631 */ 0x0423, 0x0306,
-	 /* 633 */ 0x0418, 0x0306,
-	 /* 635 */ 0x0438, 0x0306,
-	 /* 637 */ 0x0435, 0x0300,
-	 /* 639 */ 0x0435, 0x0308,
-	 /* 641 */ 0x0433, 0x0301,
-	 /* 643 */ 0x0456, 0x0308,
-	 /* 645 */ 0x043A, 0x0301,
-	 /* 647 */ 0x0438, 0x0300,
-	 /* 649 */ 0x0443, 0x0306,
-	 /* 651 */ 0x0474, 0x030F,
-	 /* 653 */ 0x0475, 0x030F,
-	 /* 655 */ 0x0416, 0x0306,
-	 /* 657 */ 0x0436, 0x0306,
-	 /* 659 */ 0x0410, 0x0306,
-	 /* 661 */ 0x0430, 0x0306,
-	 /* 663 */ 0x0410, 0x0308,
-	 /* 665 */ 0x0430, 0x0308,
-	 /* 667 */ 0x0415, 0x0306,
-	 /* 669 */ 0x0435, 0x0306,
-	 /* 671 */ 0x04D8, 0x0308,
-	 /* 673 */ 0x04D9, 0x0308,
-	 /* 675 */ 0x0416, 0x0308,
-	 /* 677 */ 0x0436, 0x0308,
-	 /* 679 */ 0x0417, 0x0308,
-	 /* 681 */ 0x0437, 0x0308,
-	 /* 683 */ 0x0418, 0x0304,
-	 /* 685 */ 0x0438, 0x0304,
-	 /* 687 */ 0x0418, 0x0308,
-	 /* 689 */ 0x0438, 0x0308,
-	 /* 691 */ 0x041E, 0x0308,
-	 /* 693 */ 0x043E, 0x0308,
-	 /* 695 */ 0x04E8, 0x0308,
-	 /* 697 */ 0x04E9, 0x0308,
-	 /* 699 */ 0x042D, 0x0308,
-	 /* 701 */ 0x044D, 0x0308,
-	 /* 703 */ 0x0423, 0x0304,
-	 /* 705 */ 0x0443, 0x0304,
-	 /* 707 */ 0x0423, 0x0308,
-	 /* 709 */ 0x0443, 0x0308,
-	 /* 711 */ 0x0423, 0x030B,
-	 /* 713 */ 0x0443, 0x030B,
-	 /* 715 */ 0x0427, 0x0308,
-	 /* 717 */ 0x0447, 0x0308,
-	 /* 719 */ 0x042B, 0x0308,
-	 /* 721 */ 0x044B, 0x0308,
-	 /* 723 */ 0x0565, 0x0582,
-	 /* 725 */ 0x0627, 0x0653,
-	 /* 727 */ 0x0627, 0x0654,
-	 /* 729 */ 0x0648, 0x0654,
-	 /* 731 */ 0x0627, 0x0655,
-	 /* 733 */ 0x064A, 0x0654,
-	 /* 735 */ 0x0627, 0x0674,
-	 /* 737 */ 0x0648, 0x0674,
-	 /* 739 */ 0x06C7, 0x0674,
-	 /* 741 */ 0x064A, 0x0674,
-	 /* 743 */ 0x06D5, 0x0654,
-	 /* 745 */ 0x06C1, 0x0654,
-	 /* 747 */ 0x06D2, 0x0654,
-	 /* 749 */ 0x0928, 0x093C,
-	 /* 751 */ 0x0930, 0x093C,
-	 /* 753 */ 0x0933, 0x093C,
-	 /* 755 */ 0x0915, 0x093C,
-	 /* 757 */ 0x0916, 0x093C,
-	 /* 759 */ 0x0917, 0x093C,
-	 /* 761 */ 0x091C, 0x093C,
-	 /* 763 */ 0x0921, 0x093C,
-	 /* 765 */ 0x0922, 0x093C,
-	 /* 767 */ 0x092B, 0x093C,
-	 /* 769 */ 0x092F, 0x093C,
-	 /* 771 */ 0x09C7, 0x09BE,
-	 /* 773 */ 0x09C7, 0x09D7,
-	 /* 775 */ 0x09A1, 0x09BC,
-	 /* 777 */ 0x09A2, 0x09BC,
-	 /* 779 */ 0x09AF, 0x09BC,
-	 /* 781 */ 0x0A32, 0x0A3C,
-	 /* 783 */ 0x0A38, 0x0A3C,
-	 /* 785 */ 0x0A16, 0x0A3C,
-	 /* 787 */ 0x0A17, 0x0A3C,
-	 /* 789 */ 0x0A1C, 0x0A3C,
-	 /* 791 */ 0x0A2B, 0x0A3C,
-	 /* 793 */ 0x0B47, 0x0B56,
-	 /* 795 */ 0x0B47, 0x0B3E,
-	 /* 797 */ 0x0B47, 0x0B57,
-	 /* 799 */ 0x0B21, 0x0B3C,
-	 /* 801 */ 0x0B22, 0x0B3C,
-	 /* 803 */ 0x0B92, 0x0BD7,
-	 /* 805 */ 0x0BC6, 0x0BBE,
-	 /* 807 */ 0x0BC7, 0x0BBE,
-	 /* 809 */ 0x0BC6, 0x0BD7,
-	 /* 811 */ 0x0C46, 0x0C56,
-	 /* 813 */ 0x0CBF, 0x0CD5,
-	 /* 815 */ 0x0CC6, 0x0CD5,
-	 /* 817 */ 0x0CC6, 0x0CD6,
-	 /* 819 */ 0x0CC6, 0x0CC2,
-	 /* 821 */ 0x0CCA, 0x0CD5,
-	 /* 823 */ 0x0D46, 0x0D3E,
-	 /* 825 */ 0x0D47, 0x0D3E,
-	 /* 827 */ 0x0D46, 0x0D57,
-	 /* 829 */ 0x0DD9, 0x0DCA,
-	 /* 831 */ 0x0DD9, 0x0DCF,
-	 /* 833 */ 0x0DDC, 0x0DCA,
-	 /* 835 */ 0x0DD9, 0x0DDF,
-	 /* 837 */ 0x0E4D, 0x0E32,
-	 /* 839 */ 0x0ECD, 0x0EB2,
-	 /* 841 */ 0x0EAB, 0x0E99,
-	 /* 843 */ 0x0EAB, 0x0EA1,
-	 /* 845 */ 0x0F42, 0x0FB7,
-	 /* 847 */ 0x0F4C, 0x0FB7,
-	 /* 849 */ 0x0F51, 0x0FB7,
-	 /* 851 */ 0x0F56, 0x0FB7,
-	 /* 853 */ 0x0F5B, 0x0FB7,
-	 /* 855 */ 0x0F40, 0x0FB5,
-	 /* 857 */ 0x0F71, 0x0F72,
-	 /* 859 */ 0x0F71, 0x0F74,
-	 /* 861 */ 0x0FB2, 0x0F80,
-	 /* 863 */ 0x0FB2, 0x0F81,
-	 /* 865 */ 0x0FB3, 0x0F80,
-	 /* 867 */ 0x0FB3, 0x0F81,
-	 /* 869 */ 0x0F71, 0x0F80,
-	 /* 871 */ 0x0F92, 0x0FB7,
-	 /* 873 */ 0x0F9C, 0x0FB7,
-	 /* 875 */ 0x0FA1, 0x0FB7,
-	 /* 877 */ 0x0FA6, 0x0FB7,
-	 /* 879 */ 0x0FAB, 0x0FB7,
-	 /* 881 */ 0x0F90, 0x0FB5,
-	 /* 883 */ 0x1025, 0x102E,
-	 /* 885 */ 0x1B05, 0x1B35,
-	 /* 887 */ 0x1B07, 0x1B35,
-	 /* 889 */ 0x1B09, 0x1B35,
-	 /* 891 */ 0x1B0B, 0x1B35,
-	 /* 893 */ 0x1B0D, 0x1B35,
-	 /* 895 */ 0x1B11, 0x1B35,
-	 /* 897 */ 0x1B3A, 0x1B35,
-	 /* 899 */ 0x1B3C, 0x1B35,
-	 /* 901 */ 0x1B3E, 0x1B35,
-	 /* 903 */ 0x1B3F, 0x1B35,
-	 /* 905 */ 0x1B42, 0x1B35,
-	 /* 907 */ 0x0041, 0x0325,
-	 /* 909 */ 0x0061, 0x0325,
-	 /* 911 */ 0x0042, 0x0307,
-	 /* 913 */ 0x0062, 0x0307,
-	 /* 915 */ 0x0042, 0x0323,
-	 /* 917 */ 0x0062, 0x0323,
-	 /* 919 */ 0x0042, 0x0331,
-	 /* 921 */ 0x0062, 0x0331,
-	 /* 923 */ 0x00C7, 0x0301,
-	 /* 925 */ 0x00E7, 0x0301,
-	 /* 927 */ 0x0044, 0x0307,
-	 /* 929 */ 0x0064, 0x0307,
-	 /* 931 */ 0x0044, 0x0323,
-	 /* 933 */ 0x0064, 0x0323,
-	 /* 935 */ 0x0044, 0x0331,
-	 /* 937 */ 0x0064, 0x0331,
-	 /* 939 */ 0x0044, 0x0327,
-	 /* 941 */ 0x0064, 0x0327,
-	 /* 943 */ 0x0044, 0x032D,
-	 /* 945 */ 0x0064, 0x032D,
-	 /* 947 */ 0x0112, 0x0300,
-	 /* 949 */ 0x0113, 0x0300,
-	 /* 951 */ 0x0112, 0x0301,
-	 /* 953 */ 0x0113, 0x0301,
-	 /* 955 */ 0x0045, 0x032D,
-	 /* 957 */ 0x0065, 0x032D,
-	 /* 959 */ 0x0045, 0x0330,
-	 /* 961 */ 0x0065, 0x0330,
-	 /* 963 */ 0x0228, 0x0306,
-	 /* 965 */ 0x0229, 0x0306,
-	 /* 967 */ 0x0046, 0x0307,
-	 /* 969 */ 0x0066, 0x0307,
-	 /* 971 */ 0x0047, 0x0304,
-	 /* 973 */ 0x0067, 0x0304,
-	 /* 975 */ 0x0048, 0x0307,
-	 /* 977 */ 0x0068, 0x0307,
-	 /* 979 */ 0x0048, 0x0323,
-	 /* 981 */ 0x0068, 0x0323,
-	 /* 983 */ 0x0048, 0x0308,
-	 /* 985 */ 0x0068, 0x0308,
-	 /* 987 */ 0x0048, 0x0327,
-	 /* 989 */ 0x0068, 0x0327,
-	 /* 991 */ 0x0048, 0x032E,
-	 /* 993 */ 0x0068, 0x032E,
-	 /* 995 */ 0x0049, 0x0330,
-	 /* 997 */ 0x0069, 0x0330,
-	 /* 999 */ 0x00CF, 0x0301,
-	 /* 1001 */ 0x00EF, 0x0301,
-	 /* 1003 */ 0x004B, 0x0301,
-	 /* 1005 */ 0x006B, 0x0301,
-	 /* 1007 */ 0x004B, 0x0323,
-	 /* 1009 */ 0x006B, 0x0323,
-	 /* 1011 */ 0x004B, 0x0331,
-	 /* 1013 */ 0x006B, 0x0331,
-	 /* 1015 */ 0x004C, 0x0323,
-	 /* 1017 */ 0x006C, 0x0323,
-	 /* 1019 */ 0x1E36, 0x0304,
-	 /* 1021 */ 0x1E37, 0x0304,
-	 /* 1023 */ 0x004C, 0x0331,
-	 /* 1025 */ 0x006C, 0x0331,
-	 /* 1027 */ 0x004C, 0x032D,
-	 /* 1029 */ 0x006C, 0x032D,
-	 /* 1031 */ 0x004D, 0x0301,
-	 /* 1033 */ 0x006D, 0x0301,
-	 /* 1035 */ 0x004D, 0x0307,
-	 /* 1037 */ 0x006D, 0x0307,
-	 /* 1039 */ 0x004D, 0x0323,
-	 /* 1041 */ 0x006D, 0x0323,
-	 /* 1043 */ 0x004E, 0x0307,
-	 /* 1045 */ 0x006E, 0x0307,
-	 /* 1047 */ 0x004E, 0x0323,
-	 /* 1049 */ 0x006E, 0x0323,
-	 /* 1051 */ 0x004E, 0x0331,
-	 /* 1053 */ 0x006E, 0x0331,
-	 /* 1055 */ 0x004E, 0x032D,
-	 /* 1057 */ 0x006E, 0x032D,
-	 /* 1059 */ 0x00D5, 0x0301,
-	 /* 1061 */ 0x00F5, 0x0301,
-	 /* 1063 */ 0x00D5, 0x0308,
-	 /* 1065 */ 0x00F5, 0x0308,
-	 /* 1067 */ 0x014C, 0x0300,
-	 /* 1069 */ 0x014D, 0x0300,
-	 /* 1071 */ 0x014C, 0x0301,
-	 /* 1073 */ 0x014D, 0x0301,
-	 /* 1075 */ 0x0050, 0x0301,
-	 /* 1077 */ 0x0070, 0x0301,
-	 /* 1079 */ 0x0050, 0x0307,
-	 /* 1081 */ 0x0070, 0x0307,
-	 /* 1083 */ 0x0052, 0x0307,
-	 /* 1085 */ 0x0072, 0x0307,
-	 /* 1087 */ 0x0052, 0x0323,
-	 /* 1089 */ 0x0072, 0x0323,
-	 /* 1091 */ 0x1E5A, 0x0304,
-	 /* 1093 */ 0x1E5B, 0x0304,
-	 /* 1095 */ 0x0052, 0x0331,
-	 /* 1097 */ 0x0072, 0x0331,
-	 /* 1099 */ 0x0053, 0x0307,
-	 /* 1101 */ 0x0073, 0x0307,
-	 /* 1103 */ 0x0053, 0x0323,
-	 /* 1105 */ 0x0073, 0x0323,
-	 /* 1107 */ 0x015A, 0x0307,
-	 /* 1109 */ 0x015B, 0x0307,
-	 /* 1111 */ 0x0160, 0x0307,
-	 /* 1113 */ 0x0161, 0x0307,
-	 /* 1115 */ 0x1E62, 0x0307,
-	 /* 1117 */ 0x1E63, 0x0307,
-	 /* 1119 */ 0x0054, 0x0307,
-	 /* 1121 */ 0x0074, 0x0307,
-	 /* 1123 */ 0x0054, 0x0323,
-	 /* 1125 */ 0x0074, 0x0323,
-	 /* 1127 */ 0x0054, 0x0331,
-	 /* 1129 */ 0x0074, 0x0331,
-	 /* 1131 */ 0x0054, 0x032D,
-	 /* 1133 */ 0x0074, 0x032D,
-	 /* 1135 */ 0x0055, 0x0324,
-	 /* 1137 */ 0x0075, 0x0324,
-	 /* 1139 */ 0x0055, 0x0330,
-	 /* 1141 */ 0x0075, 0x0330,
-	 /* 1143 */ 0x0055, 0x032D,
-	 /* 1145 */ 0x0075, 0x032D,
-	 /* 1147 */ 0x0168, 0x0301,
-	 /* 1149 */ 0x0169, 0x0301,
-	 /* 1151 */ 0x016A, 0x0308,
-	 /* 1153 */ 0x016B, 0x0308,
-	 /* 1155 */ 0x0056, 0x0303,
-	 /* 1157 */ 0x0076, 0x0303,
-	 /* 1159 */ 0x0056, 0x0323,
-	 /* 1161 */ 0x0076, 0x0323,
-	 /* 1163 */ 0x0057, 0x0300,
-	 /* 1165 */ 0x0077, 0x0300,
-	 /* 1167 */ 0x0057, 0x0301,
-	 /* 1169 */ 0x0077, 0x0301,
-	 /* 1171 */ 0x0057, 0x0308,
-	 /* 1173 */ 0x0077, 0x0308,
-	 /* 1175 */ 0x0057, 0x0307,
-	 /* 1177 */ 0x0077, 0x0307,
-	 /* 1179 */ 0x0057, 0x0323,
-	 /* 1181 */ 0x0077, 0x0323,
-	 /* 1183 */ 0x0058, 0x0307,
-	 /* 1185 */ 0x0078, 0x0307,
-	 /* 1187 */ 0x0058, 0x0308,
-	 /* 1189 */ 0x0078, 0x0308,
-	 /* 1191 */ 0x0059, 0x0307,
-	 /* 1193 */ 0x0079, 0x0307,
-	 /* 1195 */ 0x005A, 0x0302,
-	 /* 1197 */ 0x007A, 0x0302,
-	 /* 1199 */ 0x005A, 0x0323,
-	 /* 1201 */ 0x007A, 0x0323,
-	 /* 1203 */ 0x005A, 0x0331,
-	 /* 1205 */ 0x007A, 0x0331,
-	 /* 1207 */ 0x0068, 0x0331,
-	 /* 1209 */ 0x0074, 0x0308,
-	 /* 1211 */ 0x0077, 0x030A,
-	 /* 1213 */ 0x0079, 0x030A,
-	 /* 1215 */ 0x0061, 0x02BE,
-	 /* 1217 */ 0x017F, 0x0307,
-	 /* 1219 */ 0x0041, 0x0323,
-	 /* 1221 */ 0x0061, 0x0323,
-	 /* 1223 */ 0x0041, 0x0309,
-	 /* 1225 */ 0x0061, 0x0309,
-	 /* 1227 */ 0x00C2, 0x0301,
-	 /* 1229 */ 0x00E2, 0x0301,
-	 /* 1231 */ 0x00C2, 0x0300,
-	 /* 1233 */ 0x00E2, 0x0300,
-	 /* 1235 */ 0x00C2, 0x0309,
-	 /* 1237 */ 0x00E2, 0x0309,
-	 /* 1239 */ 0x00C2, 0x0303,
-	 /* 1241 */ 0x00E2, 0x0303,
-	 /* 1243 */ 0x1EA0, 0x0302,
-	 /* 1245 */ 0x1EA1, 0x0302,
-	 /* 1247 */ 0x0102, 0x0301,
-	 /* 1249 */ 0x0103, 0x0301,
-	 /* 1251 */ 0x0102, 0x0300,
-	 /* 1253 */ 0x0103, 0x0300,
-	 /* 1255 */ 0x0102, 0x0309,
-	 /* 1257 */ 0x0103, 0x0309,
-	 /* 1259 */ 0x0102, 0x0303,
-	 /* 1261 */ 0x0103, 0x0303,
-	 /* 1263 */ 0x1EA0, 0x0306,
-	 /* 1265 */ 0x1EA1, 0x0306,
-	 /* 1267 */ 0x0045, 0x0323,
-	 /* 1269 */ 0x0065, 0x0323,
-	 /* 1271 */ 0x0045, 0x0309,
-	 /* 1273 */ 0x0065, 0x0309,
-	 /* 1275 */ 0x0045, 0x0303,
-	 /* 1277 */ 0x0065, 0x0303,
-	 /* 1279 */ 0x00CA, 0x0301,
-	 /* 1281 */ 0x00EA, 0x0301,
-	 /* 1283 */ 0x00CA, 0x0300,
-	 /* 1285 */ 0x00EA, 0x0300,
-	 /* 1287 */ 0x00CA, 0x0309,
-	 /* 1289 */ 0x00EA, 0x0309,
-	 /* 1291 */ 0x00CA, 0x0303,
-	 /* 1293 */ 0x00EA, 0x0303,
-	 /* 1295 */ 0x1EB8, 0x0302,
-	 /* 1297 */ 0x1EB9, 0x0302,
-	 /* 1299 */ 0x0049, 0x0309,
-	 /* 1301 */ 0x0069, 0x0309,
-	 /* 1303 */ 0x0049, 0x0323,
-	 /* 1305 */ 0x0069, 0x0323,
-	 /* 1307 */ 0x004F, 0x0323,
-	 /* 1309 */ 0x006F, 0x0323,
-	 /* 1311 */ 0x004F, 0x0309,
-	 /* 1313 */ 0x006F, 0x0309,
-	 /* 1315 */ 0x00D4, 0x0301,
-	 /* 1317 */ 0x00F4, 0x0301,
-	 /* 1319 */ 0x00D4, 0x0300,
-	 /* 1321 */ 0x00F4, 0x0300,
-	 /* 1323 */ 0x00D4, 0x0309,
-	 /* 1325 */ 0x00F4, 0x0309,
-	 /* 1327 */ 0x00D4, 0x0303,
-	 /* 1329 */ 0x00F4, 0x0303,
-	 /* 1331 */ 0x1ECC, 0x0302,
-	 /* 1333 */ 0x1ECD, 0x0302,
-	 /* 1335 */ 0x01A0, 0x0301,
-	 /* 1337 */ 0x01A1, 0x0301,
-	 /* 1339 */ 0x01A0, 0x0300,
-	 /* 1341 */ 0x01A1, 0x0300,
-	 /* 1343 */ 0x01A0, 0x0309,
-	 /* 1345 */ 0x01A1, 0x0309,
-	 /* 1347 */ 0x01A0, 0x0303,
-	 /* 1349 */ 0x01A1, 0x0303,
-	 /* 1351 */ 0x01A0, 0x0323,
-	 /* 1353 */ 0x01A1, 0x0323,
-	 /* 1355 */ 0x0055, 0x0323,
-	 /* 1357 */ 0x0075, 0x0323,
-	 /* 1359 */ 0x0055, 0x0309,
-	 /* 1361 */ 0x0075, 0x0309,
-	 /* 1363 */ 0x01AF, 0x0301,
-	 /* 1365 */ 0x01B0, 0x0301,
-	 /* 1367 */ 0x01AF, 0x0300,
-	 /* 1369 */ 0x01B0, 0x0300,
-	 /* 1371 */ 0x01AF, 0x0309,
-	 /* 1373 */ 0x01B0, 0x0309,
-	 /* 1375 */ 0x01AF, 0x0303,
-	 /* 1377 */ 0x01B0, 0x0303,
-	 /* 1379 */ 0x01AF, 0x0323,
-	 /* 1381 */ 0x01B0, 0x0323,
-	 /* 1383 */ 0x0059, 0x0300,
-	 /* 1385 */ 0x0079, 0x0300,
-	 /* 1387 */ 0x0059, 0x0323,
-	 /* 1389 */ 0x0079, 0x0323,
-	 /* 1391 */ 0x0059, 0x0309,
-	 /* 1393 */ 0x0079, 0x0309,
-	 /* 1395 */ 0x0059, 0x0303,
-	 /* 1397 */ 0x0079, 0x0303,
-	 /* 1399 */ 0x03B1, 0x0313,
-	 /* 1401 */ 0x03B1, 0x0314,
-	 /* 1403 */ 0x1F00, 0x0300,
-	 /* 1405 */ 0x1F01, 0x0300,
-	 /* 1407 */ 0x1F00, 0x0301,
-	 /* 1409 */ 0x1F01, 0x0301,
-	 /* 1411 */ 0x1F00, 0x0342,
-	 /* 1413 */ 0x1F01, 0x0342,
-	 /* 1415 */ 0x0391, 0x0313,
-	 /* 1417 */ 0x0391, 0x0314,
-	 /* 1419 */ 0x1F08, 0x0300,
-	 /* 1421 */ 0x1F09, 0x0300,
-	 /* 1423 */ 0x1F08, 0x0301,
-	 /* 1425 */ 0x1F09, 0x0301,
-	 /* 1427 */ 0x1F08, 0x0342,
-	 /* 1429 */ 0x1F09, 0x0342,
-	 /* 1431 */ 0x03B5, 0x0313,
-	 /* 1433 */ 0x03B5, 0x0314,
-	 /* 1435 */ 0x1F10, 0x0300,
-	 /* 1437 */ 0x1F11, 0x0300,
-	 /* 1439 */ 0x1F10, 0x0301,
-	 /* 1441 */ 0x1F11, 0x0301,
-	 /* 1443 */ 0x0395, 0x0313,
-	 /* 1445 */ 0x0395, 0x0314,
-	 /* 1447 */ 0x1F18, 0x0300,
-	 /* 1449 */ 0x1F19, 0x0300,
-	 /* 1451 */ 0x1F18, 0x0301,
-	 /* 1453 */ 0x1F19, 0x0301,
-	 /* 1455 */ 0x03B7, 0x0313,
-	 /* 1457 */ 0x03B7, 0x0314,
-	 /* 1459 */ 0x1F20, 0x0300,
-	 /* 1461 */ 0x1F21, 0x0300,
-	 /* 1463 */ 0x1F20, 0x0301,
-	 /* 1465 */ 0x1F21, 0x0301,
-	 /* 1467 */ 0x1F20, 0x0342,
-	 /* 1469 */ 0x1F21, 0x0342,
-	 /* 1471 */ 0x0397, 0x0313,
-	 /* 1473 */ 0x0397, 0x0314,
-	 /* 1475 */ 0x1F28, 0x0300,
-	 /* 1477 */ 0x1F29, 0x0300,
-	 /* 1479 */ 0x1F28, 0x0301,
-	 /* 1481 */ 0x1F29, 0x0301,
-	 /* 1483 */ 0x1F28, 0x0342,
-	 /* 1485 */ 0x1F29, 0x0342,
-	 /* 1487 */ 0x03B9, 0x0313,
-	 /* 1489 */ 0x03B9, 0x0314,
-	 /* 1491 */ 0x1F30, 0x0300,
-	 /* 1493 */ 0x1F31, 0x0300,
-	 /* 1495 */ 0x1F30, 0x0301,
-	 /* 1497 */ 0x1F31, 0x0301,
-	 /* 1499 */ 0x1F30, 0x0342,
-	 /* 1501 */ 0x1F31, 0x0342,
-	 /* 1503 */ 0x0399, 0x0313,
-	 /* 1505 */ 0x0399, 0x0314,
-	 /* 1507 */ 0x1F38, 0x0300,
-	 /* 1509 */ 0x1F39, 0x0300,
-	 /* 1511 */ 0x1F38, 0x0301,
-	 /* 1513 */ 0x1F39, 0x0301,
-	 /* 1515 */ 0x1F38, 0x0342,
-	 /* 1517 */ 0x1F39, 0x0342,
-	 /* 1519 */ 0x03BF, 0x0313,
-	 /* 1521 */ 0x03BF, 0x0314,
-	 /* 1523 */ 0x1F40, 0x0300,
-	 /* 1525 */ 0x1F41, 0x0300,
-	 /* 1527 */ 0x1F40, 0x0301,
-	 /* 1529 */ 0x1F41, 0x0301,
-	 /* 1531 */ 0x039F, 0x0313,
-	 /* 1533 */ 0x039F, 0x0314,
-	 /* 1535 */ 0x1F48, 0x0300,
-	 /* 1537 */ 0x1F49, 0x0300,
-	 /* 1539 */ 0x1F48, 0x0301,
-	 /* 1541 */ 0x1F49, 0x0301,
-	 /* 1543 */ 0x03C5, 0x0313,
-	 /* 1545 */ 0x03C5, 0x0314,
-	 /* 1547 */ 0x1F50, 0x0300,
-	 /* 1549 */ 0x1F51, 0x0300,
-	 /* 1551 */ 0x1F50, 0x0301,
-	 /* 1553 */ 0x1F51, 0x0301,
-	 /* 1555 */ 0x1F50, 0x0342,
-	 /* 1557 */ 0x1F51, 0x0342,
-	 /* 1559 */ 0x03A5, 0x0314,
-	 /* 1561 */ 0x1F59, 0x0300,
-	 /* 1563 */ 0x1F59, 0x0301,
-	 /* 1565 */ 0x1F59, 0x0342,
-	 /* 1567 */ 0x03C9, 0x0313,
-	 /* 1569 */ 0x03C9, 0x0314,
-	 /* 1571 */ 0x1F60, 0x0300,
-	 /* 1573 */ 0x1F61, 0x0300,
-	 /* 1575 */ 0x1F60, 0x0301,
-	 /* 1577 */ 0x1F61, 0x0301,
-	 /* 1579 */ 0x1F60, 0x0342,
-	 /* 1581 */ 0x1F61, 0x0342,
-	 /* 1583 */ 0x03A9, 0x0313,
-	 /* 1585 */ 0x03A9, 0x0314,
-	 /* 1587 */ 0x1F68, 0x0300,
-	 /* 1589 */ 0x1F69, 0x0300,
-	 /* 1591 */ 0x1F68, 0x0301,
-	 /* 1593 */ 0x1F69, 0x0301,
-	 /* 1595 */ 0x1F68, 0x0342,
-	 /* 1597 */ 0x1F69, 0x0342,
-	 /* 1599 */ 0x03B1, 0x0300,
-	 /* 1601 */ 0x03B5, 0x0300,
-	 /* 1603 */ 0x03B7, 0x0300,
-	 /* 1605 */ 0x03B9, 0x0300,
-	 /* 1607 */ 0x03BF, 0x0300,
-	 /* 1609 */ 0x03C5, 0x0300,
-	 /* 1611 */ 0x03C9, 0x0300,
-	 /* 1613 */ 0x1F00, 0x0345,
-	 /* 1615 */ 0x1F01, 0x0345,
-	 /* 1617 */ 0x1F02, 0x0345,
-	 /* 1619 */ 0x1F03, 0x0345,
-	 /* 1621 */ 0x1F04, 0x0345,
-	 /* 1623 */ 0x1F05, 0x0345,
-	 /* 1625 */ 0x1F06, 0x0345,
-	 /* 1627 */ 0x1F07, 0x0345,
-	 /* 1629 */ 0x1F08, 0x0345,
-	 /* 1631 */ 0x1F09, 0x0345,
-	 /* 1633 */ 0x1F0A, 0x0345,
-	 /* 1635 */ 0x1F0B, 0x0345,
-	 /* 1637 */ 0x1F0C, 0x0345,
-	 /* 1639 */ 0x1F0D, 0x0345,
-	 /* 1641 */ 0x1F0E, 0x0345,
-	 /* 1643 */ 0x1F0F, 0x0345,
-	 /* 1645 */ 0x1F20, 0x0345,
-	 /* 1647 */ 0x1F21, 0x0345,
-	 /* 1649 */ 0x1F22, 0x0345,
-	 /* 1651 */ 0x1F23, 0x0345,
-	 /* 1653 */ 0x1F24, 0x0345,
-	 /* 1655 */ 0x1F25, 0x0345,
-	 /* 1657 */ 0x1F26, 0x0345,
-	 /* 1659 */ 0x1F27, 0x0345,
-	 /* 1661 */ 0x1F28, 0x0345,
-	 /* 1663 */ 0x1F29, 0x0345,
-	 /* 1665 */ 0x1F2A, 0x0345,
-	 /* 1667 */ 0x1F2B, 0x0345,
-	 /* 1669 */ 0x1F2C, 0x0345,
-	 /* 1671 */ 0x1F2D, 0x0345,
-	 /* 1673 */ 0x1F2E, 0x0345,
-	 /* 1675 */ 0x1F2F, 0x0345,
-	 /* 1677 */ 0x1F60, 0x0345,
-	 /* 1679 */ 0x1F61, 0x0345,
-	 /* 1681 */ 0x1F62, 0x0345,
-	 /* 1683 */ 0x1F63, 0x0345,
-	 /* 1685 */ 0x1F64, 0x0345,
-	 /* 1687 */ 0x1F65, 0x0345,
-	 /* 1689 */ 0x1F66, 0x0345,
-	 /* 1691 */ 0x1F67, 0x0345,
-	 /* 1693 */ 0x1F68, 0x0345,
-	 /* 1695 */ 0x1F69, 0x0345,
-	 /* 1697 */ 0x1F6A, 0x0345,
-	 /* 1699 */ 0x1F6B, 0x0345,
-	 /* 1701 */ 0x1F6C, 0x0345,
-	 /* 1703 */ 0x1F6D, 0x0345,
-	 /* 1705 */ 0x1F6E, 0x0345,
-	 /* 1707 */ 0x1F6F, 0x0345,
-	 /* 1709 */ 0x03B1, 0x0306,
-	 /* 1711 */ 0x03B1, 0x0304,
-	 /* 1713 */ 0x1F70, 0x0345,
-	 /* 1715 */ 0x03B1, 0x0345,
-	 /* 1717 */ 0x03AC, 0x0345,
-	 /* 1719 */ 0x03B1, 0x0342,
-	 /* 1721 */ 0x1FB6, 0x0345,
-	 /* 1723 */ 0x0391, 0x0306,
-	 /* 1725 */ 0x0391, 0x0304,
-	 /* 1727 */ 0x0391, 0x0300,
-	 /* 1729 */ 0x0391, 0x0345,
-	 /* 1731 */ 0x0020, 0x0313,
-	 /* 1733 */ 0x0020, 0x0313,
-	 /* 1735 */ 0x0020, 0x0342,
-	 /* 1737 */ 0x00A8, 0x0342,
-	 /* 1739 */ 0x1F74, 0x0345,
-	 /* 1741 */ 0x03B7, 0x0345,
-	 /* 1743 */ 0x03AE, 0x0345,
-	 /* 1745 */ 0x03B7, 0x0342,
-	 /* 1747 */ 0x1FC6, 0x0345,
-	 /* 1749 */ 0x0395, 0x0300,
-	 /* 1751 */ 0x0397, 0x0300,
-	 /* 1753 */ 0x0397, 0x0345,
-	 /* 1755 */ 0x1FBF, 0x0300,
-	 /* 1757 */ 0x1FBF, 0x0301,
-	 /* 1759 */ 0x1FBF, 0x0342,
-	 /* 1761 */ 0x03B9, 0x0306,
-	 /* 1763 */ 0x03B9, 0x0304,
-	 /* 1765 */ 0x03CA, 0x0300,
-	 /* 1767 */ 0x03B9, 0x0342,
-	 /* 1769 */ 0x03CA, 0x0342,
-	 /* 1771 */ 0x0399, 0x0306,
-	 /* 1773 */ 0x0399, 0x0304,
-	 /* 1775 */ 0x0399, 0x0300,
-	 /* 1777 */ 0x1FFE, 0x0300,
-	 /* 1779 */ 0x1FFE, 0x0301,
-	 /* 1781 */ 0x1FFE, 0x0342,
-	 /* 1783 */ 0x03C5, 0x0306,
-	 /* 1785 */ 0x03C5, 0x0304,
-	 /* 1787 */ 0x03CB, 0x0300,
-	 /* 1789 */ 0x03C1, 0x0313,
-	 /* 1791 */ 0x03C1, 0x0314,
-	 /* 1793 */ 0x03C5, 0x0342,
-	 /* 1795 */ 0x03CB, 0x0342,
-	 /* 1797 */ 0x03A5, 0x0306,
-	 /* 1799 */ 0x03A5, 0x0304,
-	 /* 1801 */ 0x03A5, 0x0300,
-	 /* 1803 */ 0x03A1, 0x0314,
-	 /* 1805 */ 0x00A8, 0x0300,
-	 /* 1807 */ 0x1F7C, 0x0345,
-	 /* 1809 */ 0x03C9, 0x0345,
-	 /* 1811 */ 0x03CE, 0x0345,
-	 /* 1813 */ 0x03C9, 0x0342,
-	 /* 1815 */ 0x1FF6, 0x0345,
-	 /* 1817 */ 0x039F, 0x0300,
-	 /* 1819 */ 0x03A9, 0x0300,
-	 /* 1821 */ 0x03A9, 0x0345,
-	 /* 1823 */ 0x0020, 0x0314,
-	 /* 1825 */ 0x0020, 0x0333,
-	 /* 1827 */ 0x002E, 0x002E,
-	 /* 1829 */ 0x002E, 0x002E, 0x002E,
-	 /* 1832 */ 0x2032, 0x2032,
-	 /* 1834 */ 0x2032, 0x2032, 0x2032,
-	 /* 1837 */ 0x2035, 0x2035,
-	 /* 1839 */ 0x2035, 0x2035, 0x2035,
-	 /* 1842 */ 0x0021, 0x0021,
-	 /* 1844 */ 0x0020, 0x0305,
-	 /* 1846 */ 0x003F, 0x003F,
-	 /* 1848 */ 0x003F, 0x0021,
-	 /* 1850 */ 0x0021, 0x003F,
-	 /* 1852 */ 0x2032, 0x2032, 0x2032, 0x2032,
-	 /* 1856 */ 0x0052, 0x0073,
-	 /* 1858 */ 0x0061, 0x002F, 0x0063,
-	 /* 1861 */ 0x0061, 0x002F, 0x0073,
-	 /* 1864 */ 0x00B0, 0x0043,
-	 /* 1866 */ 0x0063, 0x002F, 0x006F,
-	 /* 1869 */ 0x0063, 0x002F, 0x0075,
-	 /* 1872 */ 0x00B0, 0x0046,
-	 /* 1874 */ 0x004E, 0x006F,
-	 /* 1876 */ 0x0053, 0x004D,
-	 /* 1878 */ 0x0054, 0x0045, 0x004C,
-	 /* 1881 */ 0x0054, 0x004D,
-	 /* 1883 */ 0x0046, 0x0041, 0x0058,
-	 /* 1886 */ 0x0031, 0x2044, 0x0037,
-	 /* 1889 */ 0x0031, 0x2044, 0x0039,
-	 /* 1892 */ 0x0031, 0x2044, 0x0031, 0x0030,
-	 /* 1896 */ 0x0031, 0x2044, 0x0033,
-	 /* 1899 */ 0x0032, 0x2044, 0x0033,
-	 /* 1902 */ 0x0031, 0x2044, 0x0035,
-	 /* 1905 */ 0x0032, 0x2044, 0x0035,
-	 /* 1908 */ 0x0033, 0x2044, 0x0035,
-	 /* 1911 */ 0x0034, 0x2044, 0x0035,
-	 /* 1914 */ 0x0031, 0x2044, 0x0036,
-	 /* 1917 */ 0x0035, 0x2044, 0x0036,
-	 /* 1920 */ 0x0031, 0x2044, 0x0038,
-	 /* 1923 */ 0x0033, 0x2044, 0x0038,
-	 /* 1926 */ 0x0035, 0x2044, 0x0038,
-	 /* 1929 */ 0x0037, 0x2044, 0x0038,
-	 /* 1932 */ 0x0031, 0x2044,
-	 /* 1934 */ 0x0049, 0x0049,
-	 /* 1936 */ 0x0049, 0x0049, 0x0049,
-	 /* 1939 */ 0x0049, 0x0056,
-	 /* 1941 */ 0x0056, 0x0049,
-	 /* 1943 */ 0x0056, 0x0049, 0x0049,
-	 /* 1946 */ 0x0056, 0x0049, 0x0049, 0x0049,
-	 /* 1950 */ 0x0049, 0x0058,
-	 /* 1952 */ 0x0058, 0x0049,
-	 /* 1954 */ 0x0058, 0x0049, 0x0049,
-	 /* 1957 */ 0x0069, 0x0069,
-	 /* 1959 */ 0x0069, 0x0069, 0x0069,
-	 /* 1962 */ 0x0069, 0x0076,
-	 /* 1964 */ 0x0076, 0x0069,
-	 /* 1966 */ 0x0076, 0x0069, 0x0069,
-	 /* 1969 */ 0x0076, 0x0069, 0x0069, 0x0069,
-	 /* 1973 */ 0x0069, 0x0078,
-	 /* 1975 */ 0x0078, 0x0069,
-	 /* 1977 */ 0x0078, 0x0069, 0x0069,
-	 /* 1980 */ 0x0030, 0x2044, 0x0033,
-	 /* 1983 */ 0x2190, 0x0338,
-	 /* 1985 */ 0x2192, 0x0338,
-	 /* 1987 */ 0x2194, 0x0338,
-	 /* 1989 */ 0x21D0, 0x0338,
-	 /* 1991 */ 0x21D4, 0x0338,
-	 /* 1993 */ 0x21D2, 0x0338,
-	 /* 1995 */ 0x2203, 0x0338,
-	 /* 1997 */ 0x2208, 0x0338,
-	 /* 1999 */ 0x220B, 0x0338,
-	 /* 2001 */ 0x2223, 0x0338,
-	 /* 2003 */ 0x2225, 0x0338,
-	 /* 2005 */ 0x222B, 0x222B,
-	 /* 2007 */ 0x222B, 0x222B, 0x222B,
-	 /* 2010 */ 0x222E, 0x222E,
-	 /* 2012 */ 0x222E, 0x222E, 0x222E,
-	 /* 2015 */ 0x223C, 0x0338,
-	 /* 2017 */ 0x2243, 0x0338,
-	 /* 2019 */ 0x2245, 0x0338,
-	 /* 2021 */ 0x2248, 0x0338,
-	 /* 2023 */ 0x003D, 0x0338,
-	 /* 2025 */ 0x2261, 0x0338,
-	 /* 2027 */ 0x224D, 0x0338,
-	 /* 2029 */ 0x003C, 0x0338,
-	 /* 2031 */ 0x003E, 0x0338,
-	 /* 2033 */ 0x2264, 0x0338,
-	 /* 2035 */ 0x2265, 0x0338,
-	 /* 2037 */ 0x2272, 0x0338,
-	 /* 2039 */ 0x2273, 0x0338,
-	 /* 2041 */ 0x2276, 0x0338,
-	 /* 2043 */ 0x2277, 0x0338,
-	 /* 2045 */ 0x227A, 0x0338,
-	 /* 2047 */ 0x227B, 0x0338,
-	 /* 2049 */ 0x2282, 0x0338,
-	 /* 2051 */ 0x2283, 0x0338,
-	 /* 2053 */ 0x2286, 0x0338,
-	 /* 2055 */ 0x2287, 0x0338,
-	 /* 2057 */ 0x22A2, 0x0338,
-	 /* 2059 */ 0x22A8, 0x0338,
-	 /* 2061 */ 0x22A9, 0x0338,
-	 /* 2063 */ 0x22AB, 0x0338,
-	 /* 2065 */ 0x227C, 0x0338,
-	 /* 2067 */ 0x227D, 0x0338,
-	 /* 2069 */ 0x2291, 0x0338,
-	 /* 2071 */ 0x2292, 0x0338,
-	 /* 2073 */ 0x22B2, 0x0338,
-	 /* 2075 */ 0x22B3, 0x0338,
-	 /* 2077 */ 0x22B4, 0x0338,
-	 /* 2079 */ 0x22B5, 0x0338,
-	 /* 2081 */ 0x0031, 0x0030,
-	 /* 2083 */ 0x0031, 0x0031,
-	 /* 2085 */ 0x0031, 0x0032,
-	 /* 2087 */ 0x0031, 0x0033,
-	 /* 2089 */ 0x0031, 0x0034,
-	 /* 2091 */ 0x0031, 0x0035,
-	 /* 2093 */ 0x0031, 0x0036,
-	 /* 2095 */ 0x0031, 0x0037,
-	 /* 2097 */ 0x0031, 0x0038,
-	 /* 2099 */ 0x0031, 0x0039,
-	 /* 2101 */ 0x0032, 0x0030,
-	 /* 2103 */ 0x0028, 0x0031, 0x0029,
-	 /* 2106 */ 0x0028, 0x0032, 0x0029,
-	 /* 2109 */ 0x0028, 0x0033, 0x0029,
-	 /* 2112 */ 0x0028, 0x0034, 0x0029,
-	 /* 2115 */ 0x0028, 0x0035, 0x0029,
-	 /* 2118 */ 0x0028, 0x0036, 0x0029,
-	 /* 2121 */ 0x0028, 0x0037, 0x0029,
-	 /* 2124 */ 0x0028, 0x0038, 0x0029,
-	 /* 2127 */ 0x0028, 0x0039, 0x0029,
-	 /* 2130 */ 0x0028, 0x0031, 0x0030, 0x0029,
-	 /* 2134 */ 0x0028, 0x0031, 0x0031, 0x0029,
-	 /* 2138 */ 0x0028, 0x0031, 0x0032, 0x0029,
-	 /* 2142 */ 0x0028, 0x0031, 0x0033, 0x0029,
-	 /* 2146 */ 0x0028, 0x0031, 0x0034, 0x0029,
-	 /* 2150 */ 0x0028, 0x0031, 0x0035, 0x0029,
-	 /* 2154 */ 0x0028, 0x0031, 0x0036, 0x0029,
-	 /* 2158 */ 0x0028, 0x0031, 0x0037, 0x0029,
-	 /* 2162 */ 0x0028, 0x0031, 0x0038, 0x0029,
-	 /* 2166 */ 0x0028, 0x0031, 0x0039, 0x0029,
-	 /* 2170 */ 0x0028, 0x0032, 0x0030, 0x0029,
-	 /* 2174 */ 0x0031, 0x002E,
-	 /* 2176 */ 0x0032, 0x002E,
-	 /* 2178 */ 0x0033, 0x002E,
-	 /* 2180 */ 0x0034, 0x002E,
-	 /* 2182 */ 0x0035, 0x002E,
-	 /* 2184 */ 0x0036, 0x002E,
-	 /* 2186 */ 0x0037, 0x002E,
-	 /* 2188 */ 0x0038, 0x002E,
-	 /* 2190 */ 0x0039, 0x002E,
-	 /* 2192 */ 0x0031, 0x0030, 0x002E,
-	 /* 2195 */ 0x0031, 0x0031, 0x002E,
-	 /* 2198 */ 0x0031, 0x0032, 0x002E,
-	 /* 2201 */ 0x0031, 0x0033, 0x002E,
-	 /* 2204 */ 0x0031, 0x0034, 0x002E,
-	 /* 2207 */ 0x0031, 0x0035, 0x002E,
-	 /* 2210 */ 0x0031, 0x0036, 0x002E,
-	 /* 2213 */ 0x0031, 0x0037, 0x002E,
-	 /* 2216 */ 0x0031, 0x0038, 0x002E,
-	 /* 2219 */ 0x0031, 0x0039, 0x002E,
-	 /* 2222 */ 0x0032, 0x0030, 0x002E,
-	 /* 2225 */ 0x0028, 0x0061, 0x0029,
-	 /* 2228 */ 0x0028, 0x0062, 0x0029,
-	 /* 2231 */ 0x0028, 0x0063, 0x0029,
-	 /* 2234 */ 0x0028, 0x0064, 0x0029,
-	 /* 2237 */ 0x0028, 0x0065, 0x0029,
-	 /* 2240 */ 0x0028, 0x0066, 0x0029,
-	 /* 2243 */ 0x0028, 0x0067, 0x0029,
-	 /* 2246 */ 0x0028, 0x0068, 0x0029,
-	 /* 2249 */ 0x0028, 0x0069, 0x0029,
-	 /* 2252 */ 0x0028, 0x006A, 0x0029,
-	 /* 2255 */ 0x0028, 0x006B, 0x0029,
-	 /* 2258 */ 0x0028, 0x006C, 0x0029,
-	 /* 2261 */ 0x0028, 0x006D, 0x0029,
-	 /* 2264 */ 0x0028, 0x006E, 0x0029,
-	 /* 2267 */ 0x0028, 0x006F, 0x0029,
-	 /* 2270 */ 0x0028, 0x0070, 0x0029,
-	 /* 2273 */ 0x0028, 0x0071, 0x0029,
-	 /* 2276 */ 0x0028, 0x0072, 0x0029,
-	 /* 2279 */ 0x0028, 0x0073, 0x0029,
-	 /* 2282 */ 0x0028, 0x0074, 0x0029,
-	 /* 2285 */ 0x0028, 0x0075, 0x0029,
-	 /* 2288 */ 0x0028, 0x0076, 0x0029,
-	 /* 2291 */ 0x0028, 0x0077, 0x0029,
-	 /* 2294 */ 0x0028, 0x0078, 0x0029,
-	 /* 2297 */ 0x0028, 0x0079, 0x0029,
-	 /* 2300 */ 0x0028, 0x007A, 0x0029,
-	 /* 2303 */ 0x222B, 0x222B, 0x222B, 0x222B,
-	 /* 2307 */ 0x003A, 0x003A, 0x003D,
-	 /* 2310 */ 0x003D, 0x003D,
-	 /* 2312 */ 0x003D, 0x003D, 0x003D,
-	 /* 2315 */ 0x2ADD, 0x0338,
-	 /* 2317 */ 0x304B, 0x3099,
-	 /* 2319 */ 0x304D, 0x3099,
-	 /* 2321 */ 0x304F, 0x3099,
-	 /* 2323 */ 0x3051, 0x3099,
-	 /* 2325 */ 0x3053, 0x3099,
-	 /* 2327 */ 0x3055, 0x3099,
-	 /* 2329 */ 0x3057, 0x3099,
-	 /* 2331 */ 0x3059, 0x3099,
-	 /* 2333 */ 0x305B, 0x3099,
-	 /* 2335 */ 0x305D, 0x3099,
-	 /* 2337 */ 0x305F, 0x3099,
-	 /* 2339 */ 0x3061, 0x3099,
-	 /* 2341 */ 0x3064, 0x3099,
-	 /* 2343 */ 0x3066, 0x3099,
-	 /* 2345 */ 0x3068, 0x3099,
-	 /* 2347 */ 0x306F, 0x3099,
-	 /* 2349 */ 0x306F, 0x309A,
-	 /* 2351 */ 0x3072, 0x3099,
-	 /* 2353 */ 0x3072, 0x309A,
-	 /* 2355 */ 0x3075, 0x3099,
-	 /* 2357 */ 0x3075, 0x309A,
-	 /* 2359 */ 0x3078, 0x3099,
-	 /* 2361 */ 0x3078, 0x309A,
-	 /* 2363 */ 0x307B, 0x3099,
-	 /* 2365 */ 0x307B, 0x309A,
-	 /* 2367 */ 0x3046, 0x3099,
-	 /* 2369 */ 0x0020, 0x3099,
-	 /* 2371 */ 0x0020, 0x309A,
-	 /* 2373 */ 0x309D, 0x3099,
-	 /* 2375 */ 0x3088, 0x308A,
-	 /* 2377 */ 0x30AB, 0x3099,
-	 /* 2379 */ 0x30AD, 0x3099,
-	 /* 2381 */ 0x30AF, 0x3099,
-	 /* 2383 */ 0x30B1, 0x3099,
-	 /* 2385 */ 0x30B3, 0x3099,
-	 /* 2387 */ 0x30B5, 0x3099,
-	 /* 2389 */ 0x30B7, 0x3099,
-	 /* 2391 */ 0x30B9, 0x3099,
-	 /* 2393 */ 0x30BB, 0x3099,
-	 /* 2395 */ 0x30BD, 0x3099,
-	 /* 2397 */ 0x30BF, 0x3099,
-	 /* 2399 */ 0x30C1, 0x3099,
-	 /* 2401 */ 0x30C4, 0x3099,
-	 /* 2403 */ 0x30C6, 0x3099,
-	 /* 2405 */ 0x30C8, 0x3099,
-	 /* 2407 */ 0x30CF, 0x3099,
-	 /* 2409 */ 0x30CF, 0x309A,
-	 /* 2411 */ 0x30D2, 0x3099,
-	 /* 2413 */ 0x30D2, 0x309A,
-	 /* 2415 */ 0x30D5, 0x3099,
-	 /* 2417 */ 0x30D5, 0x309A,
-	 /* 2419 */ 0x30D8, 0x3099,
-	 /* 2421 */ 0x30D8, 0x309A,
-	 /* 2423 */ 0x30DB, 0x3099,
-	 /* 2425 */ 0x30DB, 0x309A,
-	 /* 2427 */ 0x30A6, 0x3099,
-	 /* 2429 */ 0x30EF, 0x3099,
-	 /* 2431 */ 0x30F0, 0x3099,
-	 /* 2433 */ 0x30F1, 0x3099,
-	 /* 2435 */ 0x30F2, 0x3099,
-	 /* 2437 */ 0x30FD, 0x3099,
-	 /* 2439 */ 0x30B3, 0x30C8,
-	 /* 2441 */ 0x0028, 0x1100, 0x0029,
-	 /* 2444 */ 0x0028, 0x1102, 0x0029,
-	 /* 2447 */ 0x0028, 0x1103, 0x0029,
-	 /* 2450 */ 0x0028, 0x1105, 0x0029,
-	 /* 2453 */ 0x0028, 0x1106, 0x0029,
-	 /* 2456 */ 0x0028, 0x1107, 0x0029,
-	 /* 2459 */ 0x0028, 0x1109, 0x0029,
-	 /* 2462 */ 0x0028, 0x110B, 0x0029,
-	 /* 2465 */ 0x0028, 0x110C, 0x0029,
-	 /* 2468 */ 0x0028, 0x110E, 0x0029,
-	 /* 2471 */ 0x0028, 0x110F, 0x0029,
-	 /* 2474 */ 0x0028, 0x1110, 0x0029,
-	 /* 2477 */ 0x0028, 0x1111, 0x0029,
-	 /* 2480 */ 0x0028, 0x1112, 0x0029,
-	 /* 2483 */ 0x0028, 0x1100, 0x1161, 0x0029,
-	 /* 2487 */ 0x0028, 0x1102, 0x1161, 0x0029,
-	 /* 2491 */ 0x0028, 0x1103, 0x1161, 0x0029,
-	 /* 2495 */ 0x0028, 0x1105, 0x1161, 0x0029,
-	 /* 2499 */ 0x0028, 0x1106, 0x1161, 0x0029,
-	 /* 2503 */ 0x0028, 0x1107, 0x1161, 0x0029,
-	 /* 2507 */ 0x0028, 0x1109, 0x1161, 0x0029,
-	 /* 2511 */ 0x0028, 0x110B, 0x1161, 0x0029,
-	 /* 2515 */ 0x0028, 0x110C, 0x1161, 0x0029,
-	 /* 2519 */ 0x0028, 0x110E, 0x1161, 0x0029,
-	 /* 2523 */ 0x0028, 0x110F, 0x1161, 0x0029,
-	 /* 2527 */ 0x0028, 0x1110, 0x1161, 0x0029,
-	 /* 2531 */ 0x0028, 0x1111, 0x1161, 0x0029,
-	 /* 2535 */ 0x0028, 0x1112, 0x1161, 0x0029,
-	 /* 2539 */ 0x0028, 0x110C, 0x116E, 0x0029,
-	 /* 2543 */ 0x0028, 0x110B, 0x1169, 0x110C, 0x1165, 0x11AB, 0x0029,
-	 /* 2550 */ 0x0028, 0x110B, 0x1169, 0x1112, 0x116E, 0x0029,
-	 /* 2556 */ 0x0028, 0x4E00, 0x0029,
-	 /* 2559 */ 0x0028, 0x4E8C, 0x0029,
-	 /* 2562 */ 0x0028, 0x4E09, 0x0029,
-	 /* 2565 */ 0x0028, 0x56DB, 0x0029,
-	 /* 2568 */ 0x0028, 0x4E94, 0x0029,
-	 /* 2571 */ 0x0028, 0x516D, 0x0029,
-	 /* 2574 */ 0x0028, 0x4E03, 0x0029,
-	 /* 2577 */ 0x0028, 0x516B, 0x0029,
-	 /* 2580 */ 0x0028, 0x4E5D, 0x0029,
-	 /* 2583 */ 0x0028, 0x5341, 0x0029,
-	 /* 2586 */ 0x0028, 0x6708, 0x0029,
-	 /* 2589 */ 0x0028, 0x706B, 0x0029,
-	 /* 2592 */ 0x0028, 0x6C34, 0x0029,
-	 /* 2595 */ 0x0028, 0x6728, 0x0029,
-	 /* 2598 */ 0x0028, 0x91D1, 0x0029,
-	 /* 2601 */ 0x0028, 0x571F, 0x0029,
-	 /* 2604 */ 0x0028, 0x65E5, 0x0029,
-	 /* 2607 */ 0x0028, 0x682A, 0x0029,
-	 /* 2610 */ 0x0028, 0x6709, 0x0029,
-	 /* 2613 */ 0x0028, 0x793E, 0x0029,
-	 /* 2616 */ 0x0028, 0x540D, 0x0029,
-	 /* 2619 */ 0x0028, 0x7279, 0x0029,
-	 /* 2622 */ 0x0028, 0x8CA1, 0x0029,
-	 /* 2625 */ 0x0028, 0x795D, 0x0029,
-	 /* 2628 */ 0x0028, 0x52B4, 0x0029,
-	 /* 2631 */ 0x0028, 0x4EE3, 0x0029,
-	 /* 2634 */ 0x0028, 0x547C, 0x0029,
-	 /* 2637 */ 0x0028, 0x5B66, 0x0029,
-	 /* 2640 */ 0x0028, 0x76E3, 0x0029,
-	 /* 2643 */ 0x0028, 0x4F01, 0x0029,
-	 /* 2646 */ 0x0028, 0x8CC7, 0x0029,
-	 /* 2649 */ 0x0028, 0x5354, 0x0029,
-	 /* 2652 */ 0x0028, 0x796D, 0x0029,
-	 /* 2655 */ 0x0028, 0x4F11, 0x0029,
-	 /* 2658 */ 0x0028, 0x81EA, 0x0029,
-	 /* 2661 */ 0x0028, 0x81F3, 0x0029,
-	 /* 2664 */ 0x0050, 0x0054, 0x0045,
-	 /* 2667 */ 0x0032, 0x0031,
-	 /* 2669 */ 0x0032, 0x0032,
-	 /* 2671 */ 0x0032, 0x0033,
-	 /* 2673 */ 0x0032, 0x0034,
-	 /* 2675 */ 0x0032, 0x0035,
-	 /* 2677 */ 0x0032, 0x0036,
-	 /* 2679 */ 0x0032, 0x0037,
-	 /* 2681 */ 0x0032, 0x0038,
-	 /* 2683 */ 0x0032, 0x0039,
-	 /* 2685 */ 0x0033, 0x0030,
-	 /* 2687 */ 0x0033, 0x0031,
-	 /* 2689 */ 0x0033, 0x0032,
-	 /* 2691 */ 0x0033, 0x0033,
-	 /* 2693 */ 0x0033, 0x0034,
-	 /* 2695 */ 0x0033, 0x0035,
-	 /* 2697 */ 0x1100, 0x1161,
-	 /* 2699 */ 0x1102, 0x1161,
-	 /* 2701 */ 0x1103, 0x1161,
-	 /* 2703 */ 0x1105, 0x1161,
-	 /* 2705 */ 0x1106, 0x1161,
-	 /* 2707 */ 0x1107, 0x1161,
-	 /* 2709 */ 0x1109, 0x1161,
-	 /* 2711 */ 0x110B, 0x1161,
-	 /* 2713 */ 0x110C, 0x1161,
-	 /* 2715 */ 0x110E, 0x1161,
-	 /* 2717 */ 0x110F, 0x1161,
-	 /* 2719 */ 0x1110, 0x1161,
-	 /* 2721 */ 0x1111, 0x1161,
-	 /* 2723 */ 0x1112, 0x1161,
-	 /* 2725 */ 0x110E, 0x1161, 0x11B7, 0x1100, 0x1169,
-	 /* 2730 */ 0x110C, 0x116E, 0x110B, 0x1174,
-	 /* 2734 */ 0x110B, 0x116E,
-	 /* 2736 */ 0x0033, 0x0036,
-	 /* 2738 */ 0x0033, 0x0037,
-	 /* 2740 */ 0x0033, 0x0038,
-	 /* 2742 */ 0x0033, 0x0039,
-	 /* 2744 */ 0x0034, 0x0030,
-	 /* 2746 */ 0x0034, 0x0031,
-	 /* 2748 */ 0x0034, 0x0032,
-	 /* 2750 */ 0x0034, 0x0033,
-	 /* 2752 */ 0x0034, 0x0034,
-	 /* 2754 */ 0x0034, 0x0035,
-	 /* 2756 */ 0x0034, 0x0036,
-	 /* 2758 */ 0x0034, 0x0037,
-	 /* 2760 */ 0x0034, 0x0038,
-	 /* 2762 */ 0x0034, 0x0039,
-	 /* 2764 */ 0x0035, 0x0030,
-	 /* 2766 */ 0x0031, 0x6708,
-	 /* 2768 */ 0x0032, 0x6708,
-	 /* 2770 */ 0x0033, 0x6708,
-	 /* 2772 */ 0x0034, 0x6708,
-	 /* 2774 */ 0x0035, 0x6708,
-	 /* 2776 */ 0x0036, 0x6708,
-	 /* 2778 */ 0x0037, 0x6708,
-	 /* 2780 */ 0x0038, 0x6708,
-	 /* 2782 */ 0x0039, 0x6708,
-	 /* 2784 */ 0x0031, 0x0030, 0x6708,
-	 /* 2787 */ 0x0031, 0x0031, 0x6708,
-	 /* 2790 */ 0x0031, 0x0032, 0x6708,
-	 /* 2793 */ 0x0048, 0x0067,
-	 /* 2795 */ 0x0065, 0x0072, 0x0067,
-	 /* 2798 */ 0x0065, 0x0056,
-	 /* 2800 */ 0x004C, 0x0054, 0x0044,
-	 /* 2803 */ 0x4EE4, 0x548C,
-	 /* 2805 */ 0x30A2, 0x30D1, 0x30FC, 0x30C8,
-	 /* 2809 */ 0x30A2, 0x30EB, 0x30D5, 0x30A1,
-	 /* 2813 */ 0x30A2, 0x30F3, 0x30DA, 0x30A2,
-	 /* 2817 */ 0x30A2, 0x30FC, 0x30EB,
-	 /* 2820 */ 0x30A4, 0x30CB, 0x30F3, 0x30B0,
-	 /* 2824 */ 0x30A4, 0x30F3, 0x30C1,
-	 /* 2827 */ 0x30A6, 0x30A9, 0x30F3,
-	 /* 2830 */ 0x30A8, 0x30B9, 0x30AF, 0x30FC, 0x30C9,
-	 /* 2835 */ 0x30A8, 0x30FC, 0x30AB, 0x30FC,
-	 /* 2839 */ 0x30AA, 0x30F3, 0x30B9,
-	 /* 2842 */ 0x30AA, 0x30FC, 0x30E0,
-	 /* 2845 */ 0x30AB, 0x30A4, 0x30EA,
-	 /* 2848 */ 0x30AB, 0x30E9, 0x30C3, 0x30C8,
-	 /* 2852 */ 0x30AB, 0x30ED, 0x30EA, 0x30FC,
-	 /* 2856 */ 0x30AC, 0x30ED, 0x30F3,
-	 /* 2859 */ 0x30AC, 0x30F3, 0x30DE,
-	 /* 2862 */ 0x30AE, 0x30AC,
-	 /* 2864 */ 0x30AE, 0x30CB, 0x30FC,
-	 /* 2867 */ 0x30AD, 0x30E5, 0x30EA, 0x30FC,
-	 /* 2871 */ 0x30AE, 0x30EB, 0x30C0, 0x30FC,
-	 /* 2875 */ 0x30AD, 0x30ED,
-	 /* 2877 */ 0x30AD, 0x30ED, 0x30B0, 0x30E9, 0x30E0,
-	 /* 2882 */ 0x30AD, 0x30ED, 0x30E1, 0x30FC, 0x30C8, 0x30EB,
-	 /* 2888 */ 0x30AD, 0x30ED, 0x30EF, 0x30C3, 0x30C8,
-	 /* 2893 */ 0x30B0, 0x30E9, 0x30E0,
-	 /* 2896 */ 0x30B0, 0x30E9, 0x30E0, 0x30C8, 0x30F3,
-	 /* 2901 */ 0x30AF, 0x30EB, 0x30BC, 0x30A4, 0x30ED,
-	 /* 2906 */ 0x30AF, 0x30ED, 0x30FC, 0x30CD,
-	 /* 2910 */ 0x30B1, 0x30FC, 0x30B9,
-	 /* 2913 */ 0x30B3, 0x30EB, 0x30CA,
-	 /* 2916 */ 0x30B3, 0x30FC, 0x30DD,
-	 /* 2919 */ 0x30B5, 0x30A4, 0x30AF, 0x30EB,
-	 /* 2923 */ 0x30B5, 0x30F3, 0x30C1, 0x30FC, 0x30E0,
-	 /* 2928 */ 0x30B7, 0x30EA, 0x30F3, 0x30B0,
-	 /* 2932 */ 0x30BB, 0x30F3, 0x30C1,
-	 /* 2935 */ 0x30BB, 0x30F3, 0x30C8,
-	 /* 2938 */ 0x30C0, 0x30FC, 0x30B9,
-	 /* 2941 */ 0x30C7, 0x30B7,
-	 /* 2943 */ 0x30C9, 0x30EB,
-	 /* 2945 */ 0x30C8, 0x30F3,
-	 /* 2947 */ 0x30CA, 0x30CE,
-	 /* 2949 */ 0x30CE, 0x30C3, 0x30C8,
-	 /* 2952 */ 0x30CF, 0x30A4, 0x30C4,
-	 /* 2955 */ 0x30D1, 0x30FC, 0x30BB, 0x30F3, 0x30C8,
-	 /* 2960 */ 0x30D1, 0x30FC, 0x30C4,
-	 /* 2963 */ 0x30D0, 0x30FC, 0x30EC, 0x30EB,
-	 /* 2967 */ 0x30D4, 0x30A2, 0x30B9, 0x30C8, 0x30EB,
-	 /* 2972 */ 0x30D4, 0x30AF, 0x30EB,
-	 /* 2975 */ 0x30D4, 0x30B3,
-	 /* 2977 */ 0x30D3, 0x30EB,
-	 /* 2979 */ 0x30D5, 0x30A1, 0x30E9, 0x30C3, 0x30C9,
-	 /* 2984 */ 0x30D5, 0x30A3, 0x30FC, 0x30C8,
-	 /* 2988 */ 0x30D6, 0x30C3, 0x30B7, 0x30A7, 0x30EB,
-	 /* 2993 */ 0x30D5, 0x30E9, 0x30F3,
-	 /* 2996 */ 0x30D8, 0x30AF, 0x30BF, 0x30FC, 0x30EB,
-	 /* 3001 */ 0x30DA, 0x30BD,
-	 /* 3003 */ 0x30DA, 0x30CB, 0x30D2,
-	 /* 3006 */ 0x30D8, 0x30EB, 0x30C4,
-	 /* 3009 */ 0x30DA, 0x30F3, 0x30B9,
-	 /* 3012 */ 0x30DA, 0x30FC, 0x30B8,
-	 /* 3015 */ 0x30D9, 0x30FC, 0x30BF,
-	 /* 3018 */ 0x30DD, 0x30A4, 0x30F3, 0x30C8,
-	 /* 3022 */ 0x30DC, 0x30EB, 0x30C8,
-	 /* 3025 */ 0x30DB, 0x30F3,
-	 /* 3027 */ 0x30DD, 0x30F3, 0x30C9,
-	 /* 3030 */ 0x30DB, 0x30FC, 0x30EB,
-	 /* 3033 */ 0x30DB, 0x30FC, 0x30F3,
-	 /* 3036 */ 0x30DE, 0x30A4, 0x30AF, 0x30ED,
-	 /* 3040 */ 0x30DE, 0x30A4, 0x30EB,
-	 /* 3043 */ 0x30DE, 0x30C3, 0x30CF,
-	 /* 3046 */ 0x30DE, 0x30EB, 0x30AF,
-	 /* 3049 */ 0x30DE, 0x30F3, 0x30B7, 0x30E7, 0x30F3,
-	 /* 3054 */ 0x30DF, 0x30AF, 0x30ED, 0x30F3,
-	 /* 3058 */ 0x30DF, 0x30EA,
-	 /* 3060 */ 0x30DF, 0x30EA, 0x30D0, 0x30FC, 0x30EB,
-	 /* 3065 */ 0x30E1, 0x30AC,
-	 /* 3067 */ 0x30E1, 0x30AC, 0x30C8, 0x30F3,
-	 /* 3071 */ 0x30E1, 0x30FC, 0x30C8, 0x30EB,
-	 /* 3075 */ 0x30E4, 0x30FC, 0x30C9,
-	 /* 3078 */ 0x30E4, 0x30FC, 0x30EB,
-	 /* 3081 */ 0x30E6, 0x30A2, 0x30F3,
-	 /* 3084 */ 0x30EA, 0x30C3, 0x30C8, 0x30EB,
-	 /* 3088 */ 0x30EA, 0x30E9,
-	 /* 3090 */ 0x30EB, 0x30D4, 0x30FC,
-	 /* 3093 */ 0x30EB, 0x30FC, 0x30D6, 0x30EB,
-	 /* 3097 */ 0x30EC, 0x30E0,
-	 /* 3099 */ 0x30EC, 0x30F3, 0x30C8, 0x30B2, 0x30F3,
-	 /* 3104 */ 0x30EF, 0x30C3, 0x30C8,
-	 /* 3107 */ 0x0030, 0x70B9,
-	 /* 3109 */ 0x0031, 0x70B9,
-	 /* 3111 */ 0x0032, 0x70B9,
-	 /* 3113 */ 0x0033, 0x70B9,
-	 /* 3115 */ 0x0034, 0x70B9,
-	 /* 3117 */ 0x0035, 0x70B9,
-	 /* 3119 */ 0x0036, 0x70B9,
-	 /* 3121 */ 0x0037, 0x70B9,
-	 /* 3123 */ 0x0038, 0x70B9,
-	 /* 3125 */ 0x0039, 0x70B9,
-	 /* 3127 */ 0x0031, 0x0030, 0x70B9,
-	 /* 3130 */ 0x0031, 0x0031, 0x70B9,
-	 /* 3133 */ 0x0031, 0x0032, 0x70B9,
-	 /* 3136 */ 0x0031, 0x0033, 0x70B9,
-	 /* 3139 */ 0x0031, 0x0034, 0x70B9,
-	 /* 3142 */ 0x0031, 0x0035, 0x70B9,
-	 /* 3145 */ 0x0031, 0x0036, 0x70B9,
-	 /* 3148 */ 0x0031, 0x0037, 0x70B9,
-	 /* 3151 */ 0x0031, 0x0038, 0x70B9,
-	 /* 3154 */ 0x0031, 0x0039, 0x70B9,
-	 /* 3157 */ 0x0032, 0x0030, 0x70B9,
-	 /* 3160 */ 0x0032, 0x0031, 0x70B9,
-	 /* 3163 */ 0x0032, 0x0032, 0x70B9,
-	 /* 3166 */ 0x0032, 0x0033, 0x70B9,
-	 /* 3169 */ 0x0032, 0x0034, 0x70B9,
-	 /* 3172 */ 0x0068, 0x0050, 0x0061,
-	 /* 3175 */ 0x0064, 0x0061,
-	 /* 3177 */ 0x0041, 0x0055,
-	 /* 3179 */ 0x0062, 0x0061, 0x0072,
-	 /* 3182 */ 0x006F, 0x0056,
-	 /* 3184 */ 0x0070, 0x0063,
-	 /* 3186 */ 0x0064, 0x006D,
-	 /* 3188 */ 0x0064, 0x006D, 0x00B2,
-	 /* 3191 */ 0x0064, 0x006D, 0x00B3,
-	 /* 3194 */ 0x0049, 0x0055,
-	 /* 3196 */ 0x5E73, 0x6210,
-	 /* 3198 */ 0x662D, 0x548C,
-	 /* 3200 */ 0x5927, 0x6B63,
-	 /* 3202 */ 0x660E, 0x6CBB,
-	 /* 3204 */ 0x682A, 0x5F0F, 0x4F1A, 0x793E,
-	 /* 3208 */ 0x0070, 0x0041,
-	 /* 3210 */ 0x006E, 0x0041,
-	 /* 3212 */ 0x03BC, 0x0041,
-	 /* 3214 */ 0x006D, 0x0041,
-	 /* 3216 */ 0x006B, 0x0041,
-	 /* 3218 */ 0x004B, 0x0042,
-	 /* 3220 */ 0x004D, 0x0042,
-	 /* 3222 */ 0x0047, 0x0042,
-	 /* 3224 */ 0x0063, 0x0061, 0x006C,
-	 /* 3227 */ 0x006B, 0x0063, 0x0061, 0x006C,
-	 /* 3231 */ 0x0070, 0x0046,
-	 /* 3233 */ 0x006E, 0x0046,
-	 /* 3235 */ 0x03BC, 0x0046,
-	 /* 3237 */ 0x03BC, 0x0067,
-	 /* 3239 */ 0x006D, 0x0067,
-	 /* 3241 */ 0x006B, 0x0067,
-	 /* 3243 */ 0x0048, 0x007A,
-	 /* 3245 */ 0x006B, 0x0048, 0x007A,
-	 /* 3248 */ 0x004D, 0x0048, 0x007A,
-	 /* 3251 */ 0x0047, 0x0048, 0x007A,
-	 /* 3254 */ 0x0054, 0x0048, 0x007A,
-	 /* 3257 */ 0x03BC, 0x2113,
-	 /* 3259 */ 0x006D, 0x2113,
-	 /* 3261 */ 0x0064, 0x2113,
-	 /* 3263 */ 0x006B, 0x2113,
-	 /* 3265 */ 0x0066, 0x006D,
-	 /* 3267 */ 0x006E, 0x006D,
-	 /* 3269 */ 0x03BC, 0x006D,
-	 /* 3271 */ 0x006D, 0x006D,
-	 /* 3273 */ 0x0063, 0x006D,
-	 /* 3275 */ 0x006B, 0x006D,
-	 /* 3277 */ 0x006D, 0x006D, 0x00B2,
-	 /* 3280 */ 0x0063, 0x006D, 0x00B2,
-	 /* 3283 */ 0x006D, 0x00B2,
-	 /* 3285 */ 0x006B, 0x006D, 0x00B2,
-	 /* 3288 */ 0x006D, 0x006D, 0x00B3,
-	 /* 3291 */ 0x0063, 0x006D, 0x00B3,
-	 /* 3294 */ 0x006D, 0x00B3,
-	 /* 3296 */ 0x006B, 0x006D, 0x00B3,
-	 /* 3299 */ 0x006D, 0x2215, 0x0073,
-	 /* 3302 */ 0x006D, 0x2215, 0x0073, 0x00B2,
-	 /* 3306 */ 0x0050, 0x0061,
-	 /* 3308 */ 0x006B, 0x0050, 0x0061,
-	 /* 3311 */ 0x004D, 0x0050, 0x0061,
-	 /* 3314 */ 0x0047, 0x0050, 0x0061,
-	 /* 3317 */ 0x0072, 0x0061, 0x0064,
-	 /* 3320 */ 0x0072, 0x0061, 0x0064, 0x2215, 0x0073,
-	 /* 3325 */ 0x0072, 0x0061, 0x0064, 0x2215, 0x0073, 0x00B2,
-	 /* 3331 */ 0x0070, 0x0073,
-	 /* 3333 */ 0x006E, 0x0073,
-	 /* 3335 */ 0x03BC, 0x0073,
-	 /* 3337 */ 0x006D, 0x0073,
-	 /* 3339 */ 0x0070, 0x0056,
-	 /* 3341 */ 0x006E, 0x0056,
-	 /* 3343 */ 0x03BC, 0x0056,
-	 /* 3345 */ 0x006D, 0x0056,
-	 /* 3347 */ 0x006B, 0x0056,
-	 /* 3349 */ 0x004D, 0x0056,
-	 /* 3351 */ 0x0070, 0x0057,
-	 /* 3353 */ 0x006E, 0x0057,
-	 /* 3355 */ 0x03BC, 0x0057,
-	 /* 3357 */ 0x006D, 0x0057,
-	 /* 3359 */ 0x006B, 0x0057,
-	 /* 3361 */ 0x004D, 0x0057,
-	 /* 3363 */ 0x006B, 0x03A9,
-	 /* 3365 */ 0x004D, 0x03A9,
-	 /* 3367 */ 0x0061, 0x002E, 0x006D, 0x002E,
-	 /* 3371 */ 0x0042, 0x0071,
-	 /* 3373 */ 0x0063, 0x0063,
-	 /* 3375 */ 0x0063, 0x0064,
-	 /* 3377 */ 0x0043, 0x2215, 0x006B, 0x0067,
-	 /* 3381 */ 0x0043, 0x006F, 0x002E,
-	 /* 3384 */ 0x0064, 0x0042,
-	 /* 3386 */ 0x0047, 0x0079,
-	 /* 3388 */ 0x0068, 0x0061,
-	 /* 3390 */ 0x0048, 0x0050,
-	 /* 3392 */ 0x0069, 0x006E,
-	 /* 3394 */ 0x004B, 0x004B,
-	 /* 3396 */ 0x004B, 0x004D,
-	 /* 3398 */ 0x006B, 0x0074,
-	 /* 3400 */ 0x006C, 0x006D,
-	 /* 3402 */ 0x006C, 0x006E,
-	 /* 3404 */ 0x006C, 0x006F, 0x0067,
-	 /* 3407 */ 0x006C, 0x0078,
-	 /* 3409 */ 0x006D, 0x0062,
-	 /* 3411 */ 0x006D, 0x0069, 0x006C,
-	 /* 3414 */ 0x006D, 0x006F, 0x006C,
-	 /* 3417 */ 0x0050, 0x0048,
-	 /* 3419 */ 0x0070, 0x002E, 0x006D, 0x002E,
-	 /* 3423 */ 0x0050, 0x0050, 0x004D,
-	 /* 3426 */ 0x0050, 0x0052,
-	 /* 3428 */ 0x0073, 0x0072,
-	 /* 3430 */ 0x0053, 0x0076,
-	 /* 3432 */ 0x0057, 0x0062,
-	 /* 3434 */ 0x0056, 0x2215, 0x006D,
-	 /* 3437 */ 0x0041, 0x2215, 0x006D,
-	 /* 3440 */ 0x0031, 0x65E5,
-	 /* 3442 */ 0x0032, 0x65E5,
-	 /* 3444 */ 0x0033, 0x65E5,
-	 /* 3446 */ 0x0034, 0x65E5,
-	 /* 3448 */ 0x0035, 0x65E5,
-	 /* 3450 */ 0x0036, 0x65E5,
-	 /* 3452 */ 0x0037, 0x65E5,
-	 /* 3454 */ 0x0038, 0x65E5,
-	 /* 3456 */ 0x0039, 0x65E5,
-	 /* 3458 */ 0x0031, 0x0030, 0x65E5,
-	 /* 3461 */ 0x0031, 0x0031, 0x65E5,
-	 /* 3464 */ 0x0031, 0x0032, 0x65E5,
-	 /* 3467 */ 0x0031, 0x0033, 0x65E5,
-	 /* 3470 */ 0x0031, 0x0034, 0x65E5,
-	 /* 3473 */ 0x0031, 0x0035, 0x65E5,
-	 /* 3476 */ 0x0031, 0x0036, 0x65E5,
-	 /* 3479 */ 0x0031, 0x0037, 0x65E5,
-	 /* 3482 */ 0x0031, 0x0038, 0x65E5,
-	 /* 3485 */ 0x0031, 0x0039, 0x65E5,
-	 /* 3488 */ 0x0032, 0x0030, 0x65E5,
-	 /* 3491 */ 0x0032, 0x0031, 0x65E5,
-	 /* 3494 */ 0x0032, 0x0032, 0x65E5,
-	 /* 3497 */ 0x0032, 0x0033, 0x65E5,
-	 /* 3500 */ 0x0032, 0x0034, 0x65E5,
-	 /* 3503 */ 0x0032, 0x0035, 0x65E5,
-	 /* 3506 */ 0x0032, 0x0036, 0x65E5,
-	 /* 3509 */ 0x0032, 0x0037, 0x65E5,
-	 /* 3512 */ 0x0032, 0x0038, 0x65E5,
-	 /* 3515 */ 0x0032, 0x0039, 0x65E5,
-	 /* 3518 */ 0x0033, 0x0030, 0x65E5,
-	 /* 3521 */ 0x0033, 0x0031, 0x65E5,
-	 /* 3524 */ 0x0067, 0x0061, 0x006C,
-	 /* 3527 */ 0x242EE,
-	 /* 3528 */ 0x2284A,
-	 /* 3529 */ 0x22844,
-	 /* 3530 */ 0x233D5,
-	 /* 3531 */ 0x25249,
-	 /* 3532 */ 0x25CD0,
-	 /* 3533 */ 0x27ED3,
-	 /* 3534 */ 0x0066, 0x0066,
-	 /* 3536 */ 0x0066, 0x0069,
-	 /* 3538 */ 0x0066, 0x006C,
-	 /* 3540 */ 0x0066, 0x0066, 0x0069,
-	 /* 3543 */ 0x0066, 0x0066, 0x006C,
-	 /* 3546 */ 0x017F, 0x0074,
-	 /* 3548 */ 0x0073, 0x0074,
-	 /* 3550 */ 0x0574, 0x0576,
-	 /* 3552 */ 0x0574, 0x0565,
-	 /* 3554 */ 0x0574, 0x056B,
-	 /* 3556 */ 0x057E, 0x0576,
-	 /* 3558 */ 0x0574, 0x056D,
-	 /* 3560 */ 0x05D9, 0x05B4,
-	 /* 3562 */ 0x05F2, 0x05B7,
-	 /* 3564 */ 0x05E9, 0x05C1,
-	 /* 3566 */ 0x05E9, 0x05C2,
-	 /* 3568 */ 0xFB49, 0x05C1,
-	 /* 3570 */ 0xFB49, 0x05C2,
-	 /* 3572 */ 0x05D0, 0x05B7,
-	 /* 3574 */ 0x05D0, 0x05B8,
-	 /* 3576 */ 0x05D0, 0x05BC,
-	 /* 3578 */ 0x05D1, 0x05BC,
-	 /* 3580 */ 0x05D2, 0x05BC,
-	 /* 3582 */ 0x05D3, 0x05BC,
-	 /* 3584 */ 0x05D4, 0x05BC,
-	 /* 3586 */ 0x05D5, 0x05BC,
-	 /* 3588 */ 0x05D6, 0x05BC,
-	 /* 3590 */ 0x05D8, 0x05BC,
-	 /* 3592 */ 0x05D9, 0x05BC,
-	 /* 3594 */ 0x05DA, 0x05BC,
-	 /* 3596 */ 0x05DB, 0x05BC,
-	 /* 3598 */ 0x05DC, 0x05BC,
-	 /* 3600 */ 0x05DE, 0x05BC,
-	 /* 3602 */ 0x05E0, 0x05BC,
-	 /* 3604 */ 0x05E1, 0x05BC,
-	 /* 3606 */ 0x05E3, 0x05BC,
-	 /* 3608 */ 0x05E4, 0x05BC,
-	 /* 3610 */ 0x05E6, 0x05BC,
-	 /* 3612 */ 0x05E7, 0x05BC,
-	 /* 3614 */ 0x05E8, 0x05BC,
-	 /* 3616 */ 0x05E9, 0x05BC,
-	 /* 3618 */ 0x05EA, 0x05BC,
-	 /* 3620 */ 0x05D5, 0x05B9,
-	 /* 3622 */ 0x05D1, 0x05BF,
-	 /* 3624 */ 0x05DB, 0x05BF,
-	 /* 3626 */ 0x05E4, 0x05BF,
-	 /* 3628 */ 0x05D0, 0x05DC,
-	 /* 3630 */ 0x0626, 0x0627,
-	 /* 3632 */ 0x0626, 0x0627,
-	 /* 3634 */ 0x0626, 0x06D5,
-	 /* 3636 */ 0x0626, 0x06D5,
-	 /* 3638 */ 0x0626, 0x0648,
-	 /* 3640 */ 0x0626, 0x0648,
-	 /* 3642 */ 0x0626, 0x06C7,
-	 /* 3644 */ 0x0626, 0x06C7,
-	 /* 3646 */ 0x0626, 0x06C6,
-	 /* 3648 */ 0x0626, 0x06C6,
-	 /* 3650 */ 0x0626, 0x06C8,
-	 /* 3652 */ 0x0626, 0x06C8,
-	 /* 3654 */ 0x0626, 0x06D0,
-	 /* 3656 */ 0x0626, 0x06D0,
-	 /* 3658 */ 0x0626, 0x06D0,
-	 /* 3660 */ 0x0626, 0x0649,
-	 /* 3662 */ 0x0626, 0x0649,
-	 /* 3664 */ 0x0626, 0x0649,
-	 /* 3666 */ 0x0626, 0x062C,
-	 /* 3668 */ 0x0626, 0x062D,
-	 /* 3670 */ 0x0626, 0x0645,
-	 /* 3672 */ 0x0626, 0x0649,
-	 /* 3674 */ 0x0626, 0x064A,
-	 /* 3676 */ 0x0628, 0x062C,
-	 /* 3678 */ 0x0628, 0x062D,
-	 /* 3680 */ 0x0628, 0x062E,
-	 /* 3682 */ 0x0628, 0x0645,
-	 /* 3684 */ 0x0628, 0x0649,
-	 /* 3686 */ 0x0628, 0x064A,
-	 /* 3688 */ 0x062A, 0x062C,
-	 /* 3690 */ 0x062A, 0x062D,
-	 /* 3692 */ 0x062A, 0x062E,
-	 /* 3694 */ 0x062A, 0x0645,
-	 /* 3696 */ 0x062A, 0x0649,
-	 /* 3698 */ 0x062A, 0x064A,
-	 /* 3700 */ 0x062B, 0x062C,
-	 /* 3702 */ 0x062B, 0x0645,
-	 /* 3704 */ 0x062B, 0x0649,
-	 /* 3706 */ 0x062B, 0x064A,
-	 /* 3708 */ 0x062C, 0x062D,
-	 /* 3710 */ 0x062C, 0x0645,
-	 /* 3712 */ 0x062D, 0x062C,
-	 /* 3714 */ 0x062D, 0x0645,
-	 /* 3716 */ 0x062E, 0x062C,
-	 /* 3718 */ 0x062E, 0x062D,
-	 /* 3720 */ 0x062E, 0x0645,
-	 /* 3722 */ 0x0633, 0x062C,
-	 /* 3724 */ 0x0633, 0x062D,
-	 /* 3726 */ 0x0633, 0x062E,
-	 /* 3728 */ 0x0633, 0x0645,
-	 /* 3730 */ 0x0635, 0x062D,
-	 /* 3732 */ 0x0635, 0x0645,
-	 /* 3734 */ 0x0636, 0x062C,
-	 /* 3736 */ 0x0636, 0x062D,
-	 /* 3738 */ 0x0636, 0x062E,
-	 /* 3740 */ 0x0636, 0x0645,
-	 /* 3742 */ 0x0637, 0x062D,
-	 /* 3744 */ 0x0637, 0x0645,
-	 /* 3746 */ 0x0638, 0x0645,
-	 /* 3748 */ 0x0639, 0x062C,
-	 /* 3750 */ 0x0639, 0x0645,
-	 /* 3752 */ 0x063A, 0x062C,
-	 /* 3754 */ 0x063A, 0x0645,
-	 /* 3756 */ 0x0641, 0x062C,
-	 /* 3758 */ 0x0641, 0x062D,
-	 /* 3760 */ 0x0641, 0x062E,
-	 /* 3762 */ 0x0641, 0x0645,
-	 /* 3764 */ 0x0641, 0x0649,
-	 /* 3766 */ 0x0641, 0x064A,
-	 /* 3768 */ 0x0642, 0x062D,
-	 /* 3770 */ 0x0642, 0x0645,
-	 /* 3772 */ 0x0642, 0x0649,
-	 /* 3774 */ 0x0642, 0x064A,
-	 /* 3776 */ 0x0643, 0x0627,
-	 /* 3778 */ 0x0643, 0x062C,
-	 /* 3780 */ 0x0643, 0x062D,
-	 /* 3782 */ 0x0643, 0x062E,
-	 /* 3784 */ 0x0643, 0x0644,
-	 /* 3786 */ 0x0643, 0x0645,
-	 /* 3788 */ 0x0643, 0x0649,
-	 /* 3790 */ 0x0643, 0x064A,
-	 /* 3792 */ 0x0644, 0x062C,
-	 /* 3794 */ 0x0644, 0x062D,
-	 /* 3796 */ 0x0644, 0x062E,
-	 /* 3798 */ 0x0644, 0x0645,
-	 /* 3800 */ 0x0644, 0x0649,
-	 /* 3802 */ 0x0644, 0x064A,
-	 /* 3804 */ 0x0645, 0x062C,
-	 /* 3806 */ 0x0645, 0x062D,
-	 /* 3808 */ 0x0645, 0x062E,
-	 /* 3810 */ 0x0645, 0x0645,
-	 /* 3812 */ 0x0645, 0x0649,
-	 /* 3814 */ 0x0645, 0x064A,
-	 /* 3816 */ 0x0646, 0x062C,
-	 /* 3818 */ 0x0646, 0x062D,
-	 /* 3820 */ 0x0646, 0x062E,
-	 /* 3822 */ 0x0646, 0x0645,
-	 /* 3824 */ 0x0646, 0x0649,
-	 /* 3826 */ 0x0646, 0x064A,
-	 /* 3828 */ 0x0647, 0x062C,
-	 /* 3830 */ 0x0647, 0x0645,
-	 /* 3832 */ 0x0647, 0x0649,
-	 /* 3834 */ 0x0647, 0x064A,
-	 /* 3836 */ 0x064A, 0x062C,
-	 /* 3838 */ 0x064A, 0x062D,
-	 /* 3840 */ 0x064A, 0x062E,
-	 /* 3842 */ 0x064A, 0x0645,
-	 /* 3844 */ 0x064A, 0x0649,
-	 /* 3846 */ 0x064A, 0x064A,
-	 /* 3848 */ 0x0630, 0x0670,
-	 /* 3850 */ 0x0631, 0x0670,
-	 /* 3852 */ 0x0649, 0x0670,
-	 /* 3854 */ 0x0020, 0x064C, 0x0651,
-	 /* 3857 */ 0x0020, 0x064D, 0x0651,
-	 /* 3860 */ 0x0020, 0x064E, 0x0651,
-	 /* 3863 */ 0x0020, 0x064F, 0x0651,
-	 /* 3866 */ 0x0020, 0x0650, 0x0651,
-	 /* 3869 */ 0x0020, 0x0651, 0x0670,
-	 /* 3872 */ 0x0626, 0x0631,
-	 /* 3874 */ 0x0626, 0x0632,
-	 /* 3876 */ 0x0626, 0x0645,
-	 /* 3878 */ 0x0626, 0x0646,
-	 /* 3880 */ 0x0626, 0x0649,
-	 /* 3882 */ 0x0626, 0x064A,
-	 /* 3884 */ 0x0628, 0x0631,
-	 /* 3886 */ 0x0628, 0x0632,
-	 /* 3888 */ 0x0628, 0x0645,
-	 /* 3890 */ 0x0628, 0x0646,
-	 /* 3892 */ 0x0628, 0x0649,
-	 /* 3894 */ 0x0628, 0x064A,
-	 /* 3896 */ 0x062A, 0x0631,
-	 /* 3898 */ 0x062A, 0x0632,
-	 /* 3900 */ 0x062A, 0x0645,
-	 /* 3902 */ 0x062A, 0x0646,
-	 /* 3904 */ 0x062A, 0x0649,
-	 /* 3906 */ 0x062A, 0x064A,
-	 /* 3908 */ 0x062B, 0x0631,
-	 /* 3910 */ 0x062B, 0x0632,
-	 /* 3912 */ 0x062B, 0x0645,
-	 /* 3914 */ 0x062B, 0x0646,
-	 /* 3916 */ 0x062B, 0x0649,
-	 /* 3918 */ 0x062B, 0x064A,
-	 /* 3920 */ 0x0641, 0x0649,
-	 /* 3922 */ 0x0641, 0x064A,
-	 /* 3924 */ 0x0642, 0x0649,
-	 /* 3926 */ 0x0642, 0x064A,
-	 /* 3928 */ 0x0643, 0x0627,
-	 /* 3930 */ 0x0643, 0x0644,
-	 /* 3932 */ 0x0643, 0x0645,
-	 /* 3934 */ 0x0643, 0x0649,
-	 /* 3936 */ 0x0643, 0x064A,
-	 /* 3938 */ 0x0644, 0x0645,
-	 /* 3940 */ 0x0644, 0x0649,
-	 /* 3942 */ 0x0644, 0x064A,
-	 /* 3944 */ 0x0645, 0x0627,
-	 /* 3946 */ 0x0645, 0x0645,
-	 /* 3948 */ 0x0646, 0x0631,
-	 /* 3950 */ 0x0646, 0x0632,
-	 /* 3952 */ 0x0646, 0x0645,
-	 /* 3954 */ 0x0646, 0x0646,
-	 /* 3956 */ 0x0646, 0x0649,
-	 /* 3958 */ 0x0646, 0x064A,
-	 /* 3960 */ 0x0649, 0x0670,
-	 /* 3962 */ 0x064A, 0x0631,
-	 /* 3964 */ 0x064A, 0x0632,
-	 /* 3966 */ 0x064A, 0x0645,
-	 /* 3968 */ 0x064A, 0x0646,
-	 /* 3970 */ 0x064A, 0x0649,
-	 /* 3972 */ 0x064A, 0x064A,
-	 /* 3974 */ 0x0626, 0x062C,
-	 /* 3976 */ 0x0626, 0x062D,
-	 /* 3978 */ 0x0626, 0x062E,
-	 /* 3980 */ 0x0626, 0x0645,
-	 /* 3982 */ 0x0626, 0x0647,
-	 /* 3984 */ 0x0628, 0x062C,
-	 /* 3986 */ 0x0628, 0x062D,
-	 /* 3988 */ 0x0628, 0x062E,
-	 /* 3990 */ 0x0628, 0x0645,
-	 /* 3992 */ 0x0628, 0x0647,
-	 /* 3994 */ 0x062A, 0x062C,
-	 /* 3996 */ 0x062A, 0x062D,
-	 /* 3998 */ 0x062A, 0x062E,
-	 /* 4000 */ 0x062A, 0x0645,
-	 /* 4002 */ 0x062A, 0x0647,
-	 /* 4004 */ 0x062B, 0x0645,
-	 /* 4006 */ 0x062C, 0x062D,
-	 /* 4008 */ 0x062C, 0x0645,
-	 /* 4010 */ 0x062D, 0x062C,
-	 /* 4012 */ 0x062D, 0x0645,
-	 /* 4014 */ 0x062E, 0x062C,
-	 /* 4016 */ 0x062E, 0x0645,
-	 /* 4018 */ 0x0633, 0x062C,
-	 /* 4020 */ 0x0633, 0x062D,
-	 /* 4022 */ 0x0633, 0x062E,
-	 /* 4024 */ 0x0633, 0x0645,
-	 /* 4026 */ 0x0635, 0x062D,
-	 /* 4028 */ 0x0635, 0x062E,
-	 /* 4030 */ 0x0635, 0x0645,
-	 /* 4032 */ 0x0636, 0x062C,
-	 /* 4034 */ 0x0636, 0x062D,
-	 /* 4036 */ 0x0636, 0x062E,
-	 /* 4038 */ 0x0636, 0x0645,
-	 /* 4040 */ 0x0637, 0x062D,
-	 /* 4042 */ 0x0638, 0x0645,
-	 /* 4044 */ 0x0639, 0x062C,
-	 /* 4046 */ 0x0639, 0x0645,
-	 /* 4048 */ 0x063A, 0x062C,
-	 /* 4050 */ 0x063A, 0x0645,
-	 /* 4052 */ 0x0641, 0x062C,
-	 /* 4054 */ 0x0641, 0x062D,
-	 /* 4056 */ 0x0641, 0x062E,
-	 /* 4058 */ 0x0641, 0x0645,
-	 /* 4060 */ 0x0642, 0x062D,
-	 /* 4062 */ 0x0642, 0x0645,
-	 /* 4064 */ 0x0643, 0x062C,
-	 /* 4066 */ 0x0643, 0x062D,
-	 /* 4068 */ 0x0643, 0x062E,
-	 /* 4070 */ 0x0643, 0x0644,
-	 /* 4072 */ 0x0643, 0x0645,
-	 /* 4074 */ 0x0644, 0x062C,
-	 /* 4076 */ 0x0644, 0x062D,
-	 /* 4078 */ 0x0644, 0x062E,
-	 /* 4080 */ 0x0644, 0x0645,
-	 /* 4082 */ 0x0644, 0x0647,
-	 /* 4084 */ 0x0645, 0x062C,
-	 /* 4086 */ 0x0645, 0x062D,
-	 /* 4088 */ 0x0645, 0x062E,
-	 /* 4090 */ 0x0645, 0x0645,
-	 /* 4092 */ 0x0646, 0x062C,
-	 /* 4094 */ 0x0646, 0x062D,
-	 /* 4096 */ 0x0646, 0x062E,
-	 /* 4098 */ 0x0646, 0x0645,
-	 /* 4100 */ 0x0646, 0x0647,
-	 /* 4102 */ 0x0647, 0x062C,
-	 /* 4104 */ 0x0647, 0x0645,
-	 /* 4106 */ 0x0647, 0x0670,
-	 /* 4108 */ 0x064A, 0x062C,
-	 /* 4110 */ 0x064A, 0x062D,
-	 /* 4112 */ 0x064A, 0x062E,
-	 /* 4114 */ 0x064A, 0x0645,
-	 /* 4116 */ 0x064A, 0x0647,
-	 /* 4118 */ 0x0626, 0x0645,
-	 /* 4120 */ 0x0626, 0x0647,
-	 /* 4122 */ 0x0628, 0x0645,
-	 /* 4124 */ 0x0628, 0x0647,
-	 /* 4126 */ 0x062A, 0x0645,
-	 /* 4128 */ 0x062A, 0x0647,
-	 /* 4130 */ 0x062B, 0x0645,
-	 /* 4132 */ 0x062B, 0x0647,
-	 /* 4134 */ 0x0633, 0x0645,
-	 /* 4136 */ 0x0633, 0x0647,
-	 /* 4138 */ 0x0634, 0x0645,
-	 /* 4140 */ 0x0634, 0x0647,
-	 /* 4142 */ 0x0643, 0x0644,
-	 /* 4144 */ 0x0643, 0x0645,
-	 /* 4146 */ 0x0644, 0x0645,
-	 /* 4148 */ 0x0646, 0x0645,
-	 /* 4150 */ 0x0646, 0x0647,
-	 /* 4152 */ 0x064A, 0x0645,
-	 /* 4154 */ 0x064A, 0x0647,
-	 /* 4156 */ 0x0640, 0x064E, 0x0651,
-	 /* 4159 */ 0x0640, 0x064F, 0x0651,
-	 /* 4162 */ 0x0640, 0x0650, 0x0651,
-	 /* 4165 */ 0x0637, 0x0649,
-	 /* 4167 */ 0x0637, 0x064A,
-	 /* 4169 */ 0x0639, 0x0649,
-	 /* 4171 */ 0x0639, 0x064A,
-	 /* 4173 */ 0x063A, 0x0649,
-	 /* 4175 */ 0x063A, 0x064A,
-	 /* 4177 */ 0x0633, 0x0649,
-	 /* 4179 */ 0x0633, 0x064A,
-	 /* 4181 */ 0x0634, 0x0649,
-	 /* 4183 */ 0x0634, 0x064A,
-	 /* 4185 */ 0x062D, 0x0649,
-	 /* 4187 */ 0x062D, 0x064A,
-	 /* 4189 */ 0x062C, 0x0649,
-	 /* 4191 */ 0x062C, 0x064A,
-	 /* 4193 */ 0x062E, 0x0649,
-	 /* 4195 */ 0x062E, 0x064A,
-	 /* 4197 */ 0x0635, 0x0649,
-	 /* 4199 */ 0x0635, 0x064A,
-	 /* 4201 */ 0x0636, 0x0649,
-	 /* 4203 */ 0x0636, 0x064A,
-	 /* 4205 */ 0x0634, 0x062C,
-	 /* 4207 */ 0x0634, 0x062D,
-	 /* 4209 */ 0x0634, 0x062E,
-	 /* 4211 */ 0x0634, 0x0645,
-	 /* 4213 */ 0x0634, 0x0631,
-	 /* 4215 */ 0x0633, 0x0631,
-	 /* 4217 */ 0x0635, 0x0631,
-	 /* 4219 */ 0x0636, 0x0631,
-	 /* 4221 */ 0x0637, 0x0649,
-	 /* 4223 */ 0x0637, 0x064A,
-	 /* 4225 */ 0x0639, 0x0649,
-	 /* 4227 */ 0x0639, 0x064A,
-	 /* 4229 */ 0x063A, 0x0649,
-	 /* 4231 */ 0x063A, 0x064A,
-	 /* 4233 */ 0x0633, 0x0649,
-	 /* 4235 */ 0x0633, 0x064A,
-	 /* 4237 */ 0x0634, 0x0649,
-	 /* 4239 */ 0x0634, 0x064A,
-	 /* 4241 */ 0x062D, 0x0649,
-	 /* 4243 */ 0x062D, 0x064A,
-	 /* 4245 */ 0x062C, 0x0649,
-	 /* 4247 */ 0x062C, 0x064A,
-	 /* 4249 */ 0x062E, 0x0649,
-	 /* 4251 */ 0x062E, 0x064A,
-	 /* 4253 */ 0x0635, 0x0649,
-	 /* 4255 */ 0x0635, 0x064A,
-	 /* 4257 */ 0x0636, 0x0649,
-	 /* 4259 */ 0x0636, 0x064A,
-	 /* 4261 */ 0x0634, 0x062C,
-	 /* 4263 */ 0x0634, 0x062D,
-	 /* 4265 */ 0x0634, 0x062E,
-	 /* 4267 */ 0x0634, 0x0645,
-	 /* 4269 */ 0x0634, 0x0631,
-	 /* 4271 */ 0x0633, 0x0631,
-	 /* 4273 */ 0x0635, 0x0631,
-	 /* 4275 */ 0x0636, 0x0631,
-	 /* 4277 */ 0x0634, 0x062C,
-	 /* 4279 */ 0x0634, 0x062D,
-	 /* 4281 */ 0x0634, 0x062E,
-	 /* 4283 */ 0x0634, 0x0645,
-	 /* 4285 */ 0x0633, 0x0647,
-	 /* 4287 */ 0x0634, 0x0647,
-	 /* 4289 */ 0x0637, 0x0645,
-	 /* 4291 */ 0x0633, 0x062C,
-	 /* 4293 */ 0x0633, 0x062D,
-	 /* 4295 */ 0x0633, 0x062E,
-	 /* 4297 */ 0x0634, 0x062C,
-	 /* 4299 */ 0x0634, 0x062D,
-	 /* 4301 */ 0x0634, 0x062E,
-	 /* 4303 */ 0x0637, 0x0645,
-	 /* 4305 */ 0x0638, 0x0645,
-	 /* 4307 */ 0x0627, 0x064B,
-	 /* 4309 */ 0x0627, 0x064B,
-	 /* 4311 */ 0x062A, 0x062C, 0x0645,
-	 /* 4314 */ 0x062A, 0x062D, 0x062C,
-	 /* 4317 */ 0x062A, 0x062D, 0x062C,
-	 /* 4320 */ 0x062A, 0x062D, 0x0645,
-	 /* 4323 */ 0x062A, 0x062E, 0x0645,
-	 /* 4326 */ 0x062A, 0x0645, 0x062C,
-	 /* 4329 */ 0x062A, 0x0645, 0x062D,
-	 /* 4332 */ 0x062A, 0x0645, 0x062E,
-	 /* 4335 */ 0x062C, 0x0645, 0x062D,
-	 /* 4338 */ 0x062C, 0x0645, 0x062D,
-	 /* 4341 */ 0x062D, 0x0645, 0x064A,
-	 /* 4344 */ 0x062D, 0x0645, 0x0649,
-	 /* 4347 */ 0x0633, 0x062D, 0x062C,
-	 /* 4350 */ 0x0633, 0x062C, 0x062D,
-	 /* 4353 */ 0x0633, 0x062C, 0x0649,
-	 /* 4356 */ 0x0633, 0x0645, 0x062D,
-	 /* 4359 */ 0x0633, 0x0645, 0x062D,
-	 /* 4362 */ 0x0633, 0x0645, 0x062C,
-	 /* 4365 */ 0x0633, 0x0645, 0x0645,
-	 /* 4368 */ 0x0633, 0x0645, 0x0645,
-	 /* 4371 */ 0x0635, 0x062D, 0x062D,
-	 /* 4374 */ 0x0635, 0x062D, 0x062D,
-	 /* 4377 */ 0x0635, 0x0645, 0x0645,
-	 /* 4380 */ 0x0634, 0x062D, 0x0645,
-	 /* 4383 */ 0x0634, 0x062D, 0x0645,
-	 /* 4386 */ 0x0634, 0x062C, 0x064A,
-	 /* 4389 */ 0x0634, 0x0645, 0x062E,
-	 /* 4392 */ 0x0634, 0x0645, 0x062E,
-	 /* 4395 */ 0x0634, 0x0645, 0x0645,
-	 /* 4398 */ 0x0634, 0x0645, 0x0645,
-	 /* 4401 */ 0x0636, 0x062D, 0x0649,
-	 /* 4404 */ 0x0636, 0x062E, 0x0645,
-	 /* 4407 */ 0x0636, 0x062E, 0x0645,
-	 /* 4410 */ 0x0637, 0x0645, 0x062D,
-	 /* 4413 */ 0x0637, 0x0645, 0x062D,
-	 /* 4416 */ 0x0637, 0x0645, 0x0645,
-	 /* 4419 */ 0x0637, 0x0645, 0x064A,
-	 /* 4422 */ 0x0639, 0x062C, 0x0645,
-	 /* 4425 */ 0x0639, 0x0645, 0x0645,
-	 /* 4428 */ 0x0639, 0x0645, 0x0645,
-	 /* 4431 */ 0x0639, 0x0645, 0x0649,
-	 /* 4434 */ 0x063A, 0x0645, 0x0645,
-	 /* 4437 */ 0x063A, 0x0645, 0x064A,
-	 /* 4440 */ 0x063A, 0x0645, 0x0649,
-	 /* 4443 */ 0x0641, 0x062E, 0x0645,
-	 /* 4446 */ 0x0641, 0x062E, 0x0645,
-	 /* 4449 */ 0x0642, 0x0645, 0x062D,
-	 /* 4452 */ 0x0642, 0x0645, 0x0645,
-	 /* 4455 */ 0x0644, 0x062D, 0x0645,
-	 /* 4458 */ 0x0644, 0x062D, 0x064A,
-	 /* 4461 */ 0x0644, 0x062D, 0x0649,
-	 /* 4464 */ 0x0644, 0x062C, 0x062C,
-	 /* 4467 */ 0x0644, 0x062C, 0x062C,
-	 /* 4470 */ 0x0644, 0x062E, 0x0645,
-	 /* 4473 */ 0x0644, 0x062E, 0x0645,
-	 /* 4476 */ 0x0644, 0x0645, 0x062D,
-	 /* 4479 */ 0x0644, 0x0645, 0x062D,
-	 /* 4482 */ 0x0645, 0x062D, 0x062C,
-	 /* 4485 */ 0x0645, 0x062D, 0x0645,
-	 /* 4488 */ 0x0645, 0x062D, 0x064A,
-	 /* 4491 */ 0x0645, 0x062C, 0x062D,
-	 /* 4494 */ 0x0645, 0x062C, 0x0645,
-	 /* 4497 */ 0x0645, 0x062E, 0x062C,
-	 /* 4500 */ 0x0645, 0x062E, 0x0645,
-	 /* 4503 */ 0x0645, 0x062C, 0x062E,
-	 /* 4506 */ 0x0647, 0x0645, 0x062C,
-	 /* 4509 */ 0x0647, 0x0645, 0x0645,
-	 /* 4512 */ 0x0646, 0x062D, 0x0645,
-	 /* 4515 */ 0x0646, 0x062D, 0x0649,
-	 /* 4518 */ 0x0646, 0x062C, 0x0645,
-	 /* 4521 */ 0x0646, 0x062C, 0x0645,
-	 /* 4524 */ 0x0646, 0x062C, 0x0649,
-	 /* 4527 */ 0x0646, 0x0645, 0x064A,
-	 /* 4530 */ 0x0646, 0x0645, 0x0649,
-	 /* 4533 */ 0x064A, 0x0645, 0x0645,
-	 /* 4536 */ 0x064A, 0x0645, 0x0645,
-	 /* 4539 */ 0x0628, 0x062E, 0x064A,
-	 /* 4542 */ 0x062A, 0x062C, 0x064A,
-	 /* 4545 */ 0x062A, 0x062C, 0x0649,
-	 /* 4548 */ 0x062A, 0x062E, 0x064A,
-	 /* 4551 */ 0x062A, 0x062E, 0x0649,
-	 /* 4554 */ 0x062A, 0x0645, 0x064A,
-	 /* 4557 */ 0x062A, 0x0645, 0x0649,
-	 /* 4560 */ 0x062C, 0x0645, 0x064A,
-	 /* 4563 */ 0x062C, 0x062D, 0x0649,
-	 /* 4566 */ 0x062C, 0x0645, 0x0649,
-	 /* 4569 */ 0x0633, 0x062E, 0x0649,
-	 /* 4572 */ 0x0635, 0x062D, 0x064A,
-	 /* 4575 */ 0x0634, 0x062D, 0x064A,
-	 /* 4578 */ 0x0636, 0x062D, 0x064A,
-	 /* 4581 */ 0x0644, 0x062C, 0x064A,
-	 /* 4584 */ 0x0644, 0x0645, 0x064A,
-	 /* 4587 */ 0x064A, 0x062D, 0x064A,
-	 /* 4590 */ 0x064A, 0x062C, 0x064A,
-	 /* 4593 */ 0x064A, 0x0645, 0x064A,
-	 /* 4596 */ 0x0645, 0x0645, 0x064A,
-	 /* 4599 */ 0x0642, 0x0645, 0x064A,
-	 /* 4602 */ 0x0646, 0x062D, 0x064A,
-	 /* 4605 */ 0x0642, 0x0645, 0x062D,
-	 /* 4608 */ 0x0644, 0x062D, 0x0645,
-	 /* 4611 */ 0x0639, 0x0645, 0x064A,
-	 /* 4614 */ 0x0643, 0x0645, 0x064A,
-	 /* 4617 */ 0x0646, 0x062C, 0x062D,
-	 /* 4620 */ 0x0645, 0x062E, 0x064A,
-	 /* 4623 */ 0x0644, 0x062C, 0x0645,
-	 /* 4626 */ 0x0643, 0x0645, 0x0645,
-	 /* 4629 */ 0x0644, 0x062C, 0x0645,
-	 /* 4632 */ 0x0646, 0x062C, 0x062D,
-	 /* 4635 */ 0x062C, 0x062D, 0x064A,
-	 /* 4638 */ 0x062D, 0x062C, 0x064A,
-	 /* 4641 */ 0x0645, 0x062C, 0x064A,
-	 /* 4644 */ 0x0641, 0x0645, 0x064A,
-	 /* 4647 */ 0x0628, 0x062D, 0x064A,
-	 /* 4650 */ 0x0643, 0x0645, 0x0645,
-	 /* 4653 */ 0x0639, 0x062C, 0x0645,
-	 /* 4656 */ 0x0635, 0x0645, 0x0645,
-	 /* 4659 */ 0x0633, 0x062E, 0x064A,
-	 /* 4662 */ 0x0646, 0x062C, 0x064A,
-	 /* 4665 */ 0x0635, 0x0644, 0x06D2,
-	 /* 4668 */ 0x0642, 0x0644, 0x06D2,
-	 /* 4671 */ 0x0627, 0x0644, 0x0644, 0x0647,
-	 /* 4675 */ 0x0627, 0x0643, 0x0628, 0x0631,
-	 /* 4679 */ 0x0645, 0x062D, 0x0645, 0x062F,
-	 /* 4683 */ 0x0635, 0x0644, 0x0639, 0x0645,
-	 /* 4687 */ 0x0631, 0x0633, 0x0648, 0x0644,
-	 /* 4691 */ 0x0639, 0x0644, 0x064A, 0x0647,
-	 /* 4695 */ 0x0648, 0x0633, 0x0644, 0x0645,
-	 /* 4699 */ 0x0635, 0x0644, 0x0649,
-	 /* 4702 */ 0x0635, 0x0644, 0x0649, 0x0020, 0x0627, 0x0644, 0x0644, 0x0647, 0x0020, 0x0639, 0x0644, 0x064A, 0x0647, 0x0020, 0x0648, 0x0633, 0x0644, 0x0645,
-	 /* 4720 */ 0x062C, 0x0644, 0x0020, 0x062C, 0x0644, 0x0627, 0x0644, 0x0647,
-	 /* 4728 */ 0x0631, 0x06CC, 0x0627, 0x0644,
-	 /* 4732 */ 0x0020, 0x064B,
-	 /* 4734 */ 0x0640, 0x064B,
-	 /* 4736 */ 0x0020, 0x064C,
-	 /* 4738 */ 0x0020, 0x064D,
-	 /* 4740 */ 0x0020, 0x064E,
-	 /* 4742 */ 0x0640, 0x064E,
-	 /* 4744 */ 0x0020, 0x064F,
-	 /* 4746 */ 0x0640, 0x064F,
-	 /* 4748 */ 0x0020, 0x0650,
-	 /* 4750 */ 0x0640, 0x0650,
-	 /* 4752 */ 0x0020, 0x0651,
-	 /* 4754 */ 0x0640, 0x0651,
-	 /* 4756 */ 0x0020, 0x0652,
-	 /* 4758 */ 0x0640, 0x0652,
-	 /* 4760 */ 0x0644, 0x0622,
-	 /* 4762 */ 0x0644, 0x0622,
-	 /* 4764 */ 0x0644, 0x0623,
-	 /* 4766 */ 0x0644, 0x0623,
-	 /* 4768 */ 0x0644, 0x0625,
-	 /* 4770 */ 0x0644, 0x0625,
-	 /* 4772 */ 0x0644, 0x0627,
-	 /* 4774 */ 0x0644, 0x0627,
-	 /* 4776 */ 0x105D2, 0x0307,
-	 /* 4778 */ 0x105DA, 0x0307,
-	 /* 4780 */ 0x1DF04,
-	 /* 4781 */ 0x1DF05,
-	 /* 4782 */ 0x1DF06,
-	 /* 4783 */ 0x1DF08,
-	 /* 4784 */ 0x1DF0A,
-	 /* 4785 */ 0x1DF1E,
-	 /* 4786 */ 0x11099, 0x110BA,
-	 /* 4788 */ 0x1109B, 0x110BA,
-	 /* 4790 */ 0x110A5, 0x110BA,
-	 /* 4792 */ 0x11131, 0x11127,
-	 /* 4794 */ 0x11132, 0x11127,
-	 /* 4796 */ 0x11347, 0x1133E,
-	 /* 4798 */ 0x11347, 0x11357,
-	 /* 4800 */ 0x11382, 0x113C9,
-	 /* 4802 */ 0x11384, 0x113BB,
-	 /* 4804 */ 0x1138B, 0x113C2,
-	 /* 4806 */ 0x11390, 0x113C9,
-	 /* 4808 */ 0x113C2, 0x113C2,
-	 /* 4810 */ 0x113C2, 0x113B8,
-	 /* 4812 */ 0x113C2, 0x113C9,
-	 /* 4814 */ 0x114B9, 0x114BA,
-	 /* 4816 */ 0x114B9, 0x114B0,
-	 /* 4818 */ 0x114B9, 0x114BD,
-	 /* 4820 */ 0x115B8, 0x115AF,
-	 /* 4822 */ 0x115B9, 0x115AF,
-	 /* 4824 */ 0x11935, 0x11930,
-	 /* 4826 */ 0x1611E, 0x1611E,
-	 /* 4828 */ 0x1611E, 0x16129,
-	 /* 4830 */ 0x1611E, 0x1611F,
-	 /* 4832 */ 0x16129, 0x1611F,
-	 /* 4834 */ 0x1611E, 0x16120,
-	 /* 4836 */ 0x16121, 0x1611F,
-	 /* 4838 */ 0x16122, 0x1611F,
-	 /* 4840 */ 0x16121, 0x16120,
-	 /* 4842 */ 0x16D67, 0x16D67,
-	 /* 4844 */ 0x16D63, 0x16D67,
-	 /* 4846 */ 0x16D69, 0x16D67,
-	 /* 4848 */ 0x1D157, 0x1D165,
-	 /* 4850 */ 0x1D158, 0x1D165,
-	 /* 4852 */ 0x1D15F, 0x1D16E,
-	 /* 4854 */ 0x1D15F, 0x1D16F,
-	 /* 4856 */ 0x1D15F, 0x1D170,
-	 /* 4858 */ 0x1D15F, 0x1D171,
-	 /* 4860 */ 0x1D15F, 0x1D172,
-	 /* 4862 */ 0x1D1B9, 0x1D165,
-	 /* 4864 */ 0x1D1BA, 0x1D165,
-	 /* 4866 */ 0x1D1BB, 0x1D16E,
-	 /* 4868 */ 0x1D1BC, 0x1D16E,
-	 /* 4870 */ 0x1D1BB, 0x1D16F,
-	 /* 4872 */ 0x1D1BC, 0x1D16F,
-	 /* 4874 */ 0x0030, 0x002E,
-	 /* 4876 */ 0x0030, 0x002C,
-	 /* 4878 */ 0x0031, 0x002C,
-	 /* 4880 */ 0x0032, 0x002C,
-	 /* 4882 */ 0x0033, 0x002C,
-	 /* 4884 */ 0x0034, 0x002C,
-	 /* 4886 */ 0x0035, 0x002C,
-	 /* 4888 */ 0x0036, 0x002C,
-	 /* 4890 */ 0x0037, 0x002C,
-	 /* 4892 */ 0x0038, 0x002C,
-	 /* 4894 */ 0x0039, 0x002C,
-	 /* 4896 */ 0x0028, 0x0041, 0x0029,
-	 /* 4899 */ 0x0028, 0x0042, 0x0029,
-	 /* 4902 */ 0x0028, 0x0043, 0x0029,
-	 /* 4905 */ 0x0028, 0x0044, 0x0029,
-	 /* 4908 */ 0x0028, 0x0045, 0x0029,
-	 /* 4911 */ 0x0028, 0x0046, 0x0029,
-	 /* 4914 */ 0x0028, 0x0047, 0x0029,
-	 /* 4917 */ 0x0028, 0x0048, 0x0029,
-	 /* 4920 */ 0x0028, 0x0049, 0x0029,
-	 /* 4923 */ 0x0028, 0x004A, 0x0029,
-	 /* 4926 */ 0x0028, 0x004B, 0x0029,
-	 /* 4929 */ 0x0028, 0x004C, 0x0029,
-	 /* 4932 */ 0x0028, 0x004D, 0x0029,
-	 /* 4935 */ 0x0028, 0x004E, 0x0029,
-	 /* 4938 */ 0x0028, 0x004F, 0x0029,
-	 /* 4941 */ 0x0028, 0x0050, 0x0029,
-	 /* 4944 */ 0x0028, 0x0051, 0x0029,
-	 /* 4947 */ 0x0028, 0x0052, 0x0029,
-	 /* 4950 */ 0x0028, 0x0053, 0x0029,
-	 /* 4953 */ 0x0028, 0x0054, 0x0029,
-	 /* 4956 */ 0x0028, 0x0055, 0x0029,
-	 /* 4959 */ 0x0028, 0x0056, 0x0029,
-	 /* 4962 */ 0x0028, 0x0057, 0x0029,
-	 /* 4965 */ 0x0028, 0x0058, 0x0029,
-	 /* 4968 */ 0x0028, 0x0059, 0x0029,
-	 /* 4971 */ 0x0028, 0x005A, 0x0029,
-	 /* 4974 */ 0x3014, 0x0053, 0x3015,
-	 /* 4977 */ 0x0043, 0x0044,
-	 /* 4979 */ 0x0057, 0x005A,
-	 /* 4981 */ 0x0048, 0x0056,
-	 /* 4983 */ 0x004D, 0x0056,
-	 /* 4985 */ 0x0053, 0x0044,
-	 /* 4987 */ 0x0053, 0x0053,
-	 /* 4989 */ 0x0050, 0x0050, 0x0056,
-	 /* 4992 */ 0x0057, 0x0043,
-	 /* 4994 */ 0x004D, 0x0043,
-	 /* 4996 */ 0x004D, 0x0044,
-	 /* 4998 */ 0x004D, 0x0052,
-	 /* 5000 */ 0x0044, 0x004A,
-	 /* 5002 */ 0x307B, 0x304B,
-	 /* 5004 */ 0x30B3, 0x30B3,
-	 /* 5006 */ 0x3014, 0x672C, 0x3015,
-	 /* 5009 */ 0x3014, 0x4E09, 0x3015,
-	 /* 5012 */ 0x3014, 0x4E8C, 0x3015,
-	 /* 5015 */ 0x3014, 0x5B89, 0x3015,
-	 /* 5018 */ 0x3014, 0x70B9, 0x3015,
-	 /* 5021 */ 0x3014, 0x6253, 0x3015,
-	 /* 5024 */ 0x3014, 0x76D7, 0x3015,
-	 /* 5027 */ 0x3014, 0x52DD, 0x3015,
-	 /* 5030 */ 0x3014, 0x6557, 0x3015,
-	 /* 5033 */ 0x20122,
-	 /* 5034 */ 0x2063A,
-	 /* 5035 */ 0x2051C,
-	 /* 5036 */ 0x2054B,
-	 /* 5037 */ 0x291DF,
-	 /* 5038 */ 0x20A2C,
-	 /* 5039 */ 0x20B63,
-	 /* 5040 */ 0x214E4,
-	 /* 5041 */ 0x216A8,
-	 /* 5042 */ 0x216EA,
-	 /* 5043 */ 0x219C8,
-	 /* 5044 */ 0x21B18,
-	 /* 5045 */ 0x21DE4,
-	 /* 5046 */ 0x21DE6,
-	 /* 5047 */ 0x22183,
-	 /* 5048 */ 0x2A392,
-	 /* 5049 */ 0x22331,
-	 /* 5050 */ 0x22331,
-	 /* 5051 */ 0x232B8,
-	 /* 5052 */ 0x261DA,
-	 /* 5053 */ 0x226D4,
-	 /* 5054 */ 0x22B0C,
-	 /* 5055 */ 0x22BF1,
-	 /* 5056 */ 0x2300A,
-	 /* 5057 */ 0x233C3,
-	 /* 5058 */ 0x2346D,
-	 /* 5059 */ 0x236A3,
-	 /* 5060 */ 0x238A7,
-	 /* 5061 */ 0x23A8D,
-	 /* 5062 */ 0x21D0B,
-	 /* 5063 */ 0x23AFA,
-	 /* 5064 */ 0x23CBC,
-	 /* 5065 */ 0x23D1E,
-	 /* 5066 */ 0x23ED1,
-	 /* 5067 */ 0x23F5E,
-	 /* 5068 */ 0x23F8E,
-	 /* 5069 */ 0x20525,
-	 /* 5070 */ 0x24263,
-	 /* 5071 */ 0x243AB,
-	 /* 5072 */ 0x24608,
-	 /* 5073 */ 0x24735,
-	 /* 5074 */ 0x24814,
-	 /* 5075 */ 0x24C36,
-	 /* 5076 */ 0x24C92,
-	 /* 5077 */ 0x2219F,
-	 /* 5078 */ 0x24FA1,
-	 /* 5079 */ 0x24FB8,
-	 /* 5080 */ 0x25044,
-	 /* 5081 */ 0x250F3,
-	 /* 5082 */ 0x250F2,
-	 /* 5083 */ 0x25119,
-	 /* 5084 */ 0x25133,
-	 /* 5085 */ 0x2541D,
-	 /* 5086 */ 0x25626,
-	 /* 5087 */ 0x2569A,
-	 /* 5088 */ 0x256C5,
-	 /* 5089 */ 0x2597C,
-	 /* 5090 */ 0x25AA7,
-	 /* 5091 */ 0x25AA7,
-	 /* 5092 */ 0x25BAB,
-	 /* 5093 */ 0x25C80,
-	 /* 5094 */ 0x25F86,
-	 /* 5095 */ 0x26228,
-	 /* 5096 */ 0x26247,
-	 /* 5097 */ 0x262D9,
-	 /* 5098 */ 0x2633E,
-	 /* 5099 */ 0x264DA,
-	 /* 5100 */ 0x26523,
-	 /* 5101 */ 0x265A8,
-	 /* 5102 */ 0x2335F,
-	 /* 5103 */ 0x267A7,
-	 /* 5104 */ 0x267B5,
-	 /* 5105 */ 0x23393,
-	 /* 5106 */ 0x2339C,
-	 /* 5107 */ 0x26B3C,
-	 /* 5108 */ 0x26C36,
-	 /* 5109 */ 0x26D6B,
-	 /* 5110 */ 0x26CD5,
-	 /* 5111 */ 0x273CA,
-	 /* 5112 */ 0x26F2C,
-	 /* 5113 */ 0x26FB1,
-	 /* 5114 */ 0x270D2,
-	 /* 5115 */ 0x27667,
-	 /* 5116 */ 0x278AE,
-	 /* 5117 */ 0x27966,
-	 /* 5118 */ 0x27CA8,
-	 /* 5119 */ 0x27F2F,
-	 /* 5120 */ 0x20804,
-	 /* 5121 */ 0x208DE,
-	 /* 5122 */ 0x285D2,
-	 /* 5123 */ 0x285ED,
-	 /* 5124 */ 0x2872E,
-	 /* 5125 */ 0x28BFA,
-	 /* 5126 */ 0x28D77,
-	 /* 5127 */ 0x29145,
-	 /* 5128 */ 0x2921A,
-	 /* 5129 */ 0x2940A,
-	 /* 5130 */ 0x29496,
-	 /* 5131 */ 0x295B6,
-	 /* 5132 */ 0x29B30,
-	 /* 5133 */ 0x2A0CE,
-	 /* 5134 */ 0x2A105,
-	 /* 5135 */ 0x2A20E,
-	 /* 5136 */ 0x2A291,
-	 /* 5137 */ 0x2A600
+	0,
+	8814,
+	8800,
+	8815,
+	192,
+	193,
+	194,
+	195,
+	256,
+	258,
+	550,
+	196,
+	7842,
+	197,
+	461,
+	512,
+	514,
+	7840,
+	7680,
+	260,
+	7682,
+	7684,
+	7686,
+	262,
+	264,
+	266,
+	268,
+	199,
+	7690,
+	270,
+	7692,
+	7696,
+	7698,
+	7694,
+	200,
+	201,
+	202,
+	7868,
+	274,
+	276,
+	278,
+	203,
+	7866,
+	282,
+	516,
+	518,
+	7864,
+	552,
+	280,
+	7704,
+	7706,
+	7710,
+	500,
+	284,
+	7712,
+	286,
+	288,
+	486,
+	290,
+	292,
+	7714,
+	7718,
+	542,
+	7716,
+	7720,
+	7722,
+	204,
+	205,
+	206,
+	296,
+	298,
+	300,
+	304,
+	207,
+	7880,
+	463,
+	520,
+	522,
+	7882,
+	302,
+	7724,
+	308,
+	7728,
+	488,
+	7730,
+	310,
+	7732,
+	313,
+	317,
+	7734,
+	315,
+	7740,
+	7738,
+	7742,
+	7744,
+	7746,
+	504,
+	323,
+	209,
+	7748,
+	327,
+	7750,
+	325,
+	7754,
+	7752,
+	210,
+	211,
+	212,
+	213,
+	332,
+	334,
+	558,
+	214,
+	7886,
+	336,
+	465,
+	524,
+	526,
+	416,
+	7884,
+	490,
+	7764,
+	7766,
+	340,
+	7768,
+	344,
+	528,
+	530,
+	7770,
+	342,
+	7774,
+	346,
+	348,
+	7776,
+	352,
+	7778,
+	536,
+	350,
+	7786,
+	356,
+	7788,
+	538,
+	354,
+	7792,
+	7790,
+	217,
+	218,
+	219,
+	360,
+	362,
+	364,
+	220,
+	7910,
+	366,
+	368,
+	467,
+	532,
+	534,
+	431,
+	7908,
+	7794,
+	370,
+	7798,
+	7796,
+	7804,
+	7806,
+	7808,
+	7810,
+	372,
+	7814,
+	7812,
+	7816,
+	7818,
+	7820,
+	7922,
+	221,
+	374,
+	7928,
+	562,
+	7822,
+	376,
+	7926,
+	7924,
+	377,
+	7824,
+	379,
+	381,
+	7826,
+	7828,
+	224,
+	225,
+	226,
+	227,
+	257,
+	259,
+	551,
+	228,
+	7843,
+	229,
+	462,
+	513,
+	515,
+	7841,
+	7681,
+	261,
+	7683,
+	7685,
+	7687,
+	263,
+	265,
+	267,
+	269,
+	231,
+	7691,
+	271,
+	7693,
+	7697,
+	7699,
+	7695,
+	232,
+	233,
+	234,
+	7869,
+	275,
+	277,
+	279,
+	235,
+	7867,
+	283,
+	517,
+	519,
+	7865,
+	553,
+	281,
+	7705,
+	7707,
+	7711,
+	501,
+	285,
+	7713,
+	287,
+	289,
+	487,
+	291,
+	293,
+	7715,
+	7719,
+	543,
+	7717,
+	7721,
+	7723,
+	7830,
+	236,
+	237,
+	238,
+	297,
+	299,
+	301,
+	239,
+	7881,
+	464,
+	521,
+	523,
+	7883,
+	303,
+	7725,
+	309,
+	496,
+	7729,
+	489,
+	7731,
+	311,
+	7733,
+	314,
+	318,
+	7735,
+	316,
+	7741,
+	7739,
+	7743,
+	7745,
+	7747,
+	505,
+	324,
+	241,
+	7749,
+	328,
+	7751,
+	326,
+	7755,
+	7753,
+	242,
+	243,
+	244,
+	245,
+	333,
+	335,
+	559,
+	246,
+	7887,
+	337,
+	466,
+	525,
+	527,
+	417,
+	7885,
+	491,
+	7765,
+	7767,
+	341,
+	7769,
+	345,
+	529,
+	531,
+	7771,
+	343,
+	7775,
+	347,
+	349,
+	7777,
+	353,
+	7779,
+	537,
+	351,
+	7787,
+	7831,
+	357,
+	7789,
+	539,
+	355,
+	7793,
+	7791,
+	249,
+	250,
+	251,
+	361,
+	363,
+	365,
+	252,
+	7911,
+	367,
+	369,
+	468,
+	533,
+	535,
+	432,
+	7909,
+	7795,
+	371,
+	7799,
+	7797,
+	7805,
+	7807,
+	7809,
+	7811,
+	373,
+	7815,
+	7813,
+	7832,
+	7817,
+	7819,
+	7821,
+	7923,
+	253,
+	375,
+	7929,
+	563,
+	7823,
+	255,
+	7927,
+	7833,
+	7925,
+	378,
+	7825,
+	380,
+	382,
+	7827,
+	7829,
+	8173,
+	901,
+	8129,
+	7846,
+	7844,
+	7850,
+	7848,
+	478,
+	506,
+	508,
+	482,
+	7688,
+	7872,
+	7870,
+	7876,
+	7874,
+	7726,
+	7890,
+	7888,
+	7894,
+	7892,
+	7756,
+	556,
+	7758,
+	554,
+	510,
+	475,
+	471,
+	469,
+	473,
+	7847,
+	7845,
+	7851,
+	7849,
+	479,
+	507,
+	509,
+	483,
+	7689,
+	7873,
+	7871,
+	7877,
+	7875,
+	7727,
+	7891,
+	7889,
+	7895,
+	7893,
+	7757,
+	557,
+	7759,
+	555,
+	511,
+	476,
+	472,
+	470,
+	474,
+	7856,
+	7854,
+	7860,
+	7858,
+	7857,
+	7855,
+	7861,
+	7859,
+	7700,
+	7702,
+	7701,
+	7703,
+	7760,
+	7762,
+	7761,
+	7763,
+	7780,
+	7781,
+	7782,
+	7783,
+	7800,
+	7801,
+	7802,
+	7803,
+	7835,
+	7900,
+	7898,
+	7904,
+	7902,
+	7906,
+	7901,
+	7899,
+	7905,
+	7903,
+	7907,
+	7914,
+	7912,
+	7918,
+	7916,
+	7920,
+	7915,
+	7913,
+	7919,
+	7917,
+	7921,
+	494,
+	492,
+	493,
+	480,
+	481,
+	7708,
+	7709,
+	560,
+	561,
+	495,
+	8122,
+	902,
+	8121,
+	8120,
+	7944,
+	7945,
+	8124,
+	8136,
+	904,
+	7960,
+	7961,
+	8138,
+	905,
+	7976,
+	7977,
+	8140,
+	8154,
+	906,
+	8153,
+	8152,
+	938,
+	7992,
+	7993,
+	8184,
+	908,
+	8008,
+	8009,
+	8172,
+	8170,
+	910,
+	8169,
+	8168,
+	939,
+	8025,
+	8186,
+	911,
+	8040,
+	8041,
+	8188,
+	8116,
+	8132,
+	8048,
+	940,
+	8113,
+	8112,
+	7936,
+	7937,
+	8118,
+	8115,
+	8050,
+	941,
+	7952,
+	7953,
+	8052,
+	942,
+	7968,
+	7969,
+	8134,
+	8131,
+	8054,
+	943,
+	8145,
+	8144,
+	970,
+	7984,
+	7985,
+	8150,
+	8056,
+	972,
+	8000,
+	8001,
+	8164,
+	8165,
+	8058,
+	973,
+	8161,
+	8160,
+	971,
+	8016,
+	8017,
+	8166,
+	8060,
+	974,
+	8032,
+	8033,
+	8182,
+	8179,
+	8146,
+	912,
+	8151,
+	8162,
+	944,
+	8167,
+	8180,
+	979,
+	980,
+	1031,
+	1232,
+	1234,
+	1027,
+	1024,
+	1238,
+	1025,
+	1217,
+	1244,
+	1246,
+	1037,
+	1250,
+	1049,
+	1252,
+	1036,
+	1254,
+	1262,
+	1038,
+	1264,
+	1266,
+	1268,
+	1272,
+	1260,
+	1233,
+	1235,
+	1107,
+	1104,
+	1239,
+	1105,
+	1218,
+	1245,
+	1247,
+	1117,
+	1251,
+	1081,
+	1253,
+	1116,
+	1255,
+	1263,
+	1118,
+	1265,
+	1267,
+	1269,
+	1273,
+	1261,
+	1111,
+	1142,
+	1143,
+	1242,
+	1243,
+	1258,
+	1259,
+	1570,
+	1571,
+	1573,
+	1572,
+	1574,
+	1730,
+	1747,
+	1728,
+	2345,
+	2353,
+	2356,
+	2507,
+	2508,
+	2891,
+	2888,
+	2892,
+	2964,
+	3018,
+	3020,
+	3019,
+	3144,
+	3264,
+	3274,
+	3271,
+	3272,
+	3275,
+	3402,
+	3404,
+	3403,
+	3546,
+	3548,
+	3550,
+	3549,
+	4134,
+	6918,
+	6920,
+	6922,
+	6924,
+	6926,
+	6930,
+	6971,
+	6973,
+	6976,
+	6977,
+	6979,
+	7736,
+	7737,
+	7772,
+	7773,
+	7784,
+	7785,
+	7852,
+	7862,
+	7853,
+	7863,
+	7878,
+	7879,
+	7896,
+	7897,
+	7938,
+	7940,
+	7942,
+	8064,
+	7939,
+	7941,
+	7943,
+	8065,
+	8066,
+	8067,
+	8068,
+	8069,
+	8070,
+	8071,
+	7946,
+	7948,
+	7950,
+	8072,
+	7947,
+	7949,
+	7951,
+	8073,
+	8074,
+	8075,
+	8076,
+	8077,
+	8078,
+	8079,
+	7954,
+	7956,
+	7955,
+	7957,
+	7962,
+	7964,
+	7963,
+	7965,
+	7970,
+	7972,
+	7974,
+	8080,
+	7971,
+	7973,
+	7975,
+	8081,
+	8082,
+	8083,
+	8084,
+	8085,
+	8086,
+	8087,
+	7978,
+	7980,
+	7982,
+	8088,
+	7979,
+	7981,
+	7983,
+	8089,
+	8090,
+	8091,
+	8092,
+	8093,
+	8094,
+	8095,
+	7986,
+	7988,
+	7990,
+	7987,
+	7989,
+	7991,
+	7994,
+	7996,
+	7998,
+	7995,
+	7997,
+	7999,
+	8002,
+	8004,
+	8003,
+	8005,
+	8010,
+	8012,
+	8011,
+	8013,
+	8018,
+	8020,
+	8022,
+	8019,
+	8021,
+	8023,
+	8027,
+	8029,
+	8031,
+	8034,
+	8036,
+	8038,
+	8096,
+	8035,
+	8037,
+	8039,
+	8097,
+	8098,
+	8099,
+	8100,
+	8101,
+	8102,
+	8103,
+	8042,
+	8044,
+	8046,
+	8104,
+	8043,
+	8045,
+	8047,
+	8105,
+	8106,
+	8107,
+	8108,
+	8109,
+	8110,
+	8111,
+	8114,
+	8130,
+	8178,
+	8119,
+	8141,
+	8142,
+	8143,
+	8135,
+	8183,
+	8157,
+	8158,
+	8159,
+	8602,
+	8603,
+	8622,
+	8653,
+	8655,
+	8654,
+	8708,
+	8713,
+	8716,
+	8740,
+	8742,
+	8769,
+	8772,
+	8775,
+	8777,
+	8813,
+	8802,
+	8816,
+	8817,
+	8820,
+	8821,
+	8824,
+	8825,
+	8832,
+	8833,
+	8928,
+	8929,
+	8836,
+	8837,
+	8840,
+	8841,
+	8930,
+	8931,
+	8876,
+	8877,
+	8878,
+	8879,
+	8938,
+	8939,
+	8940,
+	8941,
+	12436,
+	12364,
+	12366,
+	12368,
+	12370,
+	12372,
+	12374,
+	12376,
+	12378,
+	12380,
+	12382,
+	12384,
+	12386,
+	12389,
+	12391,
+	12393,
+	12400,
+	12401,
+	12403,
+	12404,
+	12406,
+	12407,
+	12409,
+	12410,
+	12412,
+	12413,
+	12446,
+	12532,
+	12460,
+	12462,
+	12464,
+	12466,
+	12468,
+	12470,
+	12472,
+	12474,
+	12476,
+	12478,
+	12480,
+	12482,
+	12485,
+	12487,
+	12489,
+	12496,
+	12497,
+	12499,
+	12500,
+	12502,
+	12503,
+	12505,
+	12506,
+	12508,
+	12509,
+	12535,
+	12536,
+	12537,
+	12538,
+	12542,
+	67017,
+	67044,
+	69786,
+	69788,
+	69803,
+	69934,
+	69935,
+	70475,
+	70476,
+	70531,
+	70533,
+	70542,
+	70545,
+	70599,
+	70597,
+	70600,
+	70844,
+	70843,
+	70846,
+	71098,
+	71099,
+	71992,
+	90401,
+	90403,
+	90405,
+	90402,
+	90406,
+	90408,
+	90407,
+	90404,
+	93545,
+	93544,
+	93546
 };
+
+/*
+ * Table with indexes from the secondary codepoint pointing
+ * to UnicodeDecompInverseCodes.
+ */
+static const uint16 UnicodeDecompInverseSecond[6208] =
+{
+	0,
+	0,
+	0,
+	0,
+	824,
+	0,
+	1,
+	0,
+	824,
+	0,
+	2,
+	0,
+	824,
+	0,
+	3,
+	0,
+	768,
+	40,
+	4,
+	5,
+	6,
+	7,
+	8,
+	0,
+	9,
+	10,
+	11,
+	12,
+	13,
+	0,
+	14,
+	0,
+	0,
+	15,
+	0,
+	16,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	17,
+	0,
+	18,
+	0,
+	0,
+	19,
+	0,
+	775,
+	42,
+	20,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	21,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	22,
+	0,
+	769,
+	38,
+	23,
+	24,
+	0,
+	0,
+	0,
+	0,
+	25,
+	0,
+	0,
+	0,
+	0,
+	26,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	27,
+	0,
+	775,
+	42,
+	28,
+	0,
+	0,
+	0,
+	0,
+	29,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	30,
+	0,
+	0,
+	0,
+	31,
+	0,
+	0,
+	0,
+	0,
+	0,
+	32,
+	0,
+	0,
+	0,
+	33,
+	0,
+	768,
+	48,
+	34,
+	35,
+	36,
+	37,
+	38,
+	0,
+	39,
+	40,
+	41,
+	42,
+	0,
+	0,
+	43,
+	0,
+	0,
+	44,
+	0,
+	45,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	46,
+	0,
+	0,
+	0,
+	47,
+	48,
+	0,
+	0,
+	0,
+	0,
+	49,
+	0,
+	0,
+	50,
+	0,
+	775,
+	0,
+	51,
+	0,
+	769,
+	38,
+	52,
+	53,
+	0,
+	54,
+	0,
+	55,
+	56,
+	0,
+	0,
+	0,
+	0,
+	57,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	58,
+	0,
+	770,
+	44,
+	59,
+	0,
+	0,
+	0,
+	0,
+	60,
+	61,
+	0,
+	0,
+	0,
+	62,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	63,
+	0,
+	0,
+	0,
+	64,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	65,
+	0,
+	768,
+	48,
+	66,
+	67,
+	68,
+	69,
+	70,
+	0,
+	71,
+	72,
+	73,
+	74,
+	0,
+	0,
+	75,
+	0,
+	0,
+	76,
+	0,
+	77,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	78,
+	0,
+	0,
+	0,
+	0,
+	79,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	80,
+	0,
+	770,
+	0,
+	81,
+	0,
+	769,
+	48,
+	82,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	83,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	84,
+	0,
+	0,
+	0,
+	85,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	86,
+	0,
+	769,
+	48,
+	87,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	88,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	89,
+	0,
+	0,
+	0,
+	90,
+	0,
+	0,
+	0,
+	0,
+	0,
+	91,
+	0,
+	0,
+	0,
+	92,
+	0,
+	769,
+	34,
+	93,
+	0,
+	0,
+	0,
+	0,
+	0,
+	94,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	95,
+	0,
+	768,
+	49,
+	96,
+	97,
+	0,
+	98,
+	0,
+	0,
+	0,
+	99,
+	0,
+	0,
+	0,
+	0,
+	100,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	101,
+	0,
+	0,
+	0,
+	102,
+	0,
+	0,
+	0,
+	0,
+	0,
+	103,
+	0,
+	0,
+	0,
+	104,
+	0,
+	768,
+	40,
+	105,
+	106,
+	107,
+	108,
+	109,
+	0,
+	110,
+	111,
+	112,
+	113,
+	0,
+	114,
+	115,
+	0,
+	0,
+	116,
+	0,
+	117,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	118,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	119,
+	0,
+	0,
+	0,
+	0,
+	120,
+	0,
+	769,
+	6,
+	121,
+	0,
+	0,
+	0,
+	0,
+	0,
+	122,
+	0,
+	769,
+	48,
+	123,
+	0,
+	0,
+	0,
+	0,
+	0,
+	124,
+	0,
+	0,
+	0,
+	0,
+	125,
+	0,
+	0,
+	126,
+	0,
+	127,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	128,
+	0,
+	0,
+	0,
+	129,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	130,
+	0,
+	769,
+	38,
+	131,
+	132,
+	0,
+	0,
+	0,
+	0,
+	133,
+	0,
+	0,
+	0,
+	0,
+	134,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	135,
+	0,
+	0,
+	136,
+	137,
+	0,
+	775,
+	42,
+	138,
+	0,
+	0,
+	0,
+	0,
+	139,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	140,
+	0,
+	0,
+	141,
+	142,
+	0,
+	0,
+	0,
+	0,
+	0,
+	143,
+	0,
+	0,
+	0,
+	144,
+	0,
+	768,
+	48,
+	145,
+	146,
+	147,
+	148,
+	149,
+	0,
+	150,
+	0,
+	151,
+	152,
+	153,
+	154,
+	155,
+	0,
+	0,
+	156,
+	0,
+	157,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	158,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	159,
+	160,
+	0,
+	0,
+	0,
+	161,
+	0,
+	0,
+	0,
+	0,
+	162,
+	0,
+	0,
+	163,
+	0,
+	771,
+	32,
+	164,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	165,
+	0,
+	768,
+	35,
+	166,
+	167,
+	168,
+	0,
+	0,
+	0,
+	0,
+	169,
+	170,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	171,
+	0,
+	775,
+	1,
+	172,
+	173,
+	0,
+	768,
+	35,
+	174,
+	175,
+	176,
+	177,
+	178,
+	0,
+	0,
+	179,
+	180,
+	181,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	182,
+	0,
+	769,
+	48,
+	183,
+	184,
+	0,
+	0,
+	0,
+	0,
+	185,
+	0,
+	0,
+	0,
+	0,
+	186,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	187,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	188,
+	0,
+	768,
+	40,
+	189,
+	190,
+	191,
+	192,
+	193,
+	0,
+	194,
+	195,
+	196,
+	197,
+	198,
+	0,
+	199,
+	0,
+	0,
+	200,
+	0,
+	201,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	202,
+	0,
+	203,
+	0,
+	0,
+	204,
+	0,
+	775,
+	42,
+	205,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	206,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	207,
+	0,
+	769,
+	38,
+	208,
+	209,
+	0,
+	0,
+	0,
+	0,
+	210,
+	0,
+	0,
+	0,
+	0,
+	211,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	212,
+	0,
+	775,
+	42,
+	213,
+	0,
+	0,
+	0,
+	0,
+	214,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	215,
+	0,
+	0,
+	0,
+	216,
+	0,
+	0,
+	0,
+	0,
+	0,
+	217,
+	0,
+	0,
+	0,
+	218,
+	0,
+	768,
+	48,
+	219,
+	220,
+	221,
+	222,
+	223,
+	0,
+	224,
+	225,
+	226,
+	227,
+	0,
+	0,
+	228,
+	0,
+	0,
+	229,
+	0,
+	230,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	231,
+	0,
+	0,
+	0,
+	232,
+	233,
+	0,
+	0,
+	0,
+	0,
+	234,
+	0,
+	0,
+	235,
+	0,
+	775,
+	0,
+	236,
+	0,
+	769,
+	38,
+	237,
+	238,
+	0,
+	239,
+	0,
+	240,
+	241,
+	0,
+	0,
+	0,
+	0,
+	242,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	243,
+	0,
+	770,
+	47,
+	244,
+	0,
+	0,
+	0,
+	0,
+	245,
+	246,
+	0,
+	0,
+	0,
+	247,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	248,
+	0,
+	0,
+	0,
+	249,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	250,
+	0,
+	0,
+	251,
+	0,
+	768,
+	48,
+	252,
+	253,
+	254,
+	255,
+	256,
+	0,
+	257,
+	0,
+	258,
+	259,
+	0,
+	0,
+	260,
+	0,
+	0,
+	261,
+	0,
+	262,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	263,
+	0,
+	0,
+	0,
+	0,
+	264,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	265,
+	0,
+	770,
+	10,
+	266,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	267,
+	0,
+	769,
+	48,
+	268,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	269,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	270,
+	0,
+	0,
+	0,
+	271,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	272,
+	0,
+	769,
+	48,
+	273,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	274,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	275,
+	0,
+	0,
+	0,
+	276,
+	0,
+	0,
+	0,
+	0,
+	0,
+	277,
+	0,
+	0,
+	0,
+	278,
+	0,
+	769,
+	34,
+	279,
+	0,
+	0,
+	0,
+	0,
+	0,
+	280,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	281,
+	0,
+	768,
+	49,
+	282,
+	283,
+	0,
+	284,
+	0,
+	0,
+	0,
+	285,
+	0,
+	0,
+	0,
+	0,
+	286,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	287,
+	0,
+	0,
+	0,
+	288,
+	0,
+	0,
+	0,
+	0,
+	0,
+	289,
+	0,
+	0,
+	0,
+	290,
+	0,
+	768,
+	40,
+	291,
+	292,
+	293,
+	294,
+	295,
+	0,
+	296,
+	297,
+	298,
+	299,
+	0,
+	300,
+	301,
+	0,
+	0,
+	302,
+	0,
+	303,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	304,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	305,
+	0,
+	0,
+	0,
+	0,
+	306,
+	0,
+	769,
+	6,
+	307,
+	0,
+	0,
+	0,
+	0,
+	0,
+	308,
+	0,
+	769,
+	48,
+	309,
+	0,
+	0,
+	0,
+	0,
+	0,
+	310,
+	0,
+	0,
+	0,
+	0,
+	311,
+	0,
+	0,
+	312,
+	0,
+	313,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	314,
+	0,
+	0,
+	0,
+	315,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	316,
+	0,
+	769,
+	38,
+	317,
+	318,
+	0,
+	0,
+	0,
+	0,
+	319,
+	0,
+	0,
+	0,
+	0,
+	320,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	321,
+	0,
+	0,
+	322,
+	323,
+	0,
+	775,
+	42,
+	324,
+	325,
+	0,
+	0,
+	0,
+	326,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	327,
+	0,
+	0,
+	328,
+	329,
+	0,
+	0,
+	0,
+	0,
+	0,
+	330,
+	0,
+	0,
+	0,
+	331,
+	0,
+	768,
+	48,
+	332,
+	333,
+	334,
+	335,
+	336,
+	0,
+	337,
+	0,
+	338,
+	339,
+	340,
+	341,
+	342,
+	0,
+	0,
+	343,
+	0,
+	344,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	345,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	346,
+	347,
+	0,
+	0,
+	0,
+	348,
+	0,
+	0,
+	0,
+	0,
+	349,
+	0,
+	0,
+	350,
+	0,
+	771,
+	32,
+	351,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	352,
+	0,
+	768,
+	35,
+	353,
+	354,
+	355,
+	0,
+	0,
+	0,
+	0,
+	356,
+	357,
+	0,
+	358,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	359,
+	0,
+	775,
+	1,
+	360,
+	361,
+	0,
+	768,
+	35,
+	362,
+	363,
+	364,
+	365,
+	366,
+	0,
+	0,
+	367,
+	368,
+	369,
+	370,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	371,
+	0,
+	769,
+	48,
+	372,
+	373,
+	0,
+	0,
+	0,
+	0,
+	374,
+	0,
+	0,
+	0,
+	0,
+	375,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	376,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	377,
+	0,
+	768,
+	66,
+	378,
+	379,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	380,
+	0,
+	768,
+	9,
+	381,
+	382,
+	0,
+	383,
+	0,
+	0,
+	0,
+	0,
+	0,
+	384,
+	0,
+	772,
+	0,
+	385,
+	0,
+	769,
+	0,
+	386,
+	0,
+	769,
+	3,
+	387,
+	0,
+	0,
+	388,
+	0,
+	769,
+	0,
+	389,
+	0,
+	768,
+	9,
+	390,
+	391,
+	0,
+	392,
+	0,
+	0,
+	0,
+	0,
+	0,
+	393,
+	0,
+	769,
+	0,
+	394,
+	0,
+	768,
+	9,
+	395,
+	396,
+	0,
+	397,
+	0,
+	0,
+	0,
+	0,
+	0,
+	398,
+	0,
+	769,
+	7,
+	399,
+	0,
+	0,
+	400,
+	0,
+	0,
+	0,
+	401,
+	0,
+	772,
+	0,
+	402,
+	0,
+	769,
+	0,
+	403,
+	0,
+	768,
+	12,
+	404,
+	405,
+	0,
+	0,
+	406,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	407,
+	0,
+	768,
+	9,
+	408,
+	409,
+	0,
+	410,
+	0,
+	0,
+	0,
+	0,
+	0,
+	411,
+	0,
+	772,
+	0,
+	412,
+	0,
+	769,
+	0,
+	413,
+	0,
+	769,
+	3,
+	414,
+	0,
+	0,
+	415,
+	0,
+	769,
+	0,
+	416,
+	0,
+	768,
+	9,
+	417,
+	418,
+	0,
+	419,
+	0,
+	0,
+	0,
+	0,
+	0,
+	420,
+	0,
+	769,
+	0,
+	421,
+	0,
+	768,
+	9,
+	422,
+	423,
+	0,
+	424,
+	0,
+	0,
+	0,
+	0,
+	0,
+	425,
+	0,
+	769,
+	7,
+	426,
+	0,
+	0,
+	427,
+	0,
+	0,
+	0,
+	428,
+	0,
+	772,
+	0,
+	429,
+	0,
+	769,
+	0,
+	430,
+	0,
+	768,
+	12,
+	431,
+	432,
+	0,
+	0,
+	433,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	434,
+	0,
+	768,
+	9,
+	435,
+	436,
+	0,
+	437,
+	0,
+	0,
+	0,
+	0,
+	0,
+	438,
+	0,
+	768,
+	9,
+	439,
+	440,
+	0,
+	441,
+	0,
+	0,
+	0,
+	0,
+	0,
+	442,
+	0,
+	768,
+	1,
+	443,
+	444,
+	0,
+	768,
+	1,
+	445,
+	446,
+	0,
+	768,
+	1,
+	447,
+	448,
+	0,
+	768,
+	1,
+	449,
+	450,
+	0,
+	775,
+	0,
+	451,
+	0,
+	775,
+	0,
+	452,
+	0,
+	775,
+	0,
+	453,
+	0,
+	775,
+	0,
+	454,
+	0,
+	769,
+	0,
+	455,
+	0,
+	769,
+	0,
+	456,
+	0,
+	776,
+	0,
+	457,
+	0,
+	776,
+	0,
+	458,
+	0,
+	775,
+	0,
+	459,
+	0,
+	768,
+	35,
+	460,
+	461,
+	0,
+	462,
+	0,
+	0,
+	0,
+	0,
+	0,
+	463,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	464,
+	0,
+	768,
+	35,
+	465,
+	466,
+	0,
+	467,
+	0,
+	0,
+	0,
+	0,
+	0,
+	468,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	469,
+	0,
+	768,
+	35,
+	470,
+	471,
+	0,
+	472,
+	0,
+	0,
+	0,
+	0,
+	0,
+	473,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	474,
+	0,
+	768,
+	35,
+	475,
+	476,
+	0,
+	477,
+	0,
+	0,
+	0,
+	0,
+	0,
+	478,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	479,
+	0,
+	780,
+	0,
+	480,
+	0,
+	772,
+	0,
+	481,
+	0,
+	772,
+	0,
+	482,
+	0,
+	772,
+	0,
+	483,
+	0,
+	772,
+	0,
+	484,
+	0,
+	774,
+	0,
+	485,
+	0,
+	774,
+	0,
+	486,
+	0,
+	772,
+	0,
+	487,
+	0,
+	772,
+	0,
+	488,
+	0,
+	780,
+	0,
+	489,
+	0,
+	768,
+	69,
+	490,
+	491,
+	0,
+	0,
+	492,
+	0,
+	493,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	494,
+	495,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	496,
+	0,
+	768,
+	20,
+	497,
+	498,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	499,
+	500,
+	0,
+	768,
+	69,
+	501,
+	502,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	503,
+	504,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	505,
+	0,
+	768,
+	20,
+	506,
+	507,
+	0,
+	0,
+	508,
+	0,
+	509,
+	0,
+	510,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	511,
+	512,
+	0,
+	768,
+	20,
+	513,
+	514,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	515,
+	516,
+	0,
+	788,
+	0,
+	517,
+	0,
+	768,
+	20,
+	518,
+	519,
+	0,
+	0,
+	520,
+	0,
+	521,
+	0,
+	522,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	523,
+	0,
+	768,
+	69,
+	524,
+	525,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	526,
+	527,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	528,
+	0,
+	837,
+	0,
+	529,
+	0,
+	837,
+	0,
+	530,
+	0,
+	768,
+	69,
+	531,
+	532,
+	0,
+	0,
+	533,
+	0,
+	534,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	535,
+	536,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	537,
+	0,
+	0,
+	538,
+	0,
+	768,
+	20,
+	539,
+	540,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	541,
+	542,
+	0,
+	768,
+	69,
+	543,
+	544,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	545,
+	546,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	547,
+	0,
+	0,
+	548,
+	0,
+	768,
+	66,
+	549,
+	550,
+	0,
+	0,
+	551,
+	0,
+	552,
+	0,
+	553,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	554,
+	555,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	556,
+	0,
+	768,
+	20,
+	557,
+	558,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	559,
+	560,
+	0,
+	787,
+	1,
+	561,
+	562,
+	0,
+	768,
+	66,
+	563,
+	564,
+	0,
+	0,
+	565,
+	0,
+	566,
+	0,
+	567,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	568,
+	569,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	570,
+	0,
+	768,
+	69,
+	571,
+	572,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	573,
+	574,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	575,
+	0,
+	0,
+	576,
+	0,
+	768,
+	66,
+	577,
+	578,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	579,
+	0,
+	768,
+	66,
+	580,
+	581,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	582,
+	0,
+	837,
+	0,
+	583,
+	0,
+	769,
+	7,
+	584,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	585,
+	0,
+	776,
+	0,
+	586,
+	0,
+	774,
+	2,
+	587,
+	0,
+	588,
+	0,
+	769,
+	0,
+	589,
+	0,
+	768,
+	8,
+	590,
+	0,
+	0,
+	0,
+	0,
+	0,
+	591,
+	0,
+	592,
+	0,
+	774,
+	2,
+	593,
+	0,
+	594,
+	0,
+	776,
+	0,
+	595,
+	0,
+	768,
+	8,
+	596,
+	0,
+	0,
+	0,
+	597,
+	0,
+	598,
+	0,
+	599,
+	0,
+	769,
+	0,
+	600,
+	0,
+	776,
+	0,
+	601,
+	0,
+	772,
+	7,
+	602,
+	0,
+	603,
+	0,
+	604,
+	0,
+	0,
+	605,
+	0,
+	776,
+	0,
+	606,
+	0,
+	776,
+	0,
+	607,
+	0,
+	776,
+	0,
+	608,
+	0,
+	774,
+	2,
+	609,
+	0,
+	610,
+	0,
+	769,
+	0,
+	611,
+	0,
+	768,
+	8,
+	612,
+	0,
+	0,
+	0,
+	0,
+	0,
+	613,
+	0,
+	614,
+	0,
+	774,
+	2,
+	615,
+	0,
+	616,
+	0,
+	776,
+	0,
+	617,
+	0,
+	768,
+	8,
+	618,
+	0,
+	0,
+	0,
+	619,
+	0,
+	620,
+	0,
+	621,
+	0,
+	769,
+	0,
+	622,
+	0,
+	776,
+	0,
+	623,
+	0,
+	772,
+	7,
+	624,
+	0,
+	625,
+	0,
+	626,
+	0,
+	0,
+	627,
+	0,
+	776,
+	0,
+	628,
+	0,
+	776,
+	0,
+	629,
+	0,
+	776,
+	0,
+	630,
+	0,
+	776,
+	0,
+	631,
+	0,
+	783,
+	0,
+	632,
+	0,
+	783,
+	0,
+	633,
+	0,
+	776,
+	0,
+	634,
+	0,
+	776,
+	0,
+	635,
+	0,
+	776,
+	0,
+	636,
+	0,
+	776,
+	0,
+	637,
+	0,
+	1619,
+	2,
+	638,
+	639,
+	640,
+	0,
+	1620,
+	0,
+	641,
+	0,
+	1620,
+	0,
+	642,
+	0,
+	1620,
+	0,
+	643,
+	0,
+	1620,
+	0,
+	644,
+	0,
+	1620,
+	0,
+	645,
+	0,
+	2364,
+	0,
+	646,
+	0,
+	2364,
+	0,
+	647,
+	0,
+	2364,
+	0,
+	648,
+	0,
+	2494,
+	25,
+	649,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	650,
+	0,
+	2878,
+	25,
+	651,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	652,
+	653,
+	0,
+	3031,
+	0,
+	654,
+	0,
+	3006,
+	25,
+	655,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	656,
+	0,
+	3006,
+	0,
+	657,
+	0,
+	3158,
+	0,
+	658,
+	0,
+	3285,
+	0,
+	659,
+	0,
+	3266,
+	20,
+	660,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	661,
+	662,
+	0,
+	3285,
+	0,
+	663,
+	0,
+	3390,
+	25,
+	664,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	665,
+	0,
+	3390,
+	0,
+	666,
+	0,
+	3530,
+	21,
+	667,
+	0,
+	0,
+	0,
+	0,
+	668,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	669,
+	0,
+	3530,
+	0,
+	670,
+	0,
+	4142,
+	0,
+	671,
+	0,
+	6965,
+	0,
+	672,
+	0,
+	6965,
+	0,
+	673,
+	0,
+	6965,
+	0,
+	674,
+	0,
+	6965,
+	0,
+	675,
+	0,
+	6965,
+	0,
+	676,
+	0,
+	6965,
+	0,
+	677,
+	0,
+	6965,
+	0,
+	678,
+	0,
+	6965,
+	0,
+	679,
+	0,
+	6965,
+	0,
+	680,
+	0,
+	6965,
+	0,
+	681,
+	0,
+	6965,
+	0,
+	682,
+	0,
+	772,
+	0,
+	683,
+	0,
+	772,
+	0,
+	684,
+	0,
+	772,
+	0,
+	685,
+	0,
+	772,
+	0,
+	686,
+	0,
+	775,
+	0,
+	687,
+	0,
+	775,
+	0,
+	688,
+	0,
+	770,
+	4,
+	689,
+	0,
+	0,
+	0,
+	690,
+	0,
+	770,
+	4,
+	691,
+	0,
+	0,
+	0,
+	692,
+	0,
+	770,
+	0,
+	693,
+	0,
+	770,
+	0,
+	694,
+	0,
+	770,
+	0,
+	695,
+	0,
+	770,
+	0,
+	696,
+	0,
+	768,
+	69,
+	697,
+	698,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	699,
+	0,
+	0,
+	700,
+	0,
+	768,
+	69,
+	701,
+	702,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	703,
+	0,
+	0,
+	704,
+	0,
+	837,
+	0,
+	705,
+	0,
+	837,
+	0,
+	706,
+	0,
+	837,
+	0,
+	707,
+	0,
+	837,
+	0,
+	708,
+	0,
+	837,
+	0,
+	709,
+	0,
+	837,
+	0,
+	710,
+	0,
+	768,
+	69,
+	711,
+	712,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	713,
+	0,
+	0,
+	714,
+	0,
+	768,
+	69,
+	715,
+	716,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	717,
+	0,
+	0,
+	718,
+	0,
+	837,
+	0,
+	719,
+	0,
+	837,
+	0,
+	720,
+	0,
+	837,
+	0,
+	721,
+	0,
+	837,
+	0,
+	722,
+	0,
+	837,
+	0,
+	723,
+	0,
+	837,
+	0,
+	724,
+	0,
+	768,
+	1,
+	725,
+	726,
+	0,
+	768,
+	1,
+	727,
+	728,
+	0,
+	768,
+	1,
+	729,
+	730,
+	0,
+	768,
+	1,
+	731,
+	732,
+	0,
+	768,
+	69,
+	733,
+	734,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	735,
+	0,
+	0,
+	736,
+	0,
+	768,
+	69,
+	737,
+	738,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	739,
+	0,
+	0,
+	740,
+	0,
+	837,
+	0,
+	741,
+	0,
+	837,
+	0,
+	742,
+	0,
+	837,
+	0,
+	743,
+	0,
+	837,
+	0,
+	744,
+	0,
+	837,
+	0,
+	745,
+	0,
+	837,
+	0,
+	746,
+	0,
+	768,
+	69,
+	747,
+	748,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	749,
+	0,
+	0,
+	750,
+	0,
+	768,
+	69,
+	751,
+	752,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	753,
+	0,
+	0,
+	754,
+	0,
+	837,
+	0,
+	755,
+	0,
+	837,
+	0,
+	756,
+	0,
+	837,
+	0,
+	757,
+	0,
+	837,
+	0,
+	758,
+	0,
+	837,
+	0,
+	759,
+	0,
+	837,
+	0,
+	760,
+	0,
+	768,
+	66,
+	761,
+	762,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	763,
+	0,
+	768,
+	66,
+	764,
+	765,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	766,
+	0,
+	768,
+	66,
+	767,
+	768,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	769,
+	0,
+	768,
+	66,
+	770,
+	771,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	772,
+	0,
+	768,
+	1,
+	773,
+	774,
+	0,
+	768,
+	1,
+	775,
+	776,
+	0,
+	768,
+	1,
+	777,
+	778,
+	0,
+	768,
+	1,
+	779,
+	780,
+	0,
+	768,
+	66,
+	781,
+	782,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	783,
+	0,
+	768,
+	66,
+	784,
+	785,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	786,
+	0,
+	768,
+	66,
+	787,
+	788,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	789,
+	0,
+	768,
+	69,
+	790,
+	791,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	792,
+	0,
+	0,
+	793,
+	0,
+	768,
+	69,
+	794,
+	795,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	796,
+	0,
+	0,
+	797,
+	0,
+	837,
+	0,
+	798,
+	0,
+	837,
+	0,
+	799,
+	0,
+	837,
+	0,
+	800,
+	0,
+	837,
+	0,
+	801,
+	0,
+	837,
+	0,
+	802,
+	0,
+	837,
+	0,
+	803,
+	0,
+	768,
+	69,
+	804,
+	805,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	806,
+	0,
+	0,
+	807,
+	0,
+	768,
+	69,
+	808,
+	809,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	810,
+	0,
+	0,
+	811,
+	0,
+	837,
+	0,
+	812,
+	0,
+	837,
+	0,
+	813,
+	0,
+	837,
+	0,
+	814,
+	0,
+	837,
+	0,
+	815,
+	0,
+	837,
+	0,
+	816,
+	0,
+	837,
+	0,
+	817,
+	0,
+	837,
+	0,
+	818,
+	0,
+	837,
+	0,
+	819,
+	0,
+	837,
+	0,
+	820,
+	0,
+	837,
+	0,
+	821,
+	0,
+	768,
+	66,
+	822,
+	823,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	824,
+	0,
+	837,
+	0,
+	825,
+	0,
+	837,
+	0,
+	826,
+	0,
+	768,
+	66,
+	827,
+	828,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	829,
+	0,
+	824,
+	0,
+	830,
+	0,
+	824,
+	0,
+	831,
+	0,
+	824,
+	0,
+	832,
+	0,
+	824,
+	0,
+	833,
+	0,
+	824,
+	0,
+	834,
+	0,
+	824,
+	0,
+	835,
+	0,
+	824,
+	0,
+	836,
+	0,
+	824,
+	0,
+	837,
+	0,
+	824,
+	0,
+	838,
+	0,
+	824,
+	0,
+	839,
+	0,
+	824,
+	0,
+	840,
+	0,
+	824,
+	0,
+	841,
+	0,
+	824,
+	0,
+	842,
+	0,
+	824,
+	0,
+	843,
+	0,
+	824,
+	0,
+	844,
+	0,
+	824,
+	0,
+	845,
+	0,
+	824,
+	0,
+	846,
+	0,
+	824,
+	0,
+	847,
+	0,
+	824,
+	0,
+	848,
+	0,
+	824,
+	0,
+	849,
+	0,
+	824,
+	0,
+	850,
+	0,
+	824,
+	0,
+	851,
+	0,
+	824,
+	0,
+	852,
+	0,
+	824,
+	0,
+	853,
+	0,
+	824,
+	0,
+	854,
+	0,
+	824,
+	0,
+	855,
+	0,
+	824,
+	0,
+	856,
+	0,
+	824,
+	0,
+	857,
+	0,
+	824,
+	0,
+	858,
+	0,
+	824,
+	0,
+	859,
+	0,
+	824,
+	0,
+	860,
+	0,
+	824,
+	0,
+	861,
+	0,
+	824,
+	0,
+	862,
+	0,
+	824,
+	0,
+	863,
+	0,
+	824,
+	0,
+	864,
+	0,
+	824,
+	0,
+	865,
+	0,
+	824,
+	0,
+	866,
+	0,
+	824,
+	0,
+	867,
+	0,
+	824,
+	0,
+	868,
+	0,
+	824,
+	0,
+	869,
+	0,
+	824,
+	0,
+	870,
+	0,
+	12441,
+	0,
+	871,
+	0,
+	12441,
+	0,
+	872,
+	0,
+	12441,
+	0,
+	873,
+	0,
+	12441,
+	0,
+	874,
+	0,
+	12441,
+	0,
+	875,
+	0,
+	12441,
+	0,
+	876,
+	0,
+	12441,
+	0,
+	877,
+	0,
+	12441,
+	0,
+	878,
+	0,
+	12441,
+	0,
+	879,
+	0,
+	12441,
+	0,
+	880,
+	0,
+	12441,
+	0,
+	881,
+	0,
+	12441,
+	0,
+	882,
+	0,
+	12441,
+	0,
+	883,
+	0,
+	12441,
+	0,
+	884,
+	0,
+	12441,
+	0,
+	885,
+	0,
+	12441,
+	0,
+	886,
+	0,
+	12441,
+	1,
+	887,
+	888,
+	0,
+	12441,
+	1,
+	889,
+	890,
+	0,
+	12441,
+	1,
+	891,
+	892,
+	0,
+	12441,
+	1,
+	893,
+	894,
+	0,
+	12441,
+	1,
+	895,
+	896,
+	0,
+	12441,
+	0,
+	897,
+	0,
+	12441,
+	0,
+	898,
+	0,
+	12441,
+	0,
+	899,
+	0,
+	12441,
+	0,
+	900,
+	0,
+	12441,
+	0,
+	901,
+	0,
+	12441,
+	0,
+	902,
+	0,
+	12441,
+	0,
+	903,
+	0,
+	12441,
+	0,
+	904,
+	0,
+	12441,
+	0,
+	905,
+	0,
+	12441,
+	0,
+	906,
+	0,
+	12441,
+	0,
+	907,
+	0,
+	12441,
+	0,
+	908,
+	0,
+	12441,
+	0,
+	909,
+	0,
+	12441,
+	0,
+	910,
+	0,
+	12441,
+	0,
+	911,
+	0,
+	12441,
+	0,
+	912,
+	0,
+	12441,
+	0,
+	913,
+	0,
+	12441,
+	1,
+	914,
+	915,
+	0,
+	12441,
+	1,
+	916,
+	917,
+	0,
+	12441,
+	1,
+	918,
+	919,
+	0,
+	12441,
+	1,
+	920,
+	921,
+	0,
+	12441,
+	1,
+	922,
+	923,
+	0,
+	12441,
+	0,
+	924,
+	0,
+	12441,
+	0,
+	925,
+	0,
+	12441,
+	0,
+	926,
+	0,
+	12441,
+	0,
+	927,
+	0,
+	12441,
+	0,
+	928,
+	0,
+	775,
+	0,
+	929,
+	0,
+	775,
+	0,
+	930,
+	1,
+	4282,
+	0,
+	931,
+	1,
+	4282,
+	0,
+	932,
+	1,
+	4282,
+	0,
+	933,
+	1,
+	4391,
+	0,
+	934,
+	1,
+	4391,
+	0,
+	935,
+	1,
+	4926,
+	25,
+	936,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	937,
+	1,
+	5065,
+	0,
+	938,
+	1,
+	5051,
+	0,
+	939,
+	1,
+	5058,
+	0,
+	940,
+	1,
+	5065,
+	0,
+	941,
+	1,
+	5048,
+	17,
+	942,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	943,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	944,
+	1,
+	5296,
+	13,
+	945,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	946,
+	0,
+	0,
+	947,
+	1,
+	5551,
+	0,
+	948,
+	1,
+	5551,
+	0,
+	949,
+	1,
+	6448,
+	0,
+	950,
+	1,
+	24862,
+	11,
+	951,
+	952,
+	953,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	954,
+	1,
+	24863,
+	1,
+	955,
+	956,
+	1,
+	24863,
+	0,
+	957,
+	1,
+	24863,
+	0,
+	958,
+	1,
+	28007,
+	0,
+	959,
+	1,
+	28007,
+	0,
+	960,
+	1,
+	28007,
+	0,
+	961
+};
+
+/*
+ * Used by normalization_index() to map a codepoint to an index that can be
+ * used in UnicodeDecompMain table.
+ */
+static const uint16 decomp_map[33752] =
+{
+	1,							/* U+0000A0 */
+	0,							/* U+0000A1 */
+	0,							/* U+0000A2 */
+	0,							/* U+0000A3 */
+	0,							/* U+0000A4 */
+	0,							/* U+0000A5 */
+	0,							/* U+0000A6 */
+	0,							/* U+0000A7 */
+	2,							/* U+0000A8 */
+	0,							/* U+0000A9 */
+	3,							/* U+0000AA */
+	0,							/* U+0000AB */
+	0,							/* U+0000AC */
+	0,							/* U+0000AD */
+	0,							/* U+0000AE */
+	4,							/* U+0000AF */
+	0,							/* U+0000B0 */
+	0,							/* U+0000B1 */
+	5,							/* U+0000B2 */
+	6,							/* U+0000B3 */
+	7,							/* U+0000B4 */
+	8,							/* U+0000B5 */
+	0,							/* U+0000B6 */
+	0,							/* U+0000B7 */
+	9,							/* U+0000B8 */
+	10,							/* U+0000B9 */
+	11,							/* U+0000BA */
+	0,							/* U+0000BB */
+	12,							/* U+0000BC */
+	13,							/* U+0000BD */
+	14,							/* U+0000BE */
+	0,							/* U+0000BF */
+	15,							/* U+0000C0 */
+	16,							/* U+0000C1 */
+	17,							/* U+0000C2 */
+	18,							/* U+0000C3 */
+	19,							/* U+0000C4 */
+	20,							/* U+0000C5 */
+	0,							/* U+0000C6 */
+	21,							/* U+0000C7 */
+	22,							/* U+0000C8 */
+	23,							/* U+0000C9 */
+	24,							/* U+0000CA */
+	25,							/* U+0000CB */
+	26,							/* U+0000CC */
+	27,							/* U+0000CD */
+	28,							/* U+0000CE */
+	29,							/* U+0000CF */
+	0,							/* U+0000D0 */
+	30,							/* U+0000D1 */
+	31,							/* U+0000D2 */
+	32,							/* U+0000D3 */
+	33,							/* U+0000D4 */
+	34,							/* U+0000D5 */
+	35,							/* U+0000D6 */
+	0,							/* U+0000D7 */
+	0,							/* U+0000D8 */
+	36,							/* U+0000D9 */
+	37,							/* U+0000DA */
+	38,							/* U+0000DB */
+	39,							/* U+0000DC */
+	40,							/* U+0000DD */
+	0,							/* U+0000DE */
+	0,							/* U+0000DF */
+	41,							/* U+0000E0 */
+	42,							/* U+0000E1 */
+	43,							/* U+0000E2 */
+	44,							/* U+0000E3 */
+	45,							/* U+0000E4 */
+	46,							/* U+0000E5 */
+	0,							/* U+0000E6 */
+	47,							/* U+0000E7 */
+	48,							/* U+0000E8 */
+	49,							/* U+0000E9 */
+	50,							/* U+0000EA */
+	51,							/* U+0000EB */
+	52,							/* U+0000EC */
+	53,							/* U+0000ED */
+	54,							/* U+0000EE */
+	55,							/* U+0000EF */
+	0,							/* U+0000F0 */
+	56,							/* U+0000F1 */
+	57,							/* U+0000F2 */
+	58,							/* U+0000F3 */
+	59,							/* U+0000F4 */
+	60,							/* U+0000F5 */
+	61,							/* U+0000F6 */
+	0,							/* U+0000F7 */
+	0,							/* U+0000F8 */
+	62,							/* U+0000F9 */
+	63,							/* U+0000FA */
+	64,							/* U+0000FB */
+	65,							/* U+0000FC */
+	66,							/* U+0000FD */
+	0,							/* U+0000FE */
+	67,							/* U+0000FF */
+	68,							/* U+000100 */
+	69,							/* U+000101 */
+	70,							/* U+000102 */
+	71,							/* U+000103 */
+	72,							/* U+000104 */
+	73,							/* U+000105 */
+	74,							/* U+000106 */
+	75,							/* U+000107 */
+	76,							/* U+000108 */
+	77,							/* U+000109 */
+	78,							/* U+00010A */
+	79,							/* U+00010B */
+	80,							/* U+00010C */
+	81,							/* U+00010D */
+	82,							/* U+00010E */
+	83,							/* U+00010F */
+	0,							/* U+000110 */
+	0,							/* U+000111 */
+	84,							/* U+000112 */
+	85,							/* U+000113 */
+	86,							/* U+000114 */
+	87,							/* U+000115 */
+	88,							/* U+000116 */
+	89,							/* U+000117 */
+	90,							/* U+000118 */
+	91,							/* U+000119 */
+	92,							/* U+00011A */
+	93,							/* U+00011B */
+	94,							/* U+00011C */
+	95,							/* U+00011D */
+	96,							/* U+00011E */
+	97,							/* U+00011F */
+	98,							/* U+000120 */
+	99,							/* U+000121 */
+	100,						/* U+000122 */
+	101,						/* U+000123 */
+	102,						/* U+000124 */
+	103,						/* U+000125 */
+	0,							/* U+000126 */
+	0,							/* U+000127 */
+	104,						/* U+000128 */
+	105,						/* U+000129 */
+	106,						/* U+00012A */
+	107,						/* U+00012B */
+	108,						/* U+00012C */
+	109,						/* U+00012D */
+	110,						/* U+00012E */
+	111,						/* U+00012F */
+	112,						/* U+000130 */
+	0,							/* U+000131 */
+	113,						/* U+000132 */
+	114,						/* U+000133 */
+	115,						/* U+000134 */
+	116,						/* U+000135 */
+	117,						/* U+000136 */
+	118,						/* U+000137 */
+	0,							/* U+000138 */
+	119,						/* U+000139 */
+	120,						/* U+00013A */
+	121,						/* U+00013B */
+	122,						/* U+00013C */
+	123,						/* U+00013D */
+	124,						/* U+00013E */
+	125,						/* U+00013F */
+	126,						/* U+000140 */
+	0,							/* U+000141 */
+	0,							/* U+000142 */
+	127,						/* U+000143 */
+	128,						/* U+000144 */
+	129,						/* U+000145 */
+	130,						/* U+000146 */
+	131,						/* U+000147 */
+	132,						/* U+000148 */
+	133,						/* U+000149 */
+	0,							/* U+00014A */
+	0,							/* U+00014B */
+	134,						/* U+00014C */
+	135,						/* U+00014D */
+	136,						/* U+00014E */
+	137,						/* U+00014F */
+	138,						/* U+000150 */
+	139,						/* U+000151 */
+	0,							/* U+000152 */
+	0,							/* U+000153 */
+	140,						/* U+000154 */
+	141,						/* U+000155 */
+	142,						/* U+000156 */
+	143,						/* U+000157 */
+	144,						/* U+000158 */
+	145,						/* U+000159 */
+	146,						/* U+00015A */
+	147,						/* U+00015B */
+	148,						/* U+00015C */
+	149,						/* U+00015D */
+	150,						/* U+00015E */
+	151,						/* U+00015F */
+	152,						/* U+000160 */
+	153,						/* U+000161 */
+	154,						/* U+000162 */
+	155,						/* U+000163 */
+	156,						/* U+000164 */
+	157,						/* U+000165 */
+	0,							/* U+000166 */
+	0,							/* U+000167 */
+	158,						/* U+000168 */
+	159,						/* U+000169 */
+	160,						/* U+00016A */
+	161,						/* U+00016B */
+	162,						/* U+00016C */
+	163,						/* U+00016D */
+	164,						/* U+00016E */
+	165,						/* U+00016F */
+	166,						/* U+000170 */
+	167,						/* U+000171 */
+	168,						/* U+000172 */
+	169,						/* U+000173 */
+	170,						/* U+000174 */
+	171,						/* U+000175 */
+	172,						/* U+000176 */
+	173,						/* U+000177 */
+	174,						/* U+000178 */
+	175,						/* U+000179 */
+	176,						/* U+00017A */
+	177,						/* U+00017B */
+	178,						/* U+00017C */
+	179,						/* U+00017D */
+	180,						/* U+00017E */
+	181,						/* U+00017F */
+	0,							/* U+000180 */
+	0,							/* U+000181 */
+	0,							/* U+000182 */
+	0,							/* U+000183 */
+	0,							/* U+000184 */
+	0,							/* U+000185 */
+	0,							/* U+000186 */
+	0,							/* U+000187 */
+	0,							/* U+000188 */
+	0,							/* U+000189 */
+	0,							/* U+00018A */
+	0,							/* U+00018B */
+	0,							/* U+00018C */
+	0,							/* U+00018D */
+	0,							/* U+00018E */
+	0,							/* U+00018F */
+	0,							/* U+000190 */
+	0,							/* U+000191 */
+	0,							/* U+000192 */
+	0,							/* U+000193 */
+	0,							/* U+000194 */
+	0,							/* U+000195 */
+	0,							/* U+000196 */
+	0,							/* U+000197 */
+	0,							/* U+000198 */
+	0,							/* U+000199 */
+	0,							/* U+00019A */
+	0,							/* U+00019B */
+	0,							/* U+00019C */
+	0,							/* U+00019D */
+	0,							/* U+00019E */
+	0,							/* U+00019F */
+	182,						/* U+0001A0 */
+	183,						/* U+0001A1 */
+	0,							/* U+0001A2 */
+	0,							/* U+0001A3 */
+	0,							/* U+0001A4 */
+	0,							/* U+0001A5 */
+	0,							/* U+0001A6 */
+	0,							/* U+0001A7 */
+	0,							/* U+0001A8 */
+	0,							/* U+0001A9 */
+	0,							/* U+0001AA */
+	0,							/* U+0001AB */
+	0,							/* U+0001AC */
+	0,							/* U+0001AD */
+	0,							/* U+0001AE */
+	184,						/* U+0001AF */
+	185,						/* U+0001B0 */
+	0,							/* U+0001B1 */
+	0,							/* U+0001B2 */
+	0,							/* U+0001B3 */
+	0,							/* U+0001B4 */
+	0,							/* U+0001B5 */
+	0,							/* U+0001B6 */
+	0,							/* U+0001B7 */
+	0,							/* U+0001B8 */
+	0,							/* U+0001B9 */
+	0,							/* U+0001BA */
+	0,							/* U+0001BB */
+	0,							/* U+0001BC */
+	0,							/* U+0001BD */
+	0,							/* U+0001BE */
+	0,							/* U+0001BF */
+	0,							/* U+0001C0 */
+	0,							/* U+0001C1 */
+	0,							/* U+0001C2 */
+	0,							/* U+0001C3 */
+	186,						/* U+0001C4 */
+	187,						/* U+0001C5 */
+	188,						/* U+0001C6 */
+	189,						/* U+0001C7 */
+	190,						/* U+0001C8 */
+	191,						/* U+0001C9 */
+	192,						/* U+0001CA */
+	193,						/* U+0001CB */
+	194,						/* U+0001CC */
+	195,						/* U+0001CD */
+	196,						/* U+0001CE */
+	197,						/* U+0001CF */
+	198,						/* U+0001D0 */
+	199,						/* U+0001D1 */
+	200,						/* U+0001D2 */
+	201,						/* U+0001D3 */
+	202,						/* U+0001D4 */
+	203,						/* U+0001D5 */
+	204,						/* U+0001D6 */
+	205,						/* U+0001D7 */
+	206,						/* U+0001D8 */
+	207,						/* U+0001D9 */
+	208,						/* U+0001DA */
+	209,						/* U+0001DB */
+	210,						/* U+0001DC */
+	0,							/* U+0001DD */
+	211,						/* U+0001DE */
+	212,						/* U+0001DF */
+	213,						/* U+0001E0 */
+	214,						/* U+0001E1 */
+	215,						/* U+0001E2 */
+	216,						/* U+0001E3 */
+	0,							/* U+0001E4 */
+	0,							/* U+0001E5 */
+	217,						/* U+0001E6 */
+	218,						/* U+0001E7 */
+	219,						/* U+0001E8 */
+	220,						/* U+0001E9 */
+	221,						/* U+0001EA */
+	222,						/* U+0001EB */
+	223,						/* U+0001EC */
+	224,						/* U+0001ED */
+	225,						/* U+0001EE */
+	226,						/* U+0001EF */
+	227,						/* U+0001F0 */
+	228,						/* U+0001F1 */
+	229,						/* U+0001F2 */
+	230,						/* U+0001F3 */
+	231,						/* U+0001F4 */
+	232,						/* U+0001F5 */
+	0,							/* U+0001F6 */
+	0,							/* U+0001F7 */
+	233,						/* U+0001F8 */
+	234,						/* U+0001F9 */
+	235,						/* U+0001FA */
+	236,						/* U+0001FB */
+	237,						/* U+0001FC */
+	238,						/* U+0001FD */
+	239,						/* U+0001FE */
+	240,						/* U+0001FF */
+	241,						/* U+000200 */
+	242,						/* U+000201 */
+	243,						/* U+000202 */
+	244,						/* U+000203 */
+	245,						/* U+000204 */
+	246,						/* U+000205 */
+	247,						/* U+000206 */
+	248,						/* U+000207 */
+	249,						/* U+000208 */
+	250,						/* U+000209 */
+	251,						/* U+00020A */
+	252,						/* U+00020B */
+	253,						/* U+00020C */
+	254,						/* U+00020D */
+	255,						/* U+00020E */
+	256,						/* U+00020F */
+	257,						/* U+000210 */
+	258,						/* U+000211 */
+	259,						/* U+000212 */
+	260,						/* U+000213 */
+	261,						/* U+000214 */
+	262,						/* U+000215 */
+	263,						/* U+000216 */
+	264,						/* U+000217 */
+	265,						/* U+000218 */
+	266,						/* U+000219 */
+	267,						/* U+00021A */
+	268,						/* U+00021B */
+	0,							/* U+00021C */
+	0,							/* U+00021D */
+	269,						/* U+00021E */
+	270,						/* U+00021F */
+	0,							/* U+000220 */
+	0,							/* U+000221 */
+	0,							/* U+000222 */
+	0,							/* U+000223 */
+	0,							/* U+000224 */
+	0,							/* U+000225 */
+	271,						/* U+000226 */
+	272,						/* U+000227 */
+	273,						/* U+000228 */
+	274,						/* U+000229 */
+	275,						/* U+00022A */
+	276,						/* U+00022B */
+	277,						/* U+00022C */
+	278,						/* U+00022D */
+	279,						/* U+00022E */
+	280,						/* U+00022F */
+	281,						/* U+000230 */
+	282,						/* U+000231 */
+	283,						/* U+000232 */
+	284,						/* U+000233 */
+	0,							/* U+000234 */
+	0,							/* U+000235 */
+	0,							/* U+000236 */
+	0,							/* U+000237 */
+	0,							/* U+000238 */
+	0,							/* U+000239 */
+	0,							/* U+00023A */
+	0,							/* U+00023B */
+	0,							/* U+00023C */
+	0,							/* U+00023D */
+	0,							/* U+00023E */
+	0,							/* U+00023F */
+	0,							/* U+000240 */
+	0,							/* U+000241 */
+	0,							/* U+000242 */
+	0,							/* U+000243 */
+	0,							/* U+000244 */
+	0,							/* U+000245 */
+	0,							/* U+000246 */
+	0,							/* U+000247 */
+	0,							/* U+000248 */
+	0,							/* U+000249 */
+	0,							/* U+00024A */
+	0,							/* U+00024B */
+	0,							/* U+00024C */
+	0,							/* U+00024D */
+	0,							/* U+00024E */
+	0,							/* U+00024F */
+	0,							/* U+000250 */
+	0,							/* U+000251 */
+	0,							/* U+000252 */
+	0,							/* U+000253 */
+	0,							/* U+000254 */
+	0,							/* U+000255 */
+	0,							/* U+000256 */
+	0,							/* U+000257 */
+	0,							/* U+000258 */
+	0,							/* U+000259 */
+	0,							/* U+00025A */
+	0,							/* U+00025B */
+	0,							/* U+00025C */
+	0,							/* U+00025D */
+	0,							/* U+00025E */
+	0,							/* U+00025F */
+	0,							/* U+000260 */
+	0,							/* U+000261 */
+	0,							/* U+000262 */
+	0,							/* U+000263 */
+	0,							/* U+000264 */
+	0,							/* U+000265 */
+	0,							/* U+000266 */
+	0,							/* U+000267 */
+	0,							/* U+000268 */
+	0,							/* U+000269 */
+	0,							/* U+00026A */
+	0,							/* U+00026B */
+	0,							/* U+00026C */
+	0,							/* U+00026D */
+	0,							/* U+00026E */
+	0,							/* U+00026F */
+	0,							/* U+000270 */
+	0,							/* U+000271 */
+	0,							/* U+000272 */
+	0,							/* U+000273 */
+	0,							/* U+000274 */
+	0,							/* U+000275 */
+	0,							/* U+000276 */
+	0,							/* U+000277 */
+	0,							/* U+000278 */
+	0,							/* U+000279 */
+	0,							/* U+00027A */
+	0,							/* U+00027B */
+	0,							/* U+00027C */
+	0,							/* U+00027D */
+	0,							/* U+00027E */
+	0,							/* U+00027F */
+	0,							/* U+000280 */
+	0,							/* U+000281 */
+	0,							/* U+000282 */
+	0,							/* U+000283 */
+	0,							/* U+000284 */
+	0,							/* U+000285 */
+	0,							/* U+000286 */
+	0,							/* U+000287 */
+	0,							/* U+000288 */
+	0,							/* U+000289 */
+	0,							/* U+00028A */
+	0,							/* U+00028B */
+	0,							/* U+00028C */
+	0,							/* U+00028D */
+	0,							/* U+00028E */
+	0,							/* U+00028F */
+	0,							/* U+000290 */
+	0,							/* U+000291 */
+	0,							/* U+000292 */
+	0,							/* U+000293 */
+	0,							/* U+000294 */
+	0,							/* U+000295 */
+	0,							/* U+000296 */
+	0,							/* U+000297 */
+	0,							/* U+000298 */
+	0,							/* U+000299 */
+	0,							/* U+00029A */
+	0,							/* U+00029B */
+	0,							/* U+00029C */
+	0,							/* U+00029D */
+	0,							/* U+00029E */
+	0,							/* U+00029F */
+	0,							/* U+0002A0 */
+	0,							/* U+0002A1 */
+	0,							/* U+0002A2 */
+	0,							/* U+0002A3 */
+	0,							/* U+0002A4 */
+	0,							/* U+0002A5 */
+	0,							/* U+0002A6 */
+	0,							/* U+0002A7 */
+	0,							/* U+0002A8 */
+	0,							/* U+0002A9 */
+	0,							/* U+0002AA */
+	0,							/* U+0002AB */
+	0,							/* U+0002AC */
+	0,							/* U+0002AD */
+	0,							/* U+0002AE */
+	0,							/* U+0002AF */
+	285,						/* U+0002B0 */
+	286,						/* U+0002B1 */
+	287,						/* U+0002B2 */
+	288,						/* U+0002B3 */
+	289,						/* U+0002B4 */
+	290,						/* U+0002B5 */
+	291,						/* U+0002B6 */
+	292,						/* U+0002B7 */
+	293,						/* U+0002B8 */
+	0,							/* U+0002B9 */
+	0,							/* U+0002BA */
+	0,							/* U+0002BB */
+	0,							/* U+0002BC */
+	0,							/* U+0002BD */
+	0,							/* U+0002BE */
+	0,							/* U+0002BF */
+	0,							/* U+0002C0 */
+	0,							/* U+0002C1 */
+	0,							/* U+0002C2 */
+	0,							/* U+0002C3 */
+	0,							/* U+0002C4 */
+	0,							/* U+0002C5 */
+	0,							/* U+0002C6 */
+	0,							/* U+0002C7 */
+	0,							/* U+0002C8 */
+	0,							/* U+0002C9 */
+	0,							/* U+0002CA */
+	0,							/* U+0002CB */
+	0,							/* U+0002CC */
+	0,							/* U+0002CD */
+	0,							/* U+0002CE */
+	0,							/* U+0002CF */
+	0,							/* U+0002D0 */
+	0,							/* U+0002D1 */
+	0,							/* U+0002D2 */
+	0,							/* U+0002D3 */
+	0,							/* U+0002D4 */
+	0,							/* U+0002D5 */
+	0,							/* U+0002D6 */
+	0,							/* U+0002D7 */
+	294,						/* U+0002D8 */
+	295,						/* U+0002D9 */
+	296,						/* U+0002DA */
+	297,						/* U+0002DB */
+	298,						/* U+0002DC */
+	299,						/* U+0002DD */
+	0,							/* U+0002DE */
+	0,							/* U+0002DF */
+	300,						/* U+0002E0 */
+	301,						/* U+0002E1 */
+	181,						/* U+0002E2 */
+	302,						/* U+0002E3 */
+	303,						/* U+0002E4 */
+	0,							/* U+0002E5 */
+	0,							/* U+0002E6 */
+	0,							/* U+0002E7 */
+	0,							/* U+0002E8 */
+	0,							/* U+0002E9 */
+	0,							/* U+0002EA */
+	0,							/* U+0002EB */
+	0,							/* U+0002EC */
+	0,							/* U+0002ED */
+	0,							/* U+0002EE */
+	0,							/* U+0002EF */
+	0,							/* U+0002F0 */
+	0,							/* U+0002F1 */
+	0,							/* U+0002F2 */
+	0,							/* U+0002F3 */
+	0,							/* U+0002F4 */
+	0,							/* U+0002F5 */
+	0,							/* U+0002F6 */
+	0,							/* U+0002F7 */
+	0,							/* U+0002F8 */
+	0,							/* U+0002F9 */
+	0,							/* U+0002FA */
+	0,							/* U+0002FB */
+	0,							/* U+0002FC */
+	0,							/* U+0002FD */
+	0,							/* U+0002FE */
+	0,							/* U+0002FF */
+	304,						/* U+000300 */
+	304,						/* U+000301 */
+	304,						/* U+000302 */
+	304,						/* U+000303 */
+	304,						/* U+000304 */
+	304,						/* U+000305 */
+	304,						/* U+000306 */
+	304,						/* U+000307 */
+	304,						/* U+000308 */
+	304,						/* U+000309 */
+	304,						/* U+00030A */
+	304,						/* U+00030B */
+	304,						/* U+00030C */
+	304,						/* U+00030D */
+	304,						/* U+00030E */
+	304,						/* U+00030F */
+	304,						/* U+000310 */
+	304,						/* U+000311 */
+	304,						/* U+000312 */
+	304,						/* U+000313 */
+	304,						/* U+000314 */
+	305,						/* U+000315 */
+	306,						/* U+000316 */
+	306,						/* U+000317 */
+	306,						/* U+000318 */
+	306,						/* U+000319 */
+	305,						/* U+00031A */
+	307,						/* U+00031B */
+	306,						/* U+00031C */
+	306,						/* U+00031D */
+	306,						/* U+00031E */
+	306,						/* U+00031F */
+	306,						/* U+000320 */
+	308,						/* U+000321 */
+	308,						/* U+000322 */
+	306,						/* U+000323 */
+	306,						/* U+000324 */
+	306,						/* U+000325 */
+	306,						/* U+000326 */
+	308,						/* U+000327 */
+	308,						/* U+000328 */
+	306,						/* U+000329 */
+	306,						/* U+00032A */
+	306,						/* U+00032B */
+	306,						/* U+00032C */
+	306,						/* U+00032D */
+	306,						/* U+00032E */
+	306,						/* U+00032F */
+	306,						/* U+000330 */
+	306,						/* U+000331 */
+	306,						/* U+000332 */
+	306,						/* U+000333 */
+	309,						/* U+000334 */
+	309,						/* U+000335 */
+	309,						/* U+000336 */
+	309,						/* U+000337 */
+	309,						/* U+000338 */
+	306,						/* U+000339 */
+	306,						/* U+00033A */
+	306,						/* U+00033B */
+	306,						/* U+00033C */
+	304,						/* U+00033D */
+	304,						/* U+00033E */
+	304,						/* U+00033F */
+	310,						/* U+000340 */
+	311,						/* U+000341 */
+	304,						/* U+000342 */
+	312,						/* U+000343 */
+	313,						/* U+000344 */
+	314,						/* U+000345 */
+	304,						/* U+000346 */
+	306,						/* U+000347 */
+	306,						/* U+000348 */
+	306,						/* U+000349 */
+	304,						/* U+00034A */
+	304,						/* U+00034B */
+	304,						/* U+00034C */
+	306,						/* U+00034D */
+	306,						/* U+00034E */
+	0,							/* U+00034F */
+	304,						/* U+000350 */
+	304,						/* U+000351 */
+	304,						/* U+000352 */
+	306,						/* U+000353 */
+	306,						/* U+000354 */
+	306,						/* U+000355 */
+	306,						/* U+000356 */
+	304,						/* U+000357 */
+	305,						/* U+000358 */
+	306,						/* U+000359 */
+	306,						/* U+00035A */
+	304,						/* U+00035B */
+	315,						/* U+00035C */
+	316,						/* U+00035D */
+	316,						/* U+00035E */
+	315,						/* U+00035F */
+	316,						/* U+000360 */
+	316,						/* U+000361 */
+	315,						/* U+000362 */
+	304,						/* U+000363 */
+	304,						/* U+000364 */
+	304,						/* U+000365 */
+	304,						/* U+000366 */
+	304,						/* U+000367 */
+	304,						/* U+000368 */
+	304,						/* U+000369 */
+	304,						/* U+00036A */
+	304,						/* U+00036B */
+	304,						/* U+00036C */
+	304,						/* U+00036D */
+	304,						/* U+00036E */
+	304,						/* U+00036F */
+	0,							/* U+000370 */
+	0,							/* U+000371 */
+	0,							/* U+000372 */
+	0,							/* U+000373 */
+	317,						/* U+000374 */
+	0,							/* U+000375 */
+	0,							/* U+000376 */
+	0,							/* U+000377 */
+	0,							/* U+000378 */
+	0,							/* U+000379 */
+	318,						/* U+00037A */
+	0,							/* U+00037B */
+	0,							/* U+00037C */
+	0,							/* U+00037D */
+	319,						/* U+00037E */
+	0,							/* U+00037F */
+	0,							/* U+000380 */
+	0,							/* U+000381 */
+	0,							/* U+000382 */
+	0,							/* U+000383 */
+	7,							/* U+000384 */
+	320,						/* U+000385 */
+	321,						/* U+000386 */
+	322,						/* U+000387 */
+	323,						/* U+000388 */
+	324,						/* U+000389 */
+	325,						/* U+00038A */
+	0,							/* U+00038B */
+	326,						/* U+00038C */
+	0,							/* U+00038D */
+	327,						/* U+00038E */
+	328,						/* U+00038F */
+	329,						/* U+000390 */
+	0,							/* U+000391 */
+	0,							/* U+000392 */
+	0,							/* U+000393 */
+	0,							/* U+000394 */
+	0,							/* U+000395 */
+	0,							/* U+000396 */
+	0,							/* U+000397 */
+	0,							/* U+000398 */
+	0,							/* U+000399 */
+	0,							/* U+00039A */
+	0,							/* U+00039B */
+	0,							/* U+00039C */
+	0,							/* U+00039D */
+	0,							/* U+00039E */
+	0,							/* U+00039F */
+	0,							/* U+0003A0 */
+	0,							/* U+0003A1 */
+	0,							/* U+0003A2 */
+	0,							/* U+0003A3 */
+	0,							/* U+0003A4 */
+	0,							/* U+0003A5 */
+	0,							/* U+0003A6 */
+	0,							/* U+0003A7 */
+	0,							/* U+0003A8 */
+	0,							/* U+0003A9 */
+	330,						/* U+0003AA */
+	331,						/* U+0003AB */
+	332,						/* U+0003AC */
+	333,						/* U+0003AD */
+	334,						/* U+0003AE */
+	335,						/* U+0003AF */
+	336,						/* U+0003B0 */
+	0,							/* U+0003B1 */
+	0,							/* U+0003B2 */
+	0,							/* U+0003B3 */
+	0,							/* U+0003B4 */
+	0,							/* U+0003B5 */
+	0,							/* U+0003B6 */
+	0,							/* U+0003B7 */
+	0,							/* U+0003B8 */
+	0,							/* U+0003B9 */
+	0,							/* U+0003BA */
+	0,							/* U+0003BB */
+	0,							/* U+0003BC */
+	0,							/* U+0003BD */
+	0,							/* U+0003BE */
+	0,							/* U+0003BF */
+	0,							/* U+0003C0 */
+	0,							/* U+0003C1 */
+	0,							/* U+0003C2 */
+	0,							/* U+0003C3 */
+	0,							/* U+0003C4 */
+	0,							/* U+0003C5 */
+	0,							/* U+0003C6 */
+	0,							/* U+0003C7 */
+	0,							/* U+0003C8 */
+	0,							/* U+0003C9 */
+	337,						/* U+0003CA */
+	338,						/* U+0003CB */
+	339,						/* U+0003CC */
+	340,						/* U+0003CD */
+	341,						/* U+0003CE */
+	0,							/* U+0003CF */
+	342,						/* U+0003D0 */
+	343,						/* U+0003D1 */
+	344,						/* U+0003D2 */
+	345,						/* U+0003D3 */
+	346,						/* U+0003D4 */
+	347,						/* U+0003D5 */
+	348,						/* U+0003D6 */
+	0,							/* U+0003D7 */
+	0,							/* U+0003D8 */
+	0,							/* U+0003D9 */
+	0,							/* U+0003DA */
+	0,							/* U+0003DB */
+	0,							/* U+0003DC */
+	0,							/* U+0003DD */
+	0,							/* U+0003DE */
+	0,							/* U+0003DF */
+	0,							/* U+0003E0 */
+	0,							/* U+0003E1 */
+	0,							/* U+0003E2 */
+	0,							/* U+0003E3 */
+	0,							/* U+0003E4 */
+	0,							/* U+0003E5 */
+	0,							/* U+0003E6 */
+	0,							/* U+0003E7 */
+	0,							/* U+0003E8 */
+	0,							/* U+0003E9 */
+	0,							/* U+0003EA */
+	0,							/* U+0003EB */
+	0,							/* U+0003EC */
+	0,							/* U+0003ED */
+	0,							/* U+0003EE */
+	0,							/* U+0003EF */
+	349,						/* U+0003F0 */
+	350,						/* U+0003F1 */
+	351,						/* U+0003F2 */
+	0,							/* U+0003F3 */
+	352,						/* U+0003F4 */
+	353,						/* U+0003F5 */
+	0,							/* U+0003F6 */
+	0,							/* U+0003F7 */
+	0,							/* U+0003F8 */
+	354,						/* U+0003F9 */
+	0,							/* U+0003FA */
+	0,							/* U+0003FB */
+	0,							/* U+0003FC */
+	0,							/* U+0003FD */
+	0,							/* U+0003FE */
+	0,							/* U+0003FF */
+	355,						/* U+000400 */
+	356,						/* U+000401 */
+	0,							/* U+000402 */
+	357,						/* U+000403 */
+	0,							/* U+000404 */
+	0,							/* U+000405 */
+	0,							/* U+000406 */
+	358,						/* U+000407 */
+	0,							/* U+000408 */
+	0,							/* U+000409 */
+	0,							/* U+00040A */
+	0,							/* U+00040B */
+	359,						/* U+00040C */
+	360,						/* U+00040D */
+	361,						/* U+00040E */
+	0,							/* U+00040F */
+	0,							/* U+000410 */
+	0,							/* U+000411 */
+	0,							/* U+000412 */
+	0,							/* U+000413 */
+	0,							/* U+000414 */
+	0,							/* U+000415 */
+	0,							/* U+000416 */
+	0,							/* U+000417 */
+	0,							/* U+000418 */
+	362,						/* U+000419 */
+	0,							/* U+00041A */
+	0,							/* U+00041B */
+	0,							/* U+00041C */
+	0,							/* U+00041D */
+	0,							/* U+00041E */
+	0,							/* U+00041F */
+	0,							/* U+000420 */
+	0,							/* U+000421 */
+	0,							/* U+000422 */
+	0,							/* U+000423 */
+	0,							/* U+000424 */
+	0,							/* U+000425 */
+	0,							/* U+000426 */
+	0,							/* U+000427 */
+	0,							/* U+000428 */
+	0,							/* U+000429 */
+	0,							/* U+00042A */
+	0,							/* U+00042B */
+	0,							/* U+00042C */
+	0,							/* U+00042D */
+	0,							/* U+00042E */
+	0,							/* U+00042F */
+	0,							/* U+000430 */
+	0,							/* U+000431 */
+	0,							/* U+000432 */
+	0,							/* U+000433 */
+	0,							/* U+000434 */
+	0,							/* U+000435 */
+	0,							/* U+000436 */
+	0,							/* U+000437 */
+	0,							/* U+000438 */
+	363,						/* U+000439 */
+	0,							/* U+00043A */
+	0,							/* U+00043B */
+	0,							/* U+00043C */
+	0,							/* U+00043D */
+	0,							/* U+00043E */
+	0,							/* U+00043F */
+	0,							/* U+000440 */
+	0,							/* U+000441 */
+	0,							/* U+000442 */
+	0,							/* U+000443 */
+	0,							/* U+000444 */
+	0,							/* U+000445 */
+	0,							/* U+000446 */
+	0,							/* U+000447 */
+	0,							/* U+000448 */
+	0,							/* U+000449 */
+	0,							/* U+00044A */
+	0,							/* U+00044B */
+	0,							/* U+00044C */
+	0,							/* U+00044D */
+	0,							/* U+00044E */
+	0,							/* U+00044F */
+	364,						/* U+000450 */
+	365,						/* U+000451 */
+	0,							/* U+000452 */
+	366,						/* U+000453 */
+	0,							/* U+000454 */
+	0,							/* U+000455 */
+	0,							/* U+000456 */
+	367,						/* U+000457 */
+	0,							/* U+000458 */
+	0,							/* U+000459 */
+	0,							/* U+00045A */
+	0,							/* U+00045B */
+	368,						/* U+00045C */
+	369,						/* U+00045D */
+	370,						/* U+00045E */
+	0,							/* U+00045F */
+	0,							/* U+000460 */
+	0,							/* U+000461 */
+	0,							/* U+000462 */
+	0,							/* U+000463 */
+	0,							/* U+000464 */
+	0,							/* U+000465 */
+	0,							/* U+000466 */
+	0,							/* U+000467 */
+	0,							/* U+000468 */
+	0,							/* U+000469 */
+	0,							/* U+00046A */
+	0,							/* U+00046B */
+	0,							/* U+00046C */
+	0,							/* U+00046D */
+	0,							/* U+00046E */
+	0,							/* U+00046F */
+	0,							/* U+000470 */
+	0,							/* U+000471 */
+	0,							/* U+000472 */
+	0,							/* U+000473 */
+	0,							/* U+000474 */
+	0,							/* U+000475 */
+	371,						/* U+000476 */
+	372,						/* U+000477 */
+	0,							/* U+000478 */
+	0,							/* U+000479 */
+	0,							/* U+00047A */
+	0,							/* U+00047B */
+	0,							/* U+00047C */
+	0,							/* U+00047D */
+	0,							/* U+00047E */
+	0,							/* U+00047F */
+	0,							/* U+000480 */
+	0,							/* U+000481 */
+	0,							/* U+000482 */
+	304,						/* U+000483 */
+	304,						/* U+000484 */
+	304,						/* U+000485 */
+	304,						/* U+000486 */
+	304,						/* U+000487 */
+	0,							/* U+000488 */
+	0,							/* U+000489 */
+	0,							/* U+00048A */
+	0,							/* U+00048B */
+	0,							/* U+00048C */
+	0,							/* U+00048D */
+	0,							/* U+00048E */
+	0,							/* U+00048F */
+	0,							/* U+000490 */
+	0,							/* U+000491 */
+	0,							/* U+000492 */
+	0,							/* U+000493 */
+	0,							/* U+000494 */
+	0,							/* U+000495 */
+	0,							/* U+000496 */
+	0,							/* U+000497 */
+	0,							/* U+000498 */
+	0,							/* U+000499 */
+	0,							/* U+00049A */
+	0,							/* U+00049B */
+	0,							/* U+00049C */
+	0,							/* U+00049D */
+	0,							/* U+00049E */
+	0,							/* U+00049F */
+	0,							/* U+0004A0 */
+	0,							/* U+0004A1 */
+	0,							/* U+0004A2 */
+	0,							/* U+0004A3 */
+	0,							/* U+0004A4 */
+	0,							/* U+0004A5 */
+	0,							/* U+0004A6 */
+	0,							/* U+0004A7 */
+	0,							/* U+0004A8 */
+	0,							/* U+0004A9 */
+	0,							/* U+0004AA */
+	0,							/* U+0004AB */
+	0,							/* U+0004AC */
+	0,							/* U+0004AD */
+	0,							/* U+0004AE */
+	0,							/* U+0004AF */
+	0,							/* U+0004B0 */
+	0,							/* U+0004B1 */
+	0,							/* U+0004B2 */
+	0,							/* U+0004B3 */
+	0,							/* U+0004B4 */
+	0,							/* U+0004B5 */
+	0,							/* U+0004B6 */
+	0,							/* U+0004B7 */
+	0,							/* U+0004B8 */
+	0,							/* U+0004B9 */
+	0,							/* U+0004BA */
+	0,							/* U+0004BB */
+	0,							/* U+0004BC */
+	0,							/* U+0004BD */
+	0,							/* U+0004BE */
+	0,							/* U+0004BF */
+	0,							/* U+0004C0 */
+	373,						/* U+0004C1 */
+	374,						/* U+0004C2 */
+	0,							/* U+0004C3 */
+	0,							/* U+0004C4 */
+	0,							/* U+0004C5 */
+	0,							/* U+0004C6 */
+	0,							/* U+0004C7 */
+	0,							/* U+0004C8 */
+	0,							/* U+0004C9 */
+	0,							/* U+0004CA */
+	0,							/* U+0004CB */
+	0,							/* U+0004CC */
+	0,							/* U+0004CD */
+	0,							/* U+0004CE */
+	0,							/* U+0004CF */
+	375,						/* U+0004D0 */
+	376,						/* U+0004D1 */
+	377,						/* U+0004D2 */
+	378,						/* U+0004D3 */
+	0,							/* U+0004D4 */
+	0,							/* U+0004D5 */
+	379,						/* U+0004D6 */
+	380,						/* U+0004D7 */
+	0,							/* U+0004D8 */
+	0,							/* U+0004D9 */
+	381,						/* U+0004DA */
+	382,						/* U+0004DB */
+	383,						/* U+0004DC */
+	384,						/* U+0004DD */
+	385,						/* U+0004DE */
+	386,						/* U+0004DF */
+	0,							/* U+0004E0 */
+	0,							/* U+0004E1 */
+	387,						/* U+0004E2 */
+	388,						/* U+0004E3 */
+	389,						/* U+0004E4 */
+	390,						/* U+0004E5 */
+	391,						/* U+0004E6 */
+	392,						/* U+0004E7 */
+	0,							/* U+0004E8 */
+	0,							/* U+0004E9 */
+	393,						/* U+0004EA */
+	394,						/* U+0004EB */
+	395,						/* U+0004EC */
+	396,						/* U+0004ED */
+	397,						/* U+0004EE */
+	398,						/* U+0004EF */
+	399,						/* U+0004F0 */
+	400,						/* U+0004F1 */
+	401,						/* U+0004F2 */
+	402,						/* U+0004F3 */
+	403,						/* U+0004F4 */
+	404,						/* U+0004F5 */
+	0,							/* U+0004F6 */
+	0,							/* U+0004F7 */
+	405,						/* U+0004F8 */
+	406,						/* U+0004F9 */
+	0,							/* U+0004FA */
+	0,							/* U+0004FB */
+	0,							/* U+0004FC */
+	0,							/* U+0004FD */
+	0,							/* U+0004FE */
+	0,							/* U+0004FF */
+	0,							/* U+000500 */
+	0,							/* U+000501 */
+	0,							/* U+000502 */
+	0,							/* U+000503 */
+	0,							/* U+000504 */
+	0,							/* U+000505 */
+	0,							/* U+000506 */
+	0,							/* U+000507 */
+	0,							/* U+000508 */
+	0,							/* U+000509 */
+	0,							/* U+00050A */
+	0,							/* U+00050B */
+	0,							/* U+00050C */
+	0,							/* U+00050D */
+	0,							/* U+00050E */
+	0,							/* U+00050F */
+	0,							/* U+000510 */
+	0,							/* U+000511 */
+	0,							/* U+000512 */
+	0,							/* U+000513 */
+	0,							/* U+000514 */
+	0,							/* U+000515 */
+	0,							/* U+000516 */
+	0,							/* U+000517 */
+	0,							/* U+000518 */
+	0,							/* U+000519 */
+	0,							/* U+00051A */
+	0,							/* U+00051B */
+	0,							/* U+00051C */
+	0,							/* U+00051D */
+	0,							/* U+00051E */
+	0,							/* U+00051F */
+	0,							/* U+000520 */
+	0,							/* U+000521 */
+	0,							/* U+000522 */
+	0,							/* U+000523 */
+	0,							/* U+000524 */
+	0,							/* U+000525 */
+	0,							/* U+000526 */
+	0,							/* U+000527 */
+	0,							/* U+000528 */
+	0,							/* U+000529 */
+	0,							/* U+00052A */
+	0,							/* U+00052B */
+	0,							/* U+00052C */
+	0,							/* U+00052D */
+	0,							/* U+00052E */
+	0,							/* U+00052F */
+	0,							/* U+000530 */
+	0,							/* U+000531 */
+	0,							/* U+000532 */
+	0,							/* U+000533 */
+	0,							/* U+000534 */
+	0,							/* U+000535 */
+	0,							/* U+000536 */
+	0,							/* U+000537 */
+	0,							/* U+000538 */
+	0,							/* U+000539 */
+	0,							/* U+00053A */
+	0,							/* U+00053B */
+	0,							/* U+00053C */
+	0,							/* U+00053D */
+	0,							/* U+00053E */
+	0,							/* U+00053F */
+	0,							/* U+000540 */
+	0,							/* U+000541 */
+	0,							/* U+000542 */
+	0,							/* U+000543 */
+	0,							/* U+000544 */
+	0,							/* U+000545 */
+	0,							/* U+000546 */
+	0,							/* U+000547 */
+	0,							/* U+000548 */
+	0,							/* U+000549 */
+	0,							/* U+00054A */
+	0,							/* U+00054B */
+	0,							/* U+00054C */
+	0,							/* U+00054D */
+	0,							/* U+00054E */
+	0,							/* U+00054F */
+	0,							/* U+000550 */
+	0,							/* U+000551 */
+	0,							/* U+000552 */
+	0,							/* U+000553 */
+	0,							/* U+000554 */
+	0,							/* U+000555 */
+	0,							/* U+000556 */
+	0,							/* U+000557 */
+	0,							/* U+000558 */
+	0,							/* U+000559 */
+	0,							/* U+00055A */
+	0,							/* U+00055B */
+	0,							/* U+00055C */
+	0,							/* U+00055D */
+	0,							/* U+00055E */
+	0,							/* U+00055F */
+	0,							/* U+000560 */
+	0,							/* U+000561 */
+	0,							/* U+000562 */
+	0,							/* U+000563 */
+	0,							/* U+000564 */
+	0,							/* U+000565 */
+	0,							/* U+000566 */
+	0,							/* U+000567 */
+	0,							/* U+000568 */
+	0,							/* U+000569 */
+	0,							/* U+00056A */
+	0,							/* U+00056B */
+	0,							/* U+00056C */
+	0,							/* U+00056D */
+	0,							/* U+00056E */
+	0,							/* U+00056F */
+	0,							/* U+000570 */
+	0,							/* U+000571 */
+	0,							/* U+000572 */
+	0,							/* U+000573 */
+	0,							/* U+000574 */
+	0,							/* U+000575 */
+	0,							/* U+000576 */
+	0,							/* U+000577 */
+	0,							/* U+000578 */
+	0,							/* U+000579 */
+	0,							/* U+00057A */
+	0,							/* U+00057B */
+	0,							/* U+00057C */
+	0,							/* U+00057D */
+	0,							/* U+00057E */
+	0,							/* U+00057F */
+	0,							/* U+000580 */
+	0,							/* U+000581 */
+	0,							/* U+000582 */
+	0,							/* U+000583 */
+	0,							/* U+000584 */
+	0,							/* U+000585 */
+	0,							/* U+000586 */
+	407,						/* U+000587 */
+	0,							/* U+000588 */
+	0,							/* U+000589 */
+	0,							/* U+00058A */
+	0,							/* U+00058B */
+	0,							/* U+00058C */
+	0,							/* U+00058D */
+	0,							/* U+00058E */
+	0,							/* U+00058F */
+	0,							/* U+000590 */
+	306,						/* U+000591 */
+	304,						/* U+000592 */
+	304,						/* U+000593 */
+	304,						/* U+000594 */
+	304,						/* U+000595 */
+	306,						/* U+000596 */
+	304,						/* U+000597 */
+	304,						/* U+000598 */
+	304,						/* U+000599 */
+	408,						/* U+00059A */
+	306,						/* U+00059B */
+	304,						/* U+00059C */
+	304,						/* U+00059D */
+	304,						/* U+00059E */
+	304,						/* U+00059F */
+	304,						/* U+0005A0 */
+	304,						/* U+0005A1 */
+	306,						/* U+0005A2 */
+	306,						/* U+0005A3 */
+	306,						/* U+0005A4 */
+	306,						/* U+0005A5 */
+	306,						/* U+0005A6 */
+	306,						/* U+0005A7 */
+	304,						/* U+0005A8 */
+	304,						/* U+0005A9 */
+	306,						/* U+0005AA */
+	304,						/* U+0005AB */
+	304,						/* U+0005AC */
+	408,						/* U+0005AD */
+	409,						/* U+0005AE */
+	304,						/* U+0005AF */
+	410,						/* U+0005B0 */
+	411,						/* U+0005B1 */
+	412,						/* U+0005B2 */
+	413,						/* U+0005B3 */
+	414,						/* U+0005B4 */
+	415,						/* U+0005B5 */
+	416,						/* U+0005B6 */
+	417,						/* U+0005B7 */
+	418,						/* U+0005B8 */
+	419,						/* U+0005B9 */
+	419,						/* U+0005BA */
+	420,						/* U+0005BB */
+	421,						/* U+0005BC */
+	422,						/* U+0005BD */
+	0,							/* U+0005BE */
+	423,						/* U+0005BF */
+	0,							/* U+0005C0 */
+	424,						/* U+0005C1 */
+	425,						/* U+0005C2 */
+	0,							/* U+0005C3 */
+	304,						/* U+0005C4 */
+	306,						/* U+0005C5 */
+	0,							/* U+0005C6 */
+	418,						/* U+0005C7 */
+	0,							/* U+0005C8 */
+	0,							/* U+0005C9 */
+	0,							/* U+0005CA */
+	0,							/* U+0005CB */
+	0,							/* U+0005CC */
+	0,							/* U+0005CD */
+	0,							/* U+0005CE */
+	0,							/* U+0005CF */
+	0,							/* U+0005D0 */
+	0,							/* U+0005D1 */
+	0,							/* U+0005D2 */
+	0,							/* U+0005D3 */
+	0,							/* U+0005D4 */
+	0,							/* U+0005D5 */
+	0,							/* U+0005D6 */
+	0,							/* U+0005D7 */
+	0,							/* U+0005D8 */
+	0,							/* U+0005D9 */
+	0,							/* U+0005DA */
+	0,							/* U+0005DB */
+	0,							/* U+0005DC */
+	0,							/* U+0005DD */
+	0,							/* U+0005DE */
+	0,							/* U+0005DF */
+	0,							/* U+0005E0 */
+	0,							/* U+0005E1 */
+	0,							/* U+0005E2 */
+	0,							/* U+0005E3 */
+	0,							/* U+0005E4 */
+	0,							/* U+0005E5 */
+	0,							/* U+0005E6 */
+	0,							/* U+0005E7 */
+	0,							/* U+0005E8 */
+	0,							/* U+0005E9 */
+	0,							/* U+0005EA */
+	0,							/* U+0005EB */
+	0,							/* U+0005EC */
+	0,							/* U+0005ED */
+	0,							/* U+0005EE */
+	0,							/* U+0005EF */
+	0,							/* U+0005F0 */
+	0,							/* U+0005F1 */
+	0,							/* U+0005F2 */
+	0,							/* U+0005F3 */
+	0,							/* U+0005F4 */
+	0,							/* U+0005F5 */
+	0,							/* U+0005F6 */
+	0,							/* U+0005F7 */
+	0,							/* U+0005F8 */
+	0,							/* U+0005F9 */
+	0,							/* U+0005FA */
+	0,							/* U+0005FB */
+	0,							/* U+0005FC */
+	0,							/* U+0005FD */
+	0,							/* U+0005FE */
+	0,							/* U+0005FF */
+	0,							/* U+000600 */
+	0,							/* U+000601 */
+	0,							/* U+000602 */
+	0,							/* U+000603 */
+	0,							/* U+000604 */
+	0,							/* U+000605 */
+	0,							/* U+000606 */
+	0,							/* U+000607 */
+	0,							/* U+000608 */
+	0,							/* U+000609 */
+	0,							/* U+00060A */
+	0,							/* U+00060B */
+	0,							/* U+00060C */
+	0,							/* U+00060D */
+	0,							/* U+00060E */
+	0,							/* U+00060F */
+	304,						/* U+000610 */
+	304,						/* U+000611 */
+	304,						/* U+000612 */
+	304,						/* U+000613 */
+	304,						/* U+000614 */
+	304,						/* U+000615 */
+	304,						/* U+000616 */
+	304,						/* U+000617 */
+	426,						/* U+000618 */
+	427,						/* U+000619 */
+	428,						/* U+00061A */
+	0,							/* U+00061B */
+	0,							/* U+00061C */
+	0,							/* U+00061D */
+	0,							/* U+00061E */
+	0,							/* U+00061F */
+	0,							/* U+000620 */
+	0,							/* U+000621 */
+	429,						/* U+000622 */
+	430,						/* U+000623 */
+	431,						/* U+000624 */
+	432,						/* U+000625 */
+	433,						/* U+000626 */
+	0,							/* U+000627 */
+	0,							/* U+000628 */
+	0,							/* U+000629 */
+	0,							/* U+00062A */
+	0,							/* U+00062B */
+	0,							/* U+00062C */
+	0,							/* U+00062D */
+	0,							/* U+00062E */
+	0,							/* U+00062F */
+	0,							/* U+000630 */
+	0,							/* U+000631 */
+	0,							/* U+000632 */
+	0,							/* U+000633 */
+	0,							/* U+000634 */
+	0,							/* U+000635 */
+	0,							/* U+000636 */
+	0,							/* U+000637 */
+	0,							/* U+000638 */
+	0,							/* U+000639 */
+	0,							/* U+00063A */
+	0,							/* U+00063B */
+	0,							/* U+00063C */
+	0,							/* U+00063D */
+	0,							/* U+00063E */
+	0,							/* U+00063F */
+	0,							/* U+000640 */
+	0,							/* U+000641 */
+	0,							/* U+000642 */
+	0,							/* U+000643 */
+	0,							/* U+000644 */
+	0,							/* U+000645 */
+	0,							/* U+000646 */
+	0,							/* U+000647 */
+	0,							/* U+000648 */
+	0,							/* U+000649 */
+	0,							/* U+00064A */
+	434,						/* U+00064B */
+	435,						/* U+00064C */
+	436,						/* U+00064D */
+	426,						/* U+00064E */
+	427,						/* U+00064F */
+	428,						/* U+000650 */
+	437,						/* U+000651 */
+	438,						/* U+000652 */
+	304,						/* U+000653 */
+	304,						/* U+000654 */
+	306,						/* U+000655 */
+	306,						/* U+000656 */
+	304,						/* U+000657 */
+	304,						/* U+000658 */
+	304,						/* U+000659 */
+	304,						/* U+00065A */
+	304,						/* U+00065B */
+	306,						/* U+00065C */
+	304,						/* U+00065D */
+	304,						/* U+00065E */
+	306,						/* U+00065F */
+	0,							/* U+000660 */
+	0,							/* U+000661 */
+	0,							/* U+000662 */
+	0,							/* U+000663 */
+	0,							/* U+000664 */
+	0,							/* U+000665 */
+	0,							/* U+000666 */
+	0,							/* U+000667 */
+	0,							/* U+000668 */
+	0,							/* U+000669 */
+	0,							/* U+00066A */
+	0,							/* U+00066B */
+	0,							/* U+00066C */
+	0,							/* U+00066D */
+	0,							/* U+00066E */
+	0,							/* U+00066F */
+	439,						/* U+000670 */
+	0,							/* U+000671 */
+	0,							/* U+000672 */
+	0,							/* U+000673 */
+	0,							/* U+000674 */
+	440,						/* U+000675 */
+	441,						/* U+000676 */
+	442,						/* U+000677 */
+	443,						/* U+000678 */
+	0,							/* U+000679 */
+	0,							/* U+00067A */
+	0,							/* U+00067B */
+	0,							/* U+00067C */
+	0,							/* U+00067D */
+	0,							/* U+00067E */
+	0,							/* U+00067F */
+	0,							/* U+000680 */
+	0,							/* U+000681 */
+	0,							/* U+000682 */
+	0,							/* U+000683 */
+	0,							/* U+000684 */
+	0,							/* U+000685 */
+	0,							/* U+000686 */
+	0,							/* U+000687 */
+	0,							/* U+000688 */
+	0,							/* U+000689 */
+	0,							/* U+00068A */
+	0,							/* U+00068B */
+	0,							/* U+00068C */
+	0,							/* U+00068D */
+	0,							/* U+00068E */
+	0,							/* U+00068F */
+	0,							/* U+000690 */
+	0,							/* U+000691 */
+	0,							/* U+000692 */
+	0,							/* U+000693 */
+	0,							/* U+000694 */
+	0,							/* U+000695 */
+	0,							/* U+000696 */
+	0,							/* U+000697 */
+	0,							/* U+000698 */
+	0,							/* U+000699 */
+	0,							/* U+00069A */
+	0,							/* U+00069B */
+	0,							/* U+00069C */
+	0,							/* U+00069D */
+	0,							/* U+00069E */
+	0,							/* U+00069F */
+	0,							/* U+0006A0 */
+	0,							/* U+0006A1 */
+	0,							/* U+0006A2 */
+	0,							/* U+0006A3 */
+	0,							/* U+0006A4 */
+	0,							/* U+0006A5 */
+	0,							/* U+0006A6 */
+	0,							/* U+0006A7 */
+	0,							/* U+0006A8 */
+	0,							/* U+0006A9 */
+	0,							/* U+0006AA */
+	0,							/* U+0006AB */
+	0,							/* U+0006AC */
+	0,							/* U+0006AD */
+	0,							/* U+0006AE */
+	0,							/* U+0006AF */
+	0,							/* U+0006B0 */
+	0,							/* U+0006B1 */
+	0,							/* U+0006B2 */
+	0,							/* U+0006B3 */
+	0,							/* U+0006B4 */
+	0,							/* U+0006B5 */
+	0,							/* U+0006B6 */
+	0,							/* U+0006B7 */
+	0,							/* U+0006B8 */
+	0,							/* U+0006B9 */
+	0,							/* U+0006BA */
+	0,							/* U+0006BB */
+	0,							/* U+0006BC */
+	0,							/* U+0006BD */
+	0,							/* U+0006BE */
+	0,							/* U+0006BF */
+	444,						/* U+0006C0 */
+	0,							/* U+0006C1 */
+	445,						/* U+0006C2 */
+	0,							/* U+0006C3 */
+	0,							/* U+0006C4 */
+	0,							/* U+0006C5 */
+	0,							/* U+0006C6 */
+	0,							/* U+0006C7 */
+	0,							/* U+0006C8 */
+	0,							/* U+0006C9 */
+	0,							/* U+0006CA */
+	0,							/* U+0006CB */
+	0,							/* U+0006CC */
+	0,							/* U+0006CD */
+	0,							/* U+0006CE */
+	0,							/* U+0006CF */
+	0,							/* U+0006D0 */
+	0,							/* U+0006D1 */
+	0,							/* U+0006D2 */
+	446,						/* U+0006D3 */
+	0,							/* U+0006D4 */
+	0,							/* U+0006D5 */
+	304,						/* U+0006D6 */
+	304,						/* U+0006D7 */
+	304,						/* U+0006D8 */
+	304,						/* U+0006D9 */
+	304,						/* U+0006DA */
+	304,						/* U+0006DB */
+	304,						/* U+0006DC */
+	0,							/* U+0006DD */
+	0,							/* U+0006DE */
+	304,						/* U+0006DF */
+	304,						/* U+0006E0 */
+	304,						/* U+0006E1 */
+	304,						/* U+0006E2 */
+	306,						/* U+0006E3 */
+	304,						/* U+0006E4 */
+	0,							/* U+0006E5 */
+	0,							/* U+0006E6 */
+	304,						/* U+0006E7 */
+	304,						/* U+0006E8 */
+	0,							/* U+0006E9 */
+	306,						/* U+0006EA */
+	304,						/* U+0006EB */
+	304,						/* U+0006EC */
+	306,						/* U+0006ED */
+	0,							/* U+0006EE */
+	0,							/* U+0006EF */
+	0,							/* U+0006F0 */
+	0,							/* U+0006F1 */
+	0,							/* U+0006F2 */
+	0,							/* U+0006F3 */
+	0,							/* U+0006F4 */
+	0,							/* U+0006F5 */
+	0,							/* U+0006F6 */
+	0,							/* U+0006F7 */
+	0,							/* U+0006F8 */
+	0,							/* U+0006F9 */
+	0,							/* U+0006FA */
+	0,							/* U+0006FB */
+	0,							/* U+0006FC */
+	0,							/* U+0006FD */
+	0,							/* U+0006FE */
+	0,							/* U+0006FF */
+	0,							/* U+000700 */
+	0,							/* U+000701 */
+	0,							/* U+000702 */
+	0,							/* U+000703 */
+	0,							/* U+000704 */
+	0,							/* U+000705 */
+	0,							/* U+000706 */
+	0,							/* U+000707 */
+	0,							/* U+000708 */
+	0,							/* U+000709 */
+	0,							/* U+00070A */
+	0,							/* U+00070B */
+	0,							/* U+00070C */
+	0,							/* U+00070D */
+	0,							/* U+00070E */
+	0,							/* U+00070F */
+	0,							/* U+000710 */
+	447,						/* U+000711 */
+	0,							/* U+000712 */
+	0,							/* U+000713 */
+	0,							/* U+000714 */
+	0,							/* U+000715 */
+	0,							/* U+000716 */
+	0,							/* U+000717 */
+	0,							/* U+000718 */
+	0,							/* U+000719 */
+	0,							/* U+00071A */
+	0,							/* U+00071B */
+	0,							/* U+00071C */
+	0,							/* U+00071D */
+	0,							/* U+00071E */
+	0,							/* U+00071F */
+	0,							/* U+000720 */
+	0,							/* U+000721 */
+	0,							/* U+000722 */
+	0,							/* U+000723 */
+	0,							/* U+000724 */
+	0,							/* U+000725 */
+	0,							/* U+000726 */
+	0,							/* U+000727 */
+	0,							/* U+000728 */
+	0,							/* U+000729 */
+	0,							/* U+00072A */
+	0,							/* U+00072B */
+	0,							/* U+00072C */
+	0,							/* U+00072D */
+	0,							/* U+00072E */
+	0,							/* U+00072F */
+	304,						/* U+000730 */
+	306,						/* U+000731 */
+	304,						/* U+000732 */
+	304,						/* U+000733 */
+	306,						/* U+000734 */
+	304,						/* U+000735 */
+	304,						/* U+000736 */
+	306,						/* U+000737 */
+	306,						/* U+000738 */
+	306,						/* U+000739 */
+	304,						/* U+00073A */
+	306,						/* U+00073B */
+	306,						/* U+00073C */
+	304,						/* U+00073D */
+	306,						/* U+00073E */
+	304,						/* U+00073F */
+	304,						/* U+000740 */
+	304,						/* U+000741 */
+	306,						/* U+000742 */
+	304,						/* U+000743 */
+	306,						/* U+000744 */
+	304,						/* U+000745 */
+	306,						/* U+000746 */
+	304,						/* U+000747 */
+	306,						/* U+000748 */
+	304,						/* U+000749 */
+	304,						/* U+00074A */
+	0,							/* U+00074B */
+	0,							/* U+00074C */
+	0,							/* U+00074D */
+	0,							/* U+00074E */
+	0,							/* U+00074F */
+	0,							/* U+000750 */
+	0,							/* U+000751 */
+	0,							/* U+000752 */
+	0,							/* U+000753 */
+	0,							/* U+000754 */
+	0,							/* U+000755 */
+	0,							/* U+000756 */
+	0,							/* U+000757 */
+	0,							/* U+000758 */
+	0,							/* U+000759 */
+	0,							/* U+00075A */
+	0,							/* U+00075B */
+	0,							/* U+00075C */
+	0,							/* U+00075D */
+	0,							/* U+00075E */
+	0,							/* U+00075F */
+	0,							/* U+000760 */
+	0,							/* U+000761 */
+	0,							/* U+000762 */
+	0,							/* U+000763 */
+	0,							/* U+000764 */
+	0,							/* U+000765 */
+	0,							/* U+000766 */
+	0,							/* U+000767 */
+	0,							/* U+000768 */
+	0,							/* U+000769 */
+	0,							/* U+00076A */
+	0,							/* U+00076B */
+	0,							/* U+00076C */
+	0,							/* U+00076D */
+	0,							/* U+00076E */
+	0,							/* U+00076F */
+	0,							/* U+000770 */
+	0,							/* U+000771 */
+	0,							/* U+000772 */
+	0,							/* U+000773 */
+	0,							/* U+000774 */
+	0,							/* U+000775 */
+	0,							/* U+000776 */
+	0,							/* U+000777 */
+	0,							/* U+000778 */
+	0,							/* U+000779 */
+	0,							/* U+00077A */
+	0,							/* U+00077B */
+	0,							/* U+00077C */
+	0,							/* U+00077D */
+	0,							/* U+00077E */
+	0,							/* U+00077F */
+	0,							/* U+000780 */
+	0,							/* U+000781 */
+	0,							/* U+000782 */
+	0,							/* U+000783 */
+	0,							/* U+000784 */
+	0,							/* U+000785 */
+	0,							/* U+000786 */
+	0,							/* U+000787 */
+	0,							/* U+000788 */
+	0,							/* U+000789 */
+	0,							/* U+00078A */
+	0,							/* U+00078B */
+	0,							/* U+00078C */
+	0,							/* U+00078D */
+	0,							/* U+00078E */
+	0,							/* U+00078F */
+	0,							/* U+000790 */
+	0,							/* U+000791 */
+	0,							/* U+000792 */
+	0,							/* U+000793 */
+	0,							/* U+000794 */
+	0,							/* U+000795 */
+	0,							/* U+000796 */
+	0,							/* U+000797 */
+	0,							/* U+000798 */
+	0,							/* U+000799 */
+	0,							/* U+00079A */
+	0,							/* U+00079B */
+	0,							/* U+00079C */
+	0,							/* U+00079D */
+	0,							/* U+00079E */
+	0,							/* U+00079F */
+	0,							/* U+0007A0 */
+	0,							/* U+0007A1 */
+	0,							/* U+0007A2 */
+	0,							/* U+0007A3 */
+	0,							/* U+0007A4 */
+	0,							/* U+0007A5 */
+	0,							/* U+0007A6 */
+	0,							/* U+0007A7 */
+	0,							/* U+0007A8 */
+	0,							/* U+0007A9 */
+	0,							/* U+0007AA */
+	0,							/* U+0007AB */
+	0,							/* U+0007AC */
+	0,							/* U+0007AD */
+	0,							/* U+0007AE */
+	0,							/* U+0007AF */
+	0,							/* U+0007B0 */
+	0,							/* U+0007B1 */
+	0,							/* U+0007B2 */
+	0,							/* U+0007B3 */
+	0,							/* U+0007B4 */
+	0,							/* U+0007B5 */
+	0,							/* U+0007B6 */
+	0,							/* U+0007B7 */
+	0,							/* U+0007B8 */
+	0,							/* U+0007B9 */
+	0,							/* U+0007BA */
+	0,							/* U+0007BB */
+	0,							/* U+0007BC */
+	0,							/* U+0007BD */
+	0,							/* U+0007BE */
+	0,							/* U+0007BF */
+	0,							/* U+0007C0 */
+	0,							/* U+0007C1 */
+	0,							/* U+0007C2 */
+	0,							/* U+0007C3 */
+	0,							/* U+0007C4 */
+	0,							/* U+0007C5 */
+	0,							/* U+0007C6 */
+	0,							/* U+0007C7 */
+	0,							/* U+0007C8 */
+	0,							/* U+0007C9 */
+	0,							/* U+0007CA */
+	0,							/* U+0007CB */
+	0,							/* U+0007CC */
+	0,							/* U+0007CD */
+	0,							/* U+0007CE */
+	0,							/* U+0007CF */
+	0,							/* U+0007D0 */
+	0,							/* U+0007D1 */
+	0,							/* U+0007D2 */
+	0,							/* U+0007D3 */
+	0,							/* U+0007D4 */
+	0,							/* U+0007D5 */
+	0,							/* U+0007D6 */
+	0,							/* U+0007D7 */
+	0,							/* U+0007D8 */
+	0,							/* U+0007D9 */
+	0,							/* U+0007DA */
+	0,							/* U+0007DB */
+	0,							/* U+0007DC */
+	0,							/* U+0007DD */
+	0,							/* U+0007DE */
+	0,							/* U+0007DF */
+	0,							/* U+0007E0 */
+	0,							/* U+0007E1 */
+	0,							/* U+0007E2 */
+	0,							/* U+0007E3 */
+	0,							/* U+0007E4 */
+	0,							/* U+0007E5 */
+	0,							/* U+0007E6 */
+	0,							/* U+0007E7 */
+	0,							/* U+0007E8 */
+	0,							/* U+0007E9 */
+	0,							/* U+0007EA */
+	304,						/* U+0007EB */
+	304,						/* U+0007EC */
+	304,						/* U+0007ED */
+	304,						/* U+0007EE */
+	304,						/* U+0007EF */
+	304,						/* U+0007F0 */
+	304,						/* U+0007F1 */
+	306,						/* U+0007F2 */
+	304,						/* U+0007F3 */
+	0,							/* U+0007F4 */
+	0,							/* U+0007F5 */
+	0,							/* U+0007F6 */
+	0,							/* U+0007F7 */
+	0,							/* U+0007F8 */
+	0,							/* U+0007F9 */
+	0,							/* U+0007FA */
+	0,							/* U+0007FB */
+	0,							/* U+0007FC */
+	306,						/* U+0007FD */
+	0,							/* U+0007FE */
+	0,							/* U+0007FF */
+	0,							/* U+000800 */
+	0,							/* U+000801 */
+	0,							/* U+000802 */
+	0,							/* U+000803 */
+	0,							/* U+000804 */
+	0,							/* U+000805 */
+	0,							/* U+000806 */
+	0,							/* U+000807 */
+	0,							/* U+000808 */
+	0,							/* U+000809 */
+	0,							/* U+00080A */
+	0,							/* U+00080B */
+	0,							/* U+00080C */
+	0,							/* U+00080D */
+	0,							/* U+00080E */
+	0,							/* U+00080F */
+	0,							/* U+000810 */
+	0,							/* U+000811 */
+	0,							/* U+000812 */
+	0,							/* U+000813 */
+	0,							/* U+000814 */
+	0,							/* U+000815 */
+	304,						/* U+000816 */
+	304,						/* U+000817 */
+	304,						/* U+000818 */
+	304,						/* U+000819 */
+	0,							/* U+00081A */
+	304,						/* U+00081B */
+	304,						/* U+00081C */
+	304,						/* U+00081D */
+	304,						/* U+00081E */
+	304,						/* U+00081F */
+	304,						/* U+000820 */
+	304,						/* U+000821 */
+	304,						/* U+000822 */
+	304,						/* U+000823 */
+	0,							/* U+000824 */
+	304,						/* U+000825 */
+	304,						/* U+000826 */
+	304,						/* U+000827 */
+	0,							/* U+000828 */
+	304,						/* U+000829 */
+	304,						/* U+00082A */
+	304,						/* U+00082B */
+	304,						/* U+00082C */
+	304,						/* U+00082D */
+	0,							/* U+00082E */
+	0,							/* U+00082F */
+	0,							/* U+000830 */
+	0,							/* U+000831 */
+	0,							/* U+000832 */
+	0,							/* U+000833 */
+	0,							/* U+000834 */
+	0,							/* U+000835 */
+	0,							/* U+000836 */
+	0,							/* U+000837 */
+	0,							/* U+000838 */
+	0,							/* U+000839 */
+	0,							/* U+00083A */
+	0,							/* U+00083B */
+	0,							/* U+00083C */
+	0,							/* U+00083D */
+	0,							/* U+00083E */
+	0,							/* U+00083F */
+	0,							/* U+000840 */
+	0,							/* U+000841 */
+	0,							/* U+000842 */
+	0,							/* U+000843 */
+	0,							/* U+000844 */
+	0,							/* U+000845 */
+	0,							/* U+000846 */
+	0,							/* U+000847 */
+	0,							/* U+000848 */
+	0,							/* U+000849 */
+	0,							/* U+00084A */
+	0,							/* U+00084B */
+	0,							/* U+00084C */
+	0,							/* U+00084D */
+	0,							/* U+00084E */
+	0,							/* U+00084F */
+	0,							/* U+000850 */
+	0,							/* U+000851 */
+	0,							/* U+000852 */
+	0,							/* U+000853 */
+	0,							/* U+000854 */
+	0,							/* U+000855 */
+	0,							/* U+000856 */
+	0,							/* U+000857 */
+	0,							/* U+000858 */
+	306,						/* U+000859 */
+	306,						/* U+00085A */
+	306,						/* U+00085B */
+	0,							/* U+00085C */
+	0,							/* U+00085D */
+	0,							/* U+00085E */
+	0,							/* U+00085F */
+	0,							/* U+000860 */
+	0,							/* U+000861 */
+	0,							/* U+000862 */
+	0,							/* U+000863 */
+	0,							/* U+000864 */
+	0,							/* U+000865 */
+	0,							/* U+000866 */
+	0,							/* U+000867 */
+	0,							/* U+000868 */
+	0,							/* U+000869 */
+	0,							/* U+00086A */
+	0,							/* U+00086B */
+	0,							/* U+00086C */
+	0,							/* U+00086D */
+	0,							/* U+00086E */
+	0,							/* U+00086F */
+	0,							/* U+000870 */
+	0,							/* U+000871 */
+	0,							/* U+000872 */
+	0,							/* U+000873 */
+	0,							/* U+000874 */
+	0,							/* U+000875 */
+	0,							/* U+000876 */
+	0,							/* U+000877 */
+	0,							/* U+000878 */
+	0,							/* U+000879 */
+	0,							/* U+00087A */
+	0,							/* U+00087B */
+	0,							/* U+00087C */
+	0,							/* U+00087D */
+	0,							/* U+00087E */
+	0,							/* U+00087F */
+	0,							/* U+000880 */
+	0,							/* U+000881 */
+	0,							/* U+000882 */
+	0,							/* U+000883 */
+	0,							/* U+000884 */
+	0,							/* U+000885 */
+	0,							/* U+000886 */
+	0,							/* U+000887 */
+	0,							/* U+000888 */
+	0,							/* U+000889 */
+	0,							/* U+00088A */
+	0,							/* U+00088B */
+	0,							/* U+00088C */
+	0,							/* U+00088D */
+	0,							/* U+00088E */
+	0,							/* U+00088F */
+	0,							/* U+000890 */
+	0,							/* U+000891 */
+	0,							/* U+000892 */
+	0,							/* U+000893 */
+	0,							/* U+000894 */
+	0,							/* U+000895 */
+	0,							/* U+000896 */
+	304,						/* U+000897 */
+	304,						/* U+000898 */
+	306,						/* U+000899 */
+	306,						/* U+00089A */
+	306,						/* U+00089B */
+	304,						/* U+00089C */
+	304,						/* U+00089D */
+	304,						/* U+00089E */
+	304,						/* U+00089F */
+	0,							/* U+0008A0 */
+	0,							/* U+0008A1 */
+	0,							/* U+0008A2 */
+	0,							/* U+0008A3 */
+	0,							/* U+0008A4 */
+	0,							/* U+0008A5 */
+	0,							/* U+0008A6 */
+	0,							/* U+0008A7 */
+	0,							/* U+0008A8 */
+	0,							/* U+0008A9 */
+	0,							/* U+0008AA */
+	0,							/* U+0008AB */
+	0,							/* U+0008AC */
+	0,							/* U+0008AD */
+	0,							/* U+0008AE */
+	0,							/* U+0008AF */
+	0,							/* U+0008B0 */
+	0,							/* U+0008B1 */
+	0,							/* U+0008B2 */
+	0,							/* U+0008B3 */
+	0,							/* U+0008B4 */
+	0,							/* U+0008B5 */
+	0,							/* U+0008B6 */
+	0,							/* U+0008B7 */
+	0,							/* U+0008B8 */
+	0,							/* U+0008B9 */
+	0,							/* U+0008BA */
+	0,							/* U+0008BB */
+	0,							/* U+0008BC */
+	0,							/* U+0008BD */
+	0,							/* U+0008BE */
+	0,							/* U+0008BF */
+	0,							/* U+0008C0 */
+	0,							/* U+0008C1 */
+	0,							/* U+0008C2 */
+	0,							/* U+0008C3 */
+	0,							/* U+0008C4 */
+	0,							/* U+0008C5 */
+	0,							/* U+0008C6 */
+	0,							/* U+0008C7 */
+	0,							/* U+0008C8 */
+	0,							/* U+0008C9 */
+	304,						/* U+0008CA */
+	304,						/* U+0008CB */
+	304,						/* U+0008CC */
+	304,						/* U+0008CD */
+	304,						/* U+0008CE */
+	306,						/* U+0008CF */
+	306,						/* U+0008D0 */
+	306,						/* U+0008D1 */
+	306,						/* U+0008D2 */
+	306,						/* U+0008D3 */
+	304,						/* U+0008D4 */
+	304,						/* U+0008D5 */
+	304,						/* U+0008D6 */
+	304,						/* U+0008D7 */
+	304,						/* U+0008D8 */
+	304,						/* U+0008D9 */
+	304,						/* U+0008DA */
+	304,						/* U+0008DB */
+	304,						/* U+0008DC */
+	304,						/* U+0008DD */
+	304,						/* U+0008DE */
+	304,						/* U+0008DF */
+	304,						/* U+0008E0 */
+	304,						/* U+0008E1 */
+	0,							/* U+0008E2 */
+	306,						/* U+0008E3 */
+	304,						/* U+0008E4 */
+	304,						/* U+0008E5 */
+	306,						/* U+0008E6 */
+	304,						/* U+0008E7 */
+	304,						/* U+0008E8 */
+	306,						/* U+0008E9 */
+	304,						/* U+0008EA */
+	304,						/* U+0008EB */
+	304,						/* U+0008EC */
+	306,						/* U+0008ED */
+	306,						/* U+0008EE */
+	306,						/* U+0008EF */
+	434,						/* U+0008F0 */
+	435,						/* U+0008F1 */
+	436,						/* U+0008F2 */
+	304,						/* U+0008F3 */
+	304,						/* U+0008F4 */
+	304,						/* U+0008F5 */
+	306,						/* U+0008F6 */
+	304,						/* U+0008F7 */
+	304,						/* U+0008F8 */
+	306,						/* U+0008F9 */
+	306,						/* U+0008FA */
+	304,						/* U+0008FB */
+	304,						/* U+0008FC */
+	304,						/* U+0008FD */
+	304,						/* U+0008FE */
+	304,						/* U+0008FF */
+	0,							/* U+000900 */
+	0,							/* U+000901 */
+	0,							/* U+000902 */
+	0,							/* U+000903 */
+	0,							/* U+000904 */
+	0,							/* U+000905 */
+	0,							/* U+000906 */
+	0,							/* U+000907 */
+	0,							/* U+000908 */
+	0,							/* U+000909 */
+	0,							/* U+00090A */
+	0,							/* U+00090B */
+	0,							/* U+00090C */
+	0,							/* U+00090D */
+	0,							/* U+00090E */
+	0,							/* U+00090F */
+	0,							/* U+000910 */
+	0,							/* U+000911 */
+	0,							/* U+000912 */
+	0,							/* U+000913 */
+	0,							/* U+000914 */
+	0,							/* U+000915 */
+	0,							/* U+000916 */
+	0,							/* U+000917 */
+	0,							/* U+000918 */
+	0,							/* U+000919 */
+	0,							/* U+00091A */
+	0,							/* U+00091B */
+	0,							/* U+00091C */
+	0,							/* U+00091D */
+	0,							/* U+00091E */
+	0,							/* U+00091F */
+	0,							/* U+000920 */
+	0,							/* U+000921 */
+	0,							/* U+000922 */
+	0,							/* U+000923 */
+	0,							/* U+000924 */
+	0,							/* U+000925 */
+	0,							/* U+000926 */
+	0,							/* U+000927 */
+	0,							/* U+000928 */
+	448,						/* U+000929 */
+	0,							/* U+00092A */
+	0,							/* U+00092B */
+	0,							/* U+00092C */
+	0,							/* U+00092D */
+	0,							/* U+00092E */
+	0,							/* U+00092F */
+	0,							/* U+000930 */
+	449,						/* U+000931 */
+	0,							/* U+000932 */
+	0,							/* U+000933 */
+	450,						/* U+000934 */
+	0,							/* U+000935 */
+	0,							/* U+000936 */
+	0,							/* U+000937 */
+	0,							/* U+000938 */
+	0,							/* U+000939 */
+	0,							/* U+00093A */
+	0,							/* U+00093B */
+	451,						/* U+00093C */
+	0,							/* U+00093D */
+	0,							/* U+00093E */
+	0,							/* U+00093F */
+	0,							/* U+000940 */
+	0,							/* U+000941 */
+	0,							/* U+000942 */
+	0,							/* U+000943 */
+	0,							/* U+000944 */
+	0,							/* U+000945 */
+	0,							/* U+000946 */
+	0,							/* U+000947 */
+	0,							/* U+000948 */
+	0,							/* U+000949 */
+	0,							/* U+00094A */
+	0,							/* U+00094B */
+	0,							/* U+00094C */
+	452,						/* U+00094D */
+	0,							/* U+00094E */
+	0,							/* U+00094F */
+	0,							/* U+000950 */
+	304,						/* U+000951 */
+	306,						/* U+000952 */
+	304,						/* U+000953 */
+	304,						/* U+000954 */
+	0,							/* U+000955 */
+	0,							/* U+000956 */
+	0,							/* U+000957 */
+	453,						/* U+000958 */
+	454,						/* U+000959 */
+	455,						/* U+00095A */
+	456,						/* U+00095B */
+	457,						/* U+00095C */
+	458,						/* U+00095D */
+	459,						/* U+00095E */
+	460,						/* U+00095F */
+	0,							/* U+000960 */
+	0,							/* U+000961 */
+	0,							/* U+000962 */
+	0,							/* U+000963 */
+	0,							/* U+000964 */
+	0,							/* U+000965 */
+	0,							/* U+000966 */
+	0,							/* U+000967 */
+	0,							/* U+000968 */
+	0,							/* U+000969 */
+	0,							/* U+00096A */
+	0,							/* U+00096B */
+	0,							/* U+00096C */
+	0,							/* U+00096D */
+	0,							/* U+00096E */
+	0,							/* U+00096F */
+	0,							/* U+000970 */
+	0,							/* U+000971 */
+	0,							/* U+000972 */
+	0,							/* U+000973 */
+	0,							/* U+000974 */
+	0,							/* U+000975 */
+	0,							/* U+000976 */
+	0,							/* U+000977 */
+	0,							/* U+000978 */
+	0,							/* U+000979 */
+	0,							/* U+00097A */
+	0,							/* U+00097B */
+	0,							/* U+00097C */
+	0,							/* U+00097D */
+	0,							/* U+00097E */
+	0,							/* U+00097F */
+	0,							/* U+000980 */
+	0,							/* U+000981 */
+	0,							/* U+000982 */
+	0,							/* U+000983 */
+	0,							/* U+000984 */
+	0,							/* U+000985 */
+	0,							/* U+000986 */
+	0,							/* U+000987 */
+	0,							/* U+000988 */
+	0,							/* U+000989 */
+	0,							/* U+00098A */
+	0,							/* U+00098B */
+	0,							/* U+00098C */
+	0,							/* U+00098D */
+	0,							/* U+00098E */
+	0,							/* U+00098F */
+	0,							/* U+000990 */
+	0,							/* U+000991 */
+	0,							/* U+000992 */
+	0,							/* U+000993 */
+	0,							/* U+000994 */
+	0,							/* U+000995 */
+	0,							/* U+000996 */
+	0,							/* U+000997 */
+	0,							/* U+000998 */
+	0,							/* U+000999 */
+	0,							/* U+00099A */
+	0,							/* U+00099B */
+	0,							/* U+00099C */
+	0,							/* U+00099D */
+	0,							/* U+00099E */
+	0,							/* U+00099F */
+	0,							/* U+0009A0 */
+	0,							/* U+0009A1 */
+	0,							/* U+0009A2 */
+	0,							/* U+0009A3 */
+	0,							/* U+0009A4 */
+	0,							/* U+0009A5 */
+	0,							/* U+0009A6 */
+	0,							/* U+0009A7 */
+	0,							/* U+0009A8 */
+	0,							/* U+0009A9 */
+	0,							/* U+0009AA */
+	0,							/* U+0009AB */
+	0,							/* U+0009AC */
+	0,							/* U+0009AD */
+	0,							/* U+0009AE */
+	0,							/* U+0009AF */
+	0,							/* U+0009B0 */
+	0,							/* U+0009B1 */
+	0,							/* U+0009B2 */
+	0,							/* U+0009B3 */
+	0,							/* U+0009B4 */
+	0,							/* U+0009B5 */
+	0,							/* U+0009B6 */
+	0,							/* U+0009B7 */
+	0,							/* U+0009B8 */
+	0,							/* U+0009B9 */
+	0,							/* U+0009BA */
+	0,							/* U+0009BB */
+	451,						/* U+0009BC */
+	0,							/* U+0009BD */
+	0,							/* U+0009BE */
+	0,							/* U+0009BF */
+	0,							/* U+0009C0 */
+	0,							/* U+0009C1 */
+	0,							/* U+0009C2 */
+	0,							/* U+0009C3 */
+	0,							/* U+0009C4 */
+	0,							/* U+0009C5 */
+	0,							/* U+0009C6 */
+	0,							/* U+0009C7 */
+	0,							/* U+0009C8 */
+	0,							/* U+0009C9 */
+	0,							/* U+0009CA */
+	461,						/* U+0009CB */
+	462,						/* U+0009CC */
+	452,						/* U+0009CD */
+	0,							/* U+0009CE */
+	0,							/* U+0009CF */
+	0,							/* U+0009D0 */
+	0,							/* U+0009D1 */
+	0,							/* U+0009D2 */
+	0,							/* U+0009D3 */
+	0,							/* U+0009D4 */
+	0,							/* U+0009D5 */
+	0,							/* U+0009D6 */
+	0,							/* U+0009D7 */
+	0,							/* U+0009D8 */
+	0,							/* U+0009D9 */
+	0,							/* U+0009DA */
+	0,							/* U+0009DB */
+	463,						/* U+0009DC */
+	464,						/* U+0009DD */
+	0,							/* U+0009DE */
+	465,						/* U+0009DF */
+	0,							/* U+0009E0 */
+	0,							/* U+0009E1 */
+	0,							/* U+0009E2 */
+	0,							/* U+0009E3 */
+	0,							/* U+0009E4 */
+	0,							/* U+0009E5 */
+	0,							/* U+0009E6 */
+	0,							/* U+0009E7 */
+	0,							/* U+0009E8 */
+	0,							/* U+0009E9 */
+	0,							/* U+0009EA */
+	0,							/* U+0009EB */
+	0,							/* U+0009EC */
+	0,							/* U+0009ED */
+	0,							/* U+0009EE */
+	0,							/* U+0009EF */
+	0,							/* U+0009F0 */
+	0,							/* U+0009F1 */
+	0,							/* U+0009F2 */
+	0,							/* U+0009F3 */
+	0,							/* U+0009F4 */
+	0,							/* U+0009F5 */
+	0,							/* U+0009F6 */
+	0,							/* U+0009F7 */
+	0,							/* U+0009F8 */
+	0,							/* U+0009F9 */
+	0,							/* U+0009FA */
+	0,							/* U+0009FB */
+	0,							/* U+0009FC */
+	0,							/* U+0009FD */
+	304,						/* U+0009FE */
+	0,							/* U+0009FF */
+	0,							/* U+000A00 */
+	0,							/* U+000A01 */
+	0,							/* U+000A02 */
+	0,							/* U+000A03 */
+	0,							/* U+000A04 */
+	0,							/* U+000A05 */
+	0,							/* U+000A06 */
+	0,							/* U+000A07 */
+	0,							/* U+000A08 */
+	0,							/* U+000A09 */
+	0,							/* U+000A0A */
+	0,							/* U+000A0B */
+	0,							/* U+000A0C */
+	0,							/* U+000A0D */
+	0,							/* U+000A0E */
+	0,							/* U+000A0F */
+	0,							/* U+000A10 */
+	0,							/* U+000A11 */
+	0,							/* U+000A12 */
+	0,							/* U+000A13 */
+	0,							/* U+000A14 */
+	0,							/* U+000A15 */
+	0,							/* U+000A16 */
+	0,							/* U+000A17 */
+	0,							/* U+000A18 */
+	0,							/* U+000A19 */
+	0,							/* U+000A1A */
+	0,							/* U+000A1B */
+	0,							/* U+000A1C */
+	0,							/* U+000A1D */
+	0,							/* U+000A1E */
+	0,							/* U+000A1F */
+	0,							/* U+000A20 */
+	0,							/* U+000A21 */
+	0,							/* U+000A22 */
+	0,							/* U+000A23 */
+	0,							/* U+000A24 */
+	0,							/* U+000A25 */
+	0,							/* U+000A26 */
+	0,							/* U+000A27 */
+	0,							/* U+000A28 */
+	0,							/* U+000A29 */
+	0,							/* U+000A2A */
+	0,							/* U+000A2B */
+	0,							/* U+000A2C */
+	0,							/* U+000A2D */
+	0,							/* U+000A2E */
+	0,							/* U+000A2F */
+	0,							/* U+000A30 */
+	0,							/* U+000A31 */
+	0,							/* U+000A32 */
+	466,						/* U+000A33 */
+	0,							/* U+000A34 */
+	0,							/* U+000A35 */
+	467,						/* U+000A36 */
+	0,							/* U+000A37 */
+	0,							/* U+000A38 */
+	0,							/* U+000A39 */
+	0,							/* U+000A3A */
+	0,							/* U+000A3B */
+	451,						/* U+000A3C */
+	0,							/* U+000A3D */
+	0,							/* U+000A3E */
+	0,							/* U+000A3F */
+	0,							/* U+000A40 */
+	0,							/* U+000A41 */
+	0,							/* U+000A42 */
+	0,							/* U+000A43 */
+	0,							/* U+000A44 */
+	0,							/* U+000A45 */
+	0,							/* U+000A46 */
+	0,							/* U+000A47 */
+	0,							/* U+000A48 */
+	0,							/* U+000A49 */
+	0,							/* U+000A4A */
+	0,							/* U+000A4B */
+	0,							/* U+000A4C */
+	452,						/* U+000A4D */
+	0,							/* U+000A4E */
+	0,							/* U+000A4F */
+	0,							/* U+000A50 */
+	0,							/* U+000A51 */
+	0,							/* U+000A52 */
+	0,							/* U+000A53 */
+	0,							/* U+000A54 */
+	0,							/* U+000A55 */
+	0,							/* U+000A56 */
+	0,							/* U+000A57 */
+	0,							/* U+000A58 */
+	468,						/* U+000A59 */
+	469,						/* U+000A5A */
+	470,						/* U+000A5B */
+	0,							/* U+000A5C */
+	0,							/* U+000A5D */
+	471,						/* U+000A5E */
+	0,							/* U+000A5F */
+	0,							/* U+000A60 */
+	0,							/* U+000A61 */
+	0,							/* U+000A62 */
+	0,							/* U+000A63 */
+	0,							/* U+000A64 */
+	0,							/* U+000A65 */
+	0,							/* U+000A66 */
+	0,							/* U+000A67 */
+	0,							/* U+000A68 */
+	0,							/* U+000A69 */
+	0,							/* U+000A6A */
+	0,							/* U+000A6B */
+	0,							/* U+000A6C */
+	0,							/* U+000A6D */
+	0,							/* U+000A6E */
+	0,							/* U+000A6F */
+	0,							/* U+000A70 */
+	0,							/* U+000A71 */
+	0,							/* U+000A72 */
+	0,							/* U+000A73 */
+	0,							/* U+000A74 */
+	0,							/* U+000A75 */
+	0,							/* U+000A76 */
+	0,							/* U+000A77 */
+	0,							/* U+000A78 */
+	0,							/* U+000A79 */
+	0,							/* U+000A7A */
+	0,							/* U+000A7B */
+	0,							/* U+000A7C */
+	0,							/* U+000A7D */
+	0,							/* U+000A7E */
+	0,							/* U+000A7F */
+	0,							/* U+000A80 */
+	0,							/* U+000A81 */
+	0,							/* U+000A82 */
+	0,							/* U+000A83 */
+	0,							/* U+000A84 */
+	0,							/* U+000A85 */
+	0,							/* U+000A86 */
+	0,							/* U+000A87 */
+	0,							/* U+000A88 */
+	0,							/* U+000A89 */
+	0,							/* U+000A8A */
+	0,							/* U+000A8B */
+	0,							/* U+000A8C */
+	0,							/* U+000A8D */
+	0,							/* U+000A8E */
+	0,							/* U+000A8F */
+	0,							/* U+000A90 */
+	0,							/* U+000A91 */
+	0,							/* U+000A92 */
+	0,							/* U+000A93 */
+	0,							/* U+000A94 */
+	0,							/* U+000A95 */
+	0,							/* U+000A96 */
+	0,							/* U+000A97 */
+	0,							/* U+000A98 */
+	0,							/* U+000A99 */
+	0,							/* U+000A9A */
+	0,							/* U+000A9B */
+	0,							/* U+000A9C */
+	0,							/* U+000A9D */
+	0,							/* U+000A9E */
+	0,							/* U+000A9F */
+	0,							/* U+000AA0 */
+	0,							/* U+000AA1 */
+	0,							/* U+000AA2 */
+	0,							/* U+000AA3 */
+	0,							/* U+000AA4 */
+	0,							/* U+000AA5 */
+	0,							/* U+000AA6 */
+	0,							/* U+000AA7 */
+	0,							/* U+000AA8 */
+	0,							/* U+000AA9 */
+	0,							/* U+000AAA */
+	0,							/* U+000AAB */
+	0,							/* U+000AAC */
+	0,							/* U+000AAD */
+	0,							/* U+000AAE */
+	0,							/* U+000AAF */
+	0,							/* U+000AB0 */
+	0,							/* U+000AB1 */
+	0,							/* U+000AB2 */
+	0,							/* U+000AB3 */
+	0,							/* U+000AB4 */
+	0,							/* U+000AB5 */
+	0,							/* U+000AB6 */
+	0,							/* U+000AB7 */
+	0,							/* U+000AB8 */
+	0,							/* U+000AB9 */
+	0,							/* U+000ABA */
+	0,							/* U+000ABB */
+	451,						/* U+000ABC */
+	0,							/* U+000ABD */
+	0,							/* U+000ABE */
+	0,							/* U+000ABF */
+	0,							/* U+000AC0 */
+	0,							/* U+000AC1 */
+	0,							/* U+000AC2 */
+	0,							/* U+000AC3 */
+	0,							/* U+000AC4 */
+	0,							/* U+000AC5 */
+	0,							/* U+000AC6 */
+	0,							/* U+000AC7 */
+	0,							/* U+000AC8 */
+	0,							/* U+000AC9 */
+	0,							/* U+000ACA */
+	0,							/* U+000ACB */
+	0,							/* U+000ACC */
+	452,						/* U+000ACD */
+	0,							/* U+000ACE */
+	0,							/* U+000ACF */
+	0,							/* U+000AD0 */
+	0,							/* U+000AD1 */
+	0,							/* U+000AD2 */
+	0,							/* U+000AD3 */
+	0,							/* U+000AD4 */
+	0,							/* U+000AD5 */
+	0,							/* U+000AD6 */
+	0,							/* U+000AD7 */
+	0,							/* U+000AD8 */
+	0,							/* U+000AD9 */
+	0,							/* U+000ADA */
+	0,							/* U+000ADB */
+	0,							/* U+000ADC */
+	0,							/* U+000ADD */
+	0,							/* U+000ADE */
+	0,							/* U+000ADF */
+	0,							/* U+000AE0 */
+	0,							/* U+000AE1 */
+	0,							/* U+000AE2 */
+	0,							/* U+000AE3 */
+	0,							/* U+000AE4 */
+	0,							/* U+000AE5 */
+	0,							/* U+000AE6 */
+	0,							/* U+000AE7 */
+	0,							/* U+000AE8 */
+	0,							/* U+000AE9 */
+	0,							/* U+000AEA */
+	0,							/* U+000AEB */
+	0,							/* U+000AEC */
+	0,							/* U+000AED */
+	0,							/* U+000AEE */
+	0,							/* U+000AEF */
+	0,							/* U+000AF0 */
+	0,							/* U+000AF1 */
+	0,							/* U+000AF2 */
+	0,							/* U+000AF3 */
+	0,							/* U+000AF4 */
+	0,							/* U+000AF5 */
+	0,							/* U+000AF6 */
+	0,							/* U+000AF7 */
+	0,							/* U+000AF8 */
+	0,							/* U+000AF9 */
+	0,							/* U+000AFA */
+	0,							/* U+000AFB */
+	0,							/* U+000AFC */
+	0,							/* U+000AFD */
+	0,							/* U+000AFE */
+	0,							/* U+000AFF */
+	0,							/* U+000B00 */
+	0,							/* U+000B01 */
+	0,							/* U+000B02 */
+	0,							/* U+000B03 */
+	0,							/* U+000B04 */
+	0,							/* U+000B05 */
+	0,							/* U+000B06 */
+	0,							/* U+000B07 */
+	0,							/* U+000B08 */
+	0,							/* U+000B09 */
+	0,							/* U+000B0A */
+	0,							/* U+000B0B */
+	0,							/* U+000B0C */
+	0,							/* U+000B0D */
+	0,							/* U+000B0E */
+	0,							/* U+000B0F */
+	0,							/* U+000B10 */
+	0,							/* U+000B11 */
+	0,							/* U+000B12 */
+	0,							/* U+000B13 */
+	0,							/* U+000B14 */
+	0,							/* U+000B15 */
+	0,							/* U+000B16 */
+	0,							/* U+000B17 */
+	0,							/* U+000B18 */
+	0,							/* U+000B19 */
+	0,							/* U+000B1A */
+	0,							/* U+000B1B */
+	0,							/* U+000B1C */
+	0,							/* U+000B1D */
+	0,							/* U+000B1E */
+	0,							/* U+000B1F */
+	0,							/* U+000B20 */
+	0,							/* U+000B21 */
+	0,							/* U+000B22 */
+	0,							/* U+000B23 */
+	0,							/* U+000B24 */
+	0,							/* U+000B25 */
+	0,							/* U+000B26 */
+	0,							/* U+000B27 */
+	0,							/* U+000B28 */
+	0,							/* U+000B29 */
+	0,							/* U+000B2A */
+	0,							/* U+000B2B */
+	0,							/* U+000B2C */
+	0,							/* U+000B2D */
+	0,							/* U+000B2E */
+	0,							/* U+000B2F */
+	0,							/* U+000B30 */
+	0,							/* U+000B31 */
+	0,							/* U+000B32 */
+	0,							/* U+000B33 */
+	0,							/* U+000B34 */
+	0,							/* U+000B35 */
+	0,							/* U+000B36 */
+	0,							/* U+000B37 */
+	0,							/* U+000B38 */
+	0,							/* U+000B39 */
+	0,							/* U+000B3A */
+	0,							/* U+000B3B */
+	451,						/* U+000B3C */
+	0,							/* U+000B3D */
+	0,							/* U+000B3E */
+	0,							/* U+000B3F */
+	0,							/* U+000B40 */
+	0,							/* U+000B41 */
+	0,							/* U+000B42 */
+	0,							/* U+000B43 */
+	0,							/* U+000B44 */
+	0,							/* U+000B45 */
+	0,							/* U+000B46 */
+	0,							/* U+000B47 */
+	472,						/* U+000B48 */
+	0,							/* U+000B49 */
+	0,							/* U+000B4A */
+	473,						/* U+000B4B */
+	474,						/* U+000B4C */
+	452,						/* U+000B4D */
+	0,							/* U+000B4E */
+	0,							/* U+000B4F */
+	0,							/* U+000B50 */
+	0,							/* U+000B51 */
+	0,							/* U+000B52 */
+	0,							/* U+000B53 */
+	0,							/* U+000B54 */
+	0,							/* U+000B55 */
+	0,							/* U+000B56 */
+	0,							/* U+000B57 */
+	0,							/* U+000B58 */
+	0,							/* U+000B59 */
+	0,							/* U+000B5A */
+	0,							/* U+000B5B */
+	475,						/* U+000B5C */
+	476,						/* U+000B5D */
+	0,							/* U+000B5E */
+	0,							/* U+000B5F */
+	0,							/* U+000B60 */
+	0,							/* U+000B61 */
+	0,							/* U+000B62 */
+	0,							/* U+000B63 */
+	0,							/* U+000B64 */
+	0,							/* U+000B65 */
+	0,							/* U+000B66 */
+	0,							/* U+000B67 */
+	0,							/* U+000B68 */
+	0,							/* U+000B69 */
+	0,							/* U+000B6A */
+	0,							/* U+000B6B */
+	0,							/* U+000B6C */
+	0,							/* U+000B6D */
+	0,							/* U+000B6E */
+	0,							/* U+000B6F */
+	0,							/* U+000B70 */
+	0,							/* U+000B71 */
+	0,							/* U+000B72 */
+	0,							/* U+000B73 */
+	0,							/* U+000B74 */
+	0,							/* U+000B75 */
+	0,							/* U+000B76 */
+	0,							/* U+000B77 */
+	0,							/* U+000B78 */
+	0,							/* U+000B79 */
+	0,							/* U+000B7A */
+	0,							/* U+000B7B */
+	0,							/* U+000B7C */
+	0,							/* U+000B7D */
+	0,							/* U+000B7E */
+	0,							/* U+000B7F */
+	0,							/* U+000B80 */
+	0,							/* U+000B81 */
+	0,							/* U+000B82 */
+	0,							/* U+000B83 */
+	0,							/* U+000B84 */
+	0,							/* U+000B85 */
+	0,							/* U+000B86 */
+	0,							/* U+000B87 */
+	0,							/* U+000B88 */
+	0,							/* U+000B89 */
+	0,							/* U+000B8A */
+	0,							/* U+000B8B */
+	0,							/* U+000B8C */
+	0,							/* U+000B8D */
+	0,							/* U+000B8E */
+	0,							/* U+000B8F */
+	0,							/* U+000B90 */
+	0,							/* U+000B91 */
+	0,							/* U+000B92 */
+	0,							/* U+000B93 */
+	477,						/* U+000B94 */
+	0,							/* U+000B95 */
+	0,							/* U+000B96 */
+	0,							/* U+000B97 */
+	0,							/* U+000B98 */
+	0,							/* U+000B99 */
+	0,							/* U+000B9A */
+	0,							/* U+000B9B */
+	0,							/* U+000B9C */
+	0,							/* U+000B9D */
+	0,							/* U+000B9E */
+	0,							/* U+000B9F */
+	0,							/* U+000BA0 */
+	0,							/* U+000BA1 */
+	0,							/* U+000BA2 */
+	0,							/* U+000BA3 */
+	0,							/* U+000BA4 */
+	0,							/* U+000BA5 */
+	0,							/* U+000BA6 */
+	0,							/* U+000BA7 */
+	0,							/* U+000BA8 */
+	0,							/* U+000BA9 */
+	0,							/* U+000BAA */
+	0,							/* U+000BAB */
+	0,							/* U+000BAC */
+	0,							/* U+000BAD */
+	0,							/* U+000BAE */
+	0,							/* U+000BAF */
+	0,							/* U+000BB0 */
+	0,							/* U+000BB1 */
+	0,							/* U+000BB2 */
+	0,							/* U+000BB3 */
+	0,							/* U+000BB4 */
+	0,							/* U+000BB5 */
+	0,							/* U+000BB6 */
+	0,							/* U+000BB7 */
+	0,							/* U+000BB8 */
+	0,							/* U+000BB9 */
+	0,							/* U+000BBA */
+	0,							/* U+000BBB */
+	0,							/* U+000BBC */
+	0,							/* U+000BBD */
+	0,							/* U+000BBE */
+	0,							/* U+000BBF */
+	0,							/* U+000BC0 */
+	0,							/* U+000BC1 */
+	0,							/* U+000BC2 */
+	0,							/* U+000BC3 */
+	0,							/* U+000BC4 */
+	0,							/* U+000BC5 */
+	0,							/* U+000BC6 */
+	0,							/* U+000BC7 */
+	0,							/* U+000BC8 */
+	0,							/* U+000BC9 */
+	478,						/* U+000BCA */
+	479,						/* U+000BCB */
+	480,						/* U+000BCC */
+	452,						/* U+000BCD */
+	0,							/* U+000BCE */
+	0,							/* U+000BCF */
+	0,							/* U+000BD0 */
+	0,							/* U+000BD1 */
+	0,							/* U+000BD2 */
+	0,							/* U+000BD3 */
+	0,							/* U+000BD4 */
+	0,							/* U+000BD5 */
+	0,							/* U+000BD6 */
+	0,							/* U+000BD7 */
+	0,							/* U+000BD8 */
+	0,							/* U+000BD9 */
+	0,							/* U+000BDA */
+	0,							/* U+000BDB */
+	0,							/* U+000BDC */
+	0,							/* U+000BDD */
+	0,							/* U+000BDE */
+	0,							/* U+000BDF */
+	0,							/* U+000BE0 */
+	0,							/* U+000BE1 */
+	0,							/* U+000BE2 */
+	0,							/* U+000BE3 */
+	0,							/* U+000BE4 */
+	0,							/* U+000BE5 */
+	0,							/* U+000BE6 */
+	0,							/* U+000BE7 */
+	0,							/* U+000BE8 */
+	0,							/* U+000BE9 */
+	0,							/* U+000BEA */
+	0,							/* U+000BEB */
+	0,							/* U+000BEC */
+	0,							/* U+000BED */
+	0,							/* U+000BEE */
+	0,							/* U+000BEF */
+	0,							/* U+000BF0 */
+	0,							/* U+000BF1 */
+	0,							/* U+000BF2 */
+	0,							/* U+000BF3 */
+	0,							/* U+000BF4 */
+	0,							/* U+000BF5 */
+	0,							/* U+000BF6 */
+	0,							/* U+000BF7 */
+	0,							/* U+000BF8 */
+	0,							/* U+000BF9 */
+	0,							/* U+000BFA */
+	0,							/* U+000BFB */
+	0,							/* U+000BFC */
+	0,							/* U+000BFD */
+	0,							/* U+000BFE */
+	0,							/* U+000BFF */
+	0,							/* U+000C00 */
+	0,							/* U+000C01 */
+	0,							/* U+000C02 */
+	0,							/* U+000C03 */
+	0,							/* U+000C04 */
+	0,							/* U+000C05 */
+	0,							/* U+000C06 */
+	0,							/* U+000C07 */
+	0,							/* U+000C08 */
+	0,							/* U+000C09 */
+	0,							/* U+000C0A */
+	0,							/* U+000C0B */
+	0,							/* U+000C0C */
+	0,							/* U+000C0D */
+	0,							/* U+000C0E */
+	0,							/* U+000C0F */
+	0,							/* U+000C10 */
+	0,							/* U+000C11 */
+	0,							/* U+000C12 */
+	0,							/* U+000C13 */
+	0,							/* U+000C14 */
+	0,							/* U+000C15 */
+	0,							/* U+000C16 */
+	0,							/* U+000C17 */
+	0,							/* U+000C18 */
+	0,							/* U+000C19 */
+	0,							/* U+000C1A */
+	0,							/* U+000C1B */
+	0,							/* U+000C1C */
+	0,							/* U+000C1D */
+	0,							/* U+000C1E */
+	0,							/* U+000C1F */
+	0,							/* U+000C20 */
+	0,							/* U+000C21 */
+	0,							/* U+000C22 */
+	0,							/* U+000C23 */
+	0,							/* U+000C24 */
+	0,							/* U+000C25 */
+	0,							/* U+000C26 */
+	0,							/* U+000C27 */
+	0,							/* U+000C28 */
+	0,							/* U+000C29 */
+	0,							/* U+000C2A */
+	0,							/* U+000C2B */
+	0,							/* U+000C2C */
+	0,							/* U+000C2D */
+	0,							/* U+000C2E */
+	0,							/* U+000C2F */
+	0,							/* U+000C30 */
+	0,							/* U+000C31 */
+	0,							/* U+000C32 */
+	0,							/* U+000C33 */
+	0,							/* U+000C34 */
+	0,							/* U+000C35 */
+	0,							/* U+000C36 */
+	0,							/* U+000C37 */
+	0,							/* U+000C38 */
+	0,							/* U+000C39 */
+	0,							/* U+000C3A */
+	0,							/* U+000C3B */
+	451,						/* U+000C3C */
+	0,							/* U+000C3D */
+	0,							/* U+000C3E */
+	0,							/* U+000C3F */
+	0,							/* U+000C40 */
+	0,							/* U+000C41 */
+	0,							/* U+000C42 */
+	0,							/* U+000C43 */
+	0,							/* U+000C44 */
+	0,							/* U+000C45 */
+	0,							/* U+000C46 */
+	0,							/* U+000C47 */
+	481,						/* U+000C48 */
+	0,							/* U+000C49 */
+	0,							/* U+000C4A */
+	0,							/* U+000C4B */
+	0,							/* U+000C4C */
+	452,						/* U+000C4D */
+	0,							/* U+000C4E */
+	0,							/* U+000C4F */
+	0,							/* U+000C50 */
+	0,							/* U+000C51 */
+	0,							/* U+000C52 */
+	0,							/* U+000C53 */
+	0,							/* U+000C54 */
+	482,						/* U+000C55 */
+	483,						/* U+000C56 */
+	0,							/* U+000C57 */
+	0,							/* U+000C58 */
+	0,							/* U+000C59 */
+	0,							/* U+000C5A */
+	0,							/* U+000C5B */
+	0,							/* U+000C5C */
+	0,							/* U+000C5D */
+	0,							/* U+000C5E */
+	0,							/* U+000C5F */
+	0,							/* U+000C60 */
+	0,							/* U+000C61 */
+	0,							/* U+000C62 */
+	0,							/* U+000C63 */
+	0,							/* U+000C64 */
+	0,							/* U+000C65 */
+	0,							/* U+000C66 */
+	0,							/* U+000C67 */
+	0,							/* U+000C68 */
+	0,							/* U+000C69 */
+	0,							/* U+000C6A */
+	0,							/* U+000C6B */
+	0,							/* U+000C6C */
+	0,							/* U+000C6D */
+	0,							/* U+000C6E */
+	0,							/* U+000C6F */
+	0,							/* U+000C70 */
+	0,							/* U+000C71 */
+	0,							/* U+000C72 */
+	0,							/* U+000C73 */
+	0,							/* U+000C74 */
+	0,							/* U+000C75 */
+	0,							/* U+000C76 */
+	0,							/* U+000C77 */
+	0,							/* U+000C78 */
+	0,							/* U+000C79 */
+	0,							/* U+000C7A */
+	0,							/* U+000C7B */
+	0,							/* U+000C7C */
+	0,							/* U+000C7D */
+	0,							/* U+000C7E */
+	0,							/* U+000C7F */
+	0,							/* U+000C80 */
+	0,							/* U+000C81 */
+	0,							/* U+000C82 */
+	0,							/* U+000C83 */
+	0,							/* U+000C84 */
+	0,							/* U+000C85 */
+	0,							/* U+000C86 */
+	0,							/* U+000C87 */
+	0,							/* U+000C88 */
+	0,							/* U+000C89 */
+	0,							/* U+000C8A */
+	0,							/* U+000C8B */
+	0,							/* U+000C8C */
+	0,							/* U+000C8D */
+	0,							/* U+000C8E */
+	0,							/* U+000C8F */
+	0,							/* U+000C90 */
+	0,							/* U+000C91 */
+	0,							/* U+000C92 */
+	0,							/* U+000C93 */
+	0,							/* U+000C94 */
+	0,							/* U+000C95 */
+	0,							/* U+000C96 */
+	0,							/* U+000C97 */
+	0,							/* U+000C98 */
+	0,							/* U+000C99 */
+	0,							/* U+000C9A */
+	0,							/* U+000C9B */
+	0,							/* U+000C9C */
+	0,							/* U+000C9D */
+	0,							/* U+000C9E */
+	0,							/* U+000C9F */
+	0,							/* U+000CA0 */
+	0,							/* U+000CA1 */
+	0,							/* U+000CA2 */
+	0,							/* U+000CA3 */
+	0,							/* U+000CA4 */
+	0,							/* U+000CA5 */
+	0,							/* U+000CA6 */
+	0,							/* U+000CA7 */
+	0,							/* U+000CA8 */
+	0,							/* U+000CA9 */
+	0,							/* U+000CAA */
+	0,							/* U+000CAB */
+	0,							/* U+000CAC */
+	0,							/* U+000CAD */
+	0,							/* U+000CAE */
+	0,							/* U+000CAF */
+	0,							/* U+000CB0 */
+	0,							/* U+000CB1 */
+	0,							/* U+000CB2 */
+	0,							/* U+000CB3 */
+	0,							/* U+000CB4 */
+	0,							/* U+000CB5 */
+	0,							/* U+000CB6 */
+	0,							/* U+000CB7 */
+	0,							/* U+000CB8 */
+	0,							/* U+000CB9 */
+	0,							/* U+000CBA */
+	0,							/* U+000CBB */
+	451,						/* U+000CBC */
+	0,							/* U+000CBD */
+	0,							/* U+000CBE */
+	0,							/* U+000CBF */
+	484,						/* U+000CC0 */
+	0,							/* U+000CC1 */
+	0,							/* U+000CC2 */
+	0,							/* U+000CC3 */
+	0,							/* U+000CC4 */
+	0,							/* U+000CC5 */
+	0,							/* U+000CC6 */
+	485,						/* U+000CC7 */
+	486,						/* U+000CC8 */
+	0,							/* U+000CC9 */
+	487,						/* U+000CCA */
+	488,						/* U+000CCB */
+	0,							/* U+000CCC */
+	452,						/* U+000CCD */
+	0,							/* U+000CCE */
+	0,							/* U+000CCF */
+	0,							/* U+000CD0 */
+	0,							/* U+000CD1 */
+	0,							/* U+000CD2 */
+	0,							/* U+000CD3 */
+	0,							/* U+000CD4 */
+	0,							/* U+000CD5 */
+	0,							/* U+000CD6 */
+	0,							/* U+000CD7 */
+	0,							/* U+000CD8 */
+	0,							/* U+000CD9 */
+	0,							/* U+000CDA */
+	0,							/* U+000CDB */
+	0,							/* U+000CDC */
+	0,							/* U+000CDD */
+	0,							/* U+000CDE */
+	0,							/* U+000CDF */
+	0,							/* U+000CE0 */
+	0,							/* U+000CE1 */
+	0,							/* U+000CE2 */
+	0,							/* U+000CE3 */
+	0,							/* U+000CE4 */
+	0,							/* U+000CE5 */
+	0,							/* U+000CE6 */
+	0,							/* U+000CE7 */
+	0,							/* U+000CE8 */
+	0,							/* U+000CE9 */
+	0,							/* U+000CEA */
+	0,							/* U+000CEB */
+	0,							/* U+000CEC */
+	0,							/* U+000CED */
+	0,							/* U+000CEE */
+	0,							/* U+000CEF */
+	0,							/* U+000CF0 */
+	0,							/* U+000CF1 */
+	0,							/* U+000CF2 */
+	0,							/* U+000CF3 */
+	0,							/* U+000CF4 */
+	0,							/* U+000CF5 */
+	0,							/* U+000CF6 */
+	0,							/* U+000CF7 */
+	0,							/* U+000CF8 */
+	0,							/* U+000CF9 */
+	0,							/* U+000CFA */
+	0,							/* U+000CFB */
+	0,							/* U+000CFC */
+	0,							/* U+000CFD */
+	0,							/* U+000CFE */
+	0,							/* U+000CFF */
+	0,							/* U+000D00 */
+	0,							/* U+000D01 */
+	0,							/* U+000D02 */
+	0,							/* U+000D03 */
+	0,							/* U+000D04 */
+	0,							/* U+000D05 */
+	0,							/* U+000D06 */
+	0,							/* U+000D07 */
+	0,							/* U+000D08 */
+	0,							/* U+000D09 */
+	0,							/* U+000D0A */
+	0,							/* U+000D0B */
+	0,							/* U+000D0C */
+	0,							/* U+000D0D */
+	0,							/* U+000D0E */
+	0,							/* U+000D0F */
+	0,							/* U+000D10 */
+	0,							/* U+000D11 */
+	0,							/* U+000D12 */
+	0,							/* U+000D13 */
+	0,							/* U+000D14 */
+	0,							/* U+000D15 */
+	0,							/* U+000D16 */
+	0,							/* U+000D17 */
+	0,							/* U+000D18 */
+	0,							/* U+000D19 */
+	0,							/* U+000D1A */
+	0,							/* U+000D1B */
+	0,							/* U+000D1C */
+	0,							/* U+000D1D */
+	0,							/* U+000D1E */
+	0,							/* U+000D1F */
+	0,							/* U+000D20 */
+	0,							/* U+000D21 */
+	0,							/* U+000D22 */
+	0,							/* U+000D23 */
+	0,							/* U+000D24 */
+	0,							/* U+000D25 */
+	0,							/* U+000D26 */
+	0,							/* U+000D27 */
+	0,							/* U+000D28 */
+	0,							/* U+000D29 */
+	0,							/* U+000D2A */
+	0,							/* U+000D2B */
+	0,							/* U+000D2C */
+	0,							/* U+000D2D */
+	0,							/* U+000D2E */
+	0,							/* U+000D2F */
+	0,							/* U+000D30 */
+	0,							/* U+000D31 */
+	0,							/* U+000D32 */
+	0,							/* U+000D33 */
+	0,							/* U+000D34 */
+	0,							/* U+000D35 */
+	0,							/* U+000D36 */
+	0,							/* U+000D37 */
+	0,							/* U+000D38 */
+	0,							/* U+000D39 */
+	0,							/* U+000D3A */
+	452,						/* U+000D3B */
+	452,						/* U+000D3C */
+	0,							/* U+000D3D */
+	0,							/* U+000D3E */
+	0,							/* U+000D3F */
+	0,							/* U+000D40 */
+	0,							/* U+000D41 */
+	0,							/* U+000D42 */
+	0,							/* U+000D43 */
+	0,							/* U+000D44 */
+	0,							/* U+000D45 */
+	0,							/* U+000D46 */
+	0,							/* U+000D47 */
+	0,							/* U+000D48 */
+	0,							/* U+000D49 */
+	489,						/* U+000D4A */
+	490,						/* U+000D4B */
+	491,						/* U+000D4C */
+	452,						/* U+000D4D */
+	0,							/* U+000D4E */
+	0,							/* U+000D4F */
+	0,							/* U+000D50 */
+	0,							/* U+000D51 */
+	0,							/* U+000D52 */
+	0,							/* U+000D53 */
+	0,							/* U+000D54 */
+	0,							/* U+000D55 */
+	0,							/* U+000D56 */
+	0,							/* U+000D57 */
+	0,							/* U+000D58 */
+	0,							/* U+000D59 */
+	0,							/* U+000D5A */
+	0,							/* U+000D5B */
+	0,							/* U+000D5C */
+	0,							/* U+000D5D */
+	0,							/* U+000D5E */
+	0,							/* U+000D5F */
+	0,							/* U+000D60 */
+	0,							/* U+000D61 */
+	0,							/* U+000D62 */
+	0,							/* U+000D63 */
+	0,							/* U+000D64 */
+	0,							/* U+000D65 */
+	0,							/* U+000D66 */
+	0,							/* U+000D67 */
+	0,							/* U+000D68 */
+	0,							/* U+000D69 */
+	0,							/* U+000D6A */
+	0,							/* U+000D6B */
+	0,							/* U+000D6C */
+	0,							/* U+000D6D */
+	0,							/* U+000D6E */
+	0,							/* U+000D6F */
+	0,							/* U+000D70 */
+	0,							/* U+000D71 */
+	0,							/* U+000D72 */
+	0,							/* U+000D73 */
+	0,							/* U+000D74 */
+	0,							/* U+000D75 */
+	0,							/* U+000D76 */
+	0,							/* U+000D77 */
+	0,							/* U+000D78 */
+	0,							/* U+000D79 */
+	0,							/* U+000D7A */
+	0,							/* U+000D7B */
+	0,							/* U+000D7C */
+	0,							/* U+000D7D */
+	0,							/* U+000D7E */
+	0,							/* U+000D7F */
+	0,							/* U+000D80 */
+	0,							/* U+000D81 */
+	0,							/* U+000D82 */
+	0,							/* U+000D83 */
+	0,							/* U+000D84 */
+	0,							/* U+000D85 */
+	0,							/* U+000D86 */
+	0,							/* U+000D87 */
+	0,							/* U+000D88 */
+	0,							/* U+000D89 */
+	0,							/* U+000D8A */
+	0,							/* U+000D8B */
+	0,							/* U+000D8C */
+	0,							/* U+000D8D */
+	0,							/* U+000D8E */
+	0,							/* U+000D8F */
+	0,							/* U+000D90 */
+	0,							/* U+000D91 */
+	0,							/* U+000D92 */
+	0,							/* U+000D93 */
+	0,							/* U+000D94 */
+	0,							/* U+000D95 */
+	0,							/* U+000D96 */
+	0,							/* U+000D97 */
+	0,							/* U+000D98 */
+	0,							/* U+000D99 */
+	0,							/* U+000D9A */
+	0,							/* U+000D9B */
+	0,							/* U+000D9C */
+	0,							/* U+000D9D */
+	0,							/* U+000D9E */
+	0,							/* U+000D9F */
+	0,							/* U+000DA0 */
+	0,							/* U+000DA1 */
+	0,							/* U+000DA2 */
+	0,							/* U+000DA3 */
+	0,							/* U+000DA4 */
+	0,							/* U+000DA5 */
+	0,							/* U+000DA6 */
+	0,							/* U+000DA7 */
+	0,							/* U+000DA8 */
+	0,							/* U+000DA9 */
+	0,							/* U+000DAA */
+	0,							/* U+000DAB */
+	0,							/* U+000DAC */
+	0,							/* U+000DAD */
+	0,							/* U+000DAE */
+	0,							/* U+000DAF */
+	0,							/* U+000DB0 */
+	0,							/* U+000DB1 */
+	0,							/* U+000DB2 */
+	0,							/* U+000DB3 */
+	0,							/* U+000DB4 */
+	0,							/* U+000DB5 */
+	0,							/* U+000DB6 */
+	0,							/* U+000DB7 */
+	0,							/* U+000DB8 */
+	0,							/* U+000DB9 */
+	0,							/* U+000DBA */
+	0,							/* U+000DBB */
+	0,							/* U+000DBC */
+	0,							/* U+000DBD */
+	0,							/* U+000DBE */
+	0,							/* U+000DBF */
+	0,							/* U+000DC0 */
+	0,							/* U+000DC1 */
+	0,							/* U+000DC2 */
+	0,							/* U+000DC3 */
+	0,							/* U+000DC4 */
+	0,							/* U+000DC5 */
+	0,							/* U+000DC6 */
+	0,							/* U+000DC7 */
+	0,							/* U+000DC8 */
+	0,							/* U+000DC9 */
+	452,						/* U+000DCA */
+	0,							/* U+000DCB */
+	0,							/* U+000DCC */
+	0,							/* U+000DCD */
+	0,							/* U+000DCE */
+	0,							/* U+000DCF */
+	0,							/* U+000DD0 */
+	0,							/* U+000DD1 */
+	0,							/* U+000DD2 */
+	0,							/* U+000DD3 */
+	0,							/* U+000DD4 */
+	0,							/* U+000DD5 */
+	0,							/* U+000DD6 */
+	0,							/* U+000DD7 */
+	0,							/* U+000DD8 */
+	0,							/* U+000DD9 */
+	492,						/* U+000DDA */
+	0,							/* U+000DDB */
+	493,						/* U+000DDC */
+	494,						/* U+000DDD */
+	495,						/* U+000DDE */
+	0,							/* U+000DDF */
+	0,							/* U+000DE0 */
+	0,							/* U+000DE1 */
+	0,							/* U+000DE2 */
+	0,							/* U+000DE3 */
+	0,							/* U+000DE4 */
+	0,							/* U+000DE5 */
+	0,							/* U+000DE6 */
+	0,							/* U+000DE7 */
+	0,							/* U+000DE8 */
+	0,							/* U+000DE9 */
+	0,							/* U+000DEA */
+	0,							/* U+000DEB */
+	0,							/* U+000DEC */
+	0,							/* U+000DED */
+	0,							/* U+000DEE */
+	0,							/* U+000DEF */
+	0,							/* U+000DF0 */
+	0,							/* U+000DF1 */
+	0,							/* U+000DF2 */
+	0,							/* U+000DF3 */
+	0,							/* U+000DF4 */
+	0,							/* U+000DF5 */
+	0,							/* U+000DF6 */
+	0,							/* U+000DF7 */
+	0,							/* U+000DF8 */
+	0,							/* U+000DF9 */
+	0,							/* U+000DFA */
+	0,							/* U+000DFB */
+	0,							/* U+000DFC */
+	0,							/* U+000DFD */
+	0,							/* U+000DFE */
+	0,							/* U+000DFF */
+	0,							/* U+000E00 */
+	0,							/* U+000E01 */
+	0,							/* U+000E02 */
+	0,							/* U+000E03 */
+	0,							/* U+000E04 */
+	0,							/* U+000E05 */
+	0,							/* U+000E06 */
+	0,							/* U+000E07 */
+	0,							/* U+000E08 */
+	0,							/* U+000E09 */
+	0,							/* U+000E0A */
+	0,							/* U+000E0B */
+	0,							/* U+000E0C */
+	0,							/* U+000E0D */
+	0,							/* U+000E0E */
+	0,							/* U+000E0F */
+	0,							/* U+000E10 */
+	0,							/* U+000E11 */
+	0,							/* U+000E12 */
+	0,							/* U+000E13 */
+	0,							/* U+000E14 */
+	0,							/* U+000E15 */
+	0,							/* U+000E16 */
+	0,							/* U+000E17 */
+	0,							/* U+000E18 */
+	0,							/* U+000E19 */
+	0,							/* U+000E1A */
+	0,							/* U+000E1B */
+	0,							/* U+000E1C */
+	0,							/* U+000E1D */
+	0,							/* U+000E1E */
+	0,							/* U+000E1F */
+	0,							/* U+000E20 */
+	0,							/* U+000E21 */
+	0,							/* U+000E22 */
+	0,							/* U+000E23 */
+	0,							/* U+000E24 */
+	0,							/* U+000E25 */
+	0,							/* U+000E26 */
+	0,							/* U+000E27 */
+	0,							/* U+000E28 */
+	0,							/* U+000E29 */
+	0,							/* U+000E2A */
+	0,							/* U+000E2B */
+	0,							/* U+000E2C */
+	0,							/* U+000E2D */
+	0,							/* U+000E2E */
+	0,							/* U+000E2F */
+	0,							/* U+000E30 */
+	0,							/* U+000E31 */
+	0,							/* U+000E32 */
+	496,						/* U+000E33 */
+	0,							/* U+000E34 */
+	0,							/* U+000E35 */
+	0,							/* U+000E36 */
+	0,							/* U+000E37 */
+	497,						/* U+000E38 */
+	497,						/* U+000E39 */
+	452,						/* U+000E3A */
+	0,							/* U+000E3B */
+	0,							/* U+000E3C */
+	0,							/* U+000E3D */
+	0,							/* U+000E3E */
+	0,							/* U+000E3F */
+	0,							/* U+000E40 */
+	0,							/* U+000E41 */
+	0,							/* U+000E42 */
+	0,							/* U+000E43 */
+	0,							/* U+000E44 */
+	0,							/* U+000E45 */
+	0,							/* U+000E46 */
+	0,							/* U+000E47 */
+	498,						/* U+000E48 */
+	498,						/* U+000E49 */
+	498,						/* U+000E4A */
+	498,						/* U+000E4B */
+	0,							/* U+000E4C */
+	0,							/* U+000E4D */
+	0,							/* U+000E4E */
+	0,							/* U+000E4F */
+	0,							/* U+000E50 */
+	0,							/* U+000E51 */
+	0,							/* U+000E52 */
+	0,							/* U+000E53 */
+	0,							/* U+000E54 */
+	0,							/* U+000E55 */
+	0,							/* U+000E56 */
+	0,							/* U+000E57 */
+	0,							/* U+000E58 */
+	0,							/* U+000E59 */
+	0,							/* U+000E5A */
+	0,							/* U+000E5B */
+	0,							/* U+000E5C */
+	0,							/* U+000E5D */
+	0,							/* U+000E5E */
+	0,							/* U+000E5F */
+	0,							/* U+000E60 */
+	0,							/* U+000E61 */
+	0,							/* U+000E62 */
+	0,							/* U+000E63 */
+	0,							/* U+000E64 */
+	0,							/* U+000E65 */
+	0,							/* U+000E66 */
+	0,							/* U+000E67 */
+	0,							/* U+000E68 */
+	0,							/* U+000E69 */
+	0,							/* U+000E6A */
+	0,							/* U+000E6B */
+	0,							/* U+000E6C */
+	0,							/* U+000E6D */
+	0,							/* U+000E6E */
+	0,							/* U+000E6F */
+	0,							/* U+000E70 */
+	0,							/* U+000E71 */
+	0,							/* U+000E72 */
+	0,							/* U+000E73 */
+	0,							/* U+000E74 */
+	0,							/* U+000E75 */
+	0,							/* U+000E76 */
+	0,							/* U+000E77 */
+	0,							/* U+000E78 */
+	0,							/* U+000E79 */
+	0,							/* U+000E7A */
+	0,							/* U+000E7B */
+	0,							/* U+000E7C */
+	0,							/* U+000E7D */
+	0,							/* U+000E7E */
+	0,							/* U+000E7F */
+	0,							/* U+000E80 */
+	0,							/* U+000E81 */
+	0,							/* U+000E82 */
+	0,							/* U+000E83 */
+	0,							/* U+000E84 */
+	0,							/* U+000E85 */
+	0,							/* U+000E86 */
+	0,							/* U+000E87 */
+	0,							/* U+000E88 */
+	0,							/* U+000E89 */
+	0,							/* U+000E8A */
+	0,							/* U+000E8B */
+	0,							/* U+000E8C */
+	0,							/* U+000E8D */
+	0,							/* U+000E8E */
+	0,							/* U+000E8F */
+	0,							/* U+000E90 */
+	0,							/* U+000E91 */
+	0,							/* U+000E92 */
+	0,							/* U+000E93 */
+	0,							/* U+000E94 */
+	0,							/* U+000E95 */
+	0,							/* U+000E96 */
+	0,							/* U+000E97 */
+	0,							/* U+000E98 */
+	0,							/* U+000E99 */
+	0,							/* U+000E9A */
+	0,							/* U+000E9B */
+	0,							/* U+000E9C */
+	0,							/* U+000E9D */
+	0,							/* U+000E9E */
+	0,							/* U+000E9F */
+	0,							/* U+000EA0 */
+	0,							/* U+000EA1 */
+	0,							/* U+000EA2 */
+	0,							/* U+000EA3 */
+	0,							/* U+000EA4 */
+	0,							/* U+000EA5 */
+	0,							/* U+000EA6 */
+	0,							/* U+000EA7 */
+	0,							/* U+000EA8 */
+	0,							/* U+000EA9 */
+	0,							/* U+000EAA */
+	0,							/* U+000EAB */
+	0,							/* U+000EAC */
+	0,							/* U+000EAD */
+	0,							/* U+000EAE */
+	0,							/* U+000EAF */
+	0,							/* U+000EB0 */
+	0,							/* U+000EB1 */
+	0,							/* U+000EB2 */
+	499,						/* U+000EB3 */
+	0,							/* U+000EB4 */
+	0,							/* U+000EB5 */
+	0,							/* U+000EB6 */
+	0,							/* U+000EB7 */
+	500,						/* U+000EB8 */
+	500,						/* U+000EB9 */
+	452,						/* U+000EBA */
+	0,							/* U+000EBB */
+	0,							/* U+000EBC */
+	0,							/* U+000EBD */
+	0,							/* U+000EBE */
+	0,							/* U+000EBF */
+	0,							/* U+000EC0 */
+	0,							/* U+000EC1 */
+	0,							/* U+000EC2 */
+	0,							/* U+000EC3 */
+	0,							/* U+000EC4 */
+	0,							/* U+000EC5 */
+	0,							/* U+000EC6 */
+	0,							/* U+000EC7 */
+	501,						/* U+000EC8 */
+	501,						/* U+000EC9 */
+	501,						/* U+000ECA */
+	501,						/* U+000ECB */
+	0,							/* U+000ECC */
+	0,							/* U+000ECD */
+	0,							/* U+000ECE */
+	0,							/* U+000ECF */
+	0,							/* U+000ED0 */
+	0,							/* U+000ED1 */
+	0,							/* U+000ED2 */
+	0,							/* U+000ED3 */
+	0,							/* U+000ED4 */
+	0,							/* U+000ED5 */
+	0,							/* U+000ED6 */
+	0,							/* U+000ED7 */
+	0,							/* U+000ED8 */
+	0,							/* U+000ED9 */
+	0,							/* U+000EDA */
+	0,							/* U+000EDB */
+	502,						/* U+000EDC */
+	503,						/* U+000EDD */
+	0,							/* U+000EDE */
+	0,							/* U+000EDF */
+	0,							/* U+000EE0 */
+	0,							/* U+000EE1 */
+	0,							/* U+000EE2 */
+	0,							/* U+000EE3 */
+	0,							/* U+000EE4 */
+	0,							/* U+000EE5 */
+	0,							/* U+000EE6 */
+	0,							/* U+000EE7 */
+	0,							/* U+000EE8 */
+	0,							/* U+000EE9 */
+	0,							/* U+000EEA */
+	0,							/* U+000EEB */
+	0,							/* U+000EEC */
+	0,							/* U+000EED */
+	0,							/* U+000EEE */
+	0,							/* U+000EEF */
+	0,							/* U+000EF0 */
+	0,							/* U+000EF1 */
+	0,							/* U+000EF2 */
+	0,							/* U+000EF3 */
+	0,							/* U+000EF4 */
+	0,							/* U+000EF5 */
+	0,							/* U+000EF6 */
+	0,							/* U+000EF7 */
+	0,							/* U+000EF8 */
+	0,							/* U+000EF9 */
+	0,							/* U+000EFA */
+	0,							/* U+000EFB */
+	0,							/* U+000EFC */
+	0,							/* U+000EFD */
+	0,							/* U+000EFE */
+	0,							/* U+000EFF */
+	0,							/* U+000F00 */
+	0,							/* U+000F01 */
+	0,							/* U+000F02 */
+	0,							/* U+000F03 */
+	0,							/* U+000F04 */
+	0,							/* U+000F05 */
+	0,							/* U+000F06 */
+	0,							/* U+000F07 */
+	0,							/* U+000F08 */
+	0,							/* U+000F09 */
+	0,							/* U+000F0A */
+	0,							/* U+000F0B */
+	504,						/* U+000F0C */
+	0,							/* U+000F0D */
+	0,							/* U+000F0E */
+	0,							/* U+000F0F */
+	0,							/* U+000F10 */
+	0,							/* U+000F11 */
+	0,							/* U+000F12 */
+	0,							/* U+000F13 */
+	0,							/* U+000F14 */
+	0,							/* U+000F15 */
+	0,							/* U+000F16 */
+	0,							/* U+000F17 */
+	306,						/* U+000F18 */
+	306,						/* U+000F19 */
+	0,							/* U+000F1A */
+	0,							/* U+000F1B */
+	0,							/* U+000F1C */
+	0,							/* U+000F1D */
+	0,							/* U+000F1E */
+	0,							/* U+000F1F */
+	0,							/* U+000F20 */
+	0,							/* U+000F21 */
+	0,							/* U+000F22 */
+	0,							/* U+000F23 */
+	0,							/* U+000F24 */
+	0,							/* U+000F25 */
+	0,							/* U+000F26 */
+	0,							/* U+000F27 */
+	0,							/* U+000F28 */
+	0,							/* U+000F29 */
+	0,							/* U+000F2A */
+	0,							/* U+000F2B */
+	0,							/* U+000F2C */
+	0,							/* U+000F2D */
+	0,							/* U+000F2E */
+	0,							/* U+000F2F */
+	0,							/* U+000F30 */
+	0,							/* U+000F31 */
+	0,							/* U+000F32 */
+	0,							/* U+000F33 */
+	0,							/* U+000F34 */
+	306,						/* U+000F35 */
+	0,							/* U+000F36 */
+	306,						/* U+000F37 */
+	0,							/* U+000F38 */
+	307,						/* U+000F39 */
+	0,							/* U+000F3A */
+	0,							/* U+000F3B */
+	0,							/* U+000F3C */
+	0,							/* U+000F3D */
+	0,							/* U+000F3E */
+	0,							/* U+000F3F */
+	0,							/* U+000F40 */
+	0,							/* U+000F41 */
+	0,							/* U+000F42 */
+	505,						/* U+000F43 */
+	0,							/* U+000F44 */
+	0,							/* U+000F45 */
+	0,							/* U+000F46 */
+	0,							/* U+000F47 */
+	0,							/* U+000F48 */
+	0,							/* U+000F49 */
+	0,							/* U+000F4A */
+	0,							/* U+000F4B */
+	0,							/* U+000F4C */
+	506,						/* U+000F4D */
+	0,							/* U+000F4E */
+	0,							/* U+000F4F */
+	0,							/* U+000F50 */
+	0,							/* U+000F51 */
+	507,						/* U+000F52 */
+	0,							/* U+000F53 */
+	0,							/* U+000F54 */
+	0,							/* U+000F55 */
+	0,							/* U+000F56 */
+	508,						/* U+000F57 */
+	0,							/* U+000F58 */
+	0,							/* U+000F59 */
+	0,							/* U+000F5A */
+	0,							/* U+000F5B */
+	509,						/* U+000F5C */
+	0,							/* U+000F5D */
+	0,							/* U+000F5E */
+	0,							/* U+000F5F */
+	0,							/* U+000F60 */
+	0,							/* U+000F61 */
+	0,							/* U+000F62 */
+	0,							/* U+000F63 */
+	0,							/* U+000F64 */
+	0,							/* U+000F65 */
+	0,							/* U+000F66 */
+	0,							/* U+000F67 */
+	0,							/* U+000F68 */
+	510,						/* U+000F69 */
+	0,							/* U+000F6A */
+	0,							/* U+000F6B */
+	0,							/* U+000F6C */
+	0,							/* U+000F6D */
+	0,							/* U+000F6E */
+	0,							/* U+000F6F */
+	0,							/* U+000F70 */
+	511,						/* U+000F71 */
+	512,						/* U+000F72 */
+	513,						/* U+000F73 */
+	514,						/* U+000F74 */
+	515,						/* U+000F75 */
+	516,						/* U+000F76 */
+	517,						/* U+000F77 */
+	518,						/* U+000F78 */
+	519,						/* U+000F79 */
+	512,						/* U+000F7A */
+	512,						/* U+000F7B */
+	512,						/* U+000F7C */
+	512,						/* U+000F7D */
+	0,							/* U+000F7E */
+	0,							/* U+000F7F */
+	512,						/* U+000F80 */
+	520,						/* U+000F81 */
+	304,						/* U+000F82 */
+	304,						/* U+000F83 */
+	452,						/* U+000F84 */
+	0,							/* U+000F85 */
+	304,						/* U+000F86 */
+	304,						/* U+000F87 */
+	0,							/* U+000F88 */
+	0,							/* U+000F89 */
+	0,							/* U+000F8A */
+	0,							/* U+000F8B */
+	0,							/* U+000F8C */
+	0,							/* U+000F8D */
+	0,							/* U+000F8E */
+	0,							/* U+000F8F */
+	0,							/* U+000F90 */
+	0,							/* U+000F91 */
+	0,							/* U+000F92 */
+	521,						/* U+000F93 */
+	0,							/* U+000F94 */
+	0,							/* U+000F95 */
+	0,							/* U+000F96 */
+	0,							/* U+000F97 */
+	0,							/* U+000F98 */
+	0,							/* U+000F99 */
+	0,							/* U+000F9A */
+	0,							/* U+000F9B */
+	0,							/* U+000F9C */
+	522,						/* U+000F9D */
+	0,							/* U+000F9E */
+	0,							/* U+000F9F */
+	0,							/* U+000FA0 */
+	0,							/* U+000FA1 */
+	523,						/* U+000FA2 */
+	0,							/* U+000FA3 */
+	0,							/* U+000FA4 */
+	0,							/* U+000FA5 */
+	0,							/* U+000FA6 */
+	524,						/* U+000FA7 */
+	0,							/* U+000FA8 */
+	0,							/* U+000FA9 */
+	0,							/* U+000FAA */
+	0,							/* U+000FAB */
+	525,						/* U+000FAC */
+	0,							/* U+000FAD */
+	0,							/* U+000FAE */
+	0,							/* U+000FAF */
+	0,							/* U+000FB0 */
+	0,							/* U+000FB1 */
+	0,							/* U+000FB2 */
+	0,							/* U+000FB3 */
+	0,							/* U+000FB4 */
+	0,							/* U+000FB5 */
+	0,							/* U+000FB6 */
+	0,							/* U+000FB7 */
+	0,							/* U+000FB8 */
+	526,						/* U+000FB9 */
+	0,							/* U+000FBA */
+	0,							/* U+000FBB */
+	0,							/* U+000FBC */
+	0,							/* U+000FBD */
+	0,							/* U+000FBE */
+	0,							/* U+000FBF */
+	0,							/* U+000FC0 */
+	0,							/* U+000FC1 */
+	0,							/* U+000FC2 */
+	0,							/* U+000FC3 */
+	0,							/* U+000FC4 */
+	0,							/* U+000FC5 */
+	306,						/* U+000FC6 */
+	0,							/* U+000FC7 */
+	0,							/* U+000FC8 */
+	0,							/* U+000FC9 */
+	0,							/* U+000FCA */
+	0,							/* U+000FCB */
+	0,							/* U+000FCC */
+	0,							/* U+000FCD */
+	0,							/* U+000FCE */
+	0,							/* U+000FCF */
+	0,							/* U+000FD0 */
+	0,							/* U+000FD1 */
+	0,							/* U+000FD2 */
+	0,							/* U+000FD3 */
+	0,							/* U+000FD4 */
+	0,							/* U+000FD5 */
+	0,							/* U+000FD6 */
+	0,							/* U+000FD7 */
+	0,							/* U+000FD8 */
+	0,							/* U+000FD9 */
+	0,							/* U+000FDA */
+	0,							/* U+000FDB */
+	0,							/* U+000FDC */
+	0,							/* U+000FDD */
+	0,							/* U+000FDE */
+	0,							/* U+000FDF */
+	0,							/* U+000FE0 */
+	0,							/* U+000FE1 */
+	0,							/* U+000FE2 */
+	0,							/* U+000FE3 */
+	0,							/* U+000FE4 */
+	0,							/* U+000FE5 */
+	0,							/* U+000FE6 */
+	0,							/* U+000FE7 */
+	0,							/* U+000FE8 */
+	0,							/* U+000FE9 */
+	0,							/* U+000FEA */
+	0,							/* U+000FEB */
+	0,							/* U+000FEC */
+	0,							/* U+000FED */
+	0,							/* U+000FEE */
+	0,							/* U+000FEF */
+	0,							/* U+000FF0 */
+	0,							/* U+000FF1 */
+	0,							/* U+000FF2 */
+	0,							/* U+000FF3 */
+	0,							/* U+000FF4 */
+	0,							/* U+000FF5 */
+	0,							/* U+000FF6 */
+	0,							/* U+000FF7 */
+	0,							/* U+000FF8 */
+	0,							/* U+000FF9 */
+	0,							/* U+000FFA */
+	0,							/* U+000FFB */
+	0,							/* U+000FFC */
+	0,							/* U+000FFD */
+	0,							/* U+000FFE */
+	0,							/* U+000FFF */
+	0,							/* U+001000 */
+	0,							/* U+001001 */
+	0,							/* U+001002 */
+	0,							/* U+001003 */
+	0,							/* U+001004 */
+	0,							/* U+001005 */
+	0,							/* U+001006 */
+	0,							/* U+001007 */
+	0,							/* U+001008 */
+	0,							/* U+001009 */
+	0,							/* U+00100A */
+	0,							/* U+00100B */
+	0,							/* U+00100C */
+	0,							/* U+00100D */
+	0,							/* U+00100E */
+	0,							/* U+00100F */
+	0,							/* U+001010 */
+	0,							/* U+001011 */
+	0,							/* U+001012 */
+	0,							/* U+001013 */
+	0,							/* U+001014 */
+	0,							/* U+001015 */
+	0,							/* U+001016 */
+	0,							/* U+001017 */
+	0,							/* U+001018 */
+	0,							/* U+001019 */
+	0,							/* U+00101A */
+	0,							/* U+00101B */
+	0,							/* U+00101C */
+	0,							/* U+00101D */
+	0,							/* U+00101E */
+	0,							/* U+00101F */
+	0,							/* U+001020 */
+	0,							/* U+001021 */
+	0,							/* U+001022 */
+	0,							/* U+001023 */
+	0,							/* U+001024 */
+	0,							/* U+001025 */
+	527,						/* U+001026 */
+	0,							/* U+001027 */
+	0,							/* U+001028 */
+	0,							/* U+001029 */
+	0,							/* U+00102A */
+	0,							/* U+00102B */
+	0,							/* U+00102C */
+	0,							/* U+00102D */
+	0,							/* U+00102E */
+	0,							/* U+00102F */
+	0,							/* U+001030 */
+	0,							/* U+001031 */
+	0,							/* U+001032 */
+	0,							/* U+001033 */
+	0,							/* U+001034 */
+	0,							/* U+001035 */
+	0,							/* U+001036 */
+	451,						/* U+001037 */
+	0,							/* U+001038 */
+	452,						/* U+001039 */
+	452,						/* U+00103A */
+	0,							/* U+00103B */
+	0,							/* U+00103C */
+	0,							/* U+00103D */
+	0,							/* U+00103E */
+	0,							/* U+00103F */
+	0,							/* U+001040 */
+	0,							/* U+001041 */
+	0,							/* U+001042 */
+	0,							/* U+001043 */
+	0,							/* U+001044 */
+	0,							/* U+001045 */
+	0,							/* U+001046 */
+	0,							/* U+001047 */
+	0,							/* U+001048 */
+	0,							/* U+001049 */
+	0,							/* U+00104A */
+	0,							/* U+00104B */
+	0,							/* U+00104C */
+	0,							/* U+00104D */
+	0,							/* U+00104E */
+	0,							/* U+00104F */
+	0,							/* U+001050 */
+	0,							/* U+001051 */
+	0,							/* U+001052 */
+	0,							/* U+001053 */
+	0,							/* U+001054 */
+	0,							/* U+001055 */
+	0,							/* U+001056 */
+	0,							/* U+001057 */
+	0,							/* U+001058 */
+	0,							/* U+001059 */
+	0,							/* U+00105A */
+	0,							/* U+00105B */
+	0,							/* U+00105C */
+	0,							/* U+00105D */
+	0,							/* U+00105E */
+	0,							/* U+00105F */
+	0,							/* U+001060 */
+	0,							/* U+001061 */
+	0,							/* U+001062 */
+	0,							/* U+001063 */
+	0,							/* U+001064 */
+	0,							/* U+001065 */
+	0,							/* U+001066 */
+	0,							/* U+001067 */
+	0,							/* U+001068 */
+	0,							/* U+001069 */
+	0,							/* U+00106A */
+	0,							/* U+00106B */
+	0,							/* U+00106C */
+	0,							/* U+00106D */
+	0,							/* U+00106E */
+	0,							/* U+00106F */
+	0,							/* U+001070 */
+	0,							/* U+001071 */
+	0,							/* U+001072 */
+	0,							/* U+001073 */
+	0,							/* U+001074 */
+	0,							/* U+001075 */
+	0,							/* U+001076 */
+	0,							/* U+001077 */
+	0,							/* U+001078 */
+	0,							/* U+001079 */
+	0,							/* U+00107A */
+	0,							/* U+00107B */
+	0,							/* U+00107C */
+	0,							/* U+00107D */
+	0,							/* U+00107E */
+	0,							/* U+00107F */
+	0,							/* U+001080 */
+	0,							/* U+001081 */
+	0,							/* U+001082 */
+	0,							/* U+001083 */
+	0,							/* U+001084 */
+	0,							/* U+001085 */
+	0,							/* U+001086 */
+	0,							/* U+001087 */
+	0,							/* U+001088 */
+	0,							/* U+001089 */
+	0,							/* U+00108A */
+	0,							/* U+00108B */
+	0,							/* U+00108C */
+	306,						/* U+00108D */
+	0,							/* U+00108E */
+	0,							/* U+00108F */
+	0,							/* U+001090 */
+	0,							/* U+001091 */
+	0,							/* U+001092 */
+	0,							/* U+001093 */
+	0,							/* U+001094 */
+	0,							/* U+001095 */
+	0,							/* U+001096 */
+	0,							/* U+001097 */
+	0,							/* U+001098 */
+	0,							/* U+001099 */
+	0,							/* U+00109A */
+	0,							/* U+00109B */
+	0,							/* U+00109C */
+	0,							/* U+00109D */
+	0,							/* U+00109E */
+	0,							/* U+00109F */
+	0,							/* U+0010A0 */
+	0,							/* U+0010A1 */
+	0,							/* U+0010A2 */
+	0,							/* U+0010A3 */
+	0,							/* U+0010A4 */
+	0,							/* U+0010A5 */
+	0,							/* U+0010A6 */
+	0,							/* U+0010A7 */
+	0,							/* U+0010A8 */
+	0,							/* U+0010A9 */
+	0,							/* U+0010AA */
+	0,							/* U+0010AB */
+	0,							/* U+0010AC */
+	0,							/* U+0010AD */
+	0,							/* U+0010AE */
+	0,							/* U+0010AF */
+	0,							/* U+0010B0 */
+	0,							/* U+0010B1 */
+	0,							/* U+0010B2 */
+	0,							/* U+0010B3 */
+	0,							/* U+0010B4 */
+	0,							/* U+0010B5 */
+	0,							/* U+0010B6 */
+	0,							/* U+0010B7 */
+	0,							/* U+0010B8 */
+	0,							/* U+0010B9 */
+	0,							/* U+0010BA */
+	0,							/* U+0010BB */
+	0,							/* U+0010BC */
+	0,							/* U+0010BD */
+	0,							/* U+0010BE */
+	0,							/* U+0010BF */
+	0,							/* U+0010C0 */
+	0,							/* U+0010C1 */
+	0,							/* U+0010C2 */
+	0,							/* U+0010C3 */
+	0,							/* U+0010C4 */
+	0,							/* U+0010C5 */
+	0,							/* U+0010C6 */
+	0,							/* U+0010C7 */
+	0,							/* U+0010C8 */
+	0,							/* U+0010C9 */
+	0,							/* U+0010CA */
+	0,							/* U+0010CB */
+	0,							/* U+0010CC */
+	0,							/* U+0010CD */
+	0,							/* U+0010CE */
+	0,							/* U+0010CF */
+	0,							/* U+0010D0 */
+	0,							/* U+0010D1 */
+	0,							/* U+0010D2 */
+	0,							/* U+0010D3 */
+	0,							/* U+0010D4 */
+	0,							/* U+0010D5 */
+	0,							/* U+0010D6 */
+	0,							/* U+0010D7 */
+	0,							/* U+0010D8 */
+	0,							/* U+0010D9 */
+	0,							/* U+0010DA */
+	0,							/* U+0010DB */
+	0,							/* U+0010DC */
+	0,							/* U+0010DD */
+	0,							/* U+0010DE */
+	0,							/* U+0010DF */
+	0,							/* U+0010E0 */
+	0,							/* U+0010E1 */
+	0,							/* U+0010E2 */
+	0,							/* U+0010E3 */
+	0,							/* U+0010E4 */
+	0,							/* U+0010E5 */
+	0,							/* U+0010E6 */
+	0,							/* U+0010E7 */
+	0,							/* U+0010E8 */
+	0,							/* U+0010E9 */
+	0,							/* U+0010EA */
+	0,							/* U+0010EB */
+	0,							/* U+0010EC */
+	0,							/* U+0010ED */
+	0,							/* U+0010EE */
+	0,							/* U+0010EF */
+	0,							/* U+0010F0 */
+	0,							/* U+0010F1 */
+	0,							/* U+0010F2 */
+	0,							/* U+0010F3 */
+	0,							/* U+0010F4 */
+	0,							/* U+0010F5 */
+	0,							/* U+0010F6 */
+	0,							/* U+0010F7 */
+	0,							/* U+0010F8 */
+	0,							/* U+0010F9 */
+	0,							/* U+0010FA */
+	0,							/* U+0010FB */
+	528,						/* U+0010FC */
+	0,							/* U+0010FD */
+	0,							/* U+0010FE */
+	0,							/* U+0010FF */
+	0,							/* U+001100 */
+	0,							/* U+001101 */
+	0,							/* U+001102 */
+	0,							/* U+001103 */
+	0,							/* U+001104 */
+	0,							/* U+001105 */
+	0,							/* U+001106 */
+	0,							/* U+001107 */
+	0,							/* U+001108 */
+	0,							/* U+001109 */
+	0,							/* U+00110A */
+	0,							/* U+00110B */
+	0,							/* U+00110C */
+	0,							/* U+00110D */
+	0,							/* U+00110E */
+	0,							/* U+00110F */
+	0,							/* U+001110 */
+	0,							/* U+001111 */
+	0,							/* U+001112 */
+	0,							/* U+001113 */
+	0,							/* U+001114 */
+	0,							/* U+001115 */
+	0,							/* U+001116 */
+	0,							/* U+001117 */
+	0,							/* U+001118 */
+	0,							/* U+001119 */
+	0,							/* U+00111A */
+	0,							/* U+00111B */
+	0,							/* U+00111C */
+	0,							/* U+00111D */
+	0,							/* U+00111E */
+	0,							/* U+00111F */
+	0,							/* U+001120 */
+	0,							/* U+001121 */
+	0,							/* U+001122 */
+	0,							/* U+001123 */
+	0,							/* U+001124 */
+	0,							/* U+001125 */
+	0,							/* U+001126 */
+	0,							/* U+001127 */
+	0,							/* U+001128 */
+	0,							/* U+001129 */
+	0,							/* U+00112A */
+	0,							/* U+00112B */
+	0,							/* U+00112C */
+	0,							/* U+00112D */
+	0,							/* U+00112E */
+	0,							/* U+00112F */
+	0,							/* U+001130 */
+	0,							/* U+001131 */
+	0,							/* U+001132 */
+	0,							/* U+001133 */
+	0,							/* U+001134 */
+	0,							/* U+001135 */
+	0,							/* U+001136 */
+	0,							/* U+001137 */
+	0,							/* U+001138 */
+	0,							/* U+001139 */
+	0,							/* U+00113A */
+	0,							/* U+00113B */
+	0,							/* U+00113C */
+	0,							/* U+00113D */
+	0,							/* U+00113E */
+	0,							/* U+00113F */
+	0,							/* U+001140 */
+	0,							/* U+001141 */
+	0,							/* U+001142 */
+	0,							/* U+001143 */
+	0,							/* U+001144 */
+	0,							/* U+001145 */
+	0,							/* U+001146 */
+	0,							/* U+001147 */
+	0,							/* U+001148 */
+	0,							/* U+001149 */
+	0,							/* U+00114A */
+	0,							/* U+00114B */
+	0,							/* U+00114C */
+	0,							/* U+00114D */
+	0,							/* U+00114E */
+	0,							/* U+00114F */
+	0,							/* U+001150 */
+	0,							/* U+001151 */
+	0,							/* U+001152 */
+	0,							/* U+001153 */
+	0,							/* U+001154 */
+	0,							/* U+001155 */
+	0,							/* U+001156 */
+	0,							/* U+001157 */
+	0,							/* U+001158 */
+	0,							/* U+001159 */
+	0,							/* U+00115A */
+	0,							/* U+00115B */
+	0,							/* U+00115C */
+	0,							/* U+00115D */
+	0,							/* U+00115E */
+	0,							/* U+00115F */
+	0,							/* U+001160 */
+	0,							/* U+001161 */
+	0,							/* U+001162 */
+	0,							/* U+001163 */
+	0,							/* U+001164 */
+	0,							/* U+001165 */
+	0,							/* U+001166 */
+	0,							/* U+001167 */
+	0,							/* U+001168 */
+	0,							/* U+001169 */
+	0,							/* U+00116A */
+	0,							/* U+00116B */
+	0,							/* U+00116C */
+	0,							/* U+00116D */
+	0,							/* U+00116E */
+	0,							/* U+00116F */
+	0,							/* U+001170 */
+	0,							/* U+001171 */
+	0,							/* U+001172 */
+	0,							/* U+001173 */
+	0,							/* U+001174 */
+	0,							/* U+001175 */
+	0,							/* U+001176 */
+	0,							/* U+001177 */
+	0,							/* U+001178 */
+	0,							/* U+001179 */
+	0,							/* U+00117A */
+	0,							/* U+00117B */
+	0,							/* U+00117C */
+	0,							/* U+00117D */
+	0,							/* U+00117E */
+	0,							/* U+00117F */
+	0,							/* U+001180 */
+	0,							/* U+001181 */
+	0,							/* U+001182 */
+	0,							/* U+001183 */
+	0,							/* U+001184 */
+	0,							/* U+001185 */
+	0,							/* U+001186 */
+	0,							/* U+001187 */
+	0,							/* U+001188 */
+	0,							/* U+001189 */
+	0,							/* U+00118A */
+	0,							/* U+00118B */
+	0,							/* U+00118C */
+	0,							/* U+00118D */
+	0,							/* U+00118E */
+	0,							/* U+00118F */
+	0,							/* U+001190 */
+	0,							/* U+001191 */
+	0,							/* U+001192 */
+	0,							/* U+001193 */
+	0,							/* U+001194 */
+	0,							/* U+001195 */
+	0,							/* U+001196 */
+	0,							/* U+001197 */
+	0,							/* U+001198 */
+	0,							/* U+001199 */
+	0,							/* U+00119A */
+	0,							/* U+00119B */
+	0,							/* U+00119C */
+	0,							/* U+00119D */
+	0,							/* U+00119E */
+	0,							/* U+00119F */
+	0,							/* U+0011A0 */
+	0,							/* U+0011A1 */
+	0,							/* U+0011A2 */
+	0,							/* U+0011A3 */
+	0,							/* U+0011A4 */
+	0,							/* U+0011A5 */
+	0,							/* U+0011A6 */
+	0,							/* U+0011A7 */
+	0,							/* U+0011A8 */
+	0,							/* U+0011A9 */
+	0,							/* U+0011AA */
+	0,							/* U+0011AB */
+	0,							/* U+0011AC */
+	0,							/* U+0011AD */
+	0,							/* U+0011AE */
+	0,							/* U+0011AF */
+	0,							/* U+0011B0 */
+	0,							/* U+0011B1 */
+	0,							/* U+0011B2 */
+	0,							/* U+0011B3 */
+	0,							/* U+0011B4 */
+	0,							/* U+0011B5 */
+	0,							/* U+0011B6 */
+	0,							/* U+0011B7 */
+	0,							/* U+0011B8 */
+	0,							/* U+0011B9 */
+	0,							/* U+0011BA */
+	0,							/* U+0011BB */
+	0,							/* U+0011BC */
+	0,							/* U+0011BD */
+	0,							/* U+0011BE */
+	0,							/* U+0011BF */
+	0,							/* U+0011C0 */
+	0,							/* U+0011C1 */
+	0,							/* U+0011C2 */
+	0,							/* U+0011C3 */
+	0,							/* U+0011C4 */
+	0,							/* U+0011C5 */
+	0,							/* U+0011C6 */
+	0,							/* U+0011C7 */
+	0,							/* U+0011C8 */
+	0,							/* U+0011C9 */
+	0,							/* U+0011CA */
+	0,							/* U+0011CB */
+	0,							/* U+0011CC */
+	0,							/* U+0011CD */
+	0,							/* U+0011CE */
+	0,							/* U+0011CF */
+	0,							/* U+0011D0 */
+	0,							/* U+0011D1 */
+	0,							/* U+0011D2 */
+	0,							/* U+0011D3 */
+	0,							/* U+0011D4 */
+	0,							/* U+0011D5 */
+	0,							/* U+0011D6 */
+	0,							/* U+0011D7 */
+	0,							/* U+0011D8 */
+	0,							/* U+0011D9 */
+	0,							/* U+0011DA */
+	0,							/* U+0011DB */
+	0,							/* U+0011DC */
+	0,							/* U+0011DD */
+	0,							/* U+0011DE */
+	0,							/* U+0011DF */
+	0,							/* U+0011E0 */
+	0,							/* U+0011E1 */
+	0,							/* U+0011E2 */
+	0,							/* U+0011E3 */
+	0,							/* U+0011E4 */
+	0,							/* U+0011E5 */
+	0,							/* U+0011E6 */
+	0,							/* U+0011E7 */
+	0,							/* U+0011E8 */
+	0,							/* U+0011E9 */
+	0,							/* U+0011EA */
+	0,							/* U+0011EB */
+	0,							/* U+0011EC */
+	0,							/* U+0011ED */
+	0,							/* U+0011EE */
+	0,							/* U+0011EF */
+	0,							/* U+0011F0 */
+	0,							/* U+0011F1 */
+	0,							/* U+0011F2 */
+	0,							/* U+0011F3 */
+	0,							/* U+0011F4 */
+	0,							/* U+0011F5 */
+	0,							/* U+0011F6 */
+	0,							/* U+0011F7 */
+	0,							/* U+0011F8 */
+	0,							/* U+0011F9 */
+	0,							/* U+0011FA */
+	0,							/* U+0011FB */
+	0,							/* U+0011FC */
+	0,							/* U+0011FD */
+	0,							/* U+0011FE */
+	0,							/* U+0011FF */
+	0,							/* U+001200 */
+	0,							/* U+001201 */
+	0,							/* U+001202 */
+	0,							/* U+001203 */
+	0,							/* U+001204 */
+	0,							/* U+001205 */
+	0,							/* U+001206 */
+	0,							/* U+001207 */
+	0,							/* U+001208 */
+	0,							/* U+001209 */
+	0,							/* U+00120A */
+	0,							/* U+00120B */
+	0,							/* U+00120C */
+	0,							/* U+00120D */
+	0,							/* U+00120E */
+	0,							/* U+00120F */
+	0,							/* U+001210 */
+	0,							/* U+001211 */
+	0,							/* U+001212 */
+	0,							/* U+001213 */
+	0,							/* U+001214 */
+	0,							/* U+001215 */
+	0,							/* U+001216 */
+	0,							/* U+001217 */
+	0,							/* U+001218 */
+	0,							/* U+001219 */
+	0,							/* U+00121A */
+	0,							/* U+00121B */
+	0,							/* U+00121C */
+	0,							/* U+00121D */
+	0,							/* U+00121E */
+	0,							/* U+00121F */
+	0,							/* U+001220 */
+	0,							/* U+001221 */
+	0,							/* U+001222 */
+	0,							/* U+001223 */
+	0,							/* U+001224 */
+	0,							/* U+001225 */
+	0,							/* U+001226 */
+	0,							/* U+001227 */
+	0,							/* U+001228 */
+	0,							/* U+001229 */
+	0,							/* U+00122A */
+	0,							/* U+00122B */
+	0,							/* U+00122C */
+	0,							/* U+00122D */
+	0,							/* U+00122E */
+	0,							/* U+00122F */
+	0,							/* U+001230 */
+	0,							/* U+001231 */
+	0,							/* U+001232 */
+	0,							/* U+001233 */
+	0,							/* U+001234 */
+	0,							/* U+001235 */
+	0,							/* U+001236 */
+	0,							/* U+001237 */
+	0,							/* U+001238 */
+	0,							/* U+001239 */
+	0,							/* U+00123A */
+	0,							/* U+00123B */
+	0,							/* U+00123C */
+	0,							/* U+00123D */
+	0,							/* U+00123E */
+	0,							/* U+00123F */
+	0,							/* U+001240 */
+	0,							/* U+001241 */
+	0,							/* U+001242 */
+	0,							/* U+001243 */
+	0,							/* U+001244 */
+	0,							/* U+001245 */
+	0,							/* U+001246 */
+	0,							/* U+001247 */
+	0,							/* U+001248 */
+	0,							/* U+001249 */
+	0,							/* U+00124A */
+	0,							/* U+00124B */
+	0,							/* U+00124C */
+	0,							/* U+00124D */
+	0,							/* U+00124E */
+	0,							/* U+00124F */
+	0,							/* U+001250 */
+	0,							/* U+001251 */
+	0,							/* U+001252 */
+	0,							/* U+001253 */
+	0,							/* U+001254 */
+	0,							/* U+001255 */
+	0,							/* U+001256 */
+	0,							/* U+001257 */
+	0,							/* U+001258 */
+	0,							/* U+001259 */
+	0,							/* U+00125A */
+	0,							/* U+00125B */
+	0,							/* U+00125C */
+	0,							/* U+00125D */
+	0,							/* U+00125E */
+	0,							/* U+00125F */
+	0,							/* U+001260 */
+	0,							/* U+001261 */
+	0,							/* U+001262 */
+	0,							/* U+001263 */
+	0,							/* U+001264 */
+	0,							/* U+001265 */
+	0,							/* U+001266 */
+	0,							/* U+001267 */
+	0,							/* U+001268 */
+	0,							/* U+001269 */
+	0,							/* U+00126A */
+	0,							/* U+00126B */
+	0,							/* U+00126C */
+	0,							/* U+00126D */
+	0,							/* U+00126E */
+	0,							/* U+00126F */
+	0,							/* U+001270 */
+	0,							/* U+001271 */
+	0,							/* U+001272 */
+	0,							/* U+001273 */
+	0,							/* U+001274 */
+	0,							/* U+001275 */
+	0,							/* U+001276 */
+	0,							/* U+001277 */
+	0,							/* U+001278 */
+	0,							/* U+001279 */
+	0,							/* U+00127A */
+	0,							/* U+00127B */
+	0,							/* U+00127C */
+	0,							/* U+00127D */
+	0,							/* U+00127E */
+	0,							/* U+00127F */
+	0,							/* U+001280 */
+	0,							/* U+001281 */
+	0,							/* U+001282 */
+	0,							/* U+001283 */
+	0,							/* U+001284 */
+	0,							/* U+001285 */
+	0,							/* U+001286 */
+	0,							/* U+001287 */
+	0,							/* U+001288 */
+	0,							/* U+001289 */
+	0,							/* U+00128A */
+	0,							/* U+00128B */
+	0,							/* U+00128C */
+	0,							/* U+00128D */
+	0,							/* U+00128E */
+	0,							/* U+00128F */
+	0,							/* U+001290 */
+	0,							/* U+001291 */
+	0,							/* U+001292 */
+	0,							/* U+001293 */
+	0,							/* U+001294 */
+	0,							/* U+001295 */
+	0,							/* U+001296 */
+	0,							/* U+001297 */
+	0,							/* U+001298 */
+	0,							/* U+001299 */
+	0,							/* U+00129A */
+	0,							/* U+00129B */
+	0,							/* U+00129C */
+	0,							/* U+00129D */
+	0,							/* U+00129E */
+	0,							/* U+00129F */
+	0,							/* U+0012A0 */
+	0,							/* U+0012A1 */
+	0,							/* U+0012A2 */
+	0,							/* U+0012A3 */
+	0,							/* U+0012A4 */
+	0,							/* U+0012A5 */
+	0,							/* U+0012A6 */
+	0,							/* U+0012A7 */
+	0,							/* U+0012A8 */
+	0,							/* U+0012A9 */
+	0,							/* U+0012AA */
+	0,							/* U+0012AB */
+	0,							/* U+0012AC */
+	0,							/* U+0012AD */
+	0,							/* U+0012AE */
+	0,							/* U+0012AF */
+	0,							/* U+0012B0 */
+	0,							/* U+0012B1 */
+	0,							/* U+0012B2 */
+	0,							/* U+0012B3 */
+	0,							/* U+0012B4 */
+	0,							/* U+0012B5 */
+	0,							/* U+0012B6 */
+	0,							/* U+0012B7 */
+	0,							/* U+0012B8 */
+	0,							/* U+0012B9 */
+	0,							/* U+0012BA */
+	0,							/* U+0012BB */
+	0,							/* U+0012BC */
+	0,							/* U+0012BD */
+	0,							/* U+0012BE */
+	0,							/* U+0012BF */
+	0,							/* U+0012C0 */
+	0,							/* U+0012C1 */
+	0,							/* U+0012C2 */
+	0,							/* U+0012C3 */
+	0,							/* U+0012C4 */
+	0,							/* U+0012C5 */
+	0,							/* U+0012C6 */
+	0,							/* U+0012C7 */
+	0,							/* U+0012C8 */
+	0,							/* U+0012C9 */
+	0,							/* U+0012CA */
+	0,							/* U+0012CB */
+	0,							/* U+0012CC */
+	0,							/* U+0012CD */
+	0,							/* U+0012CE */
+	0,							/* U+0012CF */
+	0,							/* U+0012D0 */
+	0,							/* U+0012D1 */
+	0,							/* U+0012D2 */
+	0,							/* U+0012D3 */
+	0,							/* U+0012D4 */
+	0,							/* U+0012D5 */
+	0,							/* U+0012D6 */
+	0,							/* U+0012D7 */
+	0,							/* U+0012D8 */
+	0,							/* U+0012D9 */
+	0,							/* U+0012DA */
+	0,							/* U+0012DB */
+	0,							/* U+0012DC */
+	0,							/* U+0012DD */
+	0,							/* U+0012DE */
+	0,							/* U+0012DF */
+	0,							/* U+0012E0 */
+	0,							/* U+0012E1 */
+	0,							/* U+0012E2 */
+	0,							/* U+0012E3 */
+	0,							/* U+0012E4 */
+	0,							/* U+0012E5 */
+	0,							/* U+0012E6 */
+	0,							/* U+0012E7 */
+	0,							/* U+0012E8 */
+	0,							/* U+0012E9 */
+	0,							/* U+0012EA */
+	0,							/* U+0012EB */
+	0,							/* U+0012EC */
+	0,							/* U+0012ED */
+	0,							/* U+0012EE */
+	0,							/* U+0012EF */
+	0,							/* U+0012F0 */
+	0,							/* U+0012F1 */
+	0,							/* U+0012F2 */
+	0,							/* U+0012F3 */
+	0,							/* U+0012F4 */
+	0,							/* U+0012F5 */
+	0,							/* U+0012F6 */
+	0,							/* U+0012F7 */
+	0,							/* U+0012F8 */
+	0,							/* U+0012F9 */
+	0,							/* U+0012FA */
+	0,							/* U+0012FB */
+	0,							/* U+0012FC */
+	0,							/* U+0012FD */
+	0,							/* U+0012FE */
+	0,							/* U+0012FF */
+	0,							/* U+001300 */
+	0,							/* U+001301 */
+	0,							/* U+001302 */
+	0,							/* U+001303 */
+	0,							/* U+001304 */
+	0,							/* U+001305 */
+	0,							/* U+001306 */
+	0,							/* U+001307 */
+	0,							/* U+001308 */
+	0,							/* U+001309 */
+	0,							/* U+00130A */
+	0,							/* U+00130B */
+	0,							/* U+00130C */
+	0,							/* U+00130D */
+	0,							/* U+00130E */
+	0,							/* U+00130F */
+	0,							/* U+001310 */
+	0,							/* U+001311 */
+	0,							/* U+001312 */
+	0,							/* U+001313 */
+	0,							/* U+001314 */
+	0,							/* U+001315 */
+	0,							/* U+001316 */
+	0,							/* U+001317 */
+	0,							/* U+001318 */
+	0,							/* U+001319 */
+	0,							/* U+00131A */
+	0,							/* U+00131B */
+	0,							/* U+00131C */
+	0,							/* U+00131D */
+	0,							/* U+00131E */
+	0,							/* U+00131F */
+	0,							/* U+001320 */
+	0,							/* U+001321 */
+	0,							/* U+001322 */
+	0,							/* U+001323 */
+	0,							/* U+001324 */
+	0,							/* U+001325 */
+	0,							/* U+001326 */
+	0,							/* U+001327 */
+	0,							/* U+001328 */
+	0,							/* U+001329 */
+	0,							/* U+00132A */
+	0,							/* U+00132B */
+	0,							/* U+00132C */
+	0,							/* U+00132D */
+	0,							/* U+00132E */
+	0,							/* U+00132F */
+	0,							/* U+001330 */
+	0,							/* U+001331 */
+	0,							/* U+001332 */
+	0,							/* U+001333 */
+	0,							/* U+001334 */
+	0,							/* U+001335 */
+	0,							/* U+001336 */
+	0,							/* U+001337 */
+	0,							/* U+001338 */
+	0,							/* U+001339 */
+	0,							/* U+00133A */
+	0,							/* U+00133B */
+	0,							/* U+00133C */
+	0,							/* U+00133D */
+	0,							/* U+00133E */
+	0,							/* U+00133F */
+	0,							/* U+001340 */
+	0,							/* U+001341 */
+	0,							/* U+001342 */
+	0,							/* U+001343 */
+	0,							/* U+001344 */
+	0,							/* U+001345 */
+	0,							/* U+001346 */
+	0,							/* U+001347 */
+	0,							/* U+001348 */
+	0,							/* U+001349 */
+	0,							/* U+00134A */
+	0,							/* U+00134B */
+	0,							/* U+00134C */
+	0,							/* U+00134D */
+	0,							/* U+00134E */
+	0,							/* U+00134F */
+	0,							/* U+001350 */
+	0,							/* U+001351 */
+	0,							/* U+001352 */
+	0,							/* U+001353 */
+	0,							/* U+001354 */
+	0,							/* U+001355 */
+	0,							/* U+001356 */
+	0,							/* U+001357 */
+	0,							/* U+001358 */
+	0,							/* U+001359 */
+	0,							/* U+00135A */
+	0,							/* U+00135B */
+	0,							/* U+00135C */
+	304,						/* U+00135D */
+	304,						/* U+00135E */
+	304,						/* U+00135F */
+	0,							/* U+001360 */
+	0,							/* U+001361 */
+	0,							/* U+001362 */
+	0,							/* U+001363 */
+	0,							/* U+001364 */
+	0,							/* U+001365 */
+	0,							/* U+001366 */
+	0,							/* U+001367 */
+	0,							/* U+001368 */
+	0,							/* U+001369 */
+	0,							/* U+00136A */
+	0,							/* U+00136B */
+	0,							/* U+00136C */
+	0,							/* U+00136D */
+	0,							/* U+00136E */
+	0,							/* U+00136F */
+	0,							/* U+001370 */
+	0,							/* U+001371 */
+	0,							/* U+001372 */
+	0,							/* U+001373 */
+	0,							/* U+001374 */
+	0,							/* U+001375 */
+	0,							/* U+001376 */
+	0,							/* U+001377 */
+	0,							/* U+001378 */
+	0,							/* U+001379 */
+	0,							/* U+00137A */
+	0,							/* U+00137B */
+	0,							/* U+00137C */
+	0,							/* U+00137D */
+	0,							/* U+00137E */
+	0,							/* U+00137F */
+	0,							/* U+001380 */
+	0,							/* U+001381 */
+	0,							/* U+001382 */
+	0,							/* U+001383 */
+	0,							/* U+001384 */
+	0,							/* U+001385 */
+	0,							/* U+001386 */
+	0,							/* U+001387 */
+	0,							/* U+001388 */
+	0,							/* U+001389 */
+	0,							/* U+00138A */
+	0,							/* U+00138B */
+	0,							/* U+00138C */
+	0,							/* U+00138D */
+	0,							/* U+00138E */
+	0,							/* U+00138F */
+	0,							/* U+001390 */
+	0,							/* U+001391 */
+	0,							/* U+001392 */
+	0,							/* U+001393 */
+	0,							/* U+001394 */
+	0,							/* U+001395 */
+	0,							/* U+001396 */
+	0,							/* U+001397 */
+	0,							/* U+001398 */
+	0,							/* U+001399 */
+	0,							/* U+00139A */
+	0,							/* U+00139B */
+	0,							/* U+00139C */
+	0,							/* U+00139D */
+	0,							/* U+00139E */
+	0,							/* U+00139F */
+	0,							/* U+0013A0 */
+	0,							/* U+0013A1 */
+	0,							/* U+0013A2 */
+	0,							/* U+0013A3 */
+	0,							/* U+0013A4 */
+	0,							/* U+0013A5 */
+	0,							/* U+0013A6 */
+	0,							/* U+0013A7 */
+	0,							/* U+0013A8 */
+	0,							/* U+0013A9 */
+	0,							/* U+0013AA */
+	0,							/* U+0013AB */
+	0,							/* U+0013AC */
+	0,							/* U+0013AD */
+	0,							/* U+0013AE */
+	0,							/* U+0013AF */
+	0,							/* U+0013B0 */
+	0,							/* U+0013B1 */
+	0,							/* U+0013B2 */
+	0,							/* U+0013B3 */
+	0,							/* U+0013B4 */
+	0,							/* U+0013B5 */
+	0,							/* U+0013B6 */
+	0,							/* U+0013B7 */
+	0,							/* U+0013B8 */
+	0,							/* U+0013B9 */
+	0,							/* U+0013BA */
+	0,							/* U+0013BB */
+	0,							/* U+0013BC */
+	0,							/* U+0013BD */
+	0,							/* U+0013BE */
+	0,							/* U+0013BF */
+	0,							/* U+0013C0 */
+	0,							/* U+0013C1 */
+	0,							/* U+0013C2 */
+	0,							/* U+0013C3 */
+	0,							/* U+0013C4 */
+	0,							/* U+0013C5 */
+	0,							/* U+0013C6 */
+	0,							/* U+0013C7 */
+	0,							/* U+0013C8 */
+	0,							/* U+0013C9 */
+	0,							/* U+0013CA */
+	0,							/* U+0013CB */
+	0,							/* U+0013CC */
+	0,							/* U+0013CD */
+	0,							/* U+0013CE */
+	0,							/* U+0013CF */
+	0,							/* U+0013D0 */
+	0,							/* U+0013D1 */
+	0,							/* U+0013D2 */
+	0,							/* U+0013D3 */
+	0,							/* U+0013D4 */
+	0,							/* U+0013D5 */
+	0,							/* U+0013D6 */
+	0,							/* U+0013D7 */
+	0,							/* U+0013D8 */
+	0,							/* U+0013D9 */
+	0,							/* U+0013DA */
+	0,							/* U+0013DB */
+	0,							/* U+0013DC */
+	0,							/* U+0013DD */
+	0,							/* U+0013DE */
+	0,							/* U+0013DF */
+	0,							/* U+0013E0 */
+	0,							/* U+0013E1 */
+	0,							/* U+0013E2 */
+	0,							/* U+0013E3 */
+	0,							/* U+0013E4 */
+	0,							/* U+0013E5 */
+	0,							/* U+0013E6 */
+	0,							/* U+0013E7 */
+	0,							/* U+0013E8 */
+	0,							/* U+0013E9 */
+	0,							/* U+0013EA */
+	0,							/* U+0013EB */
+	0,							/* U+0013EC */
+	0,							/* U+0013ED */
+	0,							/* U+0013EE */
+	0,							/* U+0013EF */
+	0,							/* U+0013F0 */
+	0,							/* U+0013F1 */
+	0,							/* U+0013F2 */
+	0,							/* U+0013F3 */
+	0,							/* U+0013F4 */
+	0,							/* U+0013F5 */
+	0,							/* U+0013F6 */
+	0,							/* U+0013F7 */
+	0,							/* U+0013F8 */
+	0,							/* U+0013F9 */
+	0,							/* U+0013FA */
+	0,							/* U+0013FB */
+	0,							/* U+0013FC */
+	0,							/* U+0013FD */
+	0,							/* U+0013FE */
+	0,							/* U+0013FF */
+	0,							/* U+001400 */
+	0,							/* U+001401 */
+	0,							/* U+001402 */
+	0,							/* U+001403 */
+	0,							/* U+001404 */
+	0,							/* U+001405 */
+	0,							/* U+001406 */
+	0,							/* U+001407 */
+	0,							/* U+001408 */
+	0,							/* U+001409 */
+	0,							/* U+00140A */
+	0,							/* U+00140B */
+	0,							/* U+00140C */
+	0,							/* U+00140D */
+	0,							/* U+00140E */
+	0,							/* U+00140F */
+	0,							/* U+001410 */
+	0,							/* U+001411 */
+	0,							/* U+001412 */
+	0,							/* U+001413 */
+	0,							/* U+001414 */
+	0,							/* U+001415 */
+	0,							/* U+001416 */
+	0,							/* U+001417 */
+	0,							/* U+001418 */
+	0,							/* U+001419 */
+	0,							/* U+00141A */
+	0,							/* U+00141B */
+	0,							/* U+00141C */
+	0,							/* U+00141D */
+	0,							/* U+00141E */
+	0,							/* U+00141F */
+	0,							/* U+001420 */
+	0,							/* U+001421 */
+	0,							/* U+001422 */
+	0,							/* U+001423 */
+	0,							/* U+001424 */
+	0,							/* U+001425 */
+	0,							/* U+001426 */
+	0,							/* U+001427 */
+	0,							/* U+001428 */
+	0,							/* U+001429 */
+	0,							/* U+00142A */
+	0,							/* U+00142B */
+	0,							/* U+00142C */
+	0,							/* U+00142D */
+	0,							/* U+00142E */
+	0,							/* U+00142F */
+	0,							/* U+001430 */
+	0,							/* U+001431 */
+	0,							/* U+001432 */
+	0,							/* U+001433 */
+	0,							/* U+001434 */
+	0,							/* U+001435 */
+	0,							/* U+001436 */
+	0,							/* U+001437 */
+	0,							/* U+001438 */
+	0,							/* U+001439 */
+	0,							/* U+00143A */
+	0,							/* U+00143B */
+	0,							/* U+00143C */
+	0,							/* U+00143D */
+	0,							/* U+00143E */
+	0,							/* U+00143F */
+	0,							/* U+001440 */
+	0,							/* U+001441 */
+	0,							/* U+001442 */
+	0,							/* U+001443 */
+	0,							/* U+001444 */
+	0,							/* U+001445 */
+	0,							/* U+001446 */
+	0,							/* U+001447 */
+	0,							/* U+001448 */
+	0,							/* U+001449 */
+	0,							/* U+00144A */
+	0,							/* U+00144B */
+	0,							/* U+00144C */
+	0,							/* U+00144D */
+	0,							/* U+00144E */
+	0,							/* U+00144F */
+	0,							/* U+001450 */
+	0,							/* U+001451 */
+	0,							/* U+001452 */
+	0,							/* U+001453 */
+	0,							/* U+001454 */
+	0,							/* U+001455 */
+	0,							/* U+001456 */
+	0,							/* U+001457 */
+	0,							/* U+001458 */
+	0,							/* U+001459 */
+	0,							/* U+00145A */
+	0,							/* U+00145B */
+	0,							/* U+00145C */
+	0,							/* U+00145D */
+	0,							/* U+00145E */
+	0,							/* U+00145F */
+	0,							/* U+001460 */
+	0,							/* U+001461 */
+	0,							/* U+001462 */
+	0,							/* U+001463 */
+	0,							/* U+001464 */
+	0,							/* U+001465 */
+	0,							/* U+001466 */
+	0,							/* U+001467 */
+	0,							/* U+001468 */
+	0,							/* U+001469 */
+	0,							/* U+00146A */
+	0,							/* U+00146B */
+	0,							/* U+00146C */
+	0,							/* U+00146D */
+	0,							/* U+00146E */
+	0,							/* U+00146F */
+	0,							/* U+001470 */
+	0,							/* U+001471 */
+	0,							/* U+001472 */
+	0,							/* U+001473 */
+	0,							/* U+001474 */
+	0,							/* U+001475 */
+	0,							/* U+001476 */
+	0,							/* U+001477 */
+	0,							/* U+001478 */
+	0,							/* U+001479 */
+	0,							/* U+00147A */
+	0,							/* U+00147B */
+	0,							/* U+00147C */
+	0,							/* U+00147D */
+	0,							/* U+00147E */
+	0,							/* U+00147F */
+	0,							/* U+001480 */
+	0,							/* U+001481 */
+	0,							/* U+001482 */
+	0,							/* U+001483 */
+	0,							/* U+001484 */
+	0,							/* U+001485 */
+	0,							/* U+001486 */
+	0,							/* U+001487 */
+	0,							/* U+001488 */
+	0,							/* U+001489 */
+	0,							/* U+00148A */
+	0,							/* U+00148B */
+	0,							/* U+00148C */
+	0,							/* U+00148D */
+	0,							/* U+00148E */
+	0,							/* U+00148F */
+	0,							/* U+001490 */
+	0,							/* U+001491 */
+	0,							/* U+001492 */
+	0,							/* U+001493 */
+	0,							/* U+001494 */
+	0,							/* U+001495 */
+	0,							/* U+001496 */
+	0,							/* U+001497 */
+	0,							/* U+001498 */
+	0,							/* U+001499 */
+	0,							/* U+00149A */
+	0,							/* U+00149B */
+	0,							/* U+00149C */
+	0,							/* U+00149D */
+	0,							/* U+00149E */
+	0,							/* U+00149F */
+	0,							/* U+0014A0 */
+	0,							/* U+0014A1 */
+	0,							/* U+0014A2 */
+	0,							/* U+0014A3 */
+	0,							/* U+0014A4 */
+	0,							/* U+0014A5 */
+	0,							/* U+0014A6 */
+	0,							/* U+0014A7 */
+	0,							/* U+0014A8 */
+	0,							/* U+0014A9 */
+	0,							/* U+0014AA */
+	0,							/* U+0014AB */
+	0,							/* U+0014AC */
+	0,							/* U+0014AD */
+	0,							/* U+0014AE */
+	0,							/* U+0014AF */
+	0,							/* U+0014B0 */
+	0,							/* U+0014B1 */
+	0,							/* U+0014B2 */
+	0,							/* U+0014B3 */
+	0,							/* U+0014B4 */
+	0,							/* U+0014B5 */
+	0,							/* U+0014B6 */
+	0,							/* U+0014B7 */
+	0,							/* U+0014B8 */
+	0,							/* U+0014B9 */
+	0,							/* U+0014BA */
+	0,							/* U+0014BB */
+	0,							/* U+0014BC */
+	0,							/* U+0014BD */
+	0,							/* U+0014BE */
+	0,							/* U+0014BF */
+	0,							/* U+0014C0 */
+	0,							/* U+0014C1 */
+	0,							/* U+0014C2 */
+	0,							/* U+0014C3 */
+	0,							/* U+0014C4 */
+	0,							/* U+0014C5 */
+	0,							/* U+0014C6 */
+	0,							/* U+0014C7 */
+	0,							/* U+0014C8 */
+	0,							/* U+0014C9 */
+	0,							/* U+0014CA */
+	0,							/* U+0014CB */
+	0,							/* U+0014CC */
+	0,							/* U+0014CD */
+	0,							/* U+0014CE */
+	0,							/* U+0014CF */
+	0,							/* U+0014D0 */
+	0,							/* U+0014D1 */
+	0,							/* U+0014D2 */
+	0,							/* U+0014D3 */
+	0,							/* U+0014D4 */
+	0,							/* U+0014D5 */
+	0,							/* U+0014D6 */
+	0,							/* U+0014D7 */
+	0,							/* U+0014D8 */
+	0,							/* U+0014D9 */
+	0,							/* U+0014DA */
+	0,							/* U+0014DB */
+	0,							/* U+0014DC */
+	0,							/* U+0014DD */
+	0,							/* U+0014DE */
+	0,							/* U+0014DF */
+	0,							/* U+0014E0 */
+	0,							/* U+0014E1 */
+	0,							/* U+0014E2 */
+	0,							/* U+0014E3 */
+	0,							/* U+0014E4 */
+	0,							/* U+0014E5 */
+	0,							/* U+0014E6 */
+	0,							/* U+0014E7 */
+	0,							/* U+0014E8 */
+	0,							/* U+0014E9 */
+	0,							/* U+0014EA */
+	0,							/* U+0014EB */
+	0,							/* U+0014EC */
+	0,							/* U+0014ED */
+	0,							/* U+0014EE */
+	0,							/* U+0014EF */
+	0,							/* U+0014F0 */
+	0,							/* U+0014F1 */
+	0,							/* U+0014F2 */
+	0,							/* U+0014F3 */
+	0,							/* U+0014F4 */
+	0,							/* U+0014F5 */
+	0,							/* U+0014F6 */
+	0,							/* U+0014F7 */
+	0,							/* U+0014F8 */
+	0,							/* U+0014F9 */
+	0,							/* U+0014FA */
+	0,							/* U+0014FB */
+	0,							/* U+0014FC */
+	0,							/* U+0014FD */
+	0,							/* U+0014FE */
+	0,							/* U+0014FF */
+	0,							/* U+001500 */
+	0,							/* U+001501 */
+	0,							/* U+001502 */
+	0,							/* U+001503 */
+	0,							/* U+001504 */
+	0,							/* U+001505 */
+	0,							/* U+001506 */
+	0,							/* U+001507 */
+	0,							/* U+001508 */
+	0,							/* U+001509 */
+	0,							/* U+00150A */
+	0,							/* U+00150B */
+	0,							/* U+00150C */
+	0,							/* U+00150D */
+	0,							/* U+00150E */
+	0,							/* U+00150F */
+	0,							/* U+001510 */
+	0,							/* U+001511 */
+	0,							/* U+001512 */
+	0,							/* U+001513 */
+	0,							/* U+001514 */
+	0,							/* U+001515 */
+	0,							/* U+001516 */
+	0,							/* U+001517 */
+	0,							/* U+001518 */
+	0,							/* U+001519 */
+	0,							/* U+00151A */
+	0,							/* U+00151B */
+	0,							/* U+00151C */
+	0,							/* U+00151D */
+	0,							/* U+00151E */
+	0,							/* U+00151F */
+	0,							/* U+001520 */
+	0,							/* U+001521 */
+	0,							/* U+001522 */
+	0,							/* U+001523 */
+	0,							/* U+001524 */
+	0,							/* U+001525 */
+	0,							/* U+001526 */
+	0,							/* U+001527 */
+	0,							/* U+001528 */
+	0,							/* U+001529 */
+	0,							/* U+00152A */
+	0,							/* U+00152B */
+	0,							/* U+00152C */
+	0,							/* U+00152D */
+	0,							/* U+00152E */
+	0,							/* U+00152F */
+	0,							/* U+001530 */
+	0,							/* U+001531 */
+	0,							/* U+001532 */
+	0,							/* U+001533 */
+	0,							/* U+001534 */
+	0,							/* U+001535 */
+	0,							/* U+001536 */
+	0,							/* U+001537 */
+	0,							/* U+001538 */
+	0,							/* U+001539 */
+	0,							/* U+00153A */
+	0,							/* U+00153B */
+	0,							/* U+00153C */
+	0,							/* U+00153D */
+	0,							/* U+00153E */
+	0,							/* U+00153F */
+	0,							/* U+001540 */
+	0,							/* U+001541 */
+	0,							/* U+001542 */
+	0,							/* U+001543 */
+	0,							/* U+001544 */
+	0,							/* U+001545 */
+	0,							/* U+001546 */
+	0,							/* U+001547 */
+	0,							/* U+001548 */
+	0,							/* U+001549 */
+	0,							/* U+00154A */
+	0,							/* U+00154B */
+	0,							/* U+00154C */
+	0,							/* U+00154D */
+	0,							/* U+00154E */
+	0,							/* U+00154F */
+	0,							/* U+001550 */
+	0,							/* U+001551 */
+	0,							/* U+001552 */
+	0,							/* U+001553 */
+	0,							/* U+001554 */
+	0,							/* U+001555 */
+	0,							/* U+001556 */
+	0,							/* U+001557 */
+	0,							/* U+001558 */
+	0,							/* U+001559 */
+	0,							/* U+00155A */
+	0,							/* U+00155B */
+	0,							/* U+00155C */
+	0,							/* U+00155D */
+	0,							/* U+00155E */
+	0,							/* U+00155F */
+	0,							/* U+001560 */
+	0,							/* U+001561 */
+	0,							/* U+001562 */
+	0,							/* U+001563 */
+	0,							/* U+001564 */
+	0,							/* U+001565 */
+	0,							/* U+001566 */
+	0,							/* U+001567 */
+	0,							/* U+001568 */
+	0,							/* U+001569 */
+	0,							/* U+00156A */
+	0,							/* U+00156B */
+	0,							/* U+00156C */
+	0,							/* U+00156D */
+	0,							/* U+00156E */
+	0,							/* U+00156F */
+	0,							/* U+001570 */
+	0,							/* U+001571 */
+	0,							/* U+001572 */
+	0,							/* U+001573 */
+	0,							/* U+001574 */
+	0,							/* U+001575 */
+	0,							/* U+001576 */
+	0,							/* U+001577 */
+	0,							/* U+001578 */
+	0,							/* U+001579 */
+	0,							/* U+00157A */
+	0,							/* U+00157B */
+	0,							/* U+00157C */
+	0,							/* U+00157D */
+	0,							/* U+00157E */
+	0,							/* U+00157F */
+	0,							/* U+001580 */
+	0,							/* U+001581 */
+	0,							/* U+001582 */
+	0,							/* U+001583 */
+	0,							/* U+001584 */
+	0,							/* U+001585 */
+	0,							/* U+001586 */
+	0,							/* U+001587 */
+	0,							/* U+001588 */
+	0,							/* U+001589 */
+	0,							/* U+00158A */
+	0,							/* U+00158B */
+	0,							/* U+00158C */
+	0,							/* U+00158D */
+	0,							/* U+00158E */
+	0,							/* U+00158F */
+	0,							/* U+001590 */
+	0,							/* U+001591 */
+	0,							/* U+001592 */
+	0,							/* U+001593 */
+	0,							/* U+001594 */
+	0,							/* U+001595 */
+	0,							/* U+001596 */
+	0,							/* U+001597 */
+	0,							/* U+001598 */
+	0,							/* U+001599 */
+	0,							/* U+00159A */
+	0,							/* U+00159B */
+	0,							/* U+00159C */
+	0,							/* U+00159D */
+	0,							/* U+00159E */
+	0,							/* U+00159F */
+	0,							/* U+0015A0 */
+	0,							/* U+0015A1 */
+	0,							/* U+0015A2 */
+	0,							/* U+0015A3 */
+	0,							/* U+0015A4 */
+	0,							/* U+0015A5 */
+	0,							/* U+0015A6 */
+	0,							/* U+0015A7 */
+	0,							/* U+0015A8 */
+	0,							/* U+0015A9 */
+	0,							/* U+0015AA */
+	0,							/* U+0015AB */
+	0,							/* U+0015AC */
+	0,							/* U+0015AD */
+	0,							/* U+0015AE */
+	0,							/* U+0015AF */
+	0,							/* U+0015B0 */
+	0,							/* U+0015B1 */
+	0,							/* U+0015B2 */
+	0,							/* U+0015B3 */
+	0,							/* U+0015B4 */
+	0,							/* U+0015B5 */
+	0,							/* U+0015B6 */
+	0,							/* U+0015B7 */
+	0,							/* U+0015B8 */
+	0,							/* U+0015B9 */
+	0,							/* U+0015BA */
+	0,							/* U+0015BB */
+	0,							/* U+0015BC */
+	0,							/* U+0015BD */
+	0,							/* U+0015BE */
+	0,							/* U+0015BF */
+	0,							/* U+0015C0 */
+	0,							/* U+0015C1 */
+	0,							/* U+0015C2 */
+	0,							/* U+0015C3 */
+	0,							/* U+0015C4 */
+	0,							/* U+0015C5 */
+	0,							/* U+0015C6 */
+	0,							/* U+0015C7 */
+	0,							/* U+0015C8 */
+	0,							/* U+0015C9 */
+	0,							/* U+0015CA */
+	0,							/* U+0015CB */
+	0,							/* U+0015CC */
+	0,							/* U+0015CD */
+	0,							/* U+0015CE */
+	0,							/* U+0015CF */
+	0,							/* U+0015D0 */
+	0,							/* U+0015D1 */
+	0,							/* U+0015D2 */
+	0,							/* U+0015D3 */
+	0,							/* U+0015D4 */
+	0,							/* U+0015D5 */
+	0,							/* U+0015D6 */
+	0,							/* U+0015D7 */
+	0,							/* U+0015D8 */
+	0,							/* U+0015D9 */
+	0,							/* U+0015DA */
+	0,							/* U+0015DB */
+	0,							/* U+0015DC */
+	0,							/* U+0015DD */
+	0,							/* U+0015DE */
+	0,							/* U+0015DF */
+	0,							/* U+0015E0 */
+	0,							/* U+0015E1 */
+	0,							/* U+0015E2 */
+	0,							/* U+0015E3 */
+	0,							/* U+0015E4 */
+	0,							/* U+0015E5 */
+	0,							/* U+0015E6 */
+	0,							/* U+0015E7 */
+	0,							/* U+0015E8 */
+	0,							/* U+0015E9 */
+	0,							/* U+0015EA */
+	0,							/* U+0015EB */
+	0,							/* U+0015EC */
+	0,							/* U+0015ED */
+	0,							/* U+0015EE */
+	0,							/* U+0015EF */
+	0,							/* U+0015F0 */
+	0,							/* U+0015F1 */
+	0,							/* U+0015F2 */
+	0,							/* U+0015F3 */
+	0,							/* U+0015F4 */
+	0,							/* U+0015F5 */
+	0,							/* U+0015F6 */
+	0,							/* U+0015F7 */
+	0,							/* U+0015F8 */
+	0,							/* U+0015F9 */
+	0,							/* U+0015FA */
+	0,							/* U+0015FB */
+	0,							/* U+0015FC */
+	0,							/* U+0015FD */
+	0,							/* U+0015FE */
+	0,							/* U+0015FF */
+	0,							/* U+001600 */
+	0,							/* U+001601 */
+	0,							/* U+001602 */
+	0,							/* U+001603 */
+	0,							/* U+001604 */
+	0,							/* U+001605 */
+	0,							/* U+001606 */
+	0,							/* U+001607 */
+	0,							/* U+001608 */
+	0,							/* U+001609 */
+	0,							/* U+00160A */
+	0,							/* U+00160B */
+	0,							/* U+00160C */
+	0,							/* U+00160D */
+	0,							/* U+00160E */
+	0,							/* U+00160F */
+	0,							/* U+001610 */
+	0,							/* U+001611 */
+	0,							/* U+001612 */
+	0,							/* U+001613 */
+	0,							/* U+001614 */
+	0,							/* U+001615 */
+	0,							/* U+001616 */
+	0,							/* U+001617 */
+	0,							/* U+001618 */
+	0,							/* U+001619 */
+	0,							/* U+00161A */
+	0,							/* U+00161B */
+	0,							/* U+00161C */
+	0,							/* U+00161D */
+	0,							/* U+00161E */
+	0,							/* U+00161F */
+	0,							/* U+001620 */
+	0,							/* U+001621 */
+	0,							/* U+001622 */
+	0,							/* U+001623 */
+	0,							/* U+001624 */
+	0,							/* U+001625 */
+	0,							/* U+001626 */
+	0,							/* U+001627 */
+	0,							/* U+001628 */
+	0,							/* U+001629 */
+	0,							/* U+00162A */
+	0,							/* U+00162B */
+	0,							/* U+00162C */
+	0,							/* U+00162D */
+	0,							/* U+00162E */
+	0,							/* U+00162F */
+	0,							/* U+001630 */
+	0,							/* U+001631 */
+	0,							/* U+001632 */
+	0,							/* U+001633 */
+	0,							/* U+001634 */
+	0,							/* U+001635 */
+	0,							/* U+001636 */
+	0,							/* U+001637 */
+	0,							/* U+001638 */
+	0,							/* U+001639 */
+	0,							/* U+00163A */
+	0,							/* U+00163B */
+	0,							/* U+00163C */
+	0,							/* U+00163D */
+	0,							/* U+00163E */
+	0,							/* U+00163F */
+	0,							/* U+001640 */
+	0,							/* U+001641 */
+	0,							/* U+001642 */
+	0,							/* U+001643 */
+	0,							/* U+001644 */
+	0,							/* U+001645 */
+	0,							/* U+001646 */
+	0,							/* U+001647 */
+	0,							/* U+001648 */
+	0,							/* U+001649 */
+	0,							/* U+00164A */
+	0,							/* U+00164B */
+	0,							/* U+00164C */
+	0,							/* U+00164D */
+	0,							/* U+00164E */
+	0,							/* U+00164F */
+	0,							/* U+001650 */
+	0,							/* U+001651 */
+	0,							/* U+001652 */
+	0,							/* U+001653 */
+	0,							/* U+001654 */
+	0,							/* U+001655 */
+	0,							/* U+001656 */
+	0,							/* U+001657 */
+	0,							/* U+001658 */
+	0,							/* U+001659 */
+	0,							/* U+00165A */
+	0,							/* U+00165B */
+	0,							/* U+00165C */
+	0,							/* U+00165D */
+	0,							/* U+00165E */
+	0,							/* U+00165F */
+	0,							/* U+001660 */
+	0,							/* U+001661 */
+	0,							/* U+001662 */
+	0,							/* U+001663 */
+	0,							/* U+001664 */
+	0,							/* U+001665 */
+	0,							/* U+001666 */
+	0,							/* U+001667 */
+	0,							/* U+001668 */
+	0,							/* U+001669 */
+	0,							/* U+00166A */
+	0,							/* U+00166B */
+	0,							/* U+00166C */
+	0,							/* U+00166D */
+	0,							/* U+00166E */
+	0,							/* U+00166F */
+	0,							/* U+001670 */
+	0,							/* U+001671 */
+	0,							/* U+001672 */
+	0,							/* U+001673 */
+	0,							/* U+001674 */
+	0,							/* U+001675 */
+	0,							/* U+001676 */
+	0,							/* U+001677 */
+	0,							/* U+001678 */
+	0,							/* U+001679 */
+	0,							/* U+00167A */
+	0,							/* U+00167B */
+	0,							/* U+00167C */
+	0,							/* U+00167D */
+	0,							/* U+00167E */
+	0,							/* U+00167F */
+	0,							/* U+001680 */
+	0,							/* U+001681 */
+	0,							/* U+001682 */
+	0,							/* U+001683 */
+	0,							/* U+001684 */
+	0,							/* U+001685 */
+	0,							/* U+001686 */
+	0,							/* U+001687 */
+	0,							/* U+001688 */
+	0,							/* U+001689 */
+	0,							/* U+00168A */
+	0,							/* U+00168B */
+	0,							/* U+00168C */
+	0,							/* U+00168D */
+	0,							/* U+00168E */
+	0,							/* U+00168F */
+	0,							/* U+001690 */
+	0,							/* U+001691 */
+	0,							/* U+001692 */
+	0,							/* U+001693 */
+	0,							/* U+001694 */
+	0,							/* U+001695 */
+	0,							/* U+001696 */
+	0,							/* U+001697 */
+	0,							/* U+001698 */
+	0,							/* U+001699 */
+	0,							/* U+00169A */
+	0,							/* U+00169B */
+	0,							/* U+00169C */
+	0,							/* U+00169D */
+	0,							/* U+00169E */
+	0,							/* U+00169F */
+	0,							/* U+0016A0 */
+	0,							/* U+0016A1 */
+	0,							/* U+0016A2 */
+	0,							/* U+0016A3 */
+	0,							/* U+0016A4 */
+	0,							/* U+0016A5 */
+	0,							/* U+0016A6 */
+	0,							/* U+0016A7 */
+	0,							/* U+0016A8 */
+	0,							/* U+0016A9 */
+	0,							/* U+0016AA */
+	0,							/* U+0016AB */
+	0,							/* U+0016AC */
+	0,							/* U+0016AD */
+	0,							/* U+0016AE */
+	0,							/* U+0016AF */
+	0,							/* U+0016B0 */
+	0,							/* U+0016B1 */
+	0,							/* U+0016B2 */
+	0,							/* U+0016B3 */
+	0,							/* U+0016B4 */
+	0,							/* U+0016B5 */
+	0,							/* U+0016B6 */
+	0,							/* U+0016B7 */
+	0,							/* U+0016B8 */
+	0,							/* U+0016B9 */
+	0,							/* U+0016BA */
+	0,							/* U+0016BB */
+	0,							/* U+0016BC */
+	0,							/* U+0016BD */
+	0,							/* U+0016BE */
+	0,							/* U+0016BF */
+	0,							/* U+0016C0 */
+	0,							/* U+0016C1 */
+	0,							/* U+0016C2 */
+	0,							/* U+0016C3 */
+	0,							/* U+0016C4 */
+	0,							/* U+0016C5 */
+	0,							/* U+0016C6 */
+	0,							/* U+0016C7 */
+	0,							/* U+0016C8 */
+	0,							/* U+0016C9 */
+	0,							/* U+0016CA */
+	0,							/* U+0016CB */
+	0,							/* U+0016CC */
+	0,							/* U+0016CD */
+	0,							/* U+0016CE */
+	0,							/* U+0016CF */
+	0,							/* U+0016D0 */
+	0,							/* U+0016D1 */
+	0,							/* U+0016D2 */
+	0,							/* U+0016D3 */
+	0,							/* U+0016D4 */
+	0,							/* U+0016D5 */
+	0,							/* U+0016D6 */
+	0,							/* U+0016D7 */
+	0,							/* U+0016D8 */
+	0,							/* U+0016D9 */
+	0,							/* U+0016DA */
+	0,							/* U+0016DB */
+	0,							/* U+0016DC */
+	0,							/* U+0016DD */
+	0,							/* U+0016DE */
+	0,							/* U+0016DF */
+	0,							/* U+0016E0 */
+	0,							/* U+0016E1 */
+	0,							/* U+0016E2 */
+	0,							/* U+0016E3 */
+	0,							/* U+0016E4 */
+	0,							/* U+0016E5 */
+	0,							/* U+0016E6 */
+	0,							/* U+0016E7 */
+	0,							/* U+0016E8 */
+	0,							/* U+0016E9 */
+	0,							/* U+0016EA */
+	0,							/* U+0016EB */
+	0,							/* U+0016EC */
+	0,							/* U+0016ED */
+	0,							/* U+0016EE */
+	0,							/* U+0016EF */
+	0,							/* U+0016F0 */
+	0,							/* U+0016F1 */
+	0,							/* U+0016F2 */
+	0,							/* U+0016F3 */
+	0,							/* U+0016F4 */
+	0,							/* U+0016F5 */
+	0,							/* U+0016F6 */
+	0,							/* U+0016F7 */
+	0,							/* U+0016F8 */
+	0,							/* U+0016F9 */
+	0,							/* U+0016FA */
+	0,							/* U+0016FB */
+	0,							/* U+0016FC */
+	0,							/* U+0016FD */
+	0,							/* U+0016FE */
+	0,							/* U+0016FF */
+	0,							/* U+001700 */
+	0,							/* U+001701 */
+	0,							/* U+001702 */
+	0,							/* U+001703 */
+	0,							/* U+001704 */
+	0,							/* U+001705 */
+	0,							/* U+001706 */
+	0,							/* U+001707 */
+	0,							/* U+001708 */
+	0,							/* U+001709 */
+	0,							/* U+00170A */
+	0,							/* U+00170B */
+	0,							/* U+00170C */
+	0,							/* U+00170D */
+	0,							/* U+00170E */
+	0,							/* U+00170F */
+	0,							/* U+001710 */
+	0,							/* U+001711 */
+	0,							/* U+001712 */
+	0,							/* U+001713 */
+	452,						/* U+001714 */
+	452,						/* U+001715 */
+	0,							/* U+001716 */
+	0,							/* U+001717 */
+	0,							/* U+001718 */
+	0,							/* U+001719 */
+	0,							/* U+00171A */
+	0,							/* U+00171B */
+	0,							/* U+00171C */
+	0,							/* U+00171D */
+	0,							/* U+00171E */
+	0,							/* U+00171F */
+	0,							/* U+001720 */
+	0,							/* U+001721 */
+	0,							/* U+001722 */
+	0,							/* U+001723 */
+	0,							/* U+001724 */
+	0,							/* U+001725 */
+	0,							/* U+001726 */
+	0,							/* U+001727 */
+	0,							/* U+001728 */
+	0,							/* U+001729 */
+	0,							/* U+00172A */
+	0,							/* U+00172B */
+	0,							/* U+00172C */
+	0,							/* U+00172D */
+	0,							/* U+00172E */
+	0,							/* U+00172F */
+	0,							/* U+001730 */
+	0,							/* U+001731 */
+	0,							/* U+001732 */
+	0,							/* U+001733 */
+	452,						/* U+001734 */
+	0,							/* U+001735 */
+	0,							/* U+001736 */
+	0,							/* U+001737 */
+	0,							/* U+001738 */
+	0,							/* U+001739 */
+	0,							/* U+00173A */
+	0,							/* U+00173B */
+	0,							/* U+00173C */
+	0,							/* U+00173D */
+	0,							/* U+00173E */
+	0,							/* U+00173F */
+	0,							/* U+001740 */
+	0,							/* U+001741 */
+	0,							/* U+001742 */
+	0,							/* U+001743 */
+	0,							/* U+001744 */
+	0,							/* U+001745 */
+	0,							/* U+001746 */
+	0,							/* U+001747 */
+	0,							/* U+001748 */
+	0,							/* U+001749 */
+	0,							/* U+00174A */
+	0,							/* U+00174B */
+	0,							/* U+00174C */
+	0,							/* U+00174D */
+	0,							/* U+00174E */
+	0,							/* U+00174F */
+	0,							/* U+001750 */
+	0,							/* U+001751 */
+	0,							/* U+001752 */
+	0,							/* U+001753 */
+	0,							/* U+001754 */
+	0,							/* U+001755 */
+	0,							/* U+001756 */
+	0,							/* U+001757 */
+	0,							/* U+001758 */
+	0,							/* U+001759 */
+	0,							/* U+00175A */
+	0,							/* U+00175B */
+	0,							/* U+00175C */
+	0,							/* U+00175D */
+	0,							/* U+00175E */
+	0,							/* U+00175F */
+	0,							/* U+001760 */
+	0,							/* U+001761 */
+	0,							/* U+001762 */
+	0,							/* U+001763 */
+	0,							/* U+001764 */
+	0,							/* U+001765 */
+	0,							/* U+001766 */
+	0,							/* U+001767 */
+	0,							/* U+001768 */
+	0,							/* U+001769 */
+	0,							/* U+00176A */
+	0,							/* U+00176B */
+	0,							/* U+00176C */
+	0,							/* U+00176D */
+	0,							/* U+00176E */
+	0,							/* U+00176F */
+	0,							/* U+001770 */
+	0,							/* U+001771 */
+	0,							/* U+001772 */
+	0,							/* U+001773 */
+	0,							/* U+001774 */
+	0,							/* U+001775 */
+	0,							/* U+001776 */
+	0,							/* U+001777 */
+	0,							/* U+001778 */
+	0,							/* U+001779 */
+	0,							/* U+00177A */
+	0,							/* U+00177B */
+	0,							/* U+00177C */
+	0,							/* U+00177D */
+	0,							/* U+00177E */
+	0,							/* U+00177F */
+	0,							/* U+001780 */
+	0,							/* U+001781 */
+	0,							/* U+001782 */
+	0,							/* U+001783 */
+	0,							/* U+001784 */
+	0,							/* U+001785 */
+	0,							/* U+001786 */
+	0,							/* U+001787 */
+	0,							/* U+001788 */
+	0,							/* U+001789 */
+	0,							/* U+00178A */
+	0,							/* U+00178B */
+	0,							/* U+00178C */
+	0,							/* U+00178D */
+	0,							/* U+00178E */
+	0,							/* U+00178F */
+	0,							/* U+001790 */
+	0,							/* U+001791 */
+	0,							/* U+001792 */
+	0,							/* U+001793 */
+	0,							/* U+001794 */
+	0,							/* U+001795 */
+	0,							/* U+001796 */
+	0,							/* U+001797 */
+	0,							/* U+001798 */
+	0,							/* U+001799 */
+	0,							/* U+00179A */
+	0,							/* U+00179B */
+	0,							/* U+00179C */
+	0,							/* U+00179D */
+	0,							/* U+00179E */
+	0,							/* U+00179F */
+	0,							/* U+0017A0 */
+	0,							/* U+0017A1 */
+	0,							/* U+0017A2 */
+	0,							/* U+0017A3 */
+	0,							/* U+0017A4 */
+	0,							/* U+0017A5 */
+	0,							/* U+0017A6 */
+	0,							/* U+0017A7 */
+	0,							/* U+0017A8 */
+	0,							/* U+0017A9 */
+	0,							/* U+0017AA */
+	0,							/* U+0017AB */
+	0,							/* U+0017AC */
+	0,							/* U+0017AD */
+	0,							/* U+0017AE */
+	0,							/* U+0017AF */
+	0,							/* U+0017B0 */
+	0,							/* U+0017B1 */
+	0,							/* U+0017B2 */
+	0,							/* U+0017B3 */
+	0,							/* U+0017B4 */
+	0,							/* U+0017B5 */
+	0,							/* U+0017B6 */
+	0,							/* U+0017B7 */
+	0,							/* U+0017B8 */
+	0,							/* U+0017B9 */
+	0,							/* U+0017BA */
+	0,							/* U+0017BB */
+	0,							/* U+0017BC */
+	0,							/* U+0017BD */
+	0,							/* U+0017BE */
+	0,							/* U+0017BF */
+	0,							/* U+0017C0 */
+	0,							/* U+0017C1 */
+	0,							/* U+0017C2 */
+	0,							/* U+0017C3 */
+	0,							/* U+0017C4 */
+	0,							/* U+0017C5 */
+	0,							/* U+0017C6 */
+	0,							/* U+0017C7 */
+	0,							/* U+0017C8 */
+	0,							/* U+0017C9 */
+	0,							/* U+0017CA */
+	0,							/* U+0017CB */
+	0,							/* U+0017CC */
+	0,							/* U+0017CD */
+	0,							/* U+0017CE */
+	0,							/* U+0017CF */
+	0,							/* U+0017D0 */
+	0,							/* U+0017D1 */
+	452,						/* U+0017D2 */
+	0,							/* U+0017D3 */
+	0,							/* U+0017D4 */
+	0,							/* U+0017D5 */
+	0,							/* U+0017D6 */
+	0,							/* U+0017D7 */
+	0,							/* U+0017D8 */
+	0,							/* U+0017D9 */
+	0,							/* U+0017DA */
+	0,							/* U+0017DB */
+	0,							/* U+0017DC */
+	304,						/* U+0017DD */
+	0,							/* U+0017DE */
+	0,							/* U+0017DF */
+	0,							/* U+0017E0 */
+	0,							/* U+0017E1 */
+	0,							/* U+0017E2 */
+	0,							/* U+0017E3 */
+	0,							/* U+0017E4 */
+	0,							/* U+0017E5 */
+	0,							/* U+0017E6 */
+	0,							/* U+0017E7 */
+	0,							/* U+0017E8 */
+	0,							/* U+0017E9 */
+	0,							/* U+0017EA */
+	0,							/* U+0017EB */
+	0,							/* U+0017EC */
+	0,							/* U+0017ED */
+	0,							/* U+0017EE */
+	0,							/* U+0017EF */
+	0,							/* U+0017F0 */
+	0,							/* U+0017F1 */
+	0,							/* U+0017F2 */
+	0,							/* U+0017F3 */
+	0,							/* U+0017F4 */
+	0,							/* U+0017F5 */
+	0,							/* U+0017F6 */
+	0,							/* U+0017F7 */
+	0,							/* U+0017F8 */
+	0,							/* U+0017F9 */
+	0,							/* U+0017FA */
+	0,							/* U+0017FB */
+	0,							/* U+0017FC */
+	0,							/* U+0017FD */
+	0,							/* U+0017FE */
+	0,							/* U+0017FF */
+	0,							/* U+001800 */
+	0,							/* U+001801 */
+	0,							/* U+001802 */
+	0,							/* U+001803 */
+	0,							/* U+001804 */
+	0,							/* U+001805 */
+	0,							/* U+001806 */
+	0,							/* U+001807 */
+	0,							/* U+001808 */
+	0,							/* U+001809 */
+	0,							/* U+00180A */
+	0,							/* U+00180B */
+	0,							/* U+00180C */
+	0,							/* U+00180D */
+	0,							/* U+00180E */
+	0,							/* U+00180F */
+	0,							/* U+001810 */
+	0,							/* U+001811 */
+	0,							/* U+001812 */
+	0,							/* U+001813 */
+	0,							/* U+001814 */
+	0,							/* U+001815 */
+	0,							/* U+001816 */
+	0,							/* U+001817 */
+	0,							/* U+001818 */
+	0,							/* U+001819 */
+	0,							/* U+00181A */
+	0,							/* U+00181B */
+	0,							/* U+00181C */
+	0,							/* U+00181D */
+	0,							/* U+00181E */
+	0,							/* U+00181F */
+	0,							/* U+001820 */
+	0,							/* U+001821 */
+	0,							/* U+001822 */
+	0,							/* U+001823 */
+	0,							/* U+001824 */
+	0,							/* U+001825 */
+	0,							/* U+001826 */
+	0,							/* U+001827 */
+	0,							/* U+001828 */
+	0,							/* U+001829 */
+	0,							/* U+00182A */
+	0,							/* U+00182B */
+	0,							/* U+00182C */
+	0,							/* U+00182D */
+	0,							/* U+00182E */
+	0,							/* U+00182F */
+	0,							/* U+001830 */
+	0,							/* U+001831 */
+	0,							/* U+001832 */
+	0,							/* U+001833 */
+	0,							/* U+001834 */
+	0,							/* U+001835 */
+	0,							/* U+001836 */
+	0,							/* U+001837 */
+	0,							/* U+001838 */
+	0,							/* U+001839 */
+	0,							/* U+00183A */
+	0,							/* U+00183B */
+	0,							/* U+00183C */
+	0,							/* U+00183D */
+	0,							/* U+00183E */
+	0,							/* U+00183F */
+	0,							/* U+001840 */
+	0,							/* U+001841 */
+	0,							/* U+001842 */
+	0,							/* U+001843 */
+	0,							/* U+001844 */
+	0,							/* U+001845 */
+	0,							/* U+001846 */
+	0,							/* U+001847 */
+	0,							/* U+001848 */
+	0,							/* U+001849 */
+	0,							/* U+00184A */
+	0,							/* U+00184B */
+	0,							/* U+00184C */
+	0,							/* U+00184D */
+	0,							/* U+00184E */
+	0,							/* U+00184F */
+	0,							/* U+001850 */
+	0,							/* U+001851 */
+	0,							/* U+001852 */
+	0,							/* U+001853 */
+	0,							/* U+001854 */
+	0,							/* U+001855 */
+	0,							/* U+001856 */
+	0,							/* U+001857 */
+	0,							/* U+001858 */
+	0,							/* U+001859 */
+	0,							/* U+00185A */
+	0,							/* U+00185B */
+	0,							/* U+00185C */
+	0,							/* U+00185D */
+	0,							/* U+00185E */
+	0,							/* U+00185F */
+	0,							/* U+001860 */
+	0,							/* U+001861 */
+	0,							/* U+001862 */
+	0,							/* U+001863 */
+	0,							/* U+001864 */
+	0,							/* U+001865 */
+	0,							/* U+001866 */
+	0,							/* U+001867 */
+	0,							/* U+001868 */
+	0,							/* U+001869 */
+	0,							/* U+00186A */
+	0,							/* U+00186B */
+	0,							/* U+00186C */
+	0,							/* U+00186D */
+	0,							/* U+00186E */
+	0,							/* U+00186F */
+	0,							/* U+001870 */
+	0,							/* U+001871 */
+	0,							/* U+001872 */
+	0,							/* U+001873 */
+	0,							/* U+001874 */
+	0,							/* U+001875 */
+	0,							/* U+001876 */
+	0,							/* U+001877 */
+	0,							/* U+001878 */
+	0,							/* U+001879 */
+	0,							/* U+00187A */
+	0,							/* U+00187B */
+	0,							/* U+00187C */
+	0,							/* U+00187D */
+	0,							/* U+00187E */
+	0,							/* U+00187F */
+	0,							/* U+001880 */
+	0,							/* U+001881 */
+	0,							/* U+001882 */
+	0,							/* U+001883 */
+	0,							/* U+001884 */
+	0,							/* U+001885 */
+	0,							/* U+001886 */
+	0,							/* U+001887 */
+	0,							/* U+001888 */
+	0,							/* U+001889 */
+	0,							/* U+00188A */
+	0,							/* U+00188B */
+	0,							/* U+00188C */
+	0,							/* U+00188D */
+	0,							/* U+00188E */
+	0,							/* U+00188F */
+	0,							/* U+001890 */
+	0,							/* U+001891 */
+	0,							/* U+001892 */
+	0,							/* U+001893 */
+	0,							/* U+001894 */
+	0,							/* U+001895 */
+	0,							/* U+001896 */
+	0,							/* U+001897 */
+	0,							/* U+001898 */
+	0,							/* U+001899 */
+	0,							/* U+00189A */
+	0,							/* U+00189B */
+	0,							/* U+00189C */
+	0,							/* U+00189D */
+	0,							/* U+00189E */
+	0,							/* U+00189F */
+	0,							/* U+0018A0 */
+	0,							/* U+0018A1 */
+	0,							/* U+0018A2 */
+	0,							/* U+0018A3 */
+	0,							/* U+0018A4 */
+	0,							/* U+0018A5 */
+	0,							/* U+0018A6 */
+	0,							/* U+0018A7 */
+	0,							/* U+0018A8 */
+	409,						/* U+0018A9 */
+	0,							/* U+0018AA */
+	0,							/* U+0018AB */
+	0,							/* U+0018AC */
+	0,							/* U+0018AD */
+	0,							/* U+0018AE */
+	0,							/* U+0018AF */
+	0,							/* U+0018B0 */
+	0,							/* U+0018B1 */
+	0,							/* U+0018B2 */
+	0,							/* U+0018B3 */
+	0,							/* U+0018B4 */
+	0,							/* U+0018B5 */
+	0,							/* U+0018B6 */
+	0,							/* U+0018B7 */
+	0,							/* U+0018B8 */
+	0,							/* U+0018B9 */
+	0,							/* U+0018BA */
+	0,							/* U+0018BB */
+	0,							/* U+0018BC */
+	0,							/* U+0018BD */
+	0,							/* U+0018BE */
+	0,							/* U+0018BF */
+	0,							/* U+0018C0 */
+	0,							/* U+0018C1 */
+	0,							/* U+0018C2 */
+	0,							/* U+0018C3 */
+	0,							/* U+0018C4 */
+	0,							/* U+0018C5 */
+	0,							/* U+0018C6 */
+	0,							/* U+0018C7 */
+	0,							/* U+0018C8 */
+	0,							/* U+0018C9 */
+	0,							/* U+0018CA */
+	0,							/* U+0018CB */
+	0,							/* U+0018CC */
+	0,							/* U+0018CD */
+	0,							/* U+0018CE */
+	0,							/* U+0018CF */
+	0,							/* U+0018D0 */
+	0,							/* U+0018D1 */
+	0,							/* U+0018D2 */
+	0,							/* U+0018D3 */
+	0,							/* U+0018D4 */
+	0,							/* U+0018D5 */
+	0,							/* U+0018D6 */
+	0,							/* U+0018D7 */
+	0,							/* U+0018D8 */
+	0,							/* U+0018D9 */
+	0,							/* U+0018DA */
+	0,							/* U+0018DB */
+	0,							/* U+0018DC */
+	0,							/* U+0018DD */
+	0,							/* U+0018DE */
+	0,							/* U+0018DF */
+	0,							/* U+0018E0 */
+	0,							/* U+0018E1 */
+	0,							/* U+0018E2 */
+	0,							/* U+0018E3 */
+	0,							/* U+0018E4 */
+	0,							/* U+0018E5 */
+	0,							/* U+0018E6 */
+	0,							/* U+0018E7 */
+	0,							/* U+0018E8 */
+	0,							/* U+0018E9 */
+	0,							/* U+0018EA */
+	0,							/* U+0018EB */
+	0,							/* U+0018EC */
+	0,							/* U+0018ED */
+	0,							/* U+0018EE */
+	0,							/* U+0018EF */
+	0,							/* U+0018F0 */
+	0,							/* U+0018F1 */
+	0,							/* U+0018F2 */
+	0,							/* U+0018F3 */
+	0,							/* U+0018F4 */
+	0,							/* U+0018F5 */
+	0,							/* U+0018F6 */
+	0,							/* U+0018F7 */
+	0,							/* U+0018F8 */
+	0,							/* U+0018F9 */
+	0,							/* U+0018FA */
+	0,							/* U+0018FB */
+	0,							/* U+0018FC */
+	0,							/* U+0018FD */
+	0,							/* U+0018FE */
+	0,							/* U+0018FF */
+	0,							/* U+001900 */
+	0,							/* U+001901 */
+	0,							/* U+001902 */
+	0,							/* U+001903 */
+	0,							/* U+001904 */
+	0,							/* U+001905 */
+	0,							/* U+001906 */
+	0,							/* U+001907 */
+	0,							/* U+001908 */
+	0,							/* U+001909 */
+	0,							/* U+00190A */
+	0,							/* U+00190B */
+	0,							/* U+00190C */
+	0,							/* U+00190D */
+	0,							/* U+00190E */
+	0,							/* U+00190F */
+	0,							/* U+001910 */
+	0,							/* U+001911 */
+	0,							/* U+001912 */
+	0,							/* U+001913 */
+	0,							/* U+001914 */
+	0,							/* U+001915 */
+	0,							/* U+001916 */
+	0,							/* U+001917 */
+	0,							/* U+001918 */
+	0,							/* U+001919 */
+	0,							/* U+00191A */
+	0,							/* U+00191B */
+	0,							/* U+00191C */
+	0,							/* U+00191D */
+	0,							/* U+00191E */
+	0,							/* U+00191F */
+	0,							/* U+001920 */
+	0,							/* U+001921 */
+	0,							/* U+001922 */
+	0,							/* U+001923 */
+	0,							/* U+001924 */
+	0,							/* U+001925 */
+	0,							/* U+001926 */
+	0,							/* U+001927 */
+	0,							/* U+001928 */
+	0,							/* U+001929 */
+	0,							/* U+00192A */
+	0,							/* U+00192B */
+	0,							/* U+00192C */
+	0,							/* U+00192D */
+	0,							/* U+00192E */
+	0,							/* U+00192F */
+	0,							/* U+001930 */
+	0,							/* U+001931 */
+	0,							/* U+001932 */
+	0,							/* U+001933 */
+	0,							/* U+001934 */
+	0,							/* U+001935 */
+	0,							/* U+001936 */
+	0,							/* U+001937 */
+	0,							/* U+001938 */
+	408,						/* U+001939 */
+	304,						/* U+00193A */
+	306,						/* U+00193B */
+	0,							/* U+00193C */
+	0,							/* U+00193D */
+	0,							/* U+00193E */
+	0,							/* U+00193F */
+	0,							/* U+001940 */
+	0,							/* U+001941 */
+	0,							/* U+001942 */
+	0,							/* U+001943 */
+	0,							/* U+001944 */
+	0,							/* U+001945 */
+	0,							/* U+001946 */
+	0,							/* U+001947 */
+	0,							/* U+001948 */
+	0,							/* U+001949 */
+	0,							/* U+00194A */
+	0,							/* U+00194B */
+	0,							/* U+00194C */
+	0,							/* U+00194D */
+	0,							/* U+00194E */
+	0,							/* U+00194F */
+	0,							/* U+001950 */
+	0,							/* U+001951 */
+	0,							/* U+001952 */
+	0,							/* U+001953 */
+	0,							/* U+001954 */
+	0,							/* U+001955 */
+	0,							/* U+001956 */
+	0,							/* U+001957 */
+	0,							/* U+001958 */
+	0,							/* U+001959 */
+	0,							/* U+00195A */
+	0,							/* U+00195B */
+	0,							/* U+00195C */
+	0,							/* U+00195D */
+	0,							/* U+00195E */
+	0,							/* U+00195F */
+	0,							/* U+001960 */
+	0,							/* U+001961 */
+	0,							/* U+001962 */
+	0,							/* U+001963 */
+	0,							/* U+001964 */
+	0,							/* U+001965 */
+	0,							/* U+001966 */
+	0,							/* U+001967 */
+	0,							/* U+001968 */
+	0,							/* U+001969 */
+	0,							/* U+00196A */
+	0,							/* U+00196B */
+	0,							/* U+00196C */
+	0,							/* U+00196D */
+	0,							/* U+00196E */
+	0,							/* U+00196F */
+	0,							/* U+001970 */
+	0,							/* U+001971 */
+	0,							/* U+001972 */
+	0,							/* U+001973 */
+	0,							/* U+001974 */
+	0,							/* U+001975 */
+	0,							/* U+001976 */
+	0,							/* U+001977 */
+	0,							/* U+001978 */
+	0,							/* U+001979 */
+	0,							/* U+00197A */
+	0,							/* U+00197B */
+	0,							/* U+00197C */
+	0,							/* U+00197D */
+	0,							/* U+00197E */
+	0,							/* U+00197F */
+	0,							/* U+001980 */
+	0,							/* U+001981 */
+	0,							/* U+001982 */
+	0,							/* U+001983 */
+	0,							/* U+001984 */
+	0,							/* U+001985 */
+	0,							/* U+001986 */
+	0,							/* U+001987 */
+	0,							/* U+001988 */
+	0,							/* U+001989 */
+	0,							/* U+00198A */
+	0,							/* U+00198B */
+	0,							/* U+00198C */
+	0,							/* U+00198D */
+	0,							/* U+00198E */
+	0,							/* U+00198F */
+	0,							/* U+001990 */
+	0,							/* U+001991 */
+	0,							/* U+001992 */
+	0,							/* U+001993 */
+	0,							/* U+001994 */
+	0,							/* U+001995 */
+	0,							/* U+001996 */
+	0,							/* U+001997 */
+	0,							/* U+001998 */
+	0,							/* U+001999 */
+	0,							/* U+00199A */
+	0,							/* U+00199B */
+	0,							/* U+00199C */
+	0,							/* U+00199D */
+	0,							/* U+00199E */
+	0,							/* U+00199F */
+	0,							/* U+0019A0 */
+	0,							/* U+0019A1 */
+	0,							/* U+0019A2 */
+	0,							/* U+0019A3 */
+	0,							/* U+0019A4 */
+	0,							/* U+0019A5 */
+	0,							/* U+0019A6 */
+	0,							/* U+0019A7 */
+	0,							/* U+0019A8 */
+	0,							/* U+0019A9 */
+	0,							/* U+0019AA */
+	0,							/* U+0019AB */
+	0,							/* U+0019AC */
+	0,							/* U+0019AD */
+	0,							/* U+0019AE */
+	0,							/* U+0019AF */
+	0,							/* U+0019B0 */
+	0,							/* U+0019B1 */
+	0,							/* U+0019B2 */
+	0,							/* U+0019B3 */
+	0,							/* U+0019B4 */
+	0,							/* U+0019B5 */
+	0,							/* U+0019B6 */
+	0,							/* U+0019B7 */
+	0,							/* U+0019B8 */
+	0,							/* U+0019B9 */
+	0,							/* U+0019BA */
+	0,							/* U+0019BB */
+	0,							/* U+0019BC */
+	0,							/* U+0019BD */
+	0,							/* U+0019BE */
+	0,							/* U+0019BF */
+	0,							/* U+0019C0 */
+	0,							/* U+0019C1 */
+	0,							/* U+0019C2 */
+	0,							/* U+0019C3 */
+	0,							/* U+0019C4 */
+	0,							/* U+0019C5 */
+	0,							/* U+0019C6 */
+	0,							/* U+0019C7 */
+	0,							/* U+0019C8 */
+	0,							/* U+0019C9 */
+	0,							/* U+0019CA */
+	0,							/* U+0019CB */
+	0,							/* U+0019CC */
+	0,							/* U+0019CD */
+	0,							/* U+0019CE */
+	0,							/* U+0019CF */
+	0,							/* U+0019D0 */
+	0,							/* U+0019D1 */
+	0,							/* U+0019D2 */
+	0,							/* U+0019D3 */
+	0,							/* U+0019D4 */
+	0,							/* U+0019D5 */
+	0,							/* U+0019D6 */
+	0,							/* U+0019D7 */
+	0,							/* U+0019D8 */
+	0,							/* U+0019D9 */
+	0,							/* U+0019DA */
+	0,							/* U+0019DB */
+	0,							/* U+0019DC */
+	0,							/* U+0019DD */
+	0,							/* U+0019DE */
+	0,							/* U+0019DF */
+	0,							/* U+0019E0 */
+	0,							/* U+0019E1 */
+	0,							/* U+0019E2 */
+	0,							/* U+0019E3 */
+	0,							/* U+0019E4 */
+	0,							/* U+0019E5 */
+	0,							/* U+0019E6 */
+	0,							/* U+0019E7 */
+	0,							/* U+0019E8 */
+	0,							/* U+0019E9 */
+	0,							/* U+0019EA */
+	0,							/* U+0019EB */
+	0,							/* U+0019EC */
+	0,							/* U+0019ED */
+	0,							/* U+0019EE */
+	0,							/* U+0019EF */
+	0,							/* U+0019F0 */
+	0,							/* U+0019F1 */
+	0,							/* U+0019F2 */
+	0,							/* U+0019F3 */
+	0,							/* U+0019F4 */
+	0,							/* U+0019F5 */
+	0,							/* U+0019F6 */
+	0,							/* U+0019F7 */
+	0,							/* U+0019F8 */
+	0,							/* U+0019F9 */
+	0,							/* U+0019FA */
+	0,							/* U+0019FB */
+	0,							/* U+0019FC */
+	0,							/* U+0019FD */
+	0,							/* U+0019FE */
+	0,							/* U+0019FF */
+	0,							/* U+001A00 */
+	0,							/* U+001A01 */
+	0,							/* U+001A02 */
+	0,							/* U+001A03 */
+	0,							/* U+001A04 */
+	0,							/* U+001A05 */
+	0,							/* U+001A06 */
+	0,							/* U+001A07 */
+	0,							/* U+001A08 */
+	0,							/* U+001A09 */
+	0,							/* U+001A0A */
+	0,							/* U+001A0B */
+	0,							/* U+001A0C */
+	0,							/* U+001A0D */
+	0,							/* U+001A0E */
+	0,							/* U+001A0F */
+	0,							/* U+001A10 */
+	0,							/* U+001A11 */
+	0,							/* U+001A12 */
+	0,							/* U+001A13 */
+	0,							/* U+001A14 */
+	0,							/* U+001A15 */
+	0,							/* U+001A16 */
+	304,						/* U+001A17 */
+	306,						/* U+001A18 */
+	0,							/* U+001A19 */
+	0,							/* U+001A1A */
+	0,							/* U+001A1B */
+	0,							/* U+001A1C */
+	0,							/* U+001A1D */
+	0,							/* U+001A1E */
+	0,							/* U+001A1F */
+	0,							/* U+001A20 */
+	0,							/* U+001A21 */
+	0,							/* U+001A22 */
+	0,							/* U+001A23 */
+	0,							/* U+001A24 */
+	0,							/* U+001A25 */
+	0,							/* U+001A26 */
+	0,							/* U+001A27 */
+	0,							/* U+001A28 */
+	0,							/* U+001A29 */
+	0,							/* U+001A2A */
+	0,							/* U+001A2B */
+	0,							/* U+001A2C */
+	0,							/* U+001A2D */
+	0,							/* U+001A2E */
+	0,							/* U+001A2F */
+	0,							/* U+001A30 */
+	0,							/* U+001A31 */
+	0,							/* U+001A32 */
+	0,							/* U+001A33 */
+	0,							/* U+001A34 */
+	0,							/* U+001A35 */
+	0,							/* U+001A36 */
+	0,							/* U+001A37 */
+	0,							/* U+001A38 */
+	0,							/* U+001A39 */
+	0,							/* U+001A3A */
+	0,							/* U+001A3B */
+	0,							/* U+001A3C */
+	0,							/* U+001A3D */
+	0,							/* U+001A3E */
+	0,							/* U+001A3F */
+	0,							/* U+001A40 */
+	0,							/* U+001A41 */
+	0,							/* U+001A42 */
+	0,							/* U+001A43 */
+	0,							/* U+001A44 */
+	0,							/* U+001A45 */
+	0,							/* U+001A46 */
+	0,							/* U+001A47 */
+	0,							/* U+001A48 */
+	0,							/* U+001A49 */
+	0,							/* U+001A4A */
+	0,							/* U+001A4B */
+	0,							/* U+001A4C */
+	0,							/* U+001A4D */
+	0,							/* U+001A4E */
+	0,							/* U+001A4F */
+	0,							/* U+001A50 */
+	0,							/* U+001A51 */
+	0,							/* U+001A52 */
+	0,							/* U+001A53 */
+	0,							/* U+001A54 */
+	0,							/* U+001A55 */
+	0,							/* U+001A56 */
+	0,							/* U+001A57 */
+	0,							/* U+001A58 */
+	0,							/* U+001A59 */
+	0,							/* U+001A5A */
+	0,							/* U+001A5B */
+	0,							/* U+001A5C */
+	0,							/* U+001A5D */
+	0,							/* U+001A5E */
+	0,							/* U+001A5F */
+	452,						/* U+001A60 */
+	0,							/* U+001A61 */
+	0,							/* U+001A62 */
+	0,							/* U+001A63 */
+	0,							/* U+001A64 */
+	0,							/* U+001A65 */
+	0,							/* U+001A66 */
+	0,							/* U+001A67 */
+	0,							/* U+001A68 */
+	0,							/* U+001A69 */
+	0,							/* U+001A6A */
+	0,							/* U+001A6B */
+	0,							/* U+001A6C */
+	0,							/* U+001A6D */
+	0,							/* U+001A6E */
+	0,							/* U+001A6F */
+	0,							/* U+001A70 */
+	0,							/* U+001A71 */
+	0,							/* U+001A72 */
+	0,							/* U+001A73 */
+	0,							/* U+001A74 */
+	304,						/* U+001A75 */
+	304,						/* U+001A76 */
+	304,						/* U+001A77 */
+	304,						/* U+001A78 */
+	304,						/* U+001A79 */
+	304,						/* U+001A7A */
+	304,						/* U+001A7B */
+	304,						/* U+001A7C */
+	0,							/* U+001A7D */
+	0,							/* U+001A7E */
+	306,						/* U+001A7F */
+	0,							/* U+001A80 */
+	0,							/* U+001A81 */
+	0,							/* U+001A82 */
+	0,							/* U+001A83 */
+	0,							/* U+001A84 */
+	0,							/* U+001A85 */
+	0,							/* U+001A86 */
+	0,							/* U+001A87 */
+	0,							/* U+001A88 */
+	0,							/* U+001A89 */
+	0,							/* U+001A8A */
+	0,							/* U+001A8B */
+	0,							/* U+001A8C */
+	0,							/* U+001A8D */
+	0,							/* U+001A8E */
+	0,							/* U+001A8F */
+	0,							/* U+001A90 */
+	0,							/* U+001A91 */
+	0,							/* U+001A92 */
+	0,							/* U+001A93 */
+	0,							/* U+001A94 */
+	0,							/* U+001A95 */
+	0,							/* U+001A96 */
+	0,							/* U+001A97 */
+	0,							/* U+001A98 */
+	0,							/* U+001A99 */
+	0,							/* U+001A9A */
+	0,							/* U+001A9B */
+	0,							/* U+001A9C */
+	0,							/* U+001A9D */
+	0,							/* U+001A9E */
+	0,							/* U+001A9F */
+	0,							/* U+001AA0 */
+	0,							/* U+001AA1 */
+	0,							/* U+001AA2 */
+	0,							/* U+001AA3 */
+	0,							/* U+001AA4 */
+	0,							/* U+001AA5 */
+	0,							/* U+001AA6 */
+	0,							/* U+001AA7 */
+	0,							/* U+001AA8 */
+	0,							/* U+001AA9 */
+	0,							/* U+001AAA */
+	0,							/* U+001AAB */
+	0,							/* U+001AAC */
+	0,							/* U+001AAD */
+	0,							/* U+001AAE */
+	0,							/* U+001AAF */
+	304,						/* U+001AB0 */
+	304,						/* U+001AB1 */
+	304,						/* U+001AB2 */
+	304,						/* U+001AB3 */
+	304,						/* U+001AB4 */
+	306,						/* U+001AB5 */
+	306,						/* U+001AB6 */
+	306,						/* U+001AB7 */
+	306,						/* U+001AB8 */
+	306,						/* U+001AB9 */
+	306,						/* U+001ABA */
+	304,						/* U+001ABB */
+	304,						/* U+001ABC */
+	306,						/* U+001ABD */
+	0,							/* U+001ABE */
+	306,						/* U+001ABF */
+	306,						/* U+001AC0 */
+	304,						/* U+001AC1 */
+	304,						/* U+001AC2 */
+	306,						/* U+001AC3 */
+	306,						/* U+001AC4 */
+	304,						/* U+001AC5 */
+	304,						/* U+001AC6 */
+	304,						/* U+001AC7 */
+	304,						/* U+001AC8 */
+	304,						/* U+001AC9 */
+	306,						/* U+001ACA */
+	304,						/* U+001ACB */
+	304,						/* U+001ACC */
+	304,						/* U+001ACD */
+	304,						/* U+001ACE */
+	0,							/* U+001ACF */
+	0,							/* U+001AD0 */
+	0,							/* U+001AD1 */
+	0,							/* U+001AD2 */
+	0,							/* U+001AD3 */
+	0,							/* U+001AD4 */
+	0,							/* U+001AD5 */
+	0,							/* U+001AD6 */
+	0,							/* U+001AD7 */
+	0,							/* U+001AD8 */
+	0,							/* U+001AD9 */
+	0,							/* U+001ADA */
+	0,							/* U+001ADB */
+	0,							/* U+001ADC */
+	0,							/* U+001ADD */
+	0,							/* U+001ADE */
+	0,							/* U+001ADF */
+	0,							/* U+001AE0 */
+	0,							/* U+001AE1 */
+	0,							/* U+001AE2 */
+	0,							/* U+001AE3 */
+	0,							/* U+001AE4 */
+	0,							/* U+001AE5 */
+	0,							/* U+001AE6 */
+	0,							/* U+001AE7 */
+	0,							/* U+001AE8 */
+	0,							/* U+001AE9 */
+	0,							/* U+001AEA */
+	0,							/* U+001AEB */
+	0,							/* U+001AEC */
+	0,							/* U+001AED */
+	0,							/* U+001AEE */
+	0,							/* U+001AEF */
+	0,							/* U+001AF0 */
+	0,							/* U+001AF1 */
+	0,							/* U+001AF2 */
+	0,							/* U+001AF3 */
+	0,							/* U+001AF4 */
+	0,							/* U+001AF5 */
+	0,							/* U+001AF6 */
+	0,							/* U+001AF7 */
+	0,							/* U+001AF8 */
+	0,							/* U+001AF9 */
+	0,							/* U+001AFA */
+	0,							/* U+001AFB */
+	0,							/* U+001AFC */
+	0,							/* U+001AFD */
+	0,							/* U+001AFE */
+	0,							/* U+001AFF */
+	0,							/* U+001B00 */
+	0,							/* U+001B01 */
+	0,							/* U+001B02 */
+	0,							/* U+001B03 */
+	0,							/* U+001B04 */
+	0,							/* U+001B05 */
+	529,						/* U+001B06 */
+	0,							/* U+001B07 */
+	530,						/* U+001B08 */
+	0,							/* U+001B09 */
+	531,						/* U+001B0A */
+	0,							/* U+001B0B */
+	532,						/* U+001B0C */
+	0,							/* U+001B0D */
+	533,						/* U+001B0E */
+	0,							/* U+001B0F */
+	0,							/* U+001B10 */
+	0,							/* U+001B11 */
+	534,						/* U+001B12 */
+	0,							/* U+001B13 */
+	0,							/* U+001B14 */
+	0,							/* U+001B15 */
+	0,							/* U+001B16 */
+	0,							/* U+001B17 */
+	0,							/* U+001B18 */
+	0,							/* U+001B19 */
+	0,							/* U+001B1A */
+	0,							/* U+001B1B */
+	0,							/* U+001B1C */
+	0,							/* U+001B1D */
+	0,							/* U+001B1E */
+	0,							/* U+001B1F */
+	0,							/* U+001B20 */
+	0,							/* U+001B21 */
+	0,							/* U+001B22 */
+	0,							/* U+001B23 */
+	0,							/* U+001B24 */
+	0,							/* U+001B25 */
+	0,							/* U+001B26 */
+	0,							/* U+001B27 */
+	0,							/* U+001B28 */
+	0,							/* U+001B29 */
+	0,							/* U+001B2A */
+	0,							/* U+001B2B */
+	0,							/* U+001B2C */
+	0,							/* U+001B2D */
+	0,							/* U+001B2E */
+	0,							/* U+001B2F */
+	0,							/* U+001B30 */
+	0,							/* U+001B31 */
+	0,							/* U+001B32 */
+	0,							/* U+001B33 */
+	451,						/* U+001B34 */
+	0,							/* U+001B35 */
+	0,							/* U+001B36 */
+	0,							/* U+001B37 */
+	0,							/* U+001B38 */
+	0,							/* U+001B39 */
+	0,							/* U+001B3A */
+	535,						/* U+001B3B */
+	0,							/* U+001B3C */
+	536,						/* U+001B3D */
+	0,							/* U+001B3E */
+	0,							/* U+001B3F */
+	537,						/* U+001B40 */
+	538,						/* U+001B41 */
+	0,							/* U+001B42 */
+	539,						/* U+001B43 */
+	452,						/* U+001B44 */
+	0,							/* U+001B45 */
+	0,							/* U+001B46 */
+	0,							/* U+001B47 */
+	0,							/* U+001B48 */
+	0,							/* U+001B49 */
+	0,							/* U+001B4A */
+	0,							/* U+001B4B */
+	0,							/* U+001B4C */
+	0,							/* U+001B4D */
+	0,							/* U+001B4E */
+	0,							/* U+001B4F */
+	0,							/* U+001B50 */
+	0,							/* U+001B51 */
+	0,							/* U+001B52 */
+	0,							/* U+001B53 */
+	0,							/* U+001B54 */
+	0,							/* U+001B55 */
+	0,							/* U+001B56 */
+	0,							/* U+001B57 */
+	0,							/* U+001B58 */
+	0,							/* U+001B59 */
+	0,							/* U+001B5A */
+	0,							/* U+001B5B */
+	0,							/* U+001B5C */
+	0,							/* U+001B5D */
+	0,							/* U+001B5E */
+	0,							/* U+001B5F */
+	0,							/* U+001B60 */
+	0,							/* U+001B61 */
+	0,							/* U+001B62 */
+	0,							/* U+001B63 */
+	0,							/* U+001B64 */
+	0,							/* U+001B65 */
+	0,							/* U+001B66 */
+	0,							/* U+001B67 */
+	0,							/* U+001B68 */
+	0,							/* U+001B69 */
+	0,							/* U+001B6A */
+	304,						/* U+001B6B */
+	306,						/* U+001B6C */
+	304,						/* U+001B6D */
+	304,						/* U+001B6E */
+	304,						/* U+001B6F */
+	304,						/* U+001B70 */
+	304,						/* U+001B71 */
+	304,						/* U+001B72 */
+	304,						/* U+001B73 */
+	0,							/* U+001B74 */
+	0,							/* U+001B75 */
+	0,							/* U+001B76 */
+	0,							/* U+001B77 */
+	0,							/* U+001B78 */
+	0,							/* U+001B79 */
+	0,							/* U+001B7A */
+	0,							/* U+001B7B */
+	0,							/* U+001B7C */
+	0,							/* U+001B7D */
+	0,							/* U+001B7E */
+	0,							/* U+001B7F */
+	0,							/* U+001B80 */
+	0,							/* U+001B81 */
+	0,							/* U+001B82 */
+	0,							/* U+001B83 */
+	0,							/* U+001B84 */
+	0,							/* U+001B85 */
+	0,							/* U+001B86 */
+	0,							/* U+001B87 */
+	0,							/* U+001B88 */
+	0,							/* U+001B89 */
+	0,							/* U+001B8A */
+	0,							/* U+001B8B */
+	0,							/* U+001B8C */
+	0,							/* U+001B8D */
+	0,							/* U+001B8E */
+	0,							/* U+001B8F */
+	0,							/* U+001B90 */
+	0,							/* U+001B91 */
+	0,							/* U+001B92 */
+	0,							/* U+001B93 */
+	0,							/* U+001B94 */
+	0,							/* U+001B95 */
+	0,							/* U+001B96 */
+	0,							/* U+001B97 */
+	0,							/* U+001B98 */
+	0,							/* U+001B99 */
+	0,							/* U+001B9A */
+	0,							/* U+001B9B */
+	0,							/* U+001B9C */
+	0,							/* U+001B9D */
+	0,							/* U+001B9E */
+	0,							/* U+001B9F */
+	0,							/* U+001BA0 */
+	0,							/* U+001BA1 */
+	0,							/* U+001BA2 */
+	0,							/* U+001BA3 */
+	0,							/* U+001BA4 */
+	0,							/* U+001BA5 */
+	0,							/* U+001BA6 */
+	0,							/* U+001BA7 */
+	0,							/* U+001BA8 */
+	0,							/* U+001BA9 */
+	452,						/* U+001BAA */
+	452,						/* U+001BAB */
+	0,							/* U+001BAC */
+	0,							/* U+001BAD */
+	0,							/* U+001BAE */
+	0,							/* U+001BAF */
+	0,							/* U+001BB0 */
+	0,							/* U+001BB1 */
+	0,							/* U+001BB2 */
+	0,							/* U+001BB3 */
+	0,							/* U+001BB4 */
+	0,							/* U+001BB5 */
+	0,							/* U+001BB6 */
+	0,							/* U+001BB7 */
+	0,							/* U+001BB8 */
+	0,							/* U+001BB9 */
+	0,							/* U+001BBA */
+	0,							/* U+001BBB */
+	0,							/* U+001BBC */
+	0,							/* U+001BBD */
+	0,							/* U+001BBE */
+	0,							/* U+001BBF */
+	0,							/* U+001BC0 */
+	0,							/* U+001BC1 */
+	0,							/* U+001BC2 */
+	0,							/* U+001BC3 */
+	0,							/* U+001BC4 */
+	0,							/* U+001BC5 */
+	0,							/* U+001BC6 */
+	0,							/* U+001BC7 */
+	0,							/* U+001BC8 */
+	0,							/* U+001BC9 */
+	0,							/* U+001BCA */
+	0,							/* U+001BCB */
+	0,							/* U+001BCC */
+	0,							/* U+001BCD */
+	0,							/* U+001BCE */
+	0,							/* U+001BCF */
+	0,							/* U+001BD0 */
+	0,							/* U+001BD1 */
+	0,							/* U+001BD2 */
+	0,							/* U+001BD3 */
+	0,							/* U+001BD4 */
+	0,							/* U+001BD5 */
+	0,							/* U+001BD6 */
+	0,							/* U+001BD7 */
+	0,							/* U+001BD8 */
+	0,							/* U+001BD9 */
+	0,							/* U+001BDA */
+	0,							/* U+001BDB */
+	0,							/* U+001BDC */
+	0,							/* U+001BDD */
+	0,							/* U+001BDE */
+	0,							/* U+001BDF */
+	0,							/* U+001BE0 */
+	0,							/* U+001BE1 */
+	0,							/* U+001BE2 */
+	0,							/* U+001BE3 */
+	0,							/* U+001BE4 */
+	0,							/* U+001BE5 */
+	451,						/* U+001BE6 */
+	0,							/* U+001BE7 */
+	0,							/* U+001BE8 */
+	0,							/* U+001BE9 */
+	0,							/* U+001BEA */
+	0,							/* U+001BEB */
+	0,							/* U+001BEC */
+	0,							/* U+001BED */
+	0,							/* U+001BEE */
+	0,							/* U+001BEF */
+	0,							/* U+001BF0 */
+	0,							/* U+001BF1 */
+	452,						/* U+001BF2 */
+	452,						/* U+001BF3 */
+	0,							/* U+001BF4 */
+	0,							/* U+001BF5 */
+	0,							/* U+001BF6 */
+	0,							/* U+001BF7 */
+	0,							/* U+001BF8 */
+	0,							/* U+001BF9 */
+	0,							/* U+001BFA */
+	0,							/* U+001BFB */
+	0,							/* U+001BFC */
+	0,							/* U+001BFD */
+	0,							/* U+001BFE */
+	0,							/* U+001BFF */
+	0,							/* U+001C00 */
+	0,							/* U+001C01 */
+	0,							/* U+001C02 */
+	0,							/* U+001C03 */
+	0,							/* U+001C04 */
+	0,							/* U+001C05 */
+	0,							/* U+001C06 */
+	0,							/* U+001C07 */
+	0,							/* U+001C08 */
+	0,							/* U+001C09 */
+	0,							/* U+001C0A */
+	0,							/* U+001C0B */
+	0,							/* U+001C0C */
+	0,							/* U+001C0D */
+	0,							/* U+001C0E */
+	0,							/* U+001C0F */
+	0,							/* U+001C10 */
+	0,							/* U+001C11 */
+	0,							/* U+001C12 */
+	0,							/* U+001C13 */
+	0,							/* U+001C14 */
+	0,							/* U+001C15 */
+	0,							/* U+001C16 */
+	0,							/* U+001C17 */
+	0,							/* U+001C18 */
+	0,							/* U+001C19 */
+	0,							/* U+001C1A */
+	0,							/* U+001C1B */
+	0,							/* U+001C1C */
+	0,							/* U+001C1D */
+	0,							/* U+001C1E */
+	0,							/* U+001C1F */
+	0,							/* U+001C20 */
+	0,							/* U+001C21 */
+	0,							/* U+001C22 */
+	0,							/* U+001C23 */
+	0,							/* U+001C24 */
+	0,							/* U+001C25 */
+	0,							/* U+001C26 */
+	0,							/* U+001C27 */
+	0,							/* U+001C28 */
+	0,							/* U+001C29 */
+	0,							/* U+001C2A */
+	0,							/* U+001C2B */
+	0,							/* U+001C2C */
+	0,							/* U+001C2D */
+	0,							/* U+001C2E */
+	0,							/* U+001C2F */
+	0,							/* U+001C30 */
+	0,							/* U+001C31 */
+	0,							/* U+001C32 */
+	0,							/* U+001C33 */
+	0,							/* U+001C34 */
+	0,							/* U+001C35 */
+	0,							/* U+001C36 */
+	451,						/* U+001C37 */
+	0,							/* U+001C38 */
+	0,							/* U+001C39 */
+	0,							/* U+001C3A */
+	0,							/* U+001C3B */
+	0,							/* U+001C3C */
+	0,							/* U+001C3D */
+	0,							/* U+001C3E */
+	0,							/* U+001C3F */
+	0,							/* U+001C40 */
+	0,							/* U+001C41 */
+	0,							/* U+001C42 */
+	0,							/* U+001C43 */
+	0,							/* U+001C44 */
+	0,							/* U+001C45 */
+	0,							/* U+001C46 */
+	0,							/* U+001C47 */
+	0,							/* U+001C48 */
+	0,							/* U+001C49 */
+	0,							/* U+001C4A */
+	0,							/* U+001C4B */
+	0,							/* U+001C4C */
+	0,							/* U+001C4D */
+	0,							/* U+001C4E */
+	0,							/* U+001C4F */
+	0,							/* U+001C50 */
+	0,							/* U+001C51 */
+	0,							/* U+001C52 */
+	0,							/* U+001C53 */
+	0,							/* U+001C54 */
+	0,							/* U+001C55 */
+	0,							/* U+001C56 */
+	0,							/* U+001C57 */
+	0,							/* U+001C58 */
+	0,							/* U+001C59 */
+	0,							/* U+001C5A */
+	0,							/* U+001C5B */
+	0,							/* U+001C5C */
+	0,							/* U+001C5D */
+	0,							/* U+001C5E */
+	0,							/* U+001C5F */
+	0,							/* U+001C60 */
+	0,							/* U+001C61 */
+	0,							/* U+001C62 */
+	0,							/* U+001C63 */
+	0,							/* U+001C64 */
+	0,							/* U+001C65 */
+	0,							/* U+001C66 */
+	0,							/* U+001C67 */
+	0,							/* U+001C68 */
+	0,							/* U+001C69 */
+	0,							/* U+001C6A */
+	0,							/* U+001C6B */
+	0,							/* U+001C6C */
+	0,							/* U+001C6D */
+	0,							/* U+001C6E */
+	0,							/* U+001C6F */
+	0,							/* U+001C70 */
+	0,							/* U+001C71 */
+	0,							/* U+001C72 */
+	0,							/* U+001C73 */
+	0,							/* U+001C74 */
+	0,							/* U+001C75 */
+	0,							/* U+001C76 */
+	0,							/* U+001C77 */
+	0,							/* U+001C78 */
+	0,							/* U+001C79 */
+	0,							/* U+001C7A */
+	0,							/* U+001C7B */
+	0,							/* U+001C7C */
+	0,							/* U+001C7D */
+	0,							/* U+001C7E */
+	0,							/* U+001C7F */
+	0,							/* U+001C80 */
+	0,							/* U+001C81 */
+	0,							/* U+001C82 */
+	0,							/* U+001C83 */
+	0,							/* U+001C84 */
+	0,							/* U+001C85 */
+	0,							/* U+001C86 */
+	0,							/* U+001C87 */
+	0,							/* U+001C88 */
+	0,							/* U+001C89 */
+	0,							/* U+001C8A */
+	0,							/* U+001C8B */
+	0,							/* U+001C8C */
+	0,							/* U+001C8D */
+	0,							/* U+001C8E */
+	0,							/* U+001C8F */
+	0,							/* U+001C90 */
+	0,							/* U+001C91 */
+	0,							/* U+001C92 */
+	0,							/* U+001C93 */
+	0,							/* U+001C94 */
+	0,							/* U+001C95 */
+	0,							/* U+001C96 */
+	0,							/* U+001C97 */
+	0,							/* U+001C98 */
+	0,							/* U+001C99 */
+	0,							/* U+001C9A */
+	0,							/* U+001C9B */
+	0,							/* U+001C9C */
+	0,							/* U+001C9D */
+	0,							/* U+001C9E */
+	0,							/* U+001C9F */
+	0,							/* U+001CA0 */
+	0,							/* U+001CA1 */
+	0,							/* U+001CA2 */
+	0,							/* U+001CA3 */
+	0,							/* U+001CA4 */
+	0,							/* U+001CA5 */
+	0,							/* U+001CA6 */
+	0,							/* U+001CA7 */
+	0,							/* U+001CA8 */
+	0,							/* U+001CA9 */
+	0,							/* U+001CAA */
+	0,							/* U+001CAB */
+	0,							/* U+001CAC */
+	0,							/* U+001CAD */
+	0,							/* U+001CAE */
+	0,							/* U+001CAF */
+	0,							/* U+001CB0 */
+	0,							/* U+001CB1 */
+	0,							/* U+001CB2 */
+	0,							/* U+001CB3 */
+	0,							/* U+001CB4 */
+	0,							/* U+001CB5 */
+	0,							/* U+001CB6 */
+	0,							/* U+001CB7 */
+	0,							/* U+001CB8 */
+	0,							/* U+001CB9 */
+	0,							/* U+001CBA */
+	0,							/* U+001CBB */
+	0,							/* U+001CBC */
+	0,							/* U+001CBD */
+	0,							/* U+001CBE */
+	0,							/* U+001CBF */
+	0,							/* U+001CC0 */
+	0,							/* U+001CC1 */
+	0,							/* U+001CC2 */
+	0,							/* U+001CC3 */
+	0,							/* U+001CC4 */
+	0,							/* U+001CC5 */
+	0,							/* U+001CC6 */
+	0,							/* U+001CC7 */
+	0,							/* U+001CC8 */
+	0,							/* U+001CC9 */
+	0,							/* U+001CCA */
+	0,							/* U+001CCB */
+	0,							/* U+001CCC */
+	0,							/* U+001CCD */
+	0,							/* U+001CCE */
+	0,							/* U+001CCF */
+	304,						/* U+001CD0 */
+	304,						/* U+001CD1 */
+	304,						/* U+001CD2 */
+	0,							/* U+001CD3 */
+	309,						/* U+001CD4 */
+	306,						/* U+001CD5 */
+	306,						/* U+001CD6 */
+	306,						/* U+001CD7 */
+	306,						/* U+001CD8 */
+	306,						/* U+001CD9 */
+	304,						/* U+001CDA */
+	304,						/* U+001CDB */
+	306,						/* U+001CDC */
+	306,						/* U+001CDD */
+	306,						/* U+001CDE */
+	306,						/* U+001CDF */
+	304,						/* U+001CE0 */
+	0,							/* U+001CE1 */
+	309,						/* U+001CE2 */
+	309,						/* U+001CE3 */
+	309,						/* U+001CE4 */
+	309,						/* U+001CE5 */
+	309,						/* U+001CE6 */
+	309,						/* U+001CE7 */
+	309,						/* U+001CE8 */
+	0,							/* U+001CE9 */
+	0,							/* U+001CEA */
+	0,							/* U+001CEB */
+	0,							/* U+001CEC */
+	306,						/* U+001CED */
+	0,							/* U+001CEE */
+	0,							/* U+001CEF */
+	0,							/* U+001CF0 */
+	0,							/* U+001CF1 */
+	0,							/* U+001CF2 */
+	0,							/* U+001CF3 */
+	304,						/* U+001CF4 */
+	0,							/* U+001CF5 */
+	0,							/* U+001CF6 */
+	0,							/* U+001CF7 */
+	304,						/* U+001CF8 */
+	304,						/* U+001CF9 */
+	0,							/* U+001CFA */
+	0,							/* U+001CFB */
+	0,							/* U+001CFC */
+	0,							/* U+001CFD */
+	0,							/* U+001CFE */
+	0,							/* U+001CFF */
+	0,							/* U+001D00 */
+	0,							/* U+001D01 */
+	0,							/* U+001D02 */
+	0,							/* U+001D03 */
+	0,							/* U+001D04 */
+	0,							/* U+001D05 */
+	0,							/* U+001D06 */
+	0,							/* U+001D07 */
+	0,							/* U+001D08 */
+	0,							/* U+001D09 */
+	0,							/* U+001D0A */
+	0,							/* U+001D0B */
+	0,							/* U+001D0C */
+	0,							/* U+001D0D */
+	0,							/* U+001D0E */
+	0,							/* U+001D0F */
+	0,							/* U+001D10 */
+	0,							/* U+001D11 */
+	0,							/* U+001D12 */
+	0,							/* U+001D13 */
+	0,							/* U+001D14 */
+	0,							/* U+001D15 */
+	0,							/* U+001D16 */
+	0,							/* U+001D17 */
+	0,							/* U+001D18 */
+	0,							/* U+001D19 */
+	0,							/* U+001D1A */
+	0,							/* U+001D1B */
+	0,							/* U+001D1C */
+	0,							/* U+001D1D */
+	0,							/* U+001D1E */
+	0,							/* U+001D1F */
+	0,							/* U+001D20 */
+	0,							/* U+001D21 */
+	0,							/* U+001D22 */
+	0,							/* U+001D23 */
+	0,							/* U+001D24 */
+	0,							/* U+001D25 */
+	0,							/* U+001D26 */
+	0,							/* U+001D27 */
+	0,							/* U+001D28 */
+	0,							/* U+001D29 */
+	0,							/* U+001D2A */
+	0,							/* U+001D2B */
+	540,						/* U+001D2C */
+	541,						/* U+001D2D */
+	542,						/* U+001D2E */
+	0,							/* U+001D2F */
+	543,						/* U+001D30 */
+	544,						/* U+001D31 */
+	545,						/* U+001D32 */
+	546,						/* U+001D33 */
+	547,						/* U+001D34 */
+	548,						/* U+001D35 */
+	549,						/* U+001D36 */
+	550,						/* U+001D37 */
+	551,						/* U+001D38 */
+	552,						/* U+001D39 */
+	553,						/* U+001D3A */
+	0,							/* U+001D3B */
+	554,						/* U+001D3C */
+	555,						/* U+001D3D */
+	556,						/* U+001D3E */
+	557,						/* U+001D3F */
+	558,						/* U+001D40 */
+	559,						/* U+001D41 */
+	560,						/* U+001D42 */
+	3,							/* U+001D43 */
+	561,						/* U+001D44 */
+	562,						/* U+001D45 */
+	563,						/* U+001D46 */
+	564,						/* U+001D47 */
+	565,						/* U+001D48 */
+	566,						/* U+001D49 */
+	567,						/* U+001D4A */
+	568,						/* U+001D4B */
+	569,						/* U+001D4C */
+	570,						/* U+001D4D */
+	0,							/* U+001D4E */
+	571,						/* U+001D4F */
+	572,						/* U+001D50 */
+	573,						/* U+001D51 */
+	11,							/* U+001D52 */
+	574,						/* U+001D53 */
+	575,						/* U+001D54 */
+	576,						/* U+001D55 */
+	577,						/* U+001D56 */
+	578,						/* U+001D57 */
+	579,						/* U+001D58 */
+	580,						/* U+001D59 */
+	581,						/* U+001D5A */
+	582,						/* U+001D5B */
+	583,						/* U+001D5C */
+	342,						/* U+001D5D */
+	584,						/* U+001D5E */
+	585,						/* U+001D5F */
+	347,						/* U+001D60 */
+	586,						/* U+001D61 */
+	587,						/* U+001D62 */
+	288,						/* U+001D63 */
+	579,						/* U+001D64 */
+	582,						/* U+001D65 */
+	342,						/* U+001D66 */
+	584,						/* U+001D67 */
+	350,						/* U+001D68 */
+	347,						/* U+001D69 */
+	586,						/* U+001D6A */
+	0,							/* U+001D6B */
+	0,							/* U+001D6C */
+	0,							/* U+001D6D */
+	0,							/* U+001D6E */
+	0,							/* U+001D6F */
+	0,							/* U+001D70 */
+	0,							/* U+001D71 */
+	0,							/* U+001D72 */
+	0,							/* U+001D73 */
+	0,							/* U+001D74 */
+	0,							/* U+001D75 */
+	0,							/* U+001D76 */
+	0,							/* U+001D77 */
+	588,						/* U+001D78 */
+	0,							/* U+001D79 */
+	0,							/* U+001D7A */
+	0,							/* U+001D7B */
+	0,							/* U+001D7C */
+	0,							/* U+001D7D */
+	0,							/* U+001D7E */
+	0,							/* U+001D7F */
+	0,							/* U+001D80 */
+	0,							/* U+001D81 */
+	0,							/* U+001D82 */
+	0,							/* U+001D83 */
+	0,							/* U+001D84 */
+	0,							/* U+001D85 */
+	0,							/* U+001D86 */
+	0,							/* U+001D87 */
+	0,							/* U+001D88 */
+	0,							/* U+001D89 */
+	0,							/* U+001D8A */
+	0,							/* U+001D8B */
+	0,							/* U+001D8C */
+	0,							/* U+001D8D */
+	0,							/* U+001D8E */
+	0,							/* U+001D8F */
+	0,							/* U+001D90 */
+	0,							/* U+001D91 */
+	0,							/* U+001D92 */
+	0,							/* U+001D93 */
+	0,							/* U+001D94 */
+	0,							/* U+001D95 */
+	0,							/* U+001D96 */
+	0,							/* U+001D97 */
+	0,							/* U+001D98 */
+	0,							/* U+001D99 */
+	0,							/* U+001D9A */
+	589,						/* U+001D9B */
+	590,						/* U+001D9C */
+	591,						/* U+001D9D */
+	592,						/* U+001D9E */
+	569,						/* U+001D9F */
+	593,						/* U+001DA0 */
+	594,						/* U+001DA1 */
+	595,						/* U+001DA2 */
+	596,						/* U+001DA3 */
+	597,						/* U+001DA4 */
+	598,						/* U+001DA5 */
+	599,						/* U+001DA6 */
+	600,						/* U+001DA7 */
+	601,						/* U+001DA8 */
+	602,						/* U+001DA9 */
+	603,						/* U+001DAA */
+	604,						/* U+001DAB */
+	605,						/* U+001DAC */
+	606,						/* U+001DAD */
+	607,						/* U+001DAE */
+	608,						/* U+001DAF */
+	609,						/* U+001DB0 */
+	610,						/* U+001DB1 */
+	611,						/* U+001DB2 */
+	612,						/* U+001DB3 */
+	613,						/* U+001DB4 */
+	614,						/* U+001DB5 */
+	615,						/* U+001DB6 */
+	616,						/* U+001DB7 */
+	617,						/* U+001DB8 */
+	618,						/* U+001DB9 */
+	619,						/* U+001DBA */
+	620,						/* U+001DBB */
+	621,						/* U+001DBC */
+	622,						/* U+001DBD */
+	623,						/* U+001DBE */
+	343,						/* U+001DBF */
+	304,						/* U+001DC0 */
+	304,						/* U+001DC1 */
+	306,						/* U+001DC2 */
+	304,						/* U+001DC3 */
+	304,						/* U+001DC4 */
+	304,						/* U+001DC5 */
+	304,						/* U+001DC6 */
+	304,						/* U+001DC7 */
+	304,						/* U+001DC8 */
+	304,						/* U+001DC9 */
+	306,						/* U+001DCA */
+	304,						/* U+001DCB */
+	304,						/* U+001DCC */
+	316,						/* U+001DCD */
+	624,						/* U+001DCE */
+	306,						/* U+001DCF */
+	308,						/* U+001DD0 */
+	304,						/* U+001DD1 */
+	304,						/* U+001DD2 */
+	304,						/* U+001DD3 */
+	304,						/* U+001DD4 */
+	304,						/* U+001DD5 */
+	304,						/* U+001DD6 */
+	304,						/* U+001DD7 */
+	304,						/* U+001DD8 */
+	304,						/* U+001DD9 */
+	304,						/* U+001DDA */
+	304,						/* U+001DDB */
+	304,						/* U+001DDC */
+	304,						/* U+001DDD */
+	304,						/* U+001DDE */
+	304,						/* U+001DDF */
+	304,						/* U+001DE0 */
+	304,						/* U+001DE1 */
+	304,						/* U+001DE2 */
+	304,						/* U+001DE3 */
+	304,						/* U+001DE4 */
+	304,						/* U+001DE5 */
+	304,						/* U+001DE6 */
+	304,						/* U+001DE7 */
+	304,						/* U+001DE8 */
+	304,						/* U+001DE9 */
+	304,						/* U+001DEA */
+	304,						/* U+001DEB */
+	304,						/* U+001DEC */
+	304,						/* U+001DED */
+	304,						/* U+001DEE */
+	304,						/* U+001DEF */
+	304,						/* U+001DF0 */
+	304,						/* U+001DF1 */
+	304,						/* U+001DF2 */
+	304,						/* U+001DF3 */
+	304,						/* U+001DF4 */
+	304,						/* U+001DF5 */
+	305,						/* U+001DF6 */
+	409,						/* U+001DF7 */
+	409,						/* U+001DF8 */
+	306,						/* U+001DF9 */
+	625,						/* U+001DFA */
+	304,						/* U+001DFB */
+	315,						/* U+001DFC */
+	306,						/* U+001DFD */
+	304,						/* U+001DFE */
+	306,						/* U+001DFF */
+	626,						/* U+001E00 */
+	627,						/* U+001E01 */
+	628,						/* U+001E02 */
+	629,						/* U+001E03 */
+	630,						/* U+001E04 */
+	631,						/* U+001E05 */
+	632,						/* U+001E06 */
+	633,						/* U+001E07 */
+	634,						/* U+001E08 */
+	635,						/* U+001E09 */
+	636,						/* U+001E0A */
+	637,						/* U+001E0B */
+	638,						/* U+001E0C */
+	639,						/* U+001E0D */
+	640,						/* U+001E0E */
+	641,						/* U+001E0F */
+	642,						/* U+001E10 */
+	643,						/* U+001E11 */
+	644,						/* U+001E12 */
+	645,						/* U+001E13 */
+	646,						/* U+001E14 */
+	647,						/* U+001E15 */
+	648,						/* U+001E16 */
+	649,						/* U+001E17 */
+	650,						/* U+001E18 */
+	651,						/* U+001E19 */
+	652,						/* U+001E1A */
+	653,						/* U+001E1B */
+	654,						/* U+001E1C */
+	655,						/* U+001E1D */
+	656,						/* U+001E1E */
+	657,						/* U+001E1F */
+	658,						/* U+001E20 */
+	659,						/* U+001E21 */
+	660,						/* U+001E22 */
+	661,						/* U+001E23 */
+	662,						/* U+001E24 */
+	663,						/* U+001E25 */
+	664,						/* U+001E26 */
+	665,						/* U+001E27 */
+	666,						/* U+001E28 */
+	667,						/* U+001E29 */
+	668,						/* U+001E2A */
+	669,						/* U+001E2B */
+	670,						/* U+001E2C */
+	671,						/* U+001E2D */
+	672,						/* U+001E2E */
+	673,						/* U+001E2F */
+	674,						/* U+001E30 */
+	675,						/* U+001E31 */
+	676,						/* U+001E32 */
+	677,						/* U+001E33 */
+	678,						/* U+001E34 */
+	679,						/* U+001E35 */
+	680,						/* U+001E36 */
+	681,						/* U+001E37 */
+	682,						/* U+001E38 */
+	683,						/* U+001E39 */
+	684,						/* U+001E3A */
+	685,						/* U+001E3B */
+	686,						/* U+001E3C */
+	687,						/* U+001E3D */
+	688,						/* U+001E3E */
+	689,						/* U+001E3F */
+	690,						/* U+001E40 */
+	691,						/* U+001E41 */
+	692,						/* U+001E42 */
+	693,						/* U+001E43 */
+	694,						/* U+001E44 */
+	695,						/* U+001E45 */
+	696,						/* U+001E46 */
+	697,						/* U+001E47 */
+	698,						/* U+001E48 */
+	699,						/* U+001E49 */
+	700,						/* U+001E4A */
+	701,						/* U+001E4B */
+	702,						/* U+001E4C */
+	703,						/* U+001E4D */
+	704,						/* U+001E4E */
+	705,						/* U+001E4F */
+	706,						/* U+001E50 */
+	707,						/* U+001E51 */
+	708,						/* U+001E52 */
+	709,						/* U+001E53 */
+	710,						/* U+001E54 */
+	711,						/* U+001E55 */
+	712,						/* U+001E56 */
+	713,						/* U+001E57 */
+	714,						/* U+001E58 */
+	715,						/* U+001E59 */
+	716,						/* U+001E5A */
+	717,						/* U+001E5B */
+	718,						/* U+001E5C */
+	719,						/* U+001E5D */
+	720,						/* U+001E5E */
+	721,						/* U+001E5F */
+	722,						/* U+001E60 */
+	723,						/* U+001E61 */
+	724,						/* U+001E62 */
+	725,						/* U+001E63 */
+	726,						/* U+001E64 */
+	727,						/* U+001E65 */
+	728,						/* U+001E66 */
+	729,						/* U+001E67 */
+	730,						/* U+001E68 */
+	731,						/* U+001E69 */
+	732,						/* U+001E6A */
+	733,						/* U+001E6B */
+	734,						/* U+001E6C */
+	735,						/* U+001E6D */
+	736,						/* U+001E6E */
+	737,						/* U+001E6F */
+	738,						/* U+001E70 */
+	739,						/* U+001E71 */
+	740,						/* U+001E72 */
+	741,						/* U+001E73 */
+	742,						/* U+001E74 */
+	743,						/* U+001E75 */
+	744,						/* U+001E76 */
+	745,						/* U+001E77 */
+	746,						/* U+001E78 */
+	747,						/* U+001E79 */
+	748,						/* U+001E7A */
+	749,						/* U+001E7B */
+	750,						/* U+001E7C */
+	751,						/* U+001E7D */
+	752,						/* U+001E7E */
+	753,						/* U+001E7F */
+	754,						/* U+001E80 */
+	755,						/* U+001E81 */
+	756,						/* U+001E82 */
+	757,						/* U+001E83 */
+	758,						/* U+001E84 */
+	759,						/* U+001E85 */
+	760,						/* U+001E86 */
+	761,						/* U+001E87 */
+	762,						/* U+001E88 */
+	763,						/* U+001E89 */
+	764,						/* U+001E8A */
+	765,						/* U+001E8B */
+	766,						/* U+001E8C */
+	767,						/* U+001E8D */
+	768,						/* U+001E8E */
+	769,						/* U+001E8F */
+	770,						/* U+001E90 */
+	771,						/* U+001E91 */
+	772,						/* U+001E92 */
+	773,						/* U+001E93 */
+	774,						/* U+001E94 */
+	775,						/* U+001E95 */
+	776,						/* U+001E96 */
+	777,						/* U+001E97 */
+	778,						/* U+001E98 */
+	779,						/* U+001E99 */
+	780,						/* U+001E9A */
+	781,						/* U+001E9B */
+	0,							/* U+001E9C */
+	0,							/* U+001E9D */
+	0,							/* U+001E9E */
+	0,							/* U+001E9F */
+	782,						/* U+001EA0 */
+	783,						/* U+001EA1 */
+	784,						/* U+001EA2 */
+	785,						/* U+001EA3 */
+	786,						/* U+001EA4 */
+	787,						/* U+001EA5 */
+	788,						/* U+001EA6 */
+	789,						/* U+001EA7 */
+	790,						/* U+001EA8 */
+	791,						/* U+001EA9 */
+	792,						/* U+001EAA */
+	793,						/* U+001EAB */
+	794,						/* U+001EAC */
+	795,						/* U+001EAD */
+	796,						/* U+001EAE */
+	797,						/* U+001EAF */
+	798,						/* U+001EB0 */
+	799,						/* U+001EB1 */
+	800,						/* U+001EB2 */
+	801,						/* U+001EB3 */
+	802,						/* U+001EB4 */
+	803,						/* U+001EB5 */
+	804,						/* U+001EB6 */
+	805,						/* U+001EB7 */
+	806,						/* U+001EB8 */
+	807,						/* U+001EB9 */
+	808,						/* U+001EBA */
+	809,						/* U+001EBB */
+	810,						/* U+001EBC */
+	811,						/* U+001EBD */
+	812,						/* U+001EBE */
+	813,						/* U+001EBF */
+	814,						/* U+001EC0 */
+	815,						/* U+001EC1 */
+	816,						/* U+001EC2 */
+	817,						/* U+001EC3 */
+	818,						/* U+001EC4 */
+	819,						/* U+001EC5 */
+	820,						/* U+001EC6 */
+	821,						/* U+001EC7 */
+	822,						/* U+001EC8 */
+	823,						/* U+001EC9 */
+	824,						/* U+001ECA */
+	825,						/* U+001ECB */
+	826,						/* U+001ECC */
+	827,						/* U+001ECD */
+	828,						/* U+001ECE */
+	829,						/* U+001ECF */
+	830,						/* U+001ED0 */
+	831,						/* U+001ED1 */
+	832,						/* U+001ED2 */
+	833,						/* U+001ED3 */
+	834,						/* U+001ED4 */
+	835,						/* U+001ED5 */
+	836,						/* U+001ED6 */
+	837,						/* U+001ED7 */
+	838,						/* U+001ED8 */
+	839,						/* U+001ED9 */
+	840,						/* U+001EDA */
+	841,						/* U+001EDB */
+	842,						/* U+001EDC */
+	843,						/* U+001EDD */
+	844,						/* U+001EDE */
+	845,						/* U+001EDF */
+	846,						/* U+001EE0 */
+	847,						/* U+001EE1 */
+	848,						/* U+001EE2 */
+	849,						/* U+001EE3 */
+	850,						/* U+001EE4 */
+	851,						/* U+001EE5 */
+	852,						/* U+001EE6 */
+	853,						/* U+001EE7 */
+	854,						/* U+001EE8 */
+	855,						/* U+001EE9 */
+	856,						/* U+001EEA */
+	857,						/* U+001EEB */
+	858,						/* U+001EEC */
+	859,						/* U+001EED */
+	860,						/* U+001EEE */
+	861,						/* U+001EEF */
+	862,						/* U+001EF0 */
+	863,						/* U+001EF1 */
+	864,						/* U+001EF2 */
+	865,						/* U+001EF3 */
+	866,						/* U+001EF4 */
+	867,						/* U+001EF5 */
+	868,						/* U+001EF6 */
+	869,						/* U+001EF7 */
+	870,						/* U+001EF8 */
+	871,						/* U+001EF9 */
+	0,							/* U+001EFA */
+	0,							/* U+001EFB */
+	0,							/* U+001EFC */
+	0,							/* U+001EFD */
+	0,							/* U+001EFE */
+	0,							/* U+001EFF */
+	872,						/* U+001F00 */
+	873,						/* U+001F01 */
+	874,						/* U+001F02 */
+	875,						/* U+001F03 */
+	876,						/* U+001F04 */
+	877,						/* U+001F05 */
+	878,						/* U+001F06 */
+	879,						/* U+001F07 */
+	880,						/* U+001F08 */
+	881,						/* U+001F09 */
+	882,						/* U+001F0A */
+	883,						/* U+001F0B */
+	884,						/* U+001F0C */
+	885,						/* U+001F0D */
+	886,						/* U+001F0E */
+	887,						/* U+001F0F */
+	888,						/* U+001F10 */
+	889,						/* U+001F11 */
+	890,						/* U+001F12 */
+	891,						/* U+001F13 */
+	892,						/* U+001F14 */
+	893,						/* U+001F15 */
+	0,							/* U+001F16 */
+	0,							/* U+001F17 */
+	894,						/* U+001F18 */
+	895,						/* U+001F19 */
+	896,						/* U+001F1A */
+	897,						/* U+001F1B */
+	898,						/* U+001F1C */
+	899,						/* U+001F1D */
+	0,							/* U+001F1E */
+	0,							/* U+001F1F */
+	900,						/* U+001F20 */
+	901,						/* U+001F21 */
+	902,						/* U+001F22 */
+	903,						/* U+001F23 */
+	904,						/* U+001F24 */
+	905,						/* U+001F25 */
+	906,						/* U+001F26 */
+	907,						/* U+001F27 */
+	908,						/* U+001F28 */
+	909,						/* U+001F29 */
+	910,						/* U+001F2A */
+	911,						/* U+001F2B */
+	912,						/* U+001F2C */
+	913,						/* U+001F2D */
+	914,						/* U+001F2E */
+	915,						/* U+001F2F */
+	916,						/* U+001F30 */
+	917,						/* U+001F31 */
+	918,						/* U+001F32 */
+	919,						/* U+001F33 */
+	920,						/* U+001F34 */
+	921,						/* U+001F35 */
+	922,						/* U+001F36 */
+	923,						/* U+001F37 */
+	924,						/* U+001F38 */
+	925,						/* U+001F39 */
+	926,						/* U+001F3A */
+	927,						/* U+001F3B */
+	928,						/* U+001F3C */
+	929,						/* U+001F3D */
+	930,						/* U+001F3E */
+	931,						/* U+001F3F */
+	932,						/* U+001F40 */
+	933,						/* U+001F41 */
+	934,						/* U+001F42 */
+	935,						/* U+001F43 */
+	936,						/* U+001F44 */
+	937,						/* U+001F45 */
+	0,							/* U+001F46 */
+	0,							/* U+001F47 */
+	938,						/* U+001F48 */
+	939,						/* U+001F49 */
+	940,						/* U+001F4A */
+	941,						/* U+001F4B */
+	942,						/* U+001F4C */
+	943,						/* U+001F4D */
+	0,							/* U+001F4E */
+	0,							/* U+001F4F */
+	944,						/* U+001F50 */
+	945,						/* U+001F51 */
+	946,						/* U+001F52 */
+	947,						/* U+001F53 */
+	948,						/* U+001F54 */
+	949,						/* U+001F55 */
+	950,						/* U+001F56 */
+	951,						/* U+001F57 */
+	0,							/* U+001F58 */
+	952,						/* U+001F59 */
+	0,							/* U+001F5A */
+	953,						/* U+001F5B */
+	0,							/* U+001F5C */
+	954,						/* U+001F5D */
+	0,							/* U+001F5E */
+	955,						/* U+001F5F */
+	956,						/* U+001F60 */
+	957,						/* U+001F61 */
+	958,						/* U+001F62 */
+	959,						/* U+001F63 */
+	960,						/* U+001F64 */
+	961,						/* U+001F65 */
+	962,						/* U+001F66 */
+	963,						/* U+001F67 */
+	964,						/* U+001F68 */
+	965,						/* U+001F69 */
+	966,						/* U+001F6A */
+	967,						/* U+001F6B */
+	968,						/* U+001F6C */
+	969,						/* U+001F6D */
+	970,						/* U+001F6E */
+	971,						/* U+001F6F */
+	972,						/* U+001F70 */
+	973,						/* U+001F71 */
+	974,						/* U+001F72 */
+	975,						/* U+001F73 */
+	976,						/* U+001F74 */
+	977,						/* U+001F75 */
+	978,						/* U+001F76 */
+	979,						/* U+001F77 */
+	980,						/* U+001F78 */
+	981,						/* U+001F79 */
+	982,						/* U+001F7A */
+	983,						/* U+001F7B */
+	984,						/* U+001F7C */
+	985,						/* U+001F7D */
+	0,							/* U+001F7E */
+	0,							/* U+001F7F */
+	986,						/* U+001F80 */
+	987,						/* U+001F81 */
+	988,						/* U+001F82 */
+	989,						/* U+001F83 */
+	990,						/* U+001F84 */
+	991,						/* U+001F85 */
+	992,						/* U+001F86 */
+	993,						/* U+001F87 */
+	994,						/* U+001F88 */
+	995,						/* U+001F89 */
+	996,						/* U+001F8A */
+	997,						/* U+001F8B */
+	998,						/* U+001F8C */
+	999,						/* U+001F8D */
+	1000,						/* U+001F8E */
+	1001,						/* U+001F8F */
+	1002,						/* U+001F90 */
+	1003,						/* U+001F91 */
+	1004,						/* U+001F92 */
+	1005,						/* U+001F93 */
+	1006,						/* U+001F94 */
+	1007,						/* U+001F95 */
+	1008,						/* U+001F96 */
+	1009,						/* U+001F97 */
+	1010,						/* U+001F98 */
+	1011,						/* U+001F99 */
+	1012,						/* U+001F9A */
+	1013,						/* U+001F9B */
+	1014,						/* U+001F9C */
+	1015,						/* U+001F9D */
+	1016,						/* U+001F9E */
+	1017,						/* U+001F9F */
+	1018,						/* U+001FA0 */
+	1019,						/* U+001FA1 */
+	1020,						/* U+001FA2 */
+	1021,						/* U+001FA3 */
+	1022,						/* U+001FA4 */
+	1023,						/* U+001FA5 */
+	1024,						/* U+001FA6 */
+	1025,						/* U+001FA7 */
+	1026,						/* U+001FA8 */
+	1027,						/* U+001FA9 */
+	1028,						/* U+001FAA */
+	1029,						/* U+001FAB */
+	1030,						/* U+001FAC */
+	1031,						/* U+001FAD */
+	1032,						/* U+001FAE */
+	1033,						/* U+001FAF */
+	1034,						/* U+001FB0 */
+	1035,						/* U+001FB1 */
+	1036,						/* U+001FB2 */
+	1037,						/* U+001FB3 */
+	1038,						/* U+001FB4 */
+	0,							/* U+001FB5 */
+	1039,						/* U+001FB6 */
+	1040,						/* U+001FB7 */
+	1041,						/* U+001FB8 */
+	1042,						/* U+001FB9 */
+	1043,						/* U+001FBA */
+	1044,						/* U+001FBB */
+	1045,						/* U+001FBC */
+	1046,						/* U+001FBD */
+	1047,						/* U+001FBE */
+	1046,						/* U+001FBF */
+	1048,						/* U+001FC0 */
+	1049,						/* U+001FC1 */
+	1050,						/* U+001FC2 */
+	1051,						/* U+001FC3 */
+	1052,						/* U+001FC4 */
+	0,							/* U+001FC5 */
+	1053,						/* U+001FC6 */
+	1054,						/* U+001FC7 */
+	1055,						/* U+001FC8 */
+	1056,						/* U+001FC9 */
+	1057,						/* U+001FCA */
+	1058,						/* U+001FCB */
+	1059,						/* U+001FCC */
+	1060,						/* U+001FCD */
+	1061,						/* U+001FCE */
+	1062,						/* U+001FCF */
+	1063,						/* U+001FD0 */
+	1064,						/* U+001FD1 */
+	1065,						/* U+001FD2 */
+	1066,						/* U+001FD3 */
+	0,							/* U+001FD4 */
+	0,							/* U+001FD5 */
+	1067,						/* U+001FD6 */
+	1068,						/* U+001FD7 */
+	1069,						/* U+001FD8 */
+	1070,						/* U+001FD9 */
+	1071,						/* U+001FDA */
+	1072,						/* U+001FDB */
+	0,							/* U+001FDC */
+	1073,						/* U+001FDD */
+	1074,						/* U+001FDE */
+	1075,						/* U+001FDF */
+	1076,						/* U+001FE0 */
+	1077,						/* U+001FE1 */
+	1078,						/* U+001FE2 */
+	1079,						/* U+001FE3 */
+	1080,						/* U+001FE4 */
+	1081,						/* U+001FE5 */
+	1082,						/* U+001FE6 */
+	1083,						/* U+001FE7 */
+	1084,						/* U+001FE8 */
+	1085,						/* U+001FE9 */
+	1086,						/* U+001FEA */
+	1087,						/* U+001FEB */
+	1088,						/* U+001FEC */
+	1089,						/* U+001FED */
+	1090,						/* U+001FEE */
+	1091,						/* U+001FEF */
+	0,							/* U+001FF0 */
+	0,							/* U+001FF1 */
+	1092,						/* U+001FF2 */
+	1093,						/* U+001FF3 */
+	1094,						/* U+001FF4 */
+	0,							/* U+001FF5 */
+	1095,						/* U+001FF6 */
+	1096,						/* U+001FF7 */
+	1097,						/* U+001FF8 */
+	1098,						/* U+001FF9 */
+	1099,						/* U+001FFA */
+	1100,						/* U+001FFB */
+	1101,						/* U+001FFC */
+	1102,						/* U+001FFD */
+	1103,						/* U+001FFE */
+	0,							/* U+001FFF */
+	1104,						/* U+002000 */
+	1105,						/* U+002001 */
+	1,							/* U+002002 */
+	1,							/* U+002003 */
+	1,							/* U+002004 */
+	1,							/* U+002005 */
+	1,							/* U+002006 */
+	1,							/* U+002007 */
+	1,							/* U+002008 */
+	1,							/* U+002009 */
+	1,							/* U+00200A */
+	0,							/* U+00200B */
+	0,							/* U+00200C */
+	0,							/* U+00200D */
+	0,							/* U+00200E */
+	0,							/* U+00200F */
+	0,							/* U+002010 */
+	1106,						/* U+002011 */
+	0,							/* U+002012 */
+	0,							/* U+002013 */
+	0,							/* U+002014 */
+	0,							/* U+002015 */
+	0,							/* U+002016 */
+	1107,						/* U+002017 */
+	0,							/* U+002018 */
+	0,							/* U+002019 */
+	0,							/* U+00201A */
+	0,							/* U+00201B */
+	0,							/* U+00201C */
+	0,							/* U+00201D */
+	0,							/* U+00201E */
+	0,							/* U+00201F */
+	0,							/* U+002020 */
+	0,							/* U+002021 */
+	0,							/* U+002022 */
+	0,							/* U+002023 */
+	1108,						/* U+002024 */
+	1109,						/* U+002025 */
+	1110,						/* U+002026 */
+	0,							/* U+002027 */
+	0,							/* U+002028 */
+	0,							/* U+002029 */
+	0,							/* U+00202A */
+	0,							/* U+00202B */
+	0,							/* U+00202C */
+	0,							/* U+00202D */
+	0,							/* U+00202E */
+	1,							/* U+00202F */
+	0,							/* U+002030 */
+	0,							/* U+002031 */
+	0,							/* U+002032 */
+	1111,						/* U+002033 */
+	1112,						/* U+002034 */
+	0,							/* U+002035 */
+	1113,						/* U+002036 */
+	1114,						/* U+002037 */
+	0,							/* U+002038 */
+	0,							/* U+002039 */
+	0,							/* U+00203A */
+	0,							/* U+00203B */
+	1115,						/* U+00203C */
+	0,							/* U+00203D */
+	1116,						/* U+00203E */
+	0,							/* U+00203F */
+	0,							/* U+002040 */
+	0,							/* U+002041 */
+	0,							/* U+002042 */
+	0,							/* U+002043 */
+	0,							/* U+002044 */
+	0,							/* U+002045 */
+	0,							/* U+002046 */
+	1117,						/* U+002047 */
+	1118,						/* U+002048 */
+	1119,						/* U+002049 */
+	0,							/* U+00204A */
+	0,							/* U+00204B */
+	0,							/* U+00204C */
+	0,							/* U+00204D */
+	0,							/* U+00204E */
+	0,							/* U+00204F */
+	0,							/* U+002050 */
+	0,							/* U+002051 */
+	0,							/* U+002052 */
+	0,							/* U+002053 */
+	0,							/* U+002054 */
+	0,							/* U+002055 */
+	0,							/* U+002056 */
+	1120,						/* U+002057 */
+	0,							/* U+002058 */
+	0,							/* U+002059 */
+	0,							/* U+00205A */
+	0,							/* U+00205B */
+	0,							/* U+00205C */
+	0,							/* U+00205D */
+	0,							/* U+00205E */
+	1,							/* U+00205F */
+	0,							/* U+002060 */
+	0,							/* U+002061 */
+	0,							/* U+002062 */
+	0,							/* U+002063 */
+	0,							/* U+002064 */
+	0,							/* U+002065 */
+	0,							/* U+002066 */
+	0,							/* U+002067 */
+	0,							/* U+002068 */
+	0,							/* U+002069 */
+	0,							/* U+00206A */
+	0,							/* U+00206B */
+	0,							/* U+00206C */
+	0,							/* U+00206D */
+	0,							/* U+00206E */
+	0,							/* U+00206F */
+	1121,						/* U+002070 */
+	587,						/* U+002071 */
+	0,							/* U+002072 */
+	0,							/* U+002073 */
+	1122,						/* U+002074 */
+	1123,						/* U+002075 */
+	1124,						/* U+002076 */
+	1125,						/* U+002077 */
+	1126,						/* U+002078 */
+	1127,						/* U+002079 */
+	1128,						/* U+00207A */
+	1129,						/* U+00207B */
+	1130,						/* U+00207C */
+	1131,						/* U+00207D */
+	1132,						/* U+00207E */
+	1133,						/* U+00207F */
+	1121,						/* U+002080 */
+	10,							/* U+002081 */
+	5,							/* U+002082 */
+	6,							/* U+002083 */
+	1122,						/* U+002084 */
+	1123,						/* U+002085 */
+	1124,						/* U+002086 */
+	1125,						/* U+002087 */
+	1126,						/* U+002088 */
+	1127,						/* U+002089 */
+	1128,						/* U+00208A */
+	1129,						/* U+00208B */
+	1130,						/* U+00208C */
+	1131,						/* U+00208D */
+	1132,						/* U+00208E */
+	0,							/* U+00208F */
+	3,							/* U+002090 */
+	566,						/* U+002091 */
+	11,							/* U+002092 */
+	302,						/* U+002093 */
+	567,						/* U+002094 */
+	285,						/* U+002095 */
+	571,						/* U+002096 */
+	301,						/* U+002097 */
+	572,						/* U+002098 */
+	1133,						/* U+002099 */
+	577,						/* U+00209A */
+	181,						/* U+00209B */
+	578,						/* U+00209C */
+	0,							/* U+00209D */
+	0,							/* U+00209E */
+	0,							/* U+00209F */
+	0,							/* U+0020A0 */
+	0,							/* U+0020A1 */
+	0,							/* U+0020A2 */
+	0,							/* U+0020A3 */
+	0,							/* U+0020A4 */
+	0,							/* U+0020A5 */
+	0,							/* U+0020A6 */
+	0,							/* U+0020A7 */
+	1134,						/* U+0020A8 */
+	0,							/* U+0020A9 */
+	0,							/* U+0020AA */
+	0,							/* U+0020AB */
+	0,							/* U+0020AC */
+	0,							/* U+0020AD */
+	0,							/* U+0020AE */
+	0,							/* U+0020AF */
+	0,							/* U+0020B0 */
+	0,							/* U+0020B1 */
+	0,							/* U+0020B2 */
+	0,							/* U+0020B3 */
+	0,							/* U+0020B4 */
+	0,							/* U+0020B5 */
+	0,							/* U+0020B6 */
+	0,							/* U+0020B7 */
+	0,							/* U+0020B8 */
+	0,							/* U+0020B9 */
+	0,							/* U+0020BA */
+	0,							/* U+0020BB */
+	0,							/* U+0020BC */
+	0,							/* U+0020BD */
+	0,							/* U+0020BE */
+	0,							/* U+0020BF */
+	0,							/* U+0020C0 */
+	0,							/* U+0020C1 */
+	0,							/* U+0020C2 */
+	0,							/* U+0020C3 */
+	0,							/* U+0020C4 */
+	0,							/* U+0020C5 */
+	0,							/* U+0020C6 */
+	0,							/* U+0020C7 */
+	0,							/* U+0020C8 */
+	0,							/* U+0020C9 */
+	0,							/* U+0020CA */
+	0,							/* U+0020CB */
+	0,							/* U+0020CC */
+	0,							/* U+0020CD */
+	0,							/* U+0020CE */
+	0,							/* U+0020CF */
+	304,						/* U+0020D0 */
+	304,						/* U+0020D1 */
+	309,						/* U+0020D2 */
+	309,						/* U+0020D3 */
+	304,						/* U+0020D4 */
+	304,						/* U+0020D5 */
+	304,						/* U+0020D6 */
+	304,						/* U+0020D7 */
+	309,						/* U+0020D8 */
+	309,						/* U+0020D9 */
+	309,						/* U+0020DA */
+	304,						/* U+0020DB */
+	304,						/* U+0020DC */
+	0,							/* U+0020DD */
+	0,							/* U+0020DE */
+	0,							/* U+0020DF */
+	0,							/* U+0020E0 */
+	304,						/* U+0020E1 */
+	0,							/* U+0020E2 */
+	0,							/* U+0020E3 */
+	0,							/* U+0020E4 */
+	309,						/* U+0020E5 */
+	309,						/* U+0020E6 */
+	304,						/* U+0020E7 */
+	306,						/* U+0020E8 */
+	304,						/* U+0020E9 */
+	309,						/* U+0020EA */
+	309,						/* U+0020EB */
+	306,						/* U+0020EC */
+	306,						/* U+0020ED */
+	306,						/* U+0020EE */
+	306,						/* U+0020EF */
+	304,						/* U+0020F0 */
+	0,							/* U+0020F1 */
+	0,							/* U+0020F2 */
+	0,							/* U+0020F3 */
+	0,							/* U+0020F4 */
+	0,							/* U+0020F5 */
+	0,							/* U+0020F6 */
+	0,							/* U+0020F7 */
+	0,							/* U+0020F8 */
+	0,							/* U+0020F9 */
+	0,							/* U+0020FA */
+	0,							/* U+0020FB */
+	0,							/* U+0020FC */
+	0,							/* U+0020FD */
+	0,							/* U+0020FE */
+	0,							/* U+0020FF */
+	1135,						/* U+002100 */
+	1136,						/* U+002101 */
+	1137,						/* U+002102 */
+	1138,						/* U+002103 */
+	0,							/* U+002104 */
+	1139,						/* U+002105 */
+	1140,						/* U+002106 */
+	1141,						/* U+002107 */
+	0,							/* U+002108 */
+	1142,						/* U+002109 */
+	570,						/* U+00210A */
+	547,						/* U+00210B */
+	547,						/* U+00210C */
+	547,						/* U+00210D */
+	285,						/* U+00210E */
+	1143,						/* U+00210F */
+	548,						/* U+002110 */
+	548,						/* U+002111 */
+	551,						/* U+002112 */
+	301,						/* U+002113 */
+	0,							/* U+002114 */
+	553,						/* U+002115 */
+	1144,						/* U+002116 */
+	0,							/* U+002117 */
+	0,							/* U+002118 */
+	556,						/* U+002119 */
+	1145,						/* U+00211A */
+	557,						/* U+00211B */
+	557,						/* U+00211C */
+	557,						/* U+00211D */
+	0,							/* U+00211E */
+	0,							/* U+00211F */
+	1146,						/* U+002120 */
+	1147,						/* U+002121 */
+	1148,						/* U+002122 */
+	0,							/* U+002123 */
+	1149,						/* U+002124 */
+	0,							/* U+002125 */
+	1150,						/* U+002126 */
+	0,							/* U+002127 */
+	1149,						/* U+002128 */
+	0,							/* U+002129 */
+	1151,						/* U+00212A */
+	1152,						/* U+00212B */
+	542,						/* U+00212C */
+	1137,						/* U+00212D */
+	0,							/* U+00212E */
+	566,						/* U+00212F */
+	544,						/* U+002130 */
+	1153,						/* U+002131 */
+	0,							/* U+002132 */
+	552,						/* U+002133 */
+	11,							/* U+002134 */
+	1154,						/* U+002135 */
+	1155,						/* U+002136 */
+	1156,						/* U+002137 */
+	1157,						/* U+002138 */
+	587,						/* U+002139 */
+	0,							/* U+00213A */
+	1158,						/* U+00213B */
+	348,						/* U+00213C */
+	584,						/* U+00213D */
+	1159,						/* U+00213E */
+	1160,						/* U+00213F */
+	1161,						/* U+002140 */
+	0,							/* U+002141 */
+	0,							/* U+002142 */
+	0,							/* U+002143 */
+	0,							/* U+002144 */
+	543,						/* U+002145 */
+	565,						/* U+002146 */
+	566,						/* U+002147 */
+	587,						/* U+002148 */
+	287,						/* U+002149 */
+	0,							/* U+00214A */
+	0,							/* U+00214B */
+	0,							/* U+00214C */
+	0,							/* U+00214D */
+	0,							/* U+00214E */
+	0,							/* U+00214F */
+	1162,						/* U+002150 */
+	1163,						/* U+002151 */
+	1164,						/* U+002152 */
+	1165,						/* U+002153 */
+	1166,						/* U+002154 */
+	1167,						/* U+002155 */
+	1168,						/* U+002156 */
+	1169,						/* U+002157 */
+	1170,						/* U+002158 */
+	1171,						/* U+002159 */
+	1172,						/* U+00215A */
+	1173,						/* U+00215B */
+	1174,						/* U+00215C */
+	1175,						/* U+00215D */
+	1176,						/* U+00215E */
+	1177,						/* U+00215F */
+	548,						/* U+002160 */
+	1178,						/* U+002161 */
+	1179,						/* U+002162 */
+	1180,						/* U+002163 */
+	1181,						/* U+002164 */
+	1182,						/* U+002165 */
+	1183,						/* U+002166 */
+	1184,						/* U+002167 */
+	1185,						/* U+002168 */
+	1186,						/* U+002169 */
+	1187,						/* U+00216A */
+	1188,						/* U+00216B */
+	551,						/* U+00216C */
+	1137,						/* U+00216D */
+	543,						/* U+00216E */
+	552,						/* U+00216F */
+	587,						/* U+002170 */
+	1189,						/* U+002171 */
+	1190,						/* U+002172 */
+	1191,						/* U+002173 */
+	582,						/* U+002174 */
+	1192,						/* U+002175 */
+	1193,						/* U+002176 */
+	1194,						/* U+002177 */
+	1195,						/* U+002178 */
+	302,						/* U+002179 */
+	1196,						/* U+00217A */
+	1197,						/* U+00217B */
+	301,						/* U+00217C */
+	590,						/* U+00217D */
+	565,						/* U+00217E */
+	572,						/* U+00217F */
+	0,							/* U+002180 */
+	0,							/* U+002181 */
+	0,							/* U+002182 */
+	0,							/* U+002183 */
+	0,							/* U+002184 */
+	0,							/* U+002185 */
+	0,							/* U+002186 */
+	0,							/* U+002187 */
+	0,							/* U+002188 */
+	1198,						/* U+002189 */
+	0,							/* U+00218A */
+	0,							/* U+00218B */
+	0,							/* U+00218C */
+	0,							/* U+00218D */
+	0,							/* U+00218E */
+	0,							/* U+00218F */
+	0,							/* U+002190 */
+	0,							/* U+002191 */
+	0,							/* U+002192 */
+	0,							/* U+002193 */
+	0,							/* U+002194 */
+	0,							/* U+002195 */
+	0,							/* U+002196 */
+	0,							/* U+002197 */
+	0,							/* U+002198 */
+	0,							/* U+002199 */
+	1199,						/* U+00219A */
+	1200,						/* U+00219B */
+	0,							/* U+00219C */
+	0,							/* U+00219D */
+	0,							/* U+00219E */
+	0,							/* U+00219F */
+	0,							/* U+0021A0 */
+	0,							/* U+0021A1 */
+	0,							/* U+0021A2 */
+	0,							/* U+0021A3 */
+	0,							/* U+0021A4 */
+	0,							/* U+0021A5 */
+	0,							/* U+0021A6 */
+	0,							/* U+0021A7 */
+	0,							/* U+0021A8 */
+	0,							/* U+0021A9 */
+	0,							/* U+0021AA */
+	0,							/* U+0021AB */
+	0,							/* U+0021AC */
+	0,							/* U+0021AD */
+	1201,						/* U+0021AE */
+	0,							/* U+0021AF */
+	0,							/* U+0021B0 */
+	0,							/* U+0021B1 */
+	0,							/* U+0021B2 */
+	0,							/* U+0021B3 */
+	0,							/* U+0021B4 */
+	0,							/* U+0021B5 */
+	0,							/* U+0021B6 */
+	0,							/* U+0021B7 */
+	0,							/* U+0021B8 */
+	0,							/* U+0021B9 */
+	0,							/* U+0021BA */
+	0,							/* U+0021BB */
+	0,							/* U+0021BC */
+	0,							/* U+0021BD */
+	0,							/* U+0021BE */
+	0,							/* U+0021BF */
+	0,							/* U+0021C0 */
+	0,							/* U+0021C1 */
+	0,							/* U+0021C2 */
+	0,							/* U+0021C3 */
+	0,							/* U+0021C4 */
+	0,							/* U+0021C5 */
+	0,							/* U+0021C6 */
+	0,							/* U+0021C7 */
+	0,							/* U+0021C8 */
+	0,							/* U+0021C9 */
+	0,							/* U+0021CA */
+	0,							/* U+0021CB */
+	0,							/* U+0021CC */
+	1202,						/* U+0021CD */
+	1203,						/* U+0021CE */
+	1204,						/* U+0021CF */
+	0,							/* U+0021D0 */
+	0,							/* U+0021D1 */
+	0,							/* U+0021D2 */
+	0,							/* U+0021D3 */
+	0,							/* U+0021D4 */
+	0,							/* U+0021D5 */
+	0,							/* U+0021D6 */
+	0,							/* U+0021D7 */
+	0,							/* U+0021D8 */
+	0,							/* U+0021D9 */
+	0,							/* U+0021DA */
+	0,							/* U+0021DB */
+	0,							/* U+0021DC */
+	0,							/* U+0021DD */
+	0,							/* U+0021DE */
+	0,							/* U+0021DF */
+	0,							/* U+0021E0 */
+	0,							/* U+0021E1 */
+	0,							/* U+0021E2 */
+	0,							/* U+0021E3 */
+	0,							/* U+0021E4 */
+	0,							/* U+0021E5 */
+	0,							/* U+0021E6 */
+	0,							/* U+0021E7 */
+	0,							/* U+0021E8 */
+	0,							/* U+0021E9 */
+	0,							/* U+0021EA */
+	0,							/* U+0021EB */
+	0,							/* U+0021EC */
+	0,							/* U+0021ED */
+	0,							/* U+0021EE */
+	0,							/* U+0021EF */
+	0,							/* U+0021F0 */
+	0,							/* U+0021F1 */
+	0,							/* U+0021F2 */
+	0,							/* U+0021F3 */
+	0,							/* U+0021F4 */
+	0,							/* U+0021F5 */
+	0,							/* U+0021F6 */
+	0,							/* U+0021F7 */
+	0,							/* U+0021F8 */
+	0,							/* U+0021F9 */
+	0,							/* U+0021FA */
+	0,							/* U+0021FB */
+	0,							/* U+0021FC */
+	0,							/* U+0021FD */
+	0,							/* U+0021FE */
+	0,							/* U+0021FF */
+	0,							/* U+002200 */
+	0,							/* U+002201 */
+	0,							/* U+002202 */
+	0,							/* U+002203 */
+	1205,						/* U+002204 */
+	0,							/* U+002205 */
+	0,							/* U+002206 */
+	0,							/* U+002207 */
+	0,							/* U+002208 */
+	1206,						/* U+002209 */
+	0,							/* U+00220A */
+	0,							/* U+00220B */
+	1207,						/* U+00220C */
+	0,							/* U+00220D */
+	0,							/* U+00220E */
+	0,							/* U+00220F */
+	0,							/* U+002210 */
+	0,							/* U+002211 */
+	0,							/* U+002212 */
+	0,							/* U+002213 */
+	0,							/* U+002214 */
+	0,							/* U+002215 */
+	0,							/* U+002216 */
+	0,							/* U+002217 */
+	0,							/* U+002218 */
+	0,							/* U+002219 */
+	0,							/* U+00221A */
+	0,							/* U+00221B */
+	0,							/* U+00221C */
+	0,							/* U+00221D */
+	0,							/* U+00221E */
+	0,							/* U+00221F */
+	0,							/* U+002220 */
+	0,							/* U+002221 */
+	0,							/* U+002222 */
+	0,							/* U+002223 */
+	1208,						/* U+002224 */
+	0,							/* U+002225 */
+	1209,						/* U+002226 */
+	0,							/* U+002227 */
+	0,							/* U+002228 */
+	0,							/* U+002229 */
+	0,							/* U+00222A */
+	0,							/* U+00222B */
+	1210,						/* U+00222C */
+	1211,						/* U+00222D */
+	0,							/* U+00222E */
+	1212,						/* U+00222F */
+	1213,						/* U+002230 */
+	0,							/* U+002231 */
+	0,							/* U+002232 */
+	0,							/* U+002233 */
+	0,							/* U+002234 */
+	0,							/* U+002235 */
+	0,							/* U+002236 */
+	0,							/* U+002237 */
+	0,							/* U+002238 */
+	0,							/* U+002239 */
+	0,							/* U+00223A */
+	0,							/* U+00223B */
+	0,							/* U+00223C */
+	0,							/* U+00223D */
+	0,							/* U+00223E */
+	0,							/* U+00223F */
+	0,							/* U+002240 */
+	1214,						/* U+002241 */
+	0,							/* U+002242 */
+	0,							/* U+002243 */
+	1215,						/* U+002244 */
+	0,							/* U+002245 */
+	0,							/* U+002246 */
+	1216,						/* U+002247 */
+	0,							/* U+002248 */
+	1217,						/* U+002249 */
+	0,							/* U+00224A */
+	0,							/* U+00224B */
+	0,							/* U+00224C */
+	0,							/* U+00224D */
+	0,							/* U+00224E */
+	0,							/* U+00224F */
+	0,							/* U+002250 */
+	0,							/* U+002251 */
+	0,							/* U+002252 */
+	0,							/* U+002253 */
+	0,							/* U+002254 */
+	0,							/* U+002255 */
+	0,							/* U+002256 */
+	0,							/* U+002257 */
+	0,							/* U+002258 */
+	0,							/* U+002259 */
+	0,							/* U+00225A */
+	0,							/* U+00225B */
+	0,							/* U+00225C */
+	0,							/* U+00225D */
+	0,							/* U+00225E */
+	0,							/* U+00225F */
+	1218,						/* U+002260 */
+	0,							/* U+002261 */
+	1219,						/* U+002262 */
+	0,							/* U+002263 */
+	0,							/* U+002264 */
+	0,							/* U+002265 */
+	0,							/* U+002266 */
+	0,							/* U+002267 */
+	0,							/* U+002268 */
+	0,							/* U+002269 */
+	0,							/* U+00226A */
+	0,							/* U+00226B */
+	0,							/* U+00226C */
+	1220,						/* U+00226D */
+	1221,						/* U+00226E */
+	1222,						/* U+00226F */
+	1223,						/* U+002270 */
+	1224,						/* U+002271 */
+	0,							/* U+002272 */
+	0,							/* U+002273 */
+	1225,						/* U+002274 */
+	1226,						/* U+002275 */
+	0,							/* U+002276 */
+	0,							/* U+002277 */
+	1227,						/* U+002278 */
+	1228,						/* U+002279 */
+	0,							/* U+00227A */
+	0,							/* U+00227B */
+	0,							/* U+00227C */
+	0,							/* U+00227D */
+	0,							/* U+00227E */
+	0,							/* U+00227F */
+	1229,						/* U+002280 */
+	1230,						/* U+002281 */
+	0,							/* U+002282 */
+	0,							/* U+002283 */
+	1231,						/* U+002284 */
+	1232,						/* U+002285 */
+	0,							/* U+002286 */
+	0,							/* U+002287 */
+	1233,						/* U+002288 */
+	1234,						/* U+002289 */
+	0,							/* U+00228A */
+	0,							/* U+00228B */
+	0,							/* U+00228C */
+	0,							/* U+00228D */
+	0,							/* U+00228E */
+	0,							/* U+00228F */
+	0,							/* U+002290 */
+	0,							/* U+002291 */
+	0,							/* U+002292 */
+	0,							/* U+002293 */
+	0,							/* U+002294 */
+	0,							/* U+002295 */
+	0,							/* U+002296 */
+	0,							/* U+002297 */
+	0,							/* U+002298 */
+	0,							/* U+002299 */
+	0,							/* U+00229A */
+	0,							/* U+00229B */
+	0,							/* U+00229C */
+	0,							/* U+00229D */
+	0,							/* U+00229E */
+	0,							/* U+00229F */
+	0,							/* U+0022A0 */
+	0,							/* U+0022A1 */
+	0,							/* U+0022A2 */
+	0,							/* U+0022A3 */
+	0,							/* U+0022A4 */
+	0,							/* U+0022A5 */
+	0,							/* U+0022A6 */
+	0,							/* U+0022A7 */
+	0,							/* U+0022A8 */
+	0,							/* U+0022A9 */
+	0,							/* U+0022AA */
+	0,							/* U+0022AB */
+	1235,						/* U+0022AC */
+	1236,						/* U+0022AD */
+	1237,						/* U+0022AE */
+	1238,						/* U+0022AF */
+	0,							/* U+0022B0 */
+	0,							/* U+0022B1 */
+	0,							/* U+0022B2 */
+	0,							/* U+0022B3 */
+	0,							/* U+0022B4 */
+	0,							/* U+0022B5 */
+	0,							/* U+0022B6 */
+	0,							/* U+0022B7 */
+	0,							/* U+0022B8 */
+	0,							/* U+0022B9 */
+	0,							/* U+0022BA */
+	0,							/* U+0022BB */
+	0,							/* U+0022BC */
+	0,							/* U+0022BD */
+	0,							/* U+0022BE */
+	0,							/* U+0022BF */
+	0,							/* U+0022C0 */
+	0,							/* U+0022C1 */
+	0,							/* U+0022C2 */
+	0,							/* U+0022C3 */
+	0,							/* U+0022C4 */
+	0,							/* U+0022C5 */
+	0,							/* U+0022C6 */
+	0,							/* U+0022C7 */
+	0,							/* U+0022C8 */
+	0,							/* U+0022C9 */
+	0,							/* U+0022CA */
+	0,							/* U+0022CB */
+	0,							/* U+0022CC */
+	0,							/* U+0022CD */
+	0,							/* U+0022CE */
+	0,							/* U+0022CF */
+	0,							/* U+0022D0 */
+	0,							/* U+0022D1 */
+	0,							/* U+0022D2 */
+	0,							/* U+0022D3 */
+	0,							/* U+0022D4 */
+	0,							/* U+0022D5 */
+	0,							/* U+0022D6 */
+	0,							/* U+0022D7 */
+	0,							/* U+0022D8 */
+	0,							/* U+0022D9 */
+	0,							/* U+0022DA */
+	0,							/* U+0022DB */
+	0,							/* U+0022DC */
+	0,							/* U+0022DD */
+	0,							/* U+0022DE */
+	0,							/* U+0022DF */
+	1239,						/* U+0022E0 */
+	1240,						/* U+0022E1 */
+	1241,						/* U+0022E2 */
+	1242,						/* U+0022E3 */
+	0,							/* U+0022E4 */
+	0,							/* U+0022E5 */
+	0,							/* U+0022E6 */
+	0,							/* U+0022E7 */
+	0,							/* U+0022E8 */
+	0,							/* U+0022E9 */
+	1243,						/* U+0022EA */
+	1244,						/* U+0022EB */
+	1245,						/* U+0022EC */
+	1246,						/* U+0022ED */
+	0,							/* U+0022EE */
+	0,							/* U+0022EF */
+	0,							/* U+0022F0 */
+	0,							/* U+0022F1 */
+	0,							/* U+0022F2 */
+	0,							/* U+0022F3 */
+	0,							/* U+0022F4 */
+	0,							/* U+0022F5 */
+	0,							/* U+0022F6 */
+	0,							/* U+0022F7 */
+	0,							/* U+0022F8 */
+	0,							/* U+0022F9 */
+	0,							/* U+0022FA */
+	0,							/* U+0022FB */
+	0,							/* U+0022FC */
+	0,							/* U+0022FD */
+	0,							/* U+0022FE */
+	0,							/* U+0022FF */
+	0,							/* U+002300 */
+	0,							/* U+002301 */
+	0,							/* U+002302 */
+	0,							/* U+002303 */
+	0,							/* U+002304 */
+	0,							/* U+002305 */
+	0,							/* U+002306 */
+	0,							/* U+002307 */
+	0,							/* U+002308 */
+	0,							/* U+002309 */
+	0,							/* U+00230A */
+	0,							/* U+00230B */
+	0,							/* U+00230C */
+	0,							/* U+00230D */
+	0,							/* U+00230E */
+	0,							/* U+00230F */
+	0,							/* U+002310 */
+	0,							/* U+002311 */
+	0,							/* U+002312 */
+	0,							/* U+002313 */
+	0,							/* U+002314 */
+	0,							/* U+002315 */
+	0,							/* U+002316 */
+	0,							/* U+002317 */
+	0,							/* U+002318 */
+	0,							/* U+002319 */
+	0,							/* U+00231A */
+	0,							/* U+00231B */
+	0,							/* U+00231C */
+	0,							/* U+00231D */
+	0,							/* U+00231E */
+	0,							/* U+00231F */
+	0,							/* U+002320 */
+	0,							/* U+002321 */
+	0,							/* U+002322 */
+	0,							/* U+002323 */
+	0,							/* U+002324 */
+	0,							/* U+002325 */
+	0,							/* U+002326 */
+	0,							/* U+002327 */
+	0,							/* U+002328 */
+	1247,						/* U+002329 */
+	1248,						/* U+00232A */
+	0,							/* U+00232B */
+	0,							/* U+00232C */
+	0,							/* U+00232D */
+	0,							/* U+00232E */
+	0,							/* U+00232F */
+	0,							/* U+002330 */
+	0,							/* U+002331 */
+	0,							/* U+002332 */
+	0,							/* U+002333 */
+	0,							/* U+002334 */
+	0,							/* U+002335 */
+	0,							/* U+002336 */
+	0,							/* U+002337 */
+	0,							/* U+002338 */
+	0,							/* U+002339 */
+	0,							/* U+00233A */
+	0,							/* U+00233B */
+	0,							/* U+00233C */
+	0,							/* U+00233D */
+	0,							/* U+00233E */
+	0,							/* U+00233F */
+	0,							/* U+002340 */
+	0,							/* U+002341 */
+	0,							/* U+002342 */
+	0,							/* U+002343 */
+	0,							/* U+002344 */
+	0,							/* U+002345 */
+	0,							/* U+002346 */
+	0,							/* U+002347 */
+	0,							/* U+002348 */
+	0,							/* U+002349 */
+	0,							/* U+00234A */
+	0,							/* U+00234B */
+	0,							/* U+00234C */
+	0,							/* U+00234D */
+	0,							/* U+00234E */
+	0,							/* U+00234F */
+	0,							/* U+002350 */
+	0,							/* U+002351 */
+	0,							/* U+002352 */
+	0,							/* U+002353 */
+	0,							/* U+002354 */
+	0,							/* U+002355 */
+	0,							/* U+002356 */
+	0,							/* U+002357 */
+	0,							/* U+002358 */
+	0,							/* U+002359 */
+	0,							/* U+00235A */
+	0,							/* U+00235B */
+	0,							/* U+00235C */
+	0,							/* U+00235D */
+	0,							/* U+00235E */
+	0,							/* U+00235F */
+	0,							/* U+002360 */
+	0,							/* U+002361 */
+	0,							/* U+002362 */
+	0,							/* U+002363 */
+	0,							/* U+002364 */
+	0,							/* U+002365 */
+	0,							/* U+002366 */
+	0,							/* U+002367 */
+	0,							/* U+002368 */
+	0,							/* U+002369 */
+	0,							/* U+00236A */
+	0,							/* U+00236B */
+	0,							/* U+00236C */
+	0,							/* U+00236D */
+	0,							/* U+00236E */
+	0,							/* U+00236F */
+	0,							/* U+002370 */
+	0,							/* U+002371 */
+	0,							/* U+002372 */
+	0,							/* U+002373 */
+	0,							/* U+002374 */
+	0,							/* U+002375 */
+	0,							/* U+002376 */
+	0,							/* U+002377 */
+	0,							/* U+002378 */
+	0,							/* U+002379 */
+	0,							/* U+00237A */
+	0,							/* U+00237B */
+	0,							/* U+00237C */
+	0,							/* U+00237D */
+	0,							/* U+00237E */
+	0,							/* U+00237F */
+	0,							/* U+002380 */
+	0,							/* U+002381 */
+	0,							/* U+002382 */
+	0,							/* U+002383 */
+	0,							/* U+002384 */
+	0,							/* U+002385 */
+	0,							/* U+002386 */
+	0,							/* U+002387 */
+	0,							/* U+002388 */
+	0,							/* U+002389 */
+	0,							/* U+00238A */
+	0,							/* U+00238B */
+	0,							/* U+00238C */
+	0,							/* U+00238D */
+	0,							/* U+00238E */
+	0,							/* U+00238F */
+	0,							/* U+002390 */
+	0,							/* U+002391 */
+	0,							/* U+002392 */
+	0,							/* U+002393 */
+	0,							/* U+002394 */
+	0,							/* U+002395 */
+	0,							/* U+002396 */
+	0,							/* U+002397 */
+	0,							/* U+002398 */
+	0,							/* U+002399 */
+	0,							/* U+00239A */
+	0,							/* U+00239B */
+	0,							/* U+00239C */
+	0,							/* U+00239D */
+	0,							/* U+00239E */
+	0,							/* U+00239F */
+	0,							/* U+0023A0 */
+	0,							/* U+0023A1 */
+	0,							/* U+0023A2 */
+	0,							/* U+0023A3 */
+	0,							/* U+0023A4 */
+	0,							/* U+0023A5 */
+	0,							/* U+0023A6 */
+	0,							/* U+0023A7 */
+	0,							/* U+0023A8 */
+	0,							/* U+0023A9 */
+	0,							/* U+0023AA */
+	0,							/* U+0023AB */
+	0,							/* U+0023AC */
+	0,							/* U+0023AD */
+	0,							/* U+0023AE */
+	0,							/* U+0023AF */
+	0,							/* U+0023B0 */
+	0,							/* U+0023B1 */
+	0,							/* U+0023B2 */
+	0,							/* U+0023B3 */
+	0,							/* U+0023B4 */
+	0,							/* U+0023B5 */
+	0,							/* U+0023B6 */
+	0,							/* U+0023B7 */
+	0,							/* U+0023B8 */
+	0,							/* U+0023B9 */
+	0,							/* U+0023BA */
+	0,							/* U+0023BB */
+	0,							/* U+0023BC */
+	0,							/* U+0023BD */
+	0,							/* U+0023BE */
+	0,							/* U+0023BF */
+	0,							/* U+0023C0 */
+	0,							/* U+0023C1 */
+	0,							/* U+0023C2 */
+	0,							/* U+0023C3 */
+	0,							/* U+0023C4 */
+	0,							/* U+0023C5 */
+	0,							/* U+0023C6 */
+	0,							/* U+0023C7 */
+	0,							/* U+0023C8 */
+	0,							/* U+0023C9 */
+	0,							/* U+0023CA */
+	0,							/* U+0023CB */
+	0,							/* U+0023CC */
+	0,							/* U+0023CD */
+	0,							/* U+0023CE */
+	0,							/* U+0023CF */
+	0,							/* U+0023D0 */
+	0,							/* U+0023D1 */
+	0,							/* U+0023D2 */
+	0,							/* U+0023D3 */
+	0,							/* U+0023D4 */
+	0,							/* U+0023D5 */
+	0,							/* U+0023D6 */
+	0,							/* U+0023D7 */
+	0,							/* U+0023D8 */
+	0,							/* U+0023D9 */
+	0,							/* U+0023DA */
+	0,							/* U+0023DB */
+	0,							/* U+0023DC */
+	0,							/* U+0023DD */
+	0,							/* U+0023DE */
+	0,							/* U+0023DF */
+	0,							/* U+0023E0 */
+	0,							/* U+0023E1 */
+	0,							/* U+0023E2 */
+	0,							/* U+0023E3 */
+	0,							/* U+0023E4 */
+	0,							/* U+0023E5 */
+	0,							/* U+0023E6 */
+	0,							/* U+0023E7 */
+	0,							/* U+0023E8 */
+	0,							/* U+0023E9 */
+	0,							/* U+0023EA */
+	0,							/* U+0023EB */
+	0,							/* U+0023EC */
+	0,							/* U+0023ED */
+	0,							/* U+0023EE */
+	0,							/* U+0023EF */
+	0,							/* U+0023F0 */
+	0,							/* U+0023F1 */
+	0,							/* U+0023F2 */
+	0,							/* U+0023F3 */
+	0,							/* U+0023F4 */
+	0,							/* U+0023F5 */
+	0,							/* U+0023F6 */
+	0,							/* U+0023F7 */
+	0,							/* U+0023F8 */
+	0,							/* U+0023F9 */
+	0,							/* U+0023FA */
+	0,							/* U+0023FB */
+	0,							/* U+0023FC */
+	0,							/* U+0023FD */
+	0,							/* U+0023FE */
+	0,							/* U+0023FF */
+	0,							/* U+002400 */
+	0,							/* U+002401 */
+	0,							/* U+002402 */
+	0,							/* U+002403 */
+	0,							/* U+002404 */
+	0,							/* U+002405 */
+	0,							/* U+002406 */
+	0,							/* U+002407 */
+	0,							/* U+002408 */
+	0,							/* U+002409 */
+	0,							/* U+00240A */
+	0,							/* U+00240B */
+	0,							/* U+00240C */
+	0,							/* U+00240D */
+	0,							/* U+00240E */
+	0,							/* U+00240F */
+	0,							/* U+002410 */
+	0,							/* U+002411 */
+	0,							/* U+002412 */
+	0,							/* U+002413 */
+	0,							/* U+002414 */
+	0,							/* U+002415 */
+	0,							/* U+002416 */
+	0,							/* U+002417 */
+	0,							/* U+002418 */
+	0,							/* U+002419 */
+	0,							/* U+00241A */
+	0,							/* U+00241B */
+	0,							/* U+00241C */
+	0,							/* U+00241D */
+	0,							/* U+00241E */
+	0,							/* U+00241F */
+	0,							/* U+002420 */
+	0,							/* U+002421 */
+	0,							/* U+002422 */
+	0,							/* U+002423 */
+	0,							/* U+002424 */
+	0,							/* U+002425 */
+	0,							/* U+002426 */
+	0,							/* U+002427 */
+	0,							/* U+002428 */
+	0,							/* U+002429 */
+	0,							/* U+00242A */
+	0,							/* U+00242B */
+	0,							/* U+00242C */
+	0,							/* U+00242D */
+	0,							/* U+00242E */
+	0,							/* U+00242F */
+	0,							/* U+002430 */
+	0,							/* U+002431 */
+	0,							/* U+002432 */
+	0,							/* U+002433 */
+	0,							/* U+002434 */
+	0,							/* U+002435 */
+	0,							/* U+002436 */
+	0,							/* U+002437 */
+	0,							/* U+002438 */
+	0,							/* U+002439 */
+	0,							/* U+00243A */
+	0,							/* U+00243B */
+	0,							/* U+00243C */
+	0,							/* U+00243D */
+	0,							/* U+00243E */
+	0,							/* U+00243F */
+	0,							/* U+002440 */
+	0,							/* U+002441 */
+	0,							/* U+002442 */
+	0,							/* U+002443 */
+	0,							/* U+002444 */
+	0,							/* U+002445 */
+	0,							/* U+002446 */
+	0,							/* U+002447 */
+	0,							/* U+002448 */
+	0,							/* U+002449 */
+	0,							/* U+00244A */
+	0,							/* U+00244B */
+	0,							/* U+00244C */
+	0,							/* U+00244D */
+	0,							/* U+00244E */
+	0,							/* U+00244F */
+	0,							/* U+002450 */
+	0,							/* U+002451 */
+	0,							/* U+002452 */
+	0,							/* U+002453 */
+	0,							/* U+002454 */
+	0,							/* U+002455 */
+	0,							/* U+002456 */
+	0,							/* U+002457 */
+	0,							/* U+002458 */
+	0,							/* U+002459 */
+	0,							/* U+00245A */
+	0,							/* U+00245B */
+	0,							/* U+00245C */
+	0,							/* U+00245D */
+	0,							/* U+00245E */
+	0,							/* U+00245F */
+	10,							/* U+002460 */
+	5,							/* U+002461 */
+	6,							/* U+002462 */
+	1122,						/* U+002463 */
+	1123,						/* U+002464 */
+	1124,						/* U+002465 */
+	1125,						/* U+002466 */
+	1126,						/* U+002467 */
+	1127,						/* U+002468 */
+	1249,						/* U+002469 */
+	1250,						/* U+00246A */
+	1251,						/* U+00246B */
+	1252,						/* U+00246C */
+	1253,						/* U+00246D */
+	1254,						/* U+00246E */
+	1255,						/* U+00246F */
+	1256,						/* U+002470 */
+	1257,						/* U+002471 */
+	1258,						/* U+002472 */
+	1259,						/* U+002473 */
+	1260,						/* U+002474 */
+	1261,						/* U+002475 */
+	1262,						/* U+002476 */
+	1263,						/* U+002477 */
+	1264,						/* U+002478 */
+	1265,						/* U+002479 */
+	1266,						/* U+00247A */
+	1267,						/* U+00247B */
+	1268,						/* U+00247C */
+	1269,						/* U+00247D */
+	1270,						/* U+00247E */
+	1271,						/* U+00247F */
+	1272,						/* U+002480 */
+	1273,						/* U+002481 */
+	1274,						/* U+002482 */
+	1275,						/* U+002483 */
+	1276,						/* U+002484 */
+	1277,						/* U+002485 */
+	1278,						/* U+002486 */
+	1279,						/* U+002487 */
+	1280,						/* U+002488 */
+	1281,						/* U+002489 */
+	1282,						/* U+00248A */
+	1283,						/* U+00248B */
+	1284,						/* U+00248C */
+	1285,						/* U+00248D */
+	1286,						/* U+00248E */
+	1287,						/* U+00248F */
+	1288,						/* U+002490 */
+	1289,						/* U+002491 */
+	1290,						/* U+002492 */
+	1291,						/* U+002493 */
+	1292,						/* U+002494 */
+	1293,						/* U+002495 */
+	1294,						/* U+002496 */
+	1295,						/* U+002497 */
+	1296,						/* U+002498 */
+	1297,						/* U+002499 */
+	1298,						/* U+00249A */
+	1299,						/* U+00249B */
+	1300,						/* U+00249C */
+	1301,						/* U+00249D */
+	1302,						/* U+00249E */
+	1303,						/* U+00249F */
+	1304,						/* U+0024A0 */
+	1305,						/* U+0024A1 */
+	1306,						/* U+0024A2 */
+	1307,						/* U+0024A3 */
+	1308,						/* U+0024A4 */
+	1309,						/* U+0024A5 */
+	1310,						/* U+0024A6 */
+	1311,						/* U+0024A7 */
+	1312,						/* U+0024A8 */
+	1313,						/* U+0024A9 */
+	1314,						/* U+0024AA */
+	1315,						/* U+0024AB */
+	1316,						/* U+0024AC */
+	1317,						/* U+0024AD */
+	1318,						/* U+0024AE */
+	1319,						/* U+0024AF */
+	1320,						/* U+0024B0 */
+	1321,						/* U+0024B1 */
+	1322,						/* U+0024B2 */
+	1323,						/* U+0024B3 */
+	1324,						/* U+0024B4 */
+	1325,						/* U+0024B5 */
+	540,						/* U+0024B6 */
+	542,						/* U+0024B7 */
+	1137,						/* U+0024B8 */
+	543,						/* U+0024B9 */
+	544,						/* U+0024BA */
+	1153,						/* U+0024BB */
+	546,						/* U+0024BC */
+	547,						/* U+0024BD */
+	548,						/* U+0024BE */
+	549,						/* U+0024BF */
+	550,						/* U+0024C0 */
+	551,						/* U+0024C1 */
+	552,						/* U+0024C2 */
+	553,						/* U+0024C3 */
+	554,						/* U+0024C4 */
+	556,						/* U+0024C5 */
+	1145,						/* U+0024C6 */
+	557,						/* U+0024C7 */
+	1326,						/* U+0024C8 */
+	558,						/* U+0024C9 */
+	559,						/* U+0024CA */
+	1181,						/* U+0024CB */
+	560,						/* U+0024CC */
+	1186,						/* U+0024CD */
+	1327,						/* U+0024CE */
+	1149,						/* U+0024CF */
+	3,							/* U+0024D0 */
+	564,						/* U+0024D1 */
+	590,						/* U+0024D2 */
+	565,						/* U+0024D3 */
+	566,						/* U+0024D4 */
+	593,						/* U+0024D5 */
+	570,						/* U+0024D6 */
+	285,						/* U+0024D7 */
+	587,						/* U+0024D8 */
+	287,						/* U+0024D9 */
+	571,						/* U+0024DA */
+	301,						/* U+0024DB */
+	572,						/* U+0024DC */
+	1133,						/* U+0024DD */
+	11,							/* U+0024DE */
+	577,						/* U+0024DF */
+	1328,						/* U+0024E0 */
+	288,						/* U+0024E1 */
+	181,						/* U+0024E2 */
+	578,						/* U+0024E3 */
+	579,						/* U+0024E4 */
+	582,						/* U+0024E5 */
+	292,						/* U+0024E6 */
+	302,						/* U+0024E7 */
+	293,						/* U+0024E8 */
+	620,						/* U+0024E9 */
+	1121,						/* U+0024EA */
+	0,							/* U+0024EB */
+	0,							/* U+0024EC */
+	0,							/* U+0024ED */
+	0,							/* U+0024EE */
+	0,							/* U+0024EF */
+	0,							/* U+0024F0 */
+	0,							/* U+0024F1 */
+	0,							/* U+0024F2 */
+	0,							/* U+0024F3 */
+	0,							/* U+0024F4 */
+	0,							/* U+0024F5 */
+	0,							/* U+0024F6 */
+	0,							/* U+0024F7 */
+	0,							/* U+0024F8 */
+	0,							/* U+0024F9 */
+	0,							/* U+0024FA */
+	0,							/* U+0024FB */
+	0,							/* U+0024FC */
+	0,							/* U+0024FD */
+	0,							/* U+0024FE */
+	0,							/* U+0024FF */
+	0,							/* U+002500 */
+	0,							/* U+002501 */
+	0,							/* U+002502 */
+	0,							/* U+002503 */
+	0,							/* U+002504 */
+	0,							/* U+002505 */
+	0,							/* U+002506 */
+	0,							/* U+002507 */
+	0,							/* U+002508 */
+	0,							/* U+002509 */
+	0,							/* U+00250A */
+	0,							/* U+00250B */
+	0,							/* U+00250C */
+	0,							/* U+00250D */
+	0,							/* U+00250E */
+	0,							/* U+00250F */
+	0,							/* U+002510 */
+	0,							/* U+002511 */
+	0,							/* U+002512 */
+	0,							/* U+002513 */
+	0,							/* U+002514 */
+	0,							/* U+002515 */
+	0,							/* U+002516 */
+	0,							/* U+002517 */
+	0,							/* U+002518 */
+	0,							/* U+002519 */
+	0,							/* U+00251A */
+	0,							/* U+00251B */
+	0,							/* U+00251C */
+	0,							/* U+00251D */
+	0,							/* U+00251E */
+	0,							/* U+00251F */
+	0,							/* U+002520 */
+	0,							/* U+002521 */
+	0,							/* U+002522 */
+	0,							/* U+002523 */
+	0,							/* U+002524 */
+	0,							/* U+002525 */
+	0,							/* U+002526 */
+	0,							/* U+002527 */
+	0,							/* U+002528 */
+	0,							/* U+002529 */
+	0,							/* U+00252A */
+	0,							/* U+00252B */
+	0,							/* U+00252C */
+	0,							/* U+00252D */
+	0,							/* U+00252E */
+	0,							/* U+00252F */
+	0,							/* U+002530 */
+	0,							/* U+002531 */
+	0,							/* U+002532 */
+	0,							/* U+002533 */
+	0,							/* U+002534 */
+	0,							/* U+002535 */
+	0,							/* U+002536 */
+	0,							/* U+002537 */
+	0,							/* U+002538 */
+	0,							/* U+002539 */
+	0,							/* U+00253A */
+	0,							/* U+00253B */
+	0,							/* U+00253C */
+	0,							/* U+00253D */
+	0,							/* U+00253E */
+	0,							/* U+00253F */
+	0,							/* U+002540 */
+	0,							/* U+002541 */
+	0,							/* U+002542 */
+	0,							/* U+002543 */
+	0,							/* U+002544 */
+	0,							/* U+002545 */
+	0,							/* U+002546 */
+	0,							/* U+002547 */
+	0,							/* U+002548 */
+	0,							/* U+002549 */
+	0,							/* U+00254A */
+	0,							/* U+00254B */
+	0,							/* U+00254C */
+	0,							/* U+00254D */
+	0,							/* U+00254E */
+	0,							/* U+00254F */
+	0,							/* U+002550 */
+	0,							/* U+002551 */
+	0,							/* U+002552 */
+	0,							/* U+002553 */
+	0,							/* U+002554 */
+	0,							/* U+002555 */
+	0,							/* U+002556 */
+	0,							/* U+002557 */
+	0,							/* U+002558 */
+	0,							/* U+002559 */
+	0,							/* U+00255A */
+	0,							/* U+00255B */
+	0,							/* U+00255C */
+	0,							/* U+00255D */
+	0,							/* U+00255E */
+	0,							/* U+00255F */
+	0,							/* U+002560 */
+	0,							/* U+002561 */
+	0,							/* U+002562 */
+	0,							/* U+002563 */
+	0,							/* U+002564 */
+	0,							/* U+002565 */
+	0,							/* U+002566 */
+	0,							/* U+002567 */
+	0,							/* U+002568 */
+	0,							/* U+002569 */
+	0,							/* U+00256A */
+	0,							/* U+00256B */
+	0,							/* U+00256C */
+	0,							/* U+00256D */
+	0,							/* U+00256E */
+	0,							/* U+00256F */
+	0,							/* U+002570 */
+	0,							/* U+002571 */
+	0,							/* U+002572 */
+	0,							/* U+002573 */
+	0,							/* U+002574 */
+	0,							/* U+002575 */
+	0,							/* U+002576 */
+	0,							/* U+002577 */
+	0,							/* U+002578 */
+	0,							/* U+002579 */
+	0,							/* U+00257A */
+	0,							/* U+00257B */
+	0,							/* U+00257C */
+	0,							/* U+00257D */
+	0,							/* U+00257E */
+	0,							/* U+00257F */
+	0,							/* U+002580 */
+	0,							/* U+002581 */
+	0,							/* U+002582 */
+	0,							/* U+002583 */
+	0,							/* U+002584 */
+	0,							/* U+002585 */
+	0,							/* U+002586 */
+	0,							/* U+002587 */
+	0,							/* U+002588 */
+	0,							/* U+002589 */
+	0,							/* U+00258A */
+	0,							/* U+00258B */
+	0,							/* U+00258C */
+	0,							/* U+00258D */
+	0,							/* U+00258E */
+	0,							/* U+00258F */
+	0,							/* U+002590 */
+	0,							/* U+002591 */
+	0,							/* U+002592 */
+	0,							/* U+002593 */
+	0,							/* U+002594 */
+	0,							/* U+002595 */
+	0,							/* U+002596 */
+	0,							/* U+002597 */
+	0,							/* U+002598 */
+	0,							/* U+002599 */
+	0,							/* U+00259A */
+	0,							/* U+00259B */
+	0,							/* U+00259C */
+	0,							/* U+00259D */
+	0,							/* U+00259E */
+	0,							/* U+00259F */
+	0,							/* U+0025A0 */
+	0,							/* U+0025A1 */
+	0,							/* U+0025A2 */
+	0,							/* U+0025A3 */
+	0,							/* U+0025A4 */
+	0,							/* U+0025A5 */
+	0,							/* U+0025A6 */
+	0,							/* U+0025A7 */
+	0,							/* U+0025A8 */
+	0,							/* U+0025A9 */
+	0,							/* U+0025AA */
+	0,							/* U+0025AB */
+	0,							/* U+0025AC */
+	0,							/* U+0025AD */
+	0,							/* U+0025AE */
+	0,							/* U+0025AF */
+	0,							/* U+0025B0 */
+	0,							/* U+0025B1 */
+	0,							/* U+0025B2 */
+	0,							/* U+0025B3 */
+	0,							/* U+0025B4 */
+	0,							/* U+0025B5 */
+	0,							/* U+0025B6 */
+	0,							/* U+0025B7 */
+	0,							/* U+0025B8 */
+	0,							/* U+0025B9 */
+	0,							/* U+0025BA */
+	0,							/* U+0025BB */
+	0,							/* U+0025BC */
+	0,							/* U+0025BD */
+	0,							/* U+0025BE */
+	0,							/* U+0025BF */
+	0,							/* U+0025C0 */
+	0,							/* U+0025C1 */
+	0,							/* U+0025C2 */
+	0,							/* U+0025C3 */
+	0,							/* U+0025C4 */
+	0,							/* U+0025C5 */
+	0,							/* U+0025C6 */
+	0,							/* U+0025C7 */
+	0,							/* U+0025C8 */
+	0,							/* U+0025C9 */
+	0,							/* U+0025CA */
+	0,							/* U+0025CB */
+	0,							/* U+0025CC */
+	0,							/* U+0025CD */
+	0,							/* U+0025CE */
+	0,							/* U+0025CF */
+	0,							/* U+0025D0 */
+	0,							/* U+0025D1 */
+	0,							/* U+0025D2 */
+	0,							/* U+0025D3 */
+	0,							/* U+0025D4 */
+	0,							/* U+0025D5 */
+	0,							/* U+0025D6 */
+	0,							/* U+0025D7 */
+	0,							/* U+0025D8 */
+	0,							/* U+0025D9 */
+	0,							/* U+0025DA */
+	0,							/* U+0025DB */
+	0,							/* U+0025DC */
+	0,							/* U+0025DD */
+	0,							/* U+0025DE */
+	0,							/* U+0025DF */
+	0,							/* U+0025E0 */
+	0,							/* U+0025E1 */
+	0,							/* U+0025E2 */
+	0,							/* U+0025E3 */
+	0,							/* U+0025E4 */
+	0,							/* U+0025E5 */
+	0,							/* U+0025E6 */
+	0,							/* U+0025E7 */
+	0,							/* U+0025E8 */
+	0,							/* U+0025E9 */
+	0,							/* U+0025EA */
+	0,							/* U+0025EB */
+	0,							/* U+0025EC */
+	0,							/* U+0025ED */
+	0,							/* U+0025EE */
+	0,							/* U+0025EF */
+	0,							/* U+0025F0 */
+	0,							/* U+0025F1 */
+	0,							/* U+0025F2 */
+	0,							/* U+0025F3 */
+	0,							/* U+0025F4 */
+	0,							/* U+0025F5 */
+	0,							/* U+0025F6 */
+	0,							/* U+0025F7 */
+	0,							/* U+0025F8 */
+	0,							/* U+0025F9 */
+	0,							/* U+0025FA */
+	0,							/* U+0025FB */
+	0,							/* U+0025FC */
+	0,							/* U+0025FD */
+	0,							/* U+0025FE */
+	0,							/* U+0025FF */
+	0,							/* U+002600 */
+	0,							/* U+002601 */
+	0,							/* U+002602 */
+	0,							/* U+002603 */
+	0,							/* U+002604 */
+	0,							/* U+002605 */
+	0,							/* U+002606 */
+	0,							/* U+002607 */
+	0,							/* U+002608 */
+	0,							/* U+002609 */
+	0,							/* U+00260A */
+	0,							/* U+00260B */
+	0,							/* U+00260C */
+	0,							/* U+00260D */
+	0,							/* U+00260E */
+	0,							/* U+00260F */
+	0,							/* U+002610 */
+	0,							/* U+002611 */
+	0,							/* U+002612 */
+	0,							/* U+002613 */
+	0,							/* U+002614 */
+	0,							/* U+002615 */
+	0,							/* U+002616 */
+	0,							/* U+002617 */
+	0,							/* U+002618 */
+	0,							/* U+002619 */
+	0,							/* U+00261A */
+	0,							/* U+00261B */
+	0,							/* U+00261C */
+	0,							/* U+00261D */
+	0,							/* U+00261E */
+	0,							/* U+00261F */
+	0,							/* U+002620 */
+	0,							/* U+002621 */
+	0,							/* U+002622 */
+	0,							/* U+002623 */
+	0,							/* U+002624 */
+	0,							/* U+002625 */
+	0,							/* U+002626 */
+	0,							/* U+002627 */
+	0,							/* U+002628 */
+	0,							/* U+002629 */
+	0,							/* U+00262A */
+	0,							/* U+00262B */
+	0,							/* U+00262C */
+	0,							/* U+00262D */
+	0,							/* U+00262E */
+	0,							/* U+00262F */
+	0,							/* U+002630 */
+	0,							/* U+002631 */
+	0,							/* U+002632 */
+	0,							/* U+002633 */
+	0,							/* U+002634 */
+	0,							/* U+002635 */
+	0,							/* U+002636 */
+	0,							/* U+002637 */
+	0,							/* U+002638 */
+	0,							/* U+002639 */
+	0,							/* U+00263A */
+	0,							/* U+00263B */
+	0,							/* U+00263C */
+	0,							/* U+00263D */
+	0,							/* U+00263E */
+	0,							/* U+00263F */
+	0,							/* U+002640 */
+	0,							/* U+002641 */
+	0,							/* U+002642 */
+	0,							/* U+002643 */
+	0,							/* U+002644 */
+	0,							/* U+002645 */
+	0,							/* U+002646 */
+	0,							/* U+002647 */
+	0,							/* U+002648 */
+	0,							/* U+002649 */
+	0,							/* U+00264A */
+	0,							/* U+00264B */
+	0,							/* U+00264C */
+	0,							/* U+00264D */
+	0,							/* U+00264E */
+	0,							/* U+00264F */
+	0,							/* U+002650 */
+	0,							/* U+002651 */
+	0,							/* U+002652 */
+	0,							/* U+002653 */
+	0,							/* U+002654 */
+	0,							/* U+002655 */
+	0,							/* U+002656 */
+	0,							/* U+002657 */
+	0,							/* U+002658 */
+	0,							/* U+002659 */
+	0,							/* U+00265A */
+	0,							/* U+00265B */
+	0,							/* U+00265C */
+	0,							/* U+00265D */
+	0,							/* U+00265E */
+	0,							/* U+00265F */
+	0,							/* U+002660 */
+	0,							/* U+002661 */
+	0,							/* U+002662 */
+	0,							/* U+002663 */
+	0,							/* U+002664 */
+	0,							/* U+002665 */
+	0,							/* U+002666 */
+	0,							/* U+002667 */
+	0,							/* U+002668 */
+	0,							/* U+002669 */
+	0,							/* U+00266A */
+	0,							/* U+00266B */
+	0,							/* U+00266C */
+	0,							/* U+00266D */
+	0,							/* U+00266E */
+	0,							/* U+00266F */
+	0,							/* U+002670 */
+	0,							/* U+002671 */
+	0,							/* U+002672 */
+	0,							/* U+002673 */
+	0,							/* U+002674 */
+	0,							/* U+002675 */
+	0,							/* U+002676 */
+	0,							/* U+002677 */
+	0,							/* U+002678 */
+	0,							/* U+002679 */
+	0,							/* U+00267A */
+	0,							/* U+00267B */
+	0,							/* U+00267C */
+	0,							/* U+00267D */
+	0,							/* U+00267E */
+	0,							/* U+00267F */
+	0,							/* U+002680 */
+	0,							/* U+002681 */
+	0,							/* U+002682 */
+	0,							/* U+002683 */
+	0,							/* U+002684 */
+	0,							/* U+002685 */
+	0,							/* U+002686 */
+	0,							/* U+002687 */
+	0,							/* U+002688 */
+	0,							/* U+002689 */
+	0,							/* U+00268A */
+	0,							/* U+00268B */
+	0,							/* U+00268C */
+	0,							/* U+00268D */
+	0,							/* U+00268E */
+	0,							/* U+00268F */
+	0,							/* U+002690 */
+	0,							/* U+002691 */
+	0,							/* U+002692 */
+	0,							/* U+002693 */
+	0,							/* U+002694 */
+	0,							/* U+002695 */
+	0,							/* U+002696 */
+	0,							/* U+002697 */
+	0,							/* U+002698 */
+	0,							/* U+002699 */
+	0,							/* U+00269A */
+	0,							/* U+00269B */
+	0,							/* U+00269C */
+	0,							/* U+00269D */
+	0,							/* U+00269E */
+	0,							/* U+00269F */
+	0,							/* U+0026A0 */
+	0,							/* U+0026A1 */
+	0,							/* U+0026A2 */
+	0,							/* U+0026A3 */
+	0,							/* U+0026A4 */
+	0,							/* U+0026A5 */
+	0,							/* U+0026A6 */
+	0,							/* U+0026A7 */
+	0,							/* U+0026A8 */
+	0,							/* U+0026A9 */
+	0,							/* U+0026AA */
+	0,							/* U+0026AB */
+	0,							/* U+0026AC */
+	0,							/* U+0026AD */
+	0,							/* U+0026AE */
+	0,							/* U+0026AF */
+	0,							/* U+0026B0 */
+	0,							/* U+0026B1 */
+	0,							/* U+0026B2 */
+	0,							/* U+0026B3 */
+	0,							/* U+0026B4 */
+	0,							/* U+0026B5 */
+	0,							/* U+0026B6 */
+	0,							/* U+0026B7 */
+	0,							/* U+0026B8 */
+	0,							/* U+0026B9 */
+	0,							/* U+0026BA */
+	0,							/* U+0026BB */
+	0,							/* U+0026BC */
+	0,							/* U+0026BD */
+	0,							/* U+0026BE */
+	0,							/* U+0026BF */
+	0,							/* U+0026C0 */
+	0,							/* U+0026C1 */
+	0,							/* U+0026C2 */
+	0,							/* U+0026C3 */
+	0,							/* U+0026C4 */
+	0,							/* U+0026C5 */
+	0,							/* U+0026C6 */
+	0,							/* U+0026C7 */
+	0,							/* U+0026C8 */
+	0,							/* U+0026C9 */
+	0,							/* U+0026CA */
+	0,							/* U+0026CB */
+	0,							/* U+0026CC */
+	0,							/* U+0026CD */
+	0,							/* U+0026CE */
+	0,							/* U+0026CF */
+	0,							/* U+0026D0 */
+	0,							/* U+0026D1 */
+	0,							/* U+0026D2 */
+	0,							/* U+0026D3 */
+	0,							/* U+0026D4 */
+	0,							/* U+0026D5 */
+	0,							/* U+0026D6 */
+	0,							/* U+0026D7 */
+	0,							/* U+0026D8 */
+	0,							/* U+0026D9 */
+	0,							/* U+0026DA */
+	0,							/* U+0026DB */
+	0,							/* U+0026DC */
+	0,							/* U+0026DD */
+	0,							/* U+0026DE */
+	0,							/* U+0026DF */
+	0,							/* U+0026E0 */
+	0,							/* U+0026E1 */
+	0,							/* U+0026E2 */
+	0,							/* U+0026E3 */
+	0,							/* U+0026E4 */
+	0,							/* U+0026E5 */
+	0,							/* U+0026E6 */
+	0,							/* U+0026E7 */
+	0,							/* U+0026E8 */
+	0,							/* U+0026E9 */
+	0,							/* U+0026EA */
+	0,							/* U+0026EB */
+	0,							/* U+0026EC */
+	0,							/* U+0026ED */
+	0,							/* U+0026EE */
+	0,							/* U+0026EF */
+	0,							/* U+0026F0 */
+	0,							/* U+0026F1 */
+	0,							/* U+0026F2 */
+	0,							/* U+0026F3 */
+	0,							/* U+0026F4 */
+	0,							/* U+0026F5 */
+	0,							/* U+0026F6 */
+	0,							/* U+0026F7 */
+	0,							/* U+0026F8 */
+	0,							/* U+0026F9 */
+	0,							/* U+0026FA */
+	0,							/* U+0026FB */
+	0,							/* U+0026FC */
+	0,							/* U+0026FD */
+	0,							/* U+0026FE */
+	0,							/* U+0026FF */
+	0,							/* U+002700 */
+	0,							/* U+002701 */
+	0,							/* U+002702 */
+	0,							/* U+002703 */
+	0,							/* U+002704 */
+	0,							/* U+002705 */
+	0,							/* U+002706 */
+	0,							/* U+002707 */
+	0,							/* U+002708 */
+	0,							/* U+002709 */
+	0,							/* U+00270A */
+	0,							/* U+00270B */
+	0,							/* U+00270C */
+	0,							/* U+00270D */
+	0,							/* U+00270E */
+	0,							/* U+00270F */
+	0,							/* U+002710 */
+	0,							/* U+002711 */
+	0,							/* U+002712 */
+	0,							/* U+002713 */
+	0,							/* U+002714 */
+	0,							/* U+002715 */
+	0,							/* U+002716 */
+	0,							/* U+002717 */
+	0,							/* U+002718 */
+	0,							/* U+002719 */
+	0,							/* U+00271A */
+	0,							/* U+00271B */
+	0,							/* U+00271C */
+	0,							/* U+00271D */
+	0,							/* U+00271E */
+	0,							/* U+00271F */
+	0,							/* U+002720 */
+	0,							/* U+002721 */
+	0,							/* U+002722 */
+	0,							/* U+002723 */
+	0,							/* U+002724 */
+	0,							/* U+002725 */
+	0,							/* U+002726 */
+	0,							/* U+002727 */
+	0,							/* U+002728 */
+	0,							/* U+002729 */
+	0,							/* U+00272A */
+	0,							/* U+00272B */
+	0,							/* U+00272C */
+	0,							/* U+00272D */
+	0,							/* U+00272E */
+	0,							/* U+00272F */
+	0,							/* U+002730 */
+	0,							/* U+002731 */
+	0,							/* U+002732 */
+	0,							/* U+002733 */
+	0,							/* U+002734 */
+	0,							/* U+002735 */
+	0,							/* U+002736 */
+	0,							/* U+002737 */
+	0,							/* U+002738 */
+	0,							/* U+002739 */
+	0,							/* U+00273A */
+	0,							/* U+00273B */
+	0,							/* U+00273C */
+	0,							/* U+00273D */
+	0,							/* U+00273E */
+	0,							/* U+00273F */
+	0,							/* U+002740 */
+	0,							/* U+002741 */
+	0,							/* U+002742 */
+	0,							/* U+002743 */
+	0,							/* U+002744 */
+	0,							/* U+002745 */
+	0,							/* U+002746 */
+	0,							/* U+002747 */
+	0,							/* U+002748 */
+	0,							/* U+002749 */
+	0,							/* U+00274A */
+	0,							/* U+00274B */
+	0,							/* U+00274C */
+	0,							/* U+00274D */
+	0,							/* U+00274E */
+	0,							/* U+00274F */
+	0,							/* U+002750 */
+	0,							/* U+002751 */
+	0,							/* U+002752 */
+	0,							/* U+002753 */
+	0,							/* U+002754 */
+	0,							/* U+002755 */
+	0,							/* U+002756 */
+	0,							/* U+002757 */
+	0,							/* U+002758 */
+	0,							/* U+002759 */
+	0,							/* U+00275A */
+	0,							/* U+00275B */
+	0,							/* U+00275C */
+	0,							/* U+00275D */
+	0,							/* U+00275E */
+	0,							/* U+00275F */
+	0,							/* U+002760 */
+	0,							/* U+002761 */
+	0,							/* U+002762 */
+	0,							/* U+002763 */
+	0,							/* U+002764 */
+	0,							/* U+002765 */
+	0,							/* U+002766 */
+	0,							/* U+002767 */
+	0,							/* U+002768 */
+	0,							/* U+002769 */
+	0,							/* U+00276A */
+	0,							/* U+00276B */
+	0,							/* U+00276C */
+	0,							/* U+00276D */
+	0,							/* U+00276E */
+	0,							/* U+00276F */
+	0,							/* U+002770 */
+	0,							/* U+002771 */
+	0,							/* U+002772 */
+	0,							/* U+002773 */
+	0,							/* U+002774 */
+	0,							/* U+002775 */
+	0,							/* U+002776 */
+	0,							/* U+002777 */
+	0,							/* U+002778 */
+	0,							/* U+002779 */
+	0,							/* U+00277A */
+	0,							/* U+00277B */
+	0,							/* U+00277C */
+	0,							/* U+00277D */
+	0,							/* U+00277E */
+	0,							/* U+00277F */
+	0,							/* U+002780 */
+	0,							/* U+002781 */
+	0,							/* U+002782 */
+	0,							/* U+002783 */
+	0,							/* U+002784 */
+	0,							/* U+002785 */
+	0,							/* U+002786 */
+	0,							/* U+002787 */
+	0,							/* U+002788 */
+	0,							/* U+002789 */
+	0,							/* U+00278A */
+	0,							/* U+00278B */
+	0,							/* U+00278C */
+	0,							/* U+00278D */
+	0,							/* U+00278E */
+	0,							/* U+00278F */
+	0,							/* U+002790 */
+	0,							/* U+002791 */
+	0,							/* U+002792 */
+	0,							/* U+002793 */
+	0,							/* U+002794 */
+	0,							/* U+002795 */
+	0,							/* U+002796 */
+	0,							/* U+002797 */
+	0,							/* U+002798 */
+	0,							/* U+002799 */
+	0,							/* U+00279A */
+	0,							/* U+00279B */
+	0,							/* U+00279C */
+	0,							/* U+00279D */
+	0,							/* U+00279E */
+	0,							/* U+00279F */
+	0,							/* U+0027A0 */
+	0,							/* U+0027A1 */
+	0,							/* U+0027A2 */
+	0,							/* U+0027A3 */
+	0,							/* U+0027A4 */
+	0,							/* U+0027A5 */
+	0,							/* U+0027A6 */
+	0,							/* U+0027A7 */
+	0,							/* U+0027A8 */
+	0,							/* U+0027A9 */
+	0,							/* U+0027AA */
+	0,							/* U+0027AB */
+	0,							/* U+0027AC */
+	0,							/* U+0027AD */
+	0,							/* U+0027AE */
+	0,							/* U+0027AF */
+	0,							/* U+0027B0 */
+	0,							/* U+0027B1 */
+	0,							/* U+0027B2 */
+	0,							/* U+0027B3 */
+	0,							/* U+0027B4 */
+	0,							/* U+0027B5 */
+	0,							/* U+0027B6 */
+	0,							/* U+0027B7 */
+	0,							/* U+0027B8 */
+	0,							/* U+0027B9 */
+	0,							/* U+0027BA */
+	0,							/* U+0027BB */
+	0,							/* U+0027BC */
+	0,							/* U+0027BD */
+	0,							/* U+0027BE */
+	0,							/* U+0027BF */
+	0,							/* U+0027C0 */
+	0,							/* U+0027C1 */
+	0,							/* U+0027C2 */
+	0,							/* U+0027C3 */
+	0,							/* U+0027C4 */
+	0,							/* U+0027C5 */
+	0,							/* U+0027C6 */
+	0,							/* U+0027C7 */
+	0,							/* U+0027C8 */
+	0,							/* U+0027C9 */
+	0,							/* U+0027CA */
+	0,							/* U+0027CB */
+	0,							/* U+0027CC */
+	0,							/* U+0027CD */
+	0,							/* U+0027CE */
+	0,							/* U+0027CF */
+	0,							/* U+0027D0 */
+	0,							/* U+0027D1 */
+	0,							/* U+0027D2 */
+	0,							/* U+0027D3 */
+	0,							/* U+0027D4 */
+	0,							/* U+0027D5 */
+	0,							/* U+0027D6 */
+	0,							/* U+0027D7 */
+	0,							/* U+0027D8 */
+	0,							/* U+0027D9 */
+	0,							/* U+0027DA */
+	0,							/* U+0027DB */
+	0,							/* U+0027DC */
+	0,							/* U+0027DD */
+	0,							/* U+0027DE */
+	0,							/* U+0027DF */
+	0,							/* U+0027E0 */
+	0,							/* U+0027E1 */
+	0,							/* U+0027E2 */
+	0,							/* U+0027E3 */
+	0,							/* U+0027E4 */
+	0,							/* U+0027E5 */
+	0,							/* U+0027E6 */
+	0,							/* U+0027E7 */
+	0,							/* U+0027E8 */
+	0,							/* U+0027E9 */
+	0,							/* U+0027EA */
+	0,							/* U+0027EB */
+	0,							/* U+0027EC */
+	0,							/* U+0027ED */
+	0,							/* U+0027EE */
+	0,							/* U+0027EF */
+	0,							/* U+0027F0 */
+	0,							/* U+0027F1 */
+	0,							/* U+0027F2 */
+	0,							/* U+0027F3 */
+	0,							/* U+0027F4 */
+	0,							/* U+0027F5 */
+	0,							/* U+0027F6 */
+	0,							/* U+0027F7 */
+	0,							/* U+0027F8 */
+	0,							/* U+0027F9 */
+	0,							/* U+0027FA */
+	0,							/* U+0027FB */
+	0,							/* U+0027FC */
+	0,							/* U+0027FD */
+	0,							/* U+0027FE */
+	0,							/* U+0027FF */
+	0,							/* U+002800 */
+	0,							/* U+002801 */
+	0,							/* U+002802 */
+	0,							/* U+002803 */
+	0,							/* U+002804 */
+	0,							/* U+002805 */
+	0,							/* U+002806 */
+	0,							/* U+002807 */
+	0,							/* U+002808 */
+	0,							/* U+002809 */
+	0,							/* U+00280A */
+	0,							/* U+00280B */
+	0,							/* U+00280C */
+	0,							/* U+00280D */
+	0,							/* U+00280E */
+	0,							/* U+00280F */
+	0,							/* U+002810 */
+	0,							/* U+002811 */
+	0,							/* U+002812 */
+	0,							/* U+002813 */
+	0,							/* U+002814 */
+	0,							/* U+002815 */
+	0,							/* U+002816 */
+	0,							/* U+002817 */
+	0,							/* U+002818 */
+	0,							/* U+002819 */
+	0,							/* U+00281A */
+	0,							/* U+00281B */
+	0,							/* U+00281C */
+	0,							/* U+00281D */
+	0,							/* U+00281E */
+	0,							/* U+00281F */
+	0,							/* U+002820 */
+	0,							/* U+002821 */
+	0,							/* U+002822 */
+	0,							/* U+002823 */
+	0,							/* U+002824 */
+	0,							/* U+002825 */
+	0,							/* U+002826 */
+	0,							/* U+002827 */
+	0,							/* U+002828 */
+	0,							/* U+002829 */
+	0,							/* U+00282A */
+	0,							/* U+00282B */
+	0,							/* U+00282C */
+	0,							/* U+00282D */
+	0,							/* U+00282E */
+	0,							/* U+00282F */
+	0,							/* U+002830 */
+	0,							/* U+002831 */
+	0,							/* U+002832 */
+	0,							/* U+002833 */
+	0,							/* U+002834 */
+	0,							/* U+002835 */
+	0,							/* U+002836 */
+	0,							/* U+002837 */
+	0,							/* U+002838 */
+	0,							/* U+002839 */
+	0,							/* U+00283A */
+	0,							/* U+00283B */
+	0,							/* U+00283C */
+	0,							/* U+00283D */
+	0,							/* U+00283E */
+	0,							/* U+00283F */
+	0,							/* U+002840 */
+	0,							/* U+002841 */
+	0,							/* U+002842 */
+	0,							/* U+002843 */
+	0,							/* U+002844 */
+	0,							/* U+002845 */
+	0,							/* U+002846 */
+	0,							/* U+002847 */
+	0,							/* U+002848 */
+	0,							/* U+002849 */
+	0,							/* U+00284A */
+	0,							/* U+00284B */
+	0,							/* U+00284C */
+	0,							/* U+00284D */
+	0,							/* U+00284E */
+	0,							/* U+00284F */
+	0,							/* U+002850 */
+	0,							/* U+002851 */
+	0,							/* U+002852 */
+	0,							/* U+002853 */
+	0,							/* U+002854 */
+	0,							/* U+002855 */
+	0,							/* U+002856 */
+	0,							/* U+002857 */
+	0,							/* U+002858 */
+	0,							/* U+002859 */
+	0,							/* U+00285A */
+	0,							/* U+00285B */
+	0,							/* U+00285C */
+	0,							/* U+00285D */
+	0,							/* U+00285E */
+	0,							/* U+00285F */
+	0,							/* U+002860 */
+	0,							/* U+002861 */
+	0,							/* U+002862 */
+	0,							/* U+002863 */
+	0,							/* U+002864 */
+	0,							/* U+002865 */
+	0,							/* U+002866 */
+	0,							/* U+002867 */
+	0,							/* U+002868 */
+	0,							/* U+002869 */
+	0,							/* U+00286A */
+	0,							/* U+00286B */
+	0,							/* U+00286C */
+	0,							/* U+00286D */
+	0,							/* U+00286E */
+	0,							/* U+00286F */
+	0,							/* U+002870 */
+	0,							/* U+002871 */
+	0,							/* U+002872 */
+	0,							/* U+002873 */
+	0,							/* U+002874 */
+	0,							/* U+002875 */
+	0,							/* U+002876 */
+	0,							/* U+002877 */
+	0,							/* U+002878 */
+	0,							/* U+002879 */
+	0,							/* U+00287A */
+	0,							/* U+00287B */
+	0,							/* U+00287C */
+	0,							/* U+00287D */
+	0,							/* U+00287E */
+	0,							/* U+00287F */
+	0,							/* U+002880 */
+	0,							/* U+002881 */
+	0,							/* U+002882 */
+	0,							/* U+002883 */
+	0,							/* U+002884 */
+	0,							/* U+002885 */
+	0,							/* U+002886 */
+	0,							/* U+002887 */
+	0,							/* U+002888 */
+	0,							/* U+002889 */
+	0,							/* U+00288A */
+	0,							/* U+00288B */
+	0,							/* U+00288C */
+	0,							/* U+00288D */
+	0,							/* U+00288E */
+	0,							/* U+00288F */
+	0,							/* U+002890 */
+	0,							/* U+002891 */
+	0,							/* U+002892 */
+	0,							/* U+002893 */
+	0,							/* U+002894 */
+	0,							/* U+002895 */
+	0,							/* U+002896 */
+	0,							/* U+002897 */
+	0,							/* U+002898 */
+	0,							/* U+002899 */
+	0,							/* U+00289A */
+	0,							/* U+00289B */
+	0,							/* U+00289C */
+	0,							/* U+00289D */
+	0,							/* U+00289E */
+	0,							/* U+00289F */
+	0,							/* U+0028A0 */
+	0,							/* U+0028A1 */
+	0,							/* U+0028A2 */
+	0,							/* U+0028A3 */
+	0,							/* U+0028A4 */
+	0,							/* U+0028A5 */
+	0,							/* U+0028A6 */
+	0,							/* U+0028A7 */
+	0,							/* U+0028A8 */
+	0,							/* U+0028A9 */
+	0,							/* U+0028AA */
+	0,							/* U+0028AB */
+	0,							/* U+0028AC */
+	0,							/* U+0028AD */
+	0,							/* U+0028AE */
+	0,							/* U+0028AF */
+	0,							/* U+0028B0 */
+	0,							/* U+0028B1 */
+	0,							/* U+0028B2 */
+	0,							/* U+0028B3 */
+	0,							/* U+0028B4 */
+	0,							/* U+0028B5 */
+	0,							/* U+0028B6 */
+	0,							/* U+0028B7 */
+	0,							/* U+0028B8 */
+	0,							/* U+0028B9 */
+	0,							/* U+0028BA */
+	0,							/* U+0028BB */
+	0,							/* U+0028BC */
+	0,							/* U+0028BD */
+	0,							/* U+0028BE */
+	0,							/* U+0028BF */
+	0,							/* U+0028C0 */
+	0,							/* U+0028C1 */
+	0,							/* U+0028C2 */
+	0,							/* U+0028C3 */
+	0,							/* U+0028C4 */
+	0,							/* U+0028C5 */
+	0,							/* U+0028C6 */
+	0,							/* U+0028C7 */
+	0,							/* U+0028C8 */
+	0,							/* U+0028C9 */
+	0,							/* U+0028CA */
+	0,							/* U+0028CB */
+	0,							/* U+0028CC */
+	0,							/* U+0028CD */
+	0,							/* U+0028CE */
+	0,							/* U+0028CF */
+	0,							/* U+0028D0 */
+	0,							/* U+0028D1 */
+	0,							/* U+0028D2 */
+	0,							/* U+0028D3 */
+	0,							/* U+0028D4 */
+	0,							/* U+0028D5 */
+	0,							/* U+0028D6 */
+	0,							/* U+0028D7 */
+	0,							/* U+0028D8 */
+	0,							/* U+0028D9 */
+	0,							/* U+0028DA */
+	0,							/* U+0028DB */
+	0,							/* U+0028DC */
+	0,							/* U+0028DD */
+	0,							/* U+0028DE */
+	0,							/* U+0028DF */
+	0,							/* U+0028E0 */
+	0,							/* U+0028E1 */
+	0,							/* U+0028E2 */
+	0,							/* U+0028E3 */
+	0,							/* U+0028E4 */
+	0,							/* U+0028E5 */
+	0,							/* U+0028E6 */
+	0,							/* U+0028E7 */
+	0,							/* U+0028E8 */
+	0,							/* U+0028E9 */
+	0,							/* U+0028EA */
+	0,							/* U+0028EB */
+	0,							/* U+0028EC */
+	0,							/* U+0028ED */
+	0,							/* U+0028EE */
+	0,							/* U+0028EF */
+	0,							/* U+0028F0 */
+	0,							/* U+0028F1 */
+	0,							/* U+0028F2 */
+	0,							/* U+0028F3 */
+	0,							/* U+0028F4 */
+	0,							/* U+0028F5 */
+	0,							/* U+0028F6 */
+	0,							/* U+0028F7 */
+	0,							/* U+0028F8 */
+	0,							/* U+0028F9 */
+	0,							/* U+0028FA */
+	0,							/* U+0028FB */
+	0,							/* U+0028FC */
+	0,							/* U+0028FD */
+	0,							/* U+0028FE */
+	0,							/* U+0028FF */
+	0,							/* U+002900 */
+	0,							/* U+002901 */
+	0,							/* U+002902 */
+	0,							/* U+002903 */
+	0,							/* U+002904 */
+	0,							/* U+002905 */
+	0,							/* U+002906 */
+	0,							/* U+002907 */
+	0,							/* U+002908 */
+	0,							/* U+002909 */
+	0,							/* U+00290A */
+	0,							/* U+00290B */
+	0,							/* U+00290C */
+	0,							/* U+00290D */
+	0,							/* U+00290E */
+	0,							/* U+00290F */
+	0,							/* U+002910 */
+	0,							/* U+002911 */
+	0,							/* U+002912 */
+	0,							/* U+002913 */
+	0,							/* U+002914 */
+	0,							/* U+002915 */
+	0,							/* U+002916 */
+	0,							/* U+002917 */
+	0,							/* U+002918 */
+	0,							/* U+002919 */
+	0,							/* U+00291A */
+	0,							/* U+00291B */
+	0,							/* U+00291C */
+	0,							/* U+00291D */
+	0,							/* U+00291E */
+	0,							/* U+00291F */
+	0,							/* U+002920 */
+	0,							/* U+002921 */
+	0,							/* U+002922 */
+	0,							/* U+002923 */
+	0,							/* U+002924 */
+	0,							/* U+002925 */
+	0,							/* U+002926 */
+	0,							/* U+002927 */
+	0,							/* U+002928 */
+	0,							/* U+002929 */
+	0,							/* U+00292A */
+	0,							/* U+00292B */
+	0,							/* U+00292C */
+	0,							/* U+00292D */
+	0,							/* U+00292E */
+	0,							/* U+00292F */
+	0,							/* U+002930 */
+	0,							/* U+002931 */
+	0,							/* U+002932 */
+	0,							/* U+002933 */
+	0,							/* U+002934 */
+	0,							/* U+002935 */
+	0,							/* U+002936 */
+	0,							/* U+002937 */
+	0,							/* U+002938 */
+	0,							/* U+002939 */
+	0,							/* U+00293A */
+	0,							/* U+00293B */
+	0,							/* U+00293C */
+	0,							/* U+00293D */
+	0,							/* U+00293E */
+	0,							/* U+00293F */
+	0,							/* U+002940 */
+	0,							/* U+002941 */
+	0,							/* U+002942 */
+	0,							/* U+002943 */
+	0,							/* U+002944 */
+	0,							/* U+002945 */
+	0,							/* U+002946 */
+	0,							/* U+002947 */
+	0,							/* U+002948 */
+	0,							/* U+002949 */
+	0,							/* U+00294A */
+	0,							/* U+00294B */
+	0,							/* U+00294C */
+	0,							/* U+00294D */
+	0,							/* U+00294E */
+	0,							/* U+00294F */
+	0,							/* U+002950 */
+	0,							/* U+002951 */
+	0,							/* U+002952 */
+	0,							/* U+002953 */
+	0,							/* U+002954 */
+	0,							/* U+002955 */
+	0,							/* U+002956 */
+	0,							/* U+002957 */
+	0,							/* U+002958 */
+	0,							/* U+002959 */
+	0,							/* U+00295A */
+	0,							/* U+00295B */
+	0,							/* U+00295C */
+	0,							/* U+00295D */
+	0,							/* U+00295E */
+	0,							/* U+00295F */
+	0,							/* U+002960 */
+	0,							/* U+002961 */
+	0,							/* U+002962 */
+	0,							/* U+002963 */
+	0,							/* U+002964 */
+	0,							/* U+002965 */
+	0,							/* U+002966 */
+	0,							/* U+002967 */
+	0,							/* U+002968 */
+	0,							/* U+002969 */
+	0,							/* U+00296A */
+	0,							/* U+00296B */
+	0,							/* U+00296C */
+	0,							/* U+00296D */
+	0,							/* U+00296E */
+	0,							/* U+00296F */
+	0,							/* U+002970 */
+	0,							/* U+002971 */
+	0,							/* U+002972 */
+	0,							/* U+002973 */
+	0,							/* U+002974 */
+	0,							/* U+002975 */
+	0,							/* U+002976 */
+	0,							/* U+002977 */
+	0,							/* U+002978 */
+	0,							/* U+002979 */
+	0,							/* U+00297A */
+	0,							/* U+00297B */
+	0,							/* U+00297C */
+	0,							/* U+00297D */
+	0,							/* U+00297E */
+	0,							/* U+00297F */
+	0,							/* U+002980 */
+	0,							/* U+002981 */
+	0,							/* U+002982 */
+	0,							/* U+002983 */
+	0,							/* U+002984 */
+	0,							/* U+002985 */
+	0,							/* U+002986 */
+	0,							/* U+002987 */
+	0,							/* U+002988 */
+	0,							/* U+002989 */
+	0,							/* U+00298A */
+	0,							/* U+00298B */
+	0,							/* U+00298C */
+	0,							/* U+00298D */
+	0,							/* U+00298E */
+	0,							/* U+00298F */
+	0,							/* U+002990 */
+	0,							/* U+002991 */
+	0,							/* U+002992 */
+	0,							/* U+002993 */
+	0,							/* U+002994 */
+	0,							/* U+002995 */
+	0,							/* U+002996 */
+	0,							/* U+002997 */
+	0,							/* U+002998 */
+	0,							/* U+002999 */
+	0,							/* U+00299A */
+	0,							/* U+00299B */
+	0,							/* U+00299C */
+	0,							/* U+00299D */
+	0,							/* U+00299E */
+	0,							/* U+00299F */
+	0,							/* U+0029A0 */
+	0,							/* U+0029A1 */
+	0,							/* U+0029A2 */
+	0,							/* U+0029A3 */
+	0,							/* U+0029A4 */
+	0,							/* U+0029A5 */
+	0,							/* U+0029A6 */
+	0,							/* U+0029A7 */
+	0,							/* U+0029A8 */
+	0,							/* U+0029A9 */
+	0,							/* U+0029AA */
+	0,							/* U+0029AB */
+	0,							/* U+0029AC */
+	0,							/* U+0029AD */
+	0,							/* U+0029AE */
+	0,							/* U+0029AF */
+	0,							/* U+0029B0 */
+	0,							/* U+0029B1 */
+	0,							/* U+0029B2 */
+	0,							/* U+0029B3 */
+	0,							/* U+0029B4 */
+	0,							/* U+0029B5 */
+	0,							/* U+0029B6 */
+	0,							/* U+0029B7 */
+	0,							/* U+0029B8 */
+	0,							/* U+0029B9 */
+	0,							/* U+0029BA */
+	0,							/* U+0029BB */
+	0,							/* U+0029BC */
+	0,							/* U+0029BD */
+	0,							/* U+0029BE */
+	0,							/* U+0029BF */
+	0,							/* U+0029C0 */
+	0,							/* U+0029C1 */
+	0,							/* U+0029C2 */
+	0,							/* U+0029C3 */
+	0,							/* U+0029C4 */
+	0,							/* U+0029C5 */
+	0,							/* U+0029C6 */
+	0,							/* U+0029C7 */
+	0,							/* U+0029C8 */
+	0,							/* U+0029C9 */
+	0,							/* U+0029CA */
+	0,							/* U+0029CB */
+	0,							/* U+0029CC */
+	0,							/* U+0029CD */
+	0,							/* U+0029CE */
+	0,							/* U+0029CF */
+	0,							/* U+0029D0 */
+	0,							/* U+0029D1 */
+	0,							/* U+0029D2 */
+	0,							/* U+0029D3 */
+	0,							/* U+0029D4 */
+	0,							/* U+0029D5 */
+	0,							/* U+0029D6 */
+	0,							/* U+0029D7 */
+	0,							/* U+0029D8 */
+	0,							/* U+0029D9 */
+	0,							/* U+0029DA */
+	0,							/* U+0029DB */
+	0,							/* U+0029DC */
+	0,							/* U+0029DD */
+	0,							/* U+0029DE */
+	0,							/* U+0029DF */
+	0,							/* U+0029E0 */
+	0,							/* U+0029E1 */
+	0,							/* U+0029E2 */
+	0,							/* U+0029E3 */
+	0,							/* U+0029E4 */
+	0,							/* U+0029E5 */
+	0,							/* U+0029E6 */
+	0,							/* U+0029E7 */
+	0,							/* U+0029E8 */
+	0,							/* U+0029E9 */
+	0,							/* U+0029EA */
+	0,							/* U+0029EB */
+	0,							/* U+0029EC */
+	0,							/* U+0029ED */
+	0,							/* U+0029EE */
+	0,							/* U+0029EF */
+	0,							/* U+0029F0 */
+	0,							/* U+0029F1 */
+	0,							/* U+0029F2 */
+	0,							/* U+0029F3 */
+	0,							/* U+0029F4 */
+	0,							/* U+0029F5 */
+	0,							/* U+0029F6 */
+	0,							/* U+0029F7 */
+	0,							/* U+0029F8 */
+	0,							/* U+0029F9 */
+	0,							/* U+0029FA */
+	0,							/* U+0029FB */
+	0,							/* U+0029FC */
+	0,							/* U+0029FD */
+	0,							/* U+0029FE */
+	0,							/* U+0029FF */
+	0,							/* U+002A00 */
+	0,							/* U+002A01 */
+	0,							/* U+002A02 */
+	0,							/* U+002A03 */
+	0,							/* U+002A04 */
+	0,							/* U+002A05 */
+	0,							/* U+002A06 */
+	0,							/* U+002A07 */
+	0,							/* U+002A08 */
+	0,							/* U+002A09 */
+	0,							/* U+002A0A */
+	0,							/* U+002A0B */
+	1329,						/* U+002A0C */
+	0,							/* U+002A0D */
+	0,							/* U+002A0E */
+	0,							/* U+002A0F */
+	0,							/* U+002A10 */
+	0,							/* U+002A11 */
+	0,							/* U+002A12 */
+	0,							/* U+002A13 */
+	0,							/* U+002A14 */
+	0,							/* U+002A15 */
+	0,							/* U+002A16 */
+	0,							/* U+002A17 */
+	0,							/* U+002A18 */
+	0,							/* U+002A19 */
+	0,							/* U+002A1A */
+	0,							/* U+002A1B */
+	0,							/* U+002A1C */
+	0,							/* U+002A1D */
+	0,							/* U+002A1E */
+	0,							/* U+002A1F */
+	0,							/* U+002A20 */
+	0,							/* U+002A21 */
+	0,							/* U+002A22 */
+	0,							/* U+002A23 */
+	0,							/* U+002A24 */
+	0,							/* U+002A25 */
+	0,							/* U+002A26 */
+	0,							/* U+002A27 */
+	0,							/* U+002A28 */
+	0,							/* U+002A29 */
+	0,							/* U+002A2A */
+	0,							/* U+002A2B */
+	0,							/* U+002A2C */
+	0,							/* U+002A2D */
+	0,							/* U+002A2E */
+	0,							/* U+002A2F */
+	0,							/* U+002A30 */
+	0,							/* U+002A31 */
+	0,							/* U+002A32 */
+	0,							/* U+002A33 */
+	0,							/* U+002A34 */
+	0,							/* U+002A35 */
+	0,							/* U+002A36 */
+	0,							/* U+002A37 */
+	0,							/* U+002A38 */
+	0,							/* U+002A39 */
+	0,							/* U+002A3A */
+	0,							/* U+002A3B */
+	0,							/* U+002A3C */
+	0,							/* U+002A3D */
+	0,							/* U+002A3E */
+	0,							/* U+002A3F */
+	0,							/* U+002A40 */
+	0,							/* U+002A41 */
+	0,							/* U+002A42 */
+	0,							/* U+002A43 */
+	0,							/* U+002A44 */
+	0,							/* U+002A45 */
+	0,							/* U+002A46 */
+	0,							/* U+002A47 */
+	0,							/* U+002A48 */
+	0,							/* U+002A49 */
+	0,							/* U+002A4A */
+	0,							/* U+002A4B */
+	0,							/* U+002A4C */
+	0,							/* U+002A4D */
+	0,							/* U+002A4E */
+	0,							/* U+002A4F */
+	0,							/* U+002A50 */
+	0,							/* U+002A51 */
+	0,							/* U+002A52 */
+	0,							/* U+002A53 */
+	0,							/* U+002A54 */
+	0,							/* U+002A55 */
+	0,							/* U+002A56 */
+	0,							/* U+002A57 */
+	0,							/* U+002A58 */
+	0,							/* U+002A59 */
+	0,							/* U+002A5A */
+	0,							/* U+002A5B */
+	0,							/* U+002A5C */
+	0,							/* U+002A5D */
+	0,							/* U+002A5E */
+	0,							/* U+002A5F */
+	0,							/* U+002A60 */
+	0,							/* U+002A61 */
+	0,							/* U+002A62 */
+	0,							/* U+002A63 */
+	0,							/* U+002A64 */
+	0,							/* U+002A65 */
+	0,							/* U+002A66 */
+	0,							/* U+002A67 */
+	0,							/* U+002A68 */
+	0,							/* U+002A69 */
+	0,							/* U+002A6A */
+	0,							/* U+002A6B */
+	0,							/* U+002A6C */
+	0,							/* U+002A6D */
+	0,							/* U+002A6E */
+	0,							/* U+002A6F */
+	0,							/* U+002A70 */
+	0,							/* U+002A71 */
+	0,							/* U+002A72 */
+	0,							/* U+002A73 */
+	1330,						/* U+002A74 */
+	1331,						/* U+002A75 */
+	1332,						/* U+002A76 */
+	0,							/* U+002A77 */
+	0,							/* U+002A78 */
+	0,							/* U+002A79 */
+	0,							/* U+002A7A */
+	0,							/* U+002A7B */
+	0,							/* U+002A7C */
+	0,							/* U+002A7D */
+	0,							/* U+002A7E */
+	0,							/* U+002A7F */
+	0,							/* U+002A80 */
+	0,							/* U+002A81 */
+	0,							/* U+002A82 */
+	0,							/* U+002A83 */
+	0,							/* U+002A84 */
+	0,							/* U+002A85 */
+	0,							/* U+002A86 */
+	0,							/* U+002A87 */
+	0,							/* U+002A88 */
+	0,							/* U+002A89 */
+	0,							/* U+002A8A */
+	0,							/* U+002A8B */
+	0,							/* U+002A8C */
+	0,							/* U+002A8D */
+	0,							/* U+002A8E */
+	0,							/* U+002A8F */
+	0,							/* U+002A90 */
+	0,							/* U+002A91 */
+	0,							/* U+002A92 */
+	0,							/* U+002A93 */
+	0,							/* U+002A94 */
+	0,							/* U+002A95 */
+	0,							/* U+002A96 */
+	0,							/* U+002A97 */
+	0,							/* U+002A98 */
+	0,							/* U+002A99 */
+	0,							/* U+002A9A */
+	0,							/* U+002A9B */
+	0,							/* U+002A9C */
+	0,							/* U+002A9D */
+	0,							/* U+002A9E */
+	0,							/* U+002A9F */
+	0,							/* U+002AA0 */
+	0,							/* U+002AA1 */
+	0,							/* U+002AA2 */
+	0,							/* U+002AA3 */
+	0,							/* U+002AA4 */
+	0,							/* U+002AA5 */
+	0,							/* U+002AA6 */
+	0,							/* U+002AA7 */
+	0,							/* U+002AA8 */
+	0,							/* U+002AA9 */
+	0,							/* U+002AAA */
+	0,							/* U+002AAB */
+	0,							/* U+002AAC */
+	0,							/* U+002AAD */
+	0,							/* U+002AAE */
+	0,							/* U+002AAF */
+	0,							/* U+002AB0 */
+	0,							/* U+002AB1 */
+	0,							/* U+002AB2 */
+	0,							/* U+002AB3 */
+	0,							/* U+002AB4 */
+	0,							/* U+002AB5 */
+	0,							/* U+002AB6 */
+	0,							/* U+002AB7 */
+	0,							/* U+002AB8 */
+	0,							/* U+002AB9 */
+	0,							/* U+002ABA */
+	0,							/* U+002ABB */
+	0,							/* U+002ABC */
+	0,							/* U+002ABD */
+	0,							/* U+002ABE */
+	0,							/* U+002ABF */
+	0,							/* U+002AC0 */
+	0,							/* U+002AC1 */
+	0,							/* U+002AC2 */
+	0,							/* U+002AC3 */
+	0,							/* U+002AC4 */
+	0,							/* U+002AC5 */
+	0,							/* U+002AC6 */
+	0,							/* U+002AC7 */
+	0,							/* U+002AC8 */
+	0,							/* U+002AC9 */
+	0,							/* U+002ACA */
+	0,							/* U+002ACB */
+	0,							/* U+002ACC */
+	0,							/* U+002ACD */
+	0,							/* U+002ACE */
+	0,							/* U+002ACF */
+	0,							/* U+002AD0 */
+	0,							/* U+002AD1 */
+	0,							/* U+002AD2 */
+	0,							/* U+002AD3 */
+	0,							/* U+002AD4 */
+	0,							/* U+002AD5 */
+	0,							/* U+002AD6 */
+	0,							/* U+002AD7 */
+	0,							/* U+002AD8 */
+	0,							/* U+002AD9 */
+	0,							/* U+002ADA */
+	0,							/* U+002ADB */
+	1333,						/* U+002ADC */
+	0,							/* U+002ADD */
+	0,							/* U+002ADE */
+	0,							/* U+002ADF */
+	0,							/* U+002AE0 */
+	0,							/* U+002AE1 */
+	0,							/* U+002AE2 */
+	0,							/* U+002AE3 */
+	0,							/* U+002AE4 */
+	0,							/* U+002AE5 */
+	0,							/* U+002AE6 */
+	0,							/* U+002AE7 */
+	0,							/* U+002AE8 */
+	0,							/* U+002AE9 */
+	0,							/* U+002AEA */
+	0,							/* U+002AEB */
+	0,							/* U+002AEC */
+	0,							/* U+002AED */
+	0,							/* U+002AEE */
+	0,							/* U+002AEF */
+	0,							/* U+002AF0 */
+	0,							/* U+002AF1 */
+	0,							/* U+002AF2 */
+	0,							/* U+002AF3 */
+	0,							/* U+002AF4 */
+	0,							/* U+002AF5 */
+	0,							/* U+002AF6 */
+	0,							/* U+002AF7 */
+	0,							/* U+002AF8 */
+	0,							/* U+002AF9 */
+	0,							/* U+002AFA */
+	0,							/* U+002AFB */
+	0,							/* U+002AFC */
+	0,							/* U+002AFD */
+	0,							/* U+002AFE */
+	0,							/* U+002AFF */
+	0,							/* U+002B00 */
+	0,							/* U+002B01 */
+	0,							/* U+002B02 */
+	0,							/* U+002B03 */
+	0,							/* U+002B04 */
+	0,							/* U+002B05 */
+	0,							/* U+002B06 */
+	0,							/* U+002B07 */
+	0,							/* U+002B08 */
+	0,							/* U+002B09 */
+	0,							/* U+002B0A */
+	0,							/* U+002B0B */
+	0,							/* U+002B0C */
+	0,							/* U+002B0D */
+	0,							/* U+002B0E */
+	0,							/* U+002B0F */
+	0,							/* U+002B10 */
+	0,							/* U+002B11 */
+	0,							/* U+002B12 */
+	0,							/* U+002B13 */
+	0,							/* U+002B14 */
+	0,							/* U+002B15 */
+	0,							/* U+002B16 */
+	0,							/* U+002B17 */
+	0,							/* U+002B18 */
+	0,							/* U+002B19 */
+	0,							/* U+002B1A */
+	0,							/* U+002B1B */
+	0,							/* U+002B1C */
+	0,							/* U+002B1D */
+	0,							/* U+002B1E */
+	0,							/* U+002B1F */
+	0,							/* U+002B20 */
+	0,							/* U+002B21 */
+	0,							/* U+002B22 */
+	0,							/* U+002B23 */
+	0,							/* U+002B24 */
+	0,							/* U+002B25 */
+	0,							/* U+002B26 */
+	0,							/* U+002B27 */
+	0,							/* U+002B28 */
+	0,							/* U+002B29 */
+	0,							/* U+002B2A */
+	0,							/* U+002B2B */
+	0,							/* U+002B2C */
+	0,							/* U+002B2D */
+	0,							/* U+002B2E */
+	0,							/* U+002B2F */
+	0,							/* U+002B30 */
+	0,							/* U+002B31 */
+	0,							/* U+002B32 */
+	0,							/* U+002B33 */
+	0,							/* U+002B34 */
+	0,							/* U+002B35 */
+	0,							/* U+002B36 */
+	0,							/* U+002B37 */
+	0,							/* U+002B38 */
+	0,							/* U+002B39 */
+	0,							/* U+002B3A */
+	0,							/* U+002B3B */
+	0,							/* U+002B3C */
+	0,							/* U+002B3D */
+	0,							/* U+002B3E */
+	0,							/* U+002B3F */
+	0,							/* U+002B40 */
+	0,							/* U+002B41 */
+	0,							/* U+002B42 */
+	0,							/* U+002B43 */
+	0,							/* U+002B44 */
+	0,							/* U+002B45 */
+	0,							/* U+002B46 */
+	0,							/* U+002B47 */
+	0,							/* U+002B48 */
+	0,							/* U+002B49 */
+	0,							/* U+002B4A */
+	0,							/* U+002B4B */
+	0,							/* U+002B4C */
+	0,							/* U+002B4D */
+	0,							/* U+002B4E */
+	0,							/* U+002B4F */
+	0,							/* U+002B50 */
+	0,							/* U+002B51 */
+	0,							/* U+002B52 */
+	0,							/* U+002B53 */
+	0,							/* U+002B54 */
+	0,							/* U+002B55 */
+	0,							/* U+002B56 */
+	0,							/* U+002B57 */
+	0,							/* U+002B58 */
+	0,							/* U+002B59 */
+	0,							/* U+002B5A */
+	0,							/* U+002B5B */
+	0,							/* U+002B5C */
+	0,							/* U+002B5D */
+	0,							/* U+002B5E */
+	0,							/* U+002B5F */
+	0,							/* U+002B60 */
+	0,							/* U+002B61 */
+	0,							/* U+002B62 */
+	0,							/* U+002B63 */
+	0,							/* U+002B64 */
+	0,							/* U+002B65 */
+	0,							/* U+002B66 */
+	0,							/* U+002B67 */
+	0,							/* U+002B68 */
+	0,							/* U+002B69 */
+	0,							/* U+002B6A */
+	0,							/* U+002B6B */
+	0,							/* U+002B6C */
+	0,							/* U+002B6D */
+	0,							/* U+002B6E */
+	0,							/* U+002B6F */
+	0,							/* U+002B70 */
+	0,							/* U+002B71 */
+	0,							/* U+002B72 */
+	0,							/* U+002B73 */
+	0,							/* U+002B74 */
+	0,							/* U+002B75 */
+	0,							/* U+002B76 */
+	0,							/* U+002B77 */
+	0,							/* U+002B78 */
+	0,							/* U+002B79 */
+	0,							/* U+002B7A */
+	0,							/* U+002B7B */
+	0,							/* U+002B7C */
+	0,							/* U+002B7D */
+	0,							/* U+002B7E */
+	0,							/* U+002B7F */
+	0,							/* U+002B80 */
+	0,							/* U+002B81 */
+	0,							/* U+002B82 */
+	0,							/* U+002B83 */
+	0,							/* U+002B84 */
+	0,							/* U+002B85 */
+	0,							/* U+002B86 */
+	0,							/* U+002B87 */
+	0,							/* U+002B88 */
+	0,							/* U+002B89 */
+	0,							/* U+002B8A */
+	0,							/* U+002B8B */
+	0,							/* U+002B8C */
+	0,							/* U+002B8D */
+	0,							/* U+002B8E */
+	0,							/* U+002B8F */
+	0,							/* U+002B90 */
+	0,							/* U+002B91 */
+	0,							/* U+002B92 */
+	0,							/* U+002B93 */
+	0,							/* U+002B94 */
+	0,							/* U+002B95 */
+	0,							/* U+002B96 */
+	0,							/* U+002B97 */
+	0,							/* U+002B98 */
+	0,							/* U+002B99 */
+	0,							/* U+002B9A */
+	0,							/* U+002B9B */
+	0,							/* U+002B9C */
+	0,							/* U+002B9D */
+	0,							/* U+002B9E */
+	0,							/* U+002B9F */
+	0,							/* U+002BA0 */
+	0,							/* U+002BA1 */
+	0,							/* U+002BA2 */
+	0,							/* U+002BA3 */
+	0,							/* U+002BA4 */
+	0,							/* U+002BA5 */
+	0,							/* U+002BA6 */
+	0,							/* U+002BA7 */
+	0,							/* U+002BA8 */
+	0,							/* U+002BA9 */
+	0,							/* U+002BAA */
+	0,							/* U+002BAB */
+	0,							/* U+002BAC */
+	0,							/* U+002BAD */
+	0,							/* U+002BAE */
+	0,							/* U+002BAF */
+	0,							/* U+002BB0 */
+	0,							/* U+002BB1 */
+	0,							/* U+002BB2 */
+	0,							/* U+002BB3 */
+	0,							/* U+002BB4 */
+	0,							/* U+002BB5 */
+	0,							/* U+002BB6 */
+	0,							/* U+002BB7 */
+	0,							/* U+002BB8 */
+	0,							/* U+002BB9 */
+	0,							/* U+002BBA */
+	0,							/* U+002BBB */
+	0,							/* U+002BBC */
+	0,							/* U+002BBD */
+	0,							/* U+002BBE */
+	0,							/* U+002BBF */
+	0,							/* U+002BC0 */
+	0,							/* U+002BC1 */
+	0,							/* U+002BC2 */
+	0,							/* U+002BC3 */
+	0,							/* U+002BC4 */
+	0,							/* U+002BC5 */
+	0,							/* U+002BC6 */
+	0,							/* U+002BC7 */
+	0,							/* U+002BC8 */
+	0,							/* U+002BC9 */
+	0,							/* U+002BCA */
+	0,							/* U+002BCB */
+	0,							/* U+002BCC */
+	0,							/* U+002BCD */
+	0,							/* U+002BCE */
+	0,							/* U+002BCF */
+	0,							/* U+002BD0 */
+	0,							/* U+002BD1 */
+	0,							/* U+002BD2 */
+	0,							/* U+002BD3 */
+	0,							/* U+002BD4 */
+	0,							/* U+002BD5 */
+	0,							/* U+002BD6 */
+	0,							/* U+002BD7 */
+	0,							/* U+002BD8 */
+	0,							/* U+002BD9 */
+	0,							/* U+002BDA */
+	0,							/* U+002BDB */
+	0,							/* U+002BDC */
+	0,							/* U+002BDD */
+	0,							/* U+002BDE */
+	0,							/* U+002BDF */
+	0,							/* U+002BE0 */
+	0,							/* U+002BE1 */
+	0,							/* U+002BE2 */
+	0,							/* U+002BE3 */
+	0,							/* U+002BE4 */
+	0,							/* U+002BE5 */
+	0,							/* U+002BE6 */
+	0,							/* U+002BE7 */
+	0,							/* U+002BE8 */
+	0,							/* U+002BE9 */
+	0,							/* U+002BEA */
+	0,							/* U+002BEB */
+	0,							/* U+002BEC */
+	0,							/* U+002BED */
+	0,							/* U+002BEE */
+	0,							/* U+002BEF */
+	0,							/* U+002BF0 */
+	0,							/* U+002BF1 */
+	0,							/* U+002BF2 */
+	0,							/* U+002BF3 */
+	0,							/* U+002BF4 */
+	0,							/* U+002BF5 */
+	0,							/* U+002BF6 */
+	0,							/* U+002BF7 */
+	0,							/* U+002BF8 */
+	0,							/* U+002BF9 */
+	0,							/* U+002BFA */
+	0,							/* U+002BFB */
+	0,							/* U+002BFC */
+	0,							/* U+002BFD */
+	0,							/* U+002BFE */
+	0,							/* U+002BFF */
+	0,							/* U+002C00 */
+	0,							/* U+002C01 */
+	0,							/* U+002C02 */
+	0,							/* U+002C03 */
+	0,							/* U+002C04 */
+	0,							/* U+002C05 */
+	0,							/* U+002C06 */
+	0,							/* U+002C07 */
+	0,							/* U+002C08 */
+	0,							/* U+002C09 */
+	0,							/* U+002C0A */
+	0,							/* U+002C0B */
+	0,							/* U+002C0C */
+	0,							/* U+002C0D */
+	0,							/* U+002C0E */
+	0,							/* U+002C0F */
+	0,							/* U+002C10 */
+	0,							/* U+002C11 */
+	0,							/* U+002C12 */
+	0,							/* U+002C13 */
+	0,							/* U+002C14 */
+	0,							/* U+002C15 */
+	0,							/* U+002C16 */
+	0,							/* U+002C17 */
+	0,							/* U+002C18 */
+	0,							/* U+002C19 */
+	0,							/* U+002C1A */
+	0,							/* U+002C1B */
+	0,							/* U+002C1C */
+	0,							/* U+002C1D */
+	0,							/* U+002C1E */
+	0,							/* U+002C1F */
+	0,							/* U+002C20 */
+	0,							/* U+002C21 */
+	0,							/* U+002C22 */
+	0,							/* U+002C23 */
+	0,							/* U+002C24 */
+	0,							/* U+002C25 */
+	0,							/* U+002C26 */
+	0,							/* U+002C27 */
+	0,							/* U+002C28 */
+	0,							/* U+002C29 */
+	0,							/* U+002C2A */
+	0,							/* U+002C2B */
+	0,							/* U+002C2C */
+	0,							/* U+002C2D */
+	0,							/* U+002C2E */
+	0,							/* U+002C2F */
+	0,							/* U+002C30 */
+	0,							/* U+002C31 */
+	0,							/* U+002C32 */
+	0,							/* U+002C33 */
+	0,							/* U+002C34 */
+	0,							/* U+002C35 */
+	0,							/* U+002C36 */
+	0,							/* U+002C37 */
+	0,							/* U+002C38 */
+	0,							/* U+002C39 */
+	0,							/* U+002C3A */
+	0,							/* U+002C3B */
+	0,							/* U+002C3C */
+	0,							/* U+002C3D */
+	0,							/* U+002C3E */
+	0,							/* U+002C3F */
+	0,							/* U+002C40 */
+	0,							/* U+002C41 */
+	0,							/* U+002C42 */
+	0,							/* U+002C43 */
+	0,							/* U+002C44 */
+	0,							/* U+002C45 */
+	0,							/* U+002C46 */
+	0,							/* U+002C47 */
+	0,							/* U+002C48 */
+	0,							/* U+002C49 */
+	0,							/* U+002C4A */
+	0,							/* U+002C4B */
+	0,							/* U+002C4C */
+	0,							/* U+002C4D */
+	0,							/* U+002C4E */
+	0,							/* U+002C4F */
+	0,							/* U+002C50 */
+	0,							/* U+002C51 */
+	0,							/* U+002C52 */
+	0,							/* U+002C53 */
+	0,							/* U+002C54 */
+	0,							/* U+002C55 */
+	0,							/* U+002C56 */
+	0,							/* U+002C57 */
+	0,							/* U+002C58 */
+	0,							/* U+002C59 */
+	0,							/* U+002C5A */
+	0,							/* U+002C5B */
+	0,							/* U+002C5C */
+	0,							/* U+002C5D */
+	0,							/* U+002C5E */
+	0,							/* U+002C5F */
+	0,							/* U+002C60 */
+	0,							/* U+002C61 */
+	0,							/* U+002C62 */
+	0,							/* U+002C63 */
+	0,							/* U+002C64 */
+	0,							/* U+002C65 */
+	0,							/* U+002C66 */
+	0,							/* U+002C67 */
+	0,							/* U+002C68 */
+	0,							/* U+002C69 */
+	0,							/* U+002C6A */
+	0,							/* U+002C6B */
+	0,							/* U+002C6C */
+	0,							/* U+002C6D */
+	0,							/* U+002C6E */
+	0,							/* U+002C6F */
+	0,							/* U+002C70 */
+	0,							/* U+002C71 */
+	0,							/* U+002C72 */
+	0,							/* U+002C73 */
+	0,							/* U+002C74 */
+	0,							/* U+002C75 */
+	0,							/* U+002C76 */
+	0,							/* U+002C77 */
+	0,							/* U+002C78 */
+	0,							/* U+002C79 */
+	0,							/* U+002C7A */
+	0,							/* U+002C7B */
+	287,						/* U+002C7C */
+	1181,						/* U+002C7D */
+	0,							/* U+002C7E */
+	0,							/* U+002C7F */
+	0,							/* U+002C80 */
+	0,							/* U+002C81 */
+	0,							/* U+002C82 */
+	0,							/* U+002C83 */
+	0,							/* U+002C84 */
+	0,							/* U+002C85 */
+	0,							/* U+002C86 */
+	0,							/* U+002C87 */
+	0,							/* U+002C88 */
+	0,							/* U+002C89 */
+	0,							/* U+002C8A */
+	0,							/* U+002C8B */
+	0,							/* U+002C8C */
+	0,							/* U+002C8D */
+	0,							/* U+002C8E */
+	0,							/* U+002C8F */
+	0,							/* U+002C90 */
+	0,							/* U+002C91 */
+	0,							/* U+002C92 */
+	0,							/* U+002C93 */
+	0,							/* U+002C94 */
+	0,							/* U+002C95 */
+	0,							/* U+002C96 */
+	0,							/* U+002C97 */
+	0,							/* U+002C98 */
+	0,							/* U+002C99 */
+	0,							/* U+002C9A */
+	0,							/* U+002C9B */
+	0,							/* U+002C9C */
+	0,							/* U+002C9D */
+	0,							/* U+002C9E */
+	0,							/* U+002C9F */
+	0,							/* U+002CA0 */
+	0,							/* U+002CA1 */
+	0,							/* U+002CA2 */
+	0,							/* U+002CA3 */
+	0,							/* U+002CA4 */
+	0,							/* U+002CA5 */
+	0,							/* U+002CA6 */
+	0,							/* U+002CA7 */
+	0,							/* U+002CA8 */
+	0,							/* U+002CA9 */
+	0,							/* U+002CAA */
+	0,							/* U+002CAB */
+	0,							/* U+002CAC */
+	0,							/* U+002CAD */
+	0,							/* U+002CAE */
+	0,							/* U+002CAF */
+	0,							/* U+002CB0 */
+	0,							/* U+002CB1 */
+	0,							/* U+002CB2 */
+	0,							/* U+002CB3 */
+	0,							/* U+002CB4 */
+	0,							/* U+002CB5 */
+	0,							/* U+002CB6 */
+	0,							/* U+002CB7 */
+	0,							/* U+002CB8 */
+	0,							/* U+002CB9 */
+	0,							/* U+002CBA */
+	0,							/* U+002CBB */
+	0,							/* U+002CBC */
+	0,							/* U+002CBD */
+	0,							/* U+002CBE */
+	0,							/* U+002CBF */
+	0,							/* U+002CC0 */
+	0,							/* U+002CC1 */
+	0,							/* U+002CC2 */
+	0,							/* U+002CC3 */
+	0,							/* U+002CC4 */
+	0,							/* U+002CC5 */
+	0,							/* U+002CC6 */
+	0,							/* U+002CC7 */
+	0,							/* U+002CC8 */
+	0,							/* U+002CC9 */
+	0,							/* U+002CCA */
+	0,							/* U+002CCB */
+	0,							/* U+002CCC */
+	0,							/* U+002CCD */
+	0,							/* U+002CCE */
+	0,							/* U+002CCF */
+	0,							/* U+002CD0 */
+	0,							/* U+002CD1 */
+	0,							/* U+002CD2 */
+	0,							/* U+002CD3 */
+	0,							/* U+002CD4 */
+	0,							/* U+002CD5 */
+	0,							/* U+002CD6 */
+	0,							/* U+002CD7 */
+	0,							/* U+002CD8 */
+	0,							/* U+002CD9 */
+	0,							/* U+002CDA */
+	0,							/* U+002CDB */
+	0,							/* U+002CDC */
+	0,							/* U+002CDD */
+	0,							/* U+002CDE */
+	0,							/* U+002CDF */
+	0,							/* U+002CE0 */
+	0,							/* U+002CE1 */
+	0,							/* U+002CE2 */
+	0,							/* U+002CE3 */
+	0,							/* U+002CE4 */
+	0,							/* U+002CE5 */
+	0,							/* U+002CE6 */
+	0,							/* U+002CE7 */
+	0,							/* U+002CE8 */
+	0,							/* U+002CE9 */
+	0,							/* U+002CEA */
+	0,							/* U+002CEB */
+	0,							/* U+002CEC */
+	0,							/* U+002CED */
+	0,							/* U+002CEE */
+	304,						/* U+002CEF */
+	304,						/* U+002CF0 */
+	304,						/* U+002CF1 */
+	0,							/* U+002CF2 */
+	0,							/* U+002CF3 */
+	0,							/* U+002CF4 */
+	0,							/* U+002CF5 */
+	0,							/* U+002CF6 */
+	0,							/* U+002CF7 */
+	0,							/* U+002CF8 */
+	0,							/* U+002CF9 */
+	0,							/* U+002CFA */
+	0,							/* U+002CFB */
+	0,							/* U+002CFC */
+	0,							/* U+002CFD */
+	0,							/* U+002CFE */
+	0,							/* U+002CFF */
+	0,							/* U+002D00 */
+	0,							/* U+002D01 */
+	0,							/* U+002D02 */
+	0,							/* U+002D03 */
+	0,							/* U+002D04 */
+	0,							/* U+002D05 */
+	0,							/* U+002D06 */
+	0,							/* U+002D07 */
+	0,							/* U+002D08 */
+	0,							/* U+002D09 */
+	0,							/* U+002D0A */
+	0,							/* U+002D0B */
+	0,							/* U+002D0C */
+	0,							/* U+002D0D */
+	0,							/* U+002D0E */
+	0,							/* U+002D0F */
+	0,							/* U+002D10 */
+	0,							/* U+002D11 */
+	0,							/* U+002D12 */
+	0,							/* U+002D13 */
+	0,							/* U+002D14 */
+	0,							/* U+002D15 */
+	0,							/* U+002D16 */
+	0,							/* U+002D17 */
+	0,							/* U+002D18 */
+	0,							/* U+002D19 */
+	0,							/* U+002D1A */
+	0,							/* U+002D1B */
+	0,							/* U+002D1C */
+	0,							/* U+002D1D */
+	0,							/* U+002D1E */
+	0,							/* U+002D1F */
+	0,							/* U+002D20 */
+	0,							/* U+002D21 */
+	0,							/* U+002D22 */
+	0,							/* U+002D23 */
+	0,							/* U+002D24 */
+	0,							/* U+002D25 */
+	0,							/* U+002D26 */
+	0,							/* U+002D27 */
+	0,							/* U+002D28 */
+	0,							/* U+002D29 */
+	0,							/* U+002D2A */
+	0,							/* U+002D2B */
+	0,							/* U+002D2C */
+	0,							/* U+002D2D */
+	0,							/* U+002D2E */
+	0,							/* U+002D2F */
+	0,							/* U+002D30 */
+	0,							/* U+002D31 */
+	0,							/* U+002D32 */
+	0,							/* U+002D33 */
+	0,							/* U+002D34 */
+	0,							/* U+002D35 */
+	0,							/* U+002D36 */
+	0,							/* U+002D37 */
+	0,							/* U+002D38 */
+	0,							/* U+002D39 */
+	0,							/* U+002D3A */
+	0,							/* U+002D3B */
+	0,							/* U+002D3C */
+	0,							/* U+002D3D */
+	0,							/* U+002D3E */
+	0,							/* U+002D3F */
+	0,							/* U+002D40 */
+	0,							/* U+002D41 */
+	0,							/* U+002D42 */
+	0,							/* U+002D43 */
+	0,							/* U+002D44 */
+	0,							/* U+002D45 */
+	0,							/* U+002D46 */
+	0,							/* U+002D47 */
+	0,							/* U+002D48 */
+	0,							/* U+002D49 */
+	0,							/* U+002D4A */
+	0,							/* U+002D4B */
+	0,							/* U+002D4C */
+	0,							/* U+002D4D */
+	0,							/* U+002D4E */
+	0,							/* U+002D4F */
+	0,							/* U+002D50 */
+	0,							/* U+002D51 */
+	0,							/* U+002D52 */
+	0,							/* U+002D53 */
+	0,							/* U+002D54 */
+	0,							/* U+002D55 */
+	0,							/* U+002D56 */
+	0,							/* U+002D57 */
+	0,							/* U+002D58 */
+	0,							/* U+002D59 */
+	0,							/* U+002D5A */
+	0,							/* U+002D5B */
+	0,							/* U+002D5C */
+	0,							/* U+002D5D */
+	0,							/* U+002D5E */
+	0,							/* U+002D5F */
+	0,							/* U+002D60 */
+	0,							/* U+002D61 */
+	0,							/* U+002D62 */
+	0,							/* U+002D63 */
+	0,							/* U+002D64 */
+	0,							/* U+002D65 */
+	0,							/* U+002D66 */
+	0,							/* U+002D67 */
+	0,							/* U+002D68 */
+	0,							/* U+002D69 */
+	0,							/* U+002D6A */
+	0,							/* U+002D6B */
+	0,							/* U+002D6C */
+	0,							/* U+002D6D */
+	0,							/* U+002D6E */
+	1334,						/* U+002D6F */
+	0,							/* U+002D70 */
+	0,							/* U+002D71 */
+	0,							/* U+002D72 */
+	0,							/* U+002D73 */
+	0,							/* U+002D74 */
+	0,							/* U+002D75 */
+	0,							/* U+002D76 */
+	0,							/* U+002D77 */
+	0,							/* U+002D78 */
+	0,							/* U+002D79 */
+	0,							/* U+002D7A */
+	0,							/* U+002D7B */
+	0,							/* U+002D7C */
+	0,							/* U+002D7D */
+	0,							/* U+002D7E */
+	452,						/* U+002D7F */
+	0,							/* U+002D80 */
+	0,							/* U+002D81 */
+	0,							/* U+002D82 */
+	0,							/* U+002D83 */
+	0,							/* U+002D84 */
+	0,							/* U+002D85 */
+	0,							/* U+002D86 */
+	0,							/* U+002D87 */
+	0,							/* U+002D88 */
+	0,							/* U+002D89 */
+	0,							/* U+002D8A */
+	0,							/* U+002D8B */
+	0,							/* U+002D8C */
+	0,							/* U+002D8D */
+	0,							/* U+002D8E */
+	0,							/* U+002D8F */
+	0,							/* U+002D90 */
+	0,							/* U+002D91 */
+	0,							/* U+002D92 */
+	0,							/* U+002D93 */
+	0,							/* U+002D94 */
+	0,							/* U+002D95 */
+	0,							/* U+002D96 */
+	0,							/* U+002D97 */
+	0,							/* U+002D98 */
+	0,							/* U+002D99 */
+	0,							/* U+002D9A */
+	0,							/* U+002D9B */
+	0,							/* U+002D9C */
+	0,							/* U+002D9D */
+	0,							/* U+002D9E */
+	0,							/* U+002D9F */
+	0,							/* U+002DA0 */
+	0,							/* U+002DA1 */
+	0,							/* U+002DA2 */
+	0,							/* U+002DA3 */
+	0,							/* U+002DA4 */
+	0,							/* U+002DA5 */
+	0,							/* U+002DA6 */
+	0,							/* U+002DA7 */
+	0,							/* U+002DA8 */
+	0,							/* U+002DA9 */
+	0,							/* U+002DAA */
+	0,							/* U+002DAB */
+	0,							/* U+002DAC */
+	0,							/* U+002DAD */
+	0,							/* U+002DAE */
+	0,							/* U+002DAF */
+	0,							/* U+002DB0 */
+	0,							/* U+002DB1 */
+	0,							/* U+002DB2 */
+	0,							/* U+002DB3 */
+	0,							/* U+002DB4 */
+	0,							/* U+002DB5 */
+	0,							/* U+002DB6 */
+	0,							/* U+002DB7 */
+	0,							/* U+002DB8 */
+	0,							/* U+002DB9 */
+	0,							/* U+002DBA */
+	0,							/* U+002DBB */
+	0,							/* U+002DBC */
+	0,							/* U+002DBD */
+	0,							/* U+002DBE */
+	0,							/* U+002DBF */
+	0,							/* U+002DC0 */
+	0,							/* U+002DC1 */
+	0,							/* U+002DC2 */
+	0,							/* U+002DC3 */
+	0,							/* U+002DC4 */
+	0,							/* U+002DC5 */
+	0,							/* U+002DC6 */
+	0,							/* U+002DC7 */
+	0,							/* U+002DC8 */
+	0,							/* U+002DC9 */
+	0,							/* U+002DCA */
+	0,							/* U+002DCB */
+	0,							/* U+002DCC */
+	0,							/* U+002DCD */
+	0,							/* U+002DCE */
+	0,							/* U+002DCF */
+	0,							/* U+002DD0 */
+	0,							/* U+002DD1 */
+	0,							/* U+002DD2 */
+	0,							/* U+002DD3 */
+	0,							/* U+002DD4 */
+	0,							/* U+002DD5 */
+	0,							/* U+002DD6 */
+	0,							/* U+002DD7 */
+	0,							/* U+002DD8 */
+	0,							/* U+002DD9 */
+	0,							/* U+002DDA */
+	0,							/* U+002DDB */
+	0,							/* U+002DDC */
+	0,							/* U+002DDD */
+	0,							/* U+002DDE */
+	0,							/* U+002DDF */
+	304,						/* U+002DE0 */
+	304,						/* U+002DE1 */
+	304,						/* U+002DE2 */
+	304,						/* U+002DE3 */
+	304,						/* U+002DE4 */
+	304,						/* U+002DE5 */
+	304,						/* U+002DE6 */
+	304,						/* U+002DE7 */
+	304,						/* U+002DE8 */
+	304,						/* U+002DE9 */
+	304,						/* U+002DEA */
+	304,						/* U+002DEB */
+	304,						/* U+002DEC */
+	304,						/* U+002DED */
+	304,						/* U+002DEE */
+	304,						/* U+002DEF */
+	304,						/* U+002DF0 */
+	304,						/* U+002DF1 */
+	304,						/* U+002DF2 */
+	304,						/* U+002DF3 */
+	304,						/* U+002DF4 */
+	304,						/* U+002DF5 */
+	304,						/* U+002DF6 */
+	304,						/* U+002DF7 */
+	304,						/* U+002DF8 */
+	304,						/* U+002DF9 */
+	304,						/* U+002DFA */
+	304,						/* U+002DFB */
+	304,						/* U+002DFC */
+	304,						/* U+002DFD */
+	304,						/* U+002DFE */
+	304,						/* U+002DFF */
+	0,							/* U+002E00 */
+	0,							/* U+002E01 */
+	0,							/* U+002E02 */
+	0,							/* U+002E03 */
+	0,							/* U+002E04 */
+	0,							/* U+002E05 */
+	0,							/* U+002E06 */
+	0,							/* U+002E07 */
+	0,							/* U+002E08 */
+	0,							/* U+002E09 */
+	0,							/* U+002E0A */
+	0,							/* U+002E0B */
+	0,							/* U+002E0C */
+	0,							/* U+002E0D */
+	0,							/* U+002E0E */
+	0,							/* U+002E0F */
+	0,							/* U+002E10 */
+	0,							/* U+002E11 */
+	0,							/* U+002E12 */
+	0,							/* U+002E13 */
+	0,							/* U+002E14 */
+	0,							/* U+002E15 */
+	0,							/* U+002E16 */
+	0,							/* U+002E17 */
+	0,							/* U+002E18 */
+	0,							/* U+002E19 */
+	0,							/* U+002E1A */
+	0,							/* U+002E1B */
+	0,							/* U+002E1C */
+	0,							/* U+002E1D */
+	0,							/* U+002E1E */
+	0,							/* U+002E1F */
+	0,							/* U+002E20 */
+	0,							/* U+002E21 */
+	0,							/* U+002E22 */
+	0,							/* U+002E23 */
+	0,							/* U+002E24 */
+	0,							/* U+002E25 */
+	0,							/* U+002E26 */
+	0,							/* U+002E27 */
+	0,							/* U+002E28 */
+	0,							/* U+002E29 */
+	0,							/* U+002E2A */
+	0,							/* U+002E2B */
+	0,							/* U+002E2C */
+	0,							/* U+002E2D */
+	0,							/* U+002E2E */
+	0,							/* U+002E2F */
+	0,							/* U+002E30 */
+	0,							/* U+002E31 */
+	0,							/* U+002E32 */
+	0,							/* U+002E33 */
+	0,							/* U+002E34 */
+	0,							/* U+002E35 */
+	0,							/* U+002E36 */
+	0,							/* U+002E37 */
+	0,							/* U+002E38 */
+	0,							/* U+002E39 */
+	0,							/* U+002E3A */
+	0,							/* U+002E3B */
+	0,							/* U+002E3C */
+	0,							/* U+002E3D */
+	0,							/* U+002E3E */
+	0,							/* U+002E3F */
+	0,							/* U+002E40 */
+	0,							/* U+002E41 */
+	0,							/* U+002E42 */
+	0,							/* U+002E43 */
+	0,							/* U+002E44 */
+	0,							/* U+002E45 */
+	0,							/* U+002E46 */
+	0,							/* U+002E47 */
+	0,							/* U+002E48 */
+	0,							/* U+002E49 */
+	0,							/* U+002E4A */
+	0,							/* U+002E4B */
+	0,							/* U+002E4C */
+	0,							/* U+002E4D */
+	0,							/* U+002E4E */
+	0,							/* U+002E4F */
+	0,							/* U+002E50 */
+	0,							/* U+002E51 */
+	0,							/* U+002E52 */
+	0,							/* U+002E53 */
+	0,							/* U+002E54 */
+	0,							/* U+002E55 */
+	0,							/* U+002E56 */
+	0,							/* U+002E57 */
+	0,							/* U+002E58 */
+	0,							/* U+002E59 */
+	0,							/* U+002E5A */
+	0,							/* U+002E5B */
+	0,							/* U+002E5C */
+	0,							/* U+002E5D */
+	0,							/* U+002E5E */
+	0,							/* U+002E5F */
+	0,							/* U+002E60 */
+	0,							/* U+002E61 */
+	0,							/* U+002E62 */
+	0,							/* U+002E63 */
+	0,							/* U+002E64 */
+	0,							/* U+002E65 */
+	0,							/* U+002E66 */
+	0,							/* U+002E67 */
+	0,							/* U+002E68 */
+	0,							/* U+002E69 */
+	0,							/* U+002E6A */
+	0,							/* U+002E6B */
+	0,							/* U+002E6C */
+	0,							/* U+002E6D */
+	0,							/* U+002E6E */
+	0,							/* U+002E6F */
+	0,							/* U+002E70 */
+	0,							/* U+002E71 */
+	0,							/* U+002E72 */
+	0,							/* U+002E73 */
+	0,							/* U+002E74 */
+	0,							/* U+002E75 */
+	0,							/* U+002E76 */
+	0,							/* U+002E77 */
+	0,							/* U+002E78 */
+	0,							/* U+002E79 */
+	0,							/* U+002E7A */
+	0,							/* U+002E7B */
+	0,							/* U+002E7C */
+	0,							/* U+002E7D */
+	0,							/* U+002E7E */
+	0,							/* U+002E7F */
+	0,							/* U+002E80 */
+	0,							/* U+002E81 */
+	0,							/* U+002E82 */
+	0,							/* U+002E83 */
+	0,							/* U+002E84 */
+	0,							/* U+002E85 */
+	0,							/* U+002E86 */
+	0,							/* U+002E87 */
+	0,							/* U+002E88 */
+	0,							/* U+002E89 */
+	0,							/* U+002E8A */
+	0,							/* U+002E8B */
+	0,							/* U+002E8C */
+	0,							/* U+002E8D */
+	0,							/* U+002E8E */
+	0,							/* U+002E8F */
+	0,							/* U+002E90 */
+	0,							/* U+002E91 */
+	0,							/* U+002E92 */
+	0,							/* U+002E93 */
+	0,							/* U+002E94 */
+	0,							/* U+002E95 */
+	0,							/* U+002E96 */
+	0,							/* U+002E97 */
+	0,							/* U+002E98 */
+	0,							/* U+002E99 */
+	0,							/* U+002E9A */
+	0,							/* U+002E9B */
+	0,							/* U+002E9C */
+	0,							/* U+002E9D */
+	0,							/* U+002E9E */
+	1335,						/* U+002E9F */
+	0,							/* U+002EA0 */
+	0,							/* U+002EA1 */
+	0,							/* U+002EA2 */
+	0,							/* U+002EA3 */
+	0,							/* U+002EA4 */
+	0,							/* U+002EA5 */
+	0,							/* U+002EA6 */
+	0,							/* U+002EA7 */
+	0,							/* U+002EA8 */
+	0,							/* U+002EA9 */
+	0,							/* U+002EAA */
+	0,							/* U+002EAB */
+	0,							/* U+002EAC */
+	0,							/* U+002EAD */
+	0,							/* U+002EAE */
+	0,							/* U+002EAF */
+	0,							/* U+002EB0 */
+	0,							/* U+002EB1 */
+	0,							/* U+002EB2 */
+	0,							/* U+002EB3 */
+	0,							/* U+002EB4 */
+	0,							/* U+002EB5 */
+	0,							/* U+002EB6 */
+	0,							/* U+002EB7 */
+	0,							/* U+002EB8 */
+	0,							/* U+002EB9 */
+	0,							/* U+002EBA */
+	0,							/* U+002EBB */
+	0,							/* U+002EBC */
+	0,							/* U+002EBD */
+	0,							/* U+002EBE */
+	0,							/* U+002EBF */
+	0,							/* U+002EC0 */
+	0,							/* U+002EC1 */
+	0,							/* U+002EC2 */
+	0,							/* U+002EC3 */
+	0,							/* U+002EC4 */
+	0,							/* U+002EC5 */
+	0,							/* U+002EC6 */
+	0,							/* U+002EC7 */
+	0,							/* U+002EC8 */
+	0,							/* U+002EC9 */
+	0,							/* U+002ECA */
+	0,							/* U+002ECB */
+	0,							/* U+002ECC */
+	0,							/* U+002ECD */
+	0,							/* U+002ECE */
+	0,							/* U+002ECF */
+	0,							/* U+002ED0 */
+	0,							/* U+002ED1 */
+	0,							/* U+002ED2 */
+	0,							/* U+002ED3 */
+	0,							/* U+002ED4 */
+	0,							/* U+002ED5 */
+	0,							/* U+002ED6 */
+	0,							/* U+002ED7 */
+	0,							/* U+002ED8 */
+	0,							/* U+002ED9 */
+	0,							/* U+002EDA */
+	0,							/* U+002EDB */
+	0,							/* U+002EDC */
+	0,							/* U+002EDD */
+	0,							/* U+002EDE */
+	0,							/* U+002EDF */
+	0,							/* U+002EE0 */
+	0,							/* U+002EE1 */
+	0,							/* U+002EE2 */
+	0,							/* U+002EE3 */
+	0,							/* U+002EE4 */
+	0,							/* U+002EE5 */
+	0,							/* U+002EE6 */
+	0,							/* U+002EE7 */
+	0,							/* U+002EE8 */
+	0,							/* U+002EE9 */
+	0,							/* U+002EEA */
+	0,							/* U+002EEB */
+	0,							/* U+002EEC */
+	0,							/* U+002EED */
+	0,							/* U+002EEE */
+	0,							/* U+002EEF */
+	0,							/* U+002EF0 */
+	0,							/* U+002EF1 */
+	0,							/* U+002EF2 */
+	1336,						/* U+002EF3 */
+	0,							/* U+002EF4 */
+	0,							/* U+002EF5 */
+	0,							/* U+002EF6 */
+	0,							/* U+002EF7 */
+	0,							/* U+002EF8 */
+	0,							/* U+002EF9 */
+	0,							/* U+002EFA */
+	0,							/* U+002EFB */
+	0,							/* U+002EFC */
+	0,							/* U+002EFD */
+	0,							/* U+002EFE */
+	0,							/* U+002EFF */
+	1337,						/* U+002F00 */
+	1338,						/* U+002F01 */
+	1339,						/* U+002F02 */
+	1340,						/* U+002F03 */
+	1341,						/* U+002F04 */
+	1342,						/* U+002F05 */
+	1343,						/* U+002F06 */
+	1344,						/* U+002F07 */
+	1345,						/* U+002F08 */
+	1346,						/* U+002F09 */
+	1347,						/* U+002F0A */
+	1348,						/* U+002F0B */
+	1349,						/* U+002F0C */
+	1350,						/* U+002F0D */
+	1351,						/* U+002F0E */
+	1352,						/* U+002F0F */
+	1353,						/* U+002F10 */
+	1354,						/* U+002F11 */
+	1355,						/* U+002F12 */
+	1356,						/* U+002F13 */
+	1357,						/* U+002F14 */
+	1358,						/* U+002F15 */
+	1359,						/* U+002F16 */
+	1360,						/* U+002F17 */
+	1361,						/* U+002F18 */
+	1362,						/* U+002F19 */
+	1363,						/* U+002F1A */
+	1364,						/* U+002F1B */
+	1365,						/* U+002F1C */
+	1366,						/* U+002F1D */
+	1367,						/* U+002F1E */
+	1368,						/* U+002F1F */
+	1369,						/* U+002F20 */
+	1370,						/* U+002F21 */
+	1371,						/* U+002F22 */
+	1372,						/* U+002F23 */
+	1373,						/* U+002F24 */
+	1374,						/* U+002F25 */
+	1375,						/* U+002F26 */
+	1376,						/* U+002F27 */
+	1377,						/* U+002F28 */
+	1378,						/* U+002F29 */
+	1379,						/* U+002F2A */
+	1380,						/* U+002F2B */
+	1381,						/* U+002F2C */
+	1382,						/* U+002F2D */
+	1383,						/* U+002F2E */
+	1384,						/* U+002F2F */
+	1385,						/* U+002F30 */
+	1386,						/* U+002F31 */
+	1387,						/* U+002F32 */
+	1388,						/* U+002F33 */
+	1389,						/* U+002F34 */
+	1390,						/* U+002F35 */
+	1391,						/* U+002F36 */
+	1392,						/* U+002F37 */
+	1393,						/* U+002F38 */
+	1394,						/* U+002F39 */
+	1395,						/* U+002F3A */
+	1396,						/* U+002F3B */
+	1397,						/* U+002F3C */
+	1398,						/* U+002F3D */
+	1399,						/* U+002F3E */
+	1400,						/* U+002F3F */
+	1401,						/* U+002F40 */
+	1402,						/* U+002F41 */
+	1403,						/* U+002F42 */
+	1404,						/* U+002F43 */
+	1405,						/* U+002F44 */
+	1406,						/* U+002F45 */
+	1407,						/* U+002F46 */
+	1408,						/* U+002F47 */
+	1409,						/* U+002F48 */
+	1410,						/* U+002F49 */
+	1411,						/* U+002F4A */
+	1412,						/* U+002F4B */
+	1413,						/* U+002F4C */
+	1414,						/* U+002F4D */
+	1415,						/* U+002F4E */
+	1416,						/* U+002F4F */
+	1417,						/* U+002F50 */
+	1418,						/* U+002F51 */
+	1419,						/* U+002F52 */
+	1420,						/* U+002F53 */
+	1421,						/* U+002F54 */
+	1422,						/* U+002F55 */
+	1423,						/* U+002F56 */
+	1424,						/* U+002F57 */
+	1425,						/* U+002F58 */
+	1426,						/* U+002F59 */
+	1427,						/* U+002F5A */
+	1428,						/* U+002F5B */
+	1429,						/* U+002F5C */
+	1430,						/* U+002F5D */
+	1431,						/* U+002F5E */
+	1432,						/* U+002F5F */
+	1433,						/* U+002F60 */
+	1434,						/* U+002F61 */
+	1435,						/* U+002F62 */
+	1436,						/* U+002F63 */
+	1437,						/* U+002F64 */
+	1438,						/* U+002F65 */
+	1439,						/* U+002F66 */
+	1440,						/* U+002F67 */
+	1441,						/* U+002F68 */
+	1442,						/* U+002F69 */
+	1443,						/* U+002F6A */
+	1444,						/* U+002F6B */
+	1445,						/* U+002F6C */
+	1446,						/* U+002F6D */
+	1447,						/* U+002F6E */
+	1448,						/* U+002F6F */
+	1449,						/* U+002F70 */
+	1450,						/* U+002F71 */
+	1451,						/* U+002F72 */
+	1452,						/* U+002F73 */
+	1453,						/* U+002F74 */
+	1454,						/* U+002F75 */
+	1455,						/* U+002F76 */
+	1456,						/* U+002F77 */
+	1457,						/* U+002F78 */
+	1458,						/* U+002F79 */
+	1459,						/* U+002F7A */
+	1460,						/* U+002F7B */
+	1461,						/* U+002F7C */
+	1462,						/* U+002F7D */
+	1463,						/* U+002F7E */
+	1464,						/* U+002F7F */
+	1465,						/* U+002F80 */
+	1466,						/* U+002F81 */
+	1467,						/* U+002F82 */
+	1468,						/* U+002F83 */
+	1469,						/* U+002F84 */
+	1470,						/* U+002F85 */
+	1471,						/* U+002F86 */
+	1472,						/* U+002F87 */
+	1473,						/* U+002F88 */
+	1474,						/* U+002F89 */
+	1475,						/* U+002F8A */
+	1476,						/* U+002F8B */
+	1477,						/* U+002F8C */
+	1478,						/* U+002F8D */
+	1479,						/* U+002F8E */
+	1480,						/* U+002F8F */
+	1481,						/* U+002F90 */
+	1482,						/* U+002F91 */
+	1483,						/* U+002F92 */
+	1484,						/* U+002F93 */
+	1485,						/* U+002F94 */
+	1486,						/* U+002F95 */
+	1487,						/* U+002F96 */
+	1488,						/* U+002F97 */
+	1489,						/* U+002F98 */
+	1490,						/* U+002F99 */
+	1491,						/* U+002F9A */
+	1492,						/* U+002F9B */
+	1493,						/* U+002F9C */
+	1494,						/* U+002F9D */
+	1495,						/* U+002F9E */
+	1496,						/* U+002F9F */
+	1497,						/* U+002FA0 */
+	1498,						/* U+002FA1 */
+	1499,						/* U+002FA2 */
+	1500,						/* U+002FA3 */
+	1501,						/* U+002FA4 */
+	1502,						/* U+002FA5 */
+	1503,						/* U+002FA6 */
+	1504,						/* U+002FA7 */
+	1505,						/* U+002FA8 */
+	1506,						/* U+002FA9 */
+	1507,						/* U+002FAA */
+	1508,						/* U+002FAB */
+	1509,						/* U+002FAC */
+	1510,						/* U+002FAD */
+	1511,						/* U+002FAE */
+	1512,						/* U+002FAF */
+	1513,						/* U+002FB0 */
+	1514,						/* U+002FB1 */
+	1515,						/* U+002FB2 */
+	1516,						/* U+002FB3 */
+	1517,						/* U+002FB4 */
+	1518,						/* U+002FB5 */
+	1519,						/* U+002FB6 */
+	1520,						/* U+002FB7 */
+	1521,						/* U+002FB8 */
+	1522,						/* U+002FB9 */
+	1523,						/* U+002FBA */
+	1524,						/* U+002FBB */
+	1525,						/* U+002FBC */
+	1526,						/* U+002FBD */
+	1527,						/* U+002FBE */
+	1528,						/* U+002FBF */
+	1529,						/* U+002FC0 */
+	1530,						/* U+002FC1 */
+	1531,						/* U+002FC2 */
+	1532,						/* U+002FC3 */
+	1533,						/* U+002FC4 */
+	1534,						/* U+002FC5 */
+	1535,						/* U+002FC6 */
+	1536,						/* U+002FC7 */
+	1537,						/* U+002FC8 */
+	1538,						/* U+002FC9 */
+	1539,						/* U+002FCA */
+	1540,						/* U+002FCB */
+	1541,						/* U+002FCC */
+	1542,						/* U+002FCD */
+	1543,						/* U+002FCE */
+	1544,						/* U+002FCF */
+	1545,						/* U+002FD0 */
+	1546,						/* U+002FD1 */
+	1547,						/* U+002FD2 */
+	1548,						/* U+002FD3 */
+	1549,						/* U+002FD4 */
+	1550,						/* U+002FD5 */
+	0,							/* U+002FD6 */
+	0,							/* U+002FD7 */
+	0,							/* U+002FD8 */
+	0,							/* U+002FD9 */
+	0,							/* U+002FDA */
+	0,							/* U+002FDB */
+	0,							/* U+002FDC */
+	0,							/* U+002FDD */
+	0,							/* U+002FDE */
+	0,							/* U+002FDF */
+	0,							/* U+002FE0 */
+	0,							/* U+002FE1 */
+	0,							/* U+002FE2 */
+	0,							/* U+002FE3 */
+	0,							/* U+002FE4 */
+	0,							/* U+002FE5 */
+	0,							/* U+002FE6 */
+	0,							/* U+002FE7 */
+	0,							/* U+002FE8 */
+	0,							/* U+002FE9 */
+	0,							/* U+002FEA */
+	0,							/* U+002FEB */
+	0,							/* U+002FEC */
+	0,							/* U+002FED */
+	0,							/* U+002FEE */
+	0,							/* U+002FEF */
+	0,							/* U+002FF0 */
+	0,							/* U+002FF1 */
+	0,							/* U+002FF2 */
+	0,							/* U+002FF3 */
+	0,							/* U+002FF4 */
+	0,							/* U+002FF5 */
+	0,							/* U+002FF6 */
+	0,							/* U+002FF7 */
+	0,							/* U+002FF8 */
+	0,							/* U+002FF9 */
+	0,							/* U+002FFA */
+	0,							/* U+002FFB */
+	0,							/* U+002FFC */
+	0,							/* U+002FFD */
+	0,							/* U+002FFE */
+	0,							/* U+002FFF */
+	1,							/* U+003000 */
+	0,							/* U+003001 */
+	0,							/* U+003002 */
+	0,							/* U+003003 */
+	0,							/* U+003004 */
+	0,							/* U+003005 */
+	0,							/* U+003006 */
+	0,							/* U+003007 */
+	0,							/* U+003008 */
+	0,							/* U+003009 */
+	0,							/* U+00300A */
+	0,							/* U+00300B */
+	0,							/* U+00300C */
+	0,							/* U+00300D */
+	0,							/* U+00300E */
+	0,							/* U+00300F */
+	0,							/* U+003010 */
+	0,							/* U+003011 */
+	0,							/* U+003012 */
+	0,							/* U+003013 */
+	0,							/* U+003014 */
+	0,							/* U+003015 */
+	0,							/* U+003016 */
+	0,							/* U+003017 */
+	0,							/* U+003018 */
+	0,							/* U+003019 */
+	0,							/* U+00301A */
+	0,							/* U+00301B */
+	0,							/* U+00301C */
+	0,							/* U+00301D */
+	0,							/* U+00301E */
+	0,							/* U+00301F */
+	0,							/* U+003020 */
+	0,							/* U+003021 */
+	0,							/* U+003022 */
+	0,							/* U+003023 */
+	0,							/* U+003024 */
+	0,							/* U+003025 */
+	0,							/* U+003026 */
+	0,							/* U+003027 */
+	0,							/* U+003028 */
+	0,							/* U+003029 */
+	625,						/* U+00302A */
+	409,						/* U+00302B */
+	305,						/* U+00302C */
+	408,						/* U+00302D */
+	1551,						/* U+00302E */
+	1551,						/* U+00302F */
+	0,							/* U+003030 */
+	0,							/* U+003031 */
+	0,							/* U+003032 */
+	0,							/* U+003033 */
+	0,							/* U+003034 */
+	0,							/* U+003035 */
+	1552,						/* U+003036 */
+	0,							/* U+003037 */
+	1360,						/* U+003038 */
+	1553,						/* U+003039 */
+	1554,						/* U+00303A */
+	0,							/* U+00303B */
+	0,							/* U+00303C */
+	0,							/* U+00303D */
+	0,							/* U+00303E */
+	0,							/* U+00303F */
+	0,							/* U+003040 */
+	0,							/* U+003041 */
+	0,							/* U+003042 */
+	0,							/* U+003043 */
+	0,							/* U+003044 */
+	0,							/* U+003045 */
+	0,							/* U+003046 */
+	0,							/* U+003047 */
+	0,							/* U+003048 */
+	0,							/* U+003049 */
+	0,							/* U+00304A */
+	0,							/* U+00304B */
+	1555,						/* U+00304C */
+	0,							/* U+00304D */
+	1556,						/* U+00304E */
+	0,							/* U+00304F */
+	1557,						/* U+003050 */
+	0,							/* U+003051 */
+	1558,						/* U+003052 */
+	0,							/* U+003053 */
+	1559,						/* U+003054 */
+	0,							/* U+003055 */
+	1560,						/* U+003056 */
+	0,							/* U+003057 */
+	1561,						/* U+003058 */
+	0,							/* U+003059 */
+	1562,						/* U+00305A */
+	0,							/* U+00305B */
+	1563,						/* U+00305C */
+	0,							/* U+00305D */
+	1564,						/* U+00305E */
+	0,							/* U+00305F */
+	1565,						/* U+003060 */
+	0,							/* U+003061 */
+	1566,						/* U+003062 */
+	0,							/* U+003063 */
+	0,							/* U+003064 */
+	1567,						/* U+003065 */
+	0,							/* U+003066 */
+	1568,						/* U+003067 */
+	0,							/* U+003068 */
+	1569,						/* U+003069 */
+	0,							/* U+00306A */
+	0,							/* U+00306B */
+	0,							/* U+00306C */
+	0,							/* U+00306D */
+	0,							/* U+00306E */
+	0,							/* U+00306F */
+	1570,						/* U+003070 */
+	1571,						/* U+003071 */
+	0,							/* U+003072 */
+	1572,						/* U+003073 */
+	1573,						/* U+003074 */
+	0,							/* U+003075 */
+	1574,						/* U+003076 */
+	1575,						/* U+003077 */
+	0,							/* U+003078 */
+	1576,						/* U+003079 */
+	1577,						/* U+00307A */
+	0,							/* U+00307B */
+	1578,						/* U+00307C */
+	1579,						/* U+00307D */
+	0,							/* U+00307E */
+	0,							/* U+00307F */
+	0,							/* U+003080 */
+	0,							/* U+003081 */
+	0,							/* U+003082 */
+	0,							/* U+003083 */
+	0,							/* U+003084 */
+	0,							/* U+003085 */
+	0,							/* U+003086 */
+	0,							/* U+003087 */
+	0,							/* U+003088 */
+	0,							/* U+003089 */
+	0,							/* U+00308A */
+	0,							/* U+00308B */
+	0,							/* U+00308C */
+	0,							/* U+00308D */
+	0,							/* U+00308E */
+	0,							/* U+00308F */
+	0,							/* U+003090 */
+	0,							/* U+003091 */
+	0,							/* U+003092 */
+	0,							/* U+003093 */
+	1580,						/* U+003094 */
+	0,							/* U+003095 */
+	0,							/* U+003096 */
+	0,							/* U+003097 */
+	0,							/* U+003098 */
+	1581,						/* U+003099 */
+	1581,						/* U+00309A */
+	1582,						/* U+00309B */
+	1583,						/* U+00309C */
+	0,							/* U+00309D */
+	1584,						/* U+00309E */
+	1585,						/* U+00309F */
+	0,							/* U+0030A0 */
+	0,							/* U+0030A1 */
+	0,							/* U+0030A2 */
+	0,							/* U+0030A3 */
+	0,							/* U+0030A4 */
+	0,							/* U+0030A5 */
+	0,							/* U+0030A6 */
+	0,							/* U+0030A7 */
+	0,							/* U+0030A8 */
+	0,							/* U+0030A9 */
+	0,							/* U+0030AA */
+	0,							/* U+0030AB */
+	1586,						/* U+0030AC */
+	0,							/* U+0030AD */
+	1587,						/* U+0030AE */
+	0,							/* U+0030AF */
+	1588,						/* U+0030B0 */
+	0,							/* U+0030B1 */
+	1589,						/* U+0030B2 */
+	0,							/* U+0030B3 */
+	1590,						/* U+0030B4 */
+	0,							/* U+0030B5 */
+	1591,						/* U+0030B6 */
+	0,							/* U+0030B7 */
+	1592,						/* U+0030B8 */
+	0,							/* U+0030B9 */
+	1593,						/* U+0030BA */
+	0,							/* U+0030BB */
+	1594,						/* U+0030BC */
+	0,							/* U+0030BD */
+	1595,						/* U+0030BE */
+	0,							/* U+0030BF */
+	1596,						/* U+0030C0 */
+	0,							/* U+0030C1 */
+	1597,						/* U+0030C2 */
+	0,							/* U+0030C3 */
+	0,							/* U+0030C4 */
+	1598,						/* U+0030C5 */
+	0,							/* U+0030C6 */
+	1599,						/* U+0030C7 */
+	0,							/* U+0030C8 */
+	1600,						/* U+0030C9 */
+	0,							/* U+0030CA */
+	0,							/* U+0030CB */
+	0,							/* U+0030CC */
+	0,							/* U+0030CD */
+	0,							/* U+0030CE */
+	0,							/* U+0030CF */
+	1601,						/* U+0030D0 */
+	1602,						/* U+0030D1 */
+	0,							/* U+0030D2 */
+	1603,						/* U+0030D3 */
+	1604,						/* U+0030D4 */
+	0,							/* U+0030D5 */
+	1605,						/* U+0030D6 */
+	1606,						/* U+0030D7 */
+	0,							/* U+0030D8 */
+	1607,						/* U+0030D9 */
+	1608,						/* U+0030DA */
+	0,							/* U+0030DB */
+	1609,						/* U+0030DC */
+	1610,						/* U+0030DD */
+	0,							/* U+0030DE */
+	0,							/* U+0030DF */
+	0,							/* U+0030E0 */
+	0,							/* U+0030E1 */
+	0,							/* U+0030E2 */
+	0,							/* U+0030E3 */
+	0,							/* U+0030E4 */
+	0,							/* U+0030E5 */
+	0,							/* U+0030E6 */
+	0,							/* U+0030E7 */
+	0,							/* U+0030E8 */
+	0,							/* U+0030E9 */
+	0,							/* U+0030EA */
+	0,							/* U+0030EB */
+	0,							/* U+0030EC */
+	0,							/* U+0030ED */
+	0,							/* U+0030EE */
+	0,							/* U+0030EF */
+	0,							/* U+0030F0 */
+	0,							/* U+0030F1 */
+	0,							/* U+0030F2 */
+	0,							/* U+0030F3 */
+	1611,						/* U+0030F4 */
+	0,							/* U+0030F5 */
+	0,							/* U+0030F6 */
+	1612,						/* U+0030F7 */
+	1613,						/* U+0030F8 */
+	1614,						/* U+0030F9 */
+	1615,						/* U+0030FA */
+	0,							/* U+0030FB */
+	0,							/* U+0030FC */
+	0,							/* U+0030FD */
+	1616,						/* U+0030FE */
+	1617,						/* U+0030FF */
+	0,							/* U+003100 */
+	0,							/* U+003101 */
+	0,							/* U+003102 */
+	0,							/* U+003103 */
+	0,							/* U+003104 */
+	0,							/* U+003105 */
+	0,							/* U+003106 */
+	0,							/* U+003107 */
+	0,							/* U+003108 */
+	0,							/* U+003109 */
+	0,							/* U+00310A */
+	0,							/* U+00310B */
+	0,							/* U+00310C */
+	0,							/* U+00310D */
+	0,							/* U+00310E */
+	0,							/* U+00310F */
+	0,							/* U+003110 */
+	0,							/* U+003111 */
+	0,							/* U+003112 */
+	0,							/* U+003113 */
+	0,							/* U+003114 */
+	0,							/* U+003115 */
+	0,							/* U+003116 */
+	0,							/* U+003117 */
+	0,							/* U+003118 */
+	0,							/* U+003119 */
+	0,							/* U+00311A */
+	0,							/* U+00311B */
+	0,							/* U+00311C */
+	0,							/* U+00311D */
+	0,							/* U+00311E */
+	0,							/* U+00311F */
+	0,							/* U+003120 */
+	0,							/* U+003121 */
+	0,							/* U+003122 */
+	0,							/* U+003123 */
+	0,							/* U+003124 */
+	0,							/* U+003125 */
+	0,							/* U+003126 */
+	0,							/* U+003127 */
+	0,							/* U+003128 */
+	0,							/* U+003129 */
+	0,							/* U+00312A */
+	0,							/* U+00312B */
+	0,							/* U+00312C */
+	0,							/* U+00312D */
+	0,							/* U+00312E */
+	0,							/* U+00312F */
+	0,							/* U+003130 */
+	1618,						/* U+003131 */
+	1619,						/* U+003132 */
+	1620,						/* U+003133 */
+	1621,						/* U+003134 */
+	1622,						/* U+003135 */
+	1623,						/* U+003136 */
+	1624,						/* U+003137 */
+	1625,						/* U+003138 */
+	1626,						/* U+003139 */
+	1627,						/* U+00313A */
+	1628,						/* U+00313B */
+	1629,						/* U+00313C */
+	1630,						/* U+00313D */
+	1631,						/* U+00313E */
+	1632,						/* U+00313F */
+	1633,						/* U+003140 */
+	1634,						/* U+003141 */
+	1635,						/* U+003142 */
+	1636,						/* U+003143 */
+	1637,						/* U+003144 */
+	1638,						/* U+003145 */
+	1639,						/* U+003146 */
+	1640,						/* U+003147 */
+	1641,						/* U+003148 */
+	1642,						/* U+003149 */
+	1643,						/* U+00314A */
+	1644,						/* U+00314B */
+	1645,						/* U+00314C */
+	1646,						/* U+00314D */
+	1647,						/* U+00314E */
+	1648,						/* U+00314F */
+	1649,						/* U+003150 */
+	1650,						/* U+003151 */
+	1651,						/* U+003152 */
+	1652,						/* U+003153 */
+	1653,						/* U+003154 */
+	1654,						/* U+003155 */
+	1655,						/* U+003156 */
+	1656,						/* U+003157 */
+	1657,						/* U+003158 */
+	1658,						/* U+003159 */
+	1659,						/* U+00315A */
+	1660,						/* U+00315B */
+	1661,						/* U+00315C */
+	1662,						/* U+00315D */
+	1663,						/* U+00315E */
+	1664,						/* U+00315F */
+	1665,						/* U+003160 */
+	1666,						/* U+003161 */
+	1667,						/* U+003162 */
+	1668,						/* U+003163 */
+	1669,						/* U+003164 */
+	1670,						/* U+003165 */
+	1671,						/* U+003166 */
+	1672,						/* U+003167 */
+	1673,						/* U+003168 */
+	1674,						/* U+003169 */
+	1675,						/* U+00316A */
+	1676,						/* U+00316B */
+	1677,						/* U+00316C */
+	1678,						/* U+00316D */
+	1679,						/* U+00316E */
+	1680,						/* U+00316F */
+	1681,						/* U+003170 */
+	1682,						/* U+003171 */
+	1683,						/* U+003172 */
+	1684,						/* U+003173 */
+	1685,						/* U+003174 */
+	1686,						/* U+003175 */
+	1687,						/* U+003176 */
+	1688,						/* U+003177 */
+	1689,						/* U+003178 */
+	1690,						/* U+003179 */
+	1691,						/* U+00317A */
+	1692,						/* U+00317B */
+	1693,						/* U+00317C */
+	1694,						/* U+00317D */
+	1695,						/* U+00317E */
+	1696,						/* U+00317F */
+	1697,						/* U+003180 */
+	1698,						/* U+003181 */
+	1699,						/* U+003182 */
+	1700,						/* U+003183 */
+	1701,						/* U+003184 */
+	1702,						/* U+003185 */
+	1703,						/* U+003186 */
+	1704,						/* U+003187 */
+	1705,						/* U+003188 */
+	1706,						/* U+003189 */
+	1707,						/* U+00318A */
+	1708,						/* U+00318B */
+	1709,						/* U+00318C */
+	1710,						/* U+00318D */
+	1711,						/* U+00318E */
+	0,							/* U+00318F */
+	0,							/* U+003190 */
+	0,							/* U+003191 */
+	1337,						/* U+003192 */
+	1343,						/* U+003193 */
+	1712,						/* U+003194 */
+	1713,						/* U+003195 */
+	1714,						/* U+003196 */
+	1715,						/* U+003197 */
+	1716,						/* U+003198 */
+	1717,						/* U+003199 */
+	1341,						/* U+00319A */
+	1718,						/* U+00319B */
+	1719,						/* U+00319C */
+	1720,						/* U+00319D */
+	1721,						/* U+00319E */
+	1345,						/* U+00319F */
+	0,							/* U+0031A0 */
+	0,							/* U+0031A1 */
+	0,							/* U+0031A2 */
+	0,							/* U+0031A3 */
+	0,							/* U+0031A4 */
+	0,							/* U+0031A5 */
+	0,							/* U+0031A6 */
+	0,							/* U+0031A7 */
+	0,							/* U+0031A8 */
+	0,							/* U+0031A9 */
+	0,							/* U+0031AA */
+	0,							/* U+0031AB */
+	0,							/* U+0031AC */
+	0,							/* U+0031AD */
+	0,							/* U+0031AE */
+	0,							/* U+0031AF */
+	0,							/* U+0031B0 */
+	0,							/* U+0031B1 */
+	0,							/* U+0031B2 */
+	0,							/* U+0031B3 */
+	0,							/* U+0031B4 */
+	0,							/* U+0031B5 */
+	0,							/* U+0031B6 */
+	0,							/* U+0031B7 */
+	0,							/* U+0031B8 */
+	0,							/* U+0031B9 */
+	0,							/* U+0031BA */
+	0,							/* U+0031BB */
+	0,							/* U+0031BC */
+	0,							/* U+0031BD */
+	0,							/* U+0031BE */
+	0,							/* U+0031BF */
+	0,							/* U+0031C0 */
+	0,							/* U+0031C1 */
+	0,							/* U+0031C2 */
+	0,							/* U+0031C3 */
+	0,							/* U+0031C4 */
+	0,							/* U+0031C5 */
+	0,							/* U+0031C6 */
+	0,							/* U+0031C7 */
+	0,							/* U+0031C8 */
+	0,							/* U+0031C9 */
+	0,							/* U+0031CA */
+	0,							/* U+0031CB */
+	0,							/* U+0031CC */
+	0,							/* U+0031CD */
+	0,							/* U+0031CE */
+	0,							/* U+0031CF */
+	0,							/* U+0031D0 */
+	0,							/* U+0031D1 */
+	0,							/* U+0031D2 */
+	0,							/* U+0031D3 */
+	0,							/* U+0031D4 */
+	0,							/* U+0031D5 */
+	0,							/* U+0031D6 */
+	0,							/* U+0031D7 */
+	0,							/* U+0031D8 */
+	0,							/* U+0031D9 */
+	0,							/* U+0031DA */
+	0,							/* U+0031DB */
+	0,							/* U+0031DC */
+	0,							/* U+0031DD */
+	0,							/* U+0031DE */
+	0,							/* U+0031DF */
+	0,							/* U+0031E0 */
+	0,							/* U+0031E1 */
+	0,							/* U+0031E2 */
+	0,							/* U+0031E3 */
+	0,							/* U+0031E4 */
+	0,							/* U+0031E5 */
+	0,							/* U+0031E6 */
+	0,							/* U+0031E7 */
+	0,							/* U+0031E8 */
+	0,							/* U+0031E9 */
+	0,							/* U+0031EA */
+	0,							/* U+0031EB */
+	0,							/* U+0031EC */
+	0,							/* U+0031ED */
+	0,							/* U+0031EE */
+	0,							/* U+0031EF */
+	0,							/* U+0031F0 */
+	0,							/* U+0031F1 */
+	0,							/* U+0031F2 */
+	0,							/* U+0031F3 */
+	0,							/* U+0031F4 */
+	0,							/* U+0031F5 */
+	0,							/* U+0031F6 */
+	0,							/* U+0031F7 */
+	0,							/* U+0031F8 */
+	0,							/* U+0031F9 */
+	0,							/* U+0031FA */
+	0,							/* U+0031FB */
+	0,							/* U+0031FC */
+	0,							/* U+0031FD */
+	0,							/* U+0031FE */
+	0,							/* U+0031FF */
+	1722,						/* U+003200 */
+	1723,						/* U+003201 */
+	1724,						/* U+003202 */
+	1725,						/* U+003203 */
+	1726,						/* U+003204 */
+	1727,						/* U+003205 */
+	1728,						/* U+003206 */
+	1729,						/* U+003207 */
+	1730,						/* U+003208 */
+	1731,						/* U+003209 */
+	1732,						/* U+00320A */
+	1733,						/* U+00320B */
+	1734,						/* U+00320C */
+	1735,						/* U+00320D */
+	1736,						/* U+00320E */
+	1737,						/* U+00320F */
+	1738,						/* U+003210 */
+	1739,						/* U+003211 */
+	1740,						/* U+003212 */
+	1741,						/* U+003213 */
+	1742,						/* U+003214 */
+	1743,						/* U+003215 */
+	1744,						/* U+003216 */
+	1745,						/* U+003217 */
+	1746,						/* U+003218 */
+	1747,						/* U+003219 */
+	1748,						/* U+00321A */
+	1749,						/* U+00321B */
+	1750,						/* U+00321C */
+	1751,						/* U+00321D */
+	1752,						/* U+00321E */
+	0,							/* U+00321F */
+	1753,						/* U+003220 */
+	1754,						/* U+003221 */
+	1755,						/* U+003222 */
+	1756,						/* U+003223 */
+	1757,						/* U+003224 */
+	1758,						/* U+003225 */
+	1759,						/* U+003226 */
+	1760,						/* U+003227 */
+	1761,						/* U+003228 */
+	1762,						/* U+003229 */
+	1763,						/* U+00322A */
+	1764,						/* U+00322B */
+	1765,						/* U+00322C */
+	1766,						/* U+00322D */
+	1767,						/* U+00322E */
+	1768,						/* U+00322F */
+	1769,						/* U+003230 */
+	1770,						/* U+003231 */
+	1771,						/* U+003232 */
+	1772,						/* U+003233 */
+	1773,						/* U+003234 */
+	1774,						/* U+003235 */
+	1775,						/* U+003236 */
+	1776,						/* U+003237 */
+	1777,						/* U+003238 */
+	1778,						/* U+003239 */
+	1779,						/* U+00323A */
+	1780,						/* U+00323B */
+	1781,						/* U+00323C */
+	1782,						/* U+00323D */
+	1783,						/* U+00323E */
+	1784,						/* U+00323F */
+	1785,						/* U+003240 */
+	1786,						/* U+003241 */
+	1787,						/* U+003242 */
+	1788,						/* U+003243 */
+	1789,						/* U+003244 */
+	1790,						/* U+003245 */
+	1403,						/* U+003246 */
+	1791,						/* U+003247 */
+	0,							/* U+003248 */
+	0,							/* U+003249 */
+	0,							/* U+00324A */
+	0,							/* U+00324B */
+	0,							/* U+00324C */
+	0,							/* U+00324D */
+	0,							/* U+00324E */
+	0,							/* U+00324F */
+	1792,						/* U+003250 */
+	1793,						/* U+003251 */
+	1794,						/* U+003252 */
+	1795,						/* U+003253 */
+	1796,						/* U+003254 */
+	1797,						/* U+003255 */
+	1798,						/* U+003256 */
+	1799,						/* U+003257 */
+	1800,						/* U+003258 */
+	1801,						/* U+003259 */
+	1802,						/* U+00325A */
+	1803,						/* U+00325B */
+	1804,						/* U+00325C */
+	1805,						/* U+00325D */
+	1806,						/* U+00325E */
+	1807,						/* U+00325F */
+	1618,						/* U+003260 */
+	1621,						/* U+003261 */
+	1624,						/* U+003262 */
+	1626,						/* U+003263 */
+	1634,						/* U+003264 */
+	1635,						/* U+003265 */
+	1638,						/* U+003266 */
+	1640,						/* U+003267 */
+	1641,						/* U+003268 */
+	1643,						/* U+003269 */
+	1644,						/* U+00326A */
+	1645,						/* U+00326B */
+	1646,						/* U+00326C */
+	1647,						/* U+00326D */
+	1808,						/* U+00326E */
+	1809,						/* U+00326F */
+	1810,						/* U+003270 */
+	1811,						/* U+003271 */
+	1812,						/* U+003272 */
+	1813,						/* U+003273 */
+	1814,						/* U+003274 */
+	1815,						/* U+003275 */
+	1816,						/* U+003276 */
+	1817,						/* U+003277 */
+	1818,						/* U+003278 */
+	1819,						/* U+003279 */
+	1820,						/* U+00327A */
+	1821,						/* U+00327B */
+	1822,						/* U+00327C */
+	1823,						/* U+00327D */
+	1824,						/* U+00327E */
+	0,							/* U+00327F */
+	1337,						/* U+003280 */
+	1343,						/* U+003281 */
+	1712,						/* U+003282 */
+	1713,						/* U+003283 */
+	1825,						/* U+003284 */
+	1826,						/* U+003285 */
+	1827,						/* U+003286 */
+	1348,						/* U+003287 */
+	1828,						/* U+003288 */
+	1360,						/* U+003289 */
+	1410,						/* U+00328A */
+	1422,						/* U+00328B */
+	1421,						/* U+00328C */
+	1411,						/* U+00328D */
+	1503,						/* U+00328E */
+	1368,						/* U+00328F */
+	1408,						/* U+003290 */
+	1829,						/* U+003291 */
+	1830,						/* U+003292 */
+	1831,						/* U+003293 */
+	1832,						/* U+003294 */
+	1833,						/* U+003295 */
+	1834,						/* U+003296 */
+	1835,						/* U+003297 */
+	1836,						/* U+003298 */
+	1837,						/* U+003299 */
+	1838,						/* U+00329A */
+	1374,						/* U+00329B */
+	1839,						/* U+00329C */
+	1840,						/* U+00329D */
+	1841,						/* U+00329E */
+	1842,						/* U+00329F */
+	1843,						/* U+0032A0 */
+	1844,						/* U+0032A1 */
+	1845,						/* U+0032A2 */
+	1846,						/* U+0032A3 */
+	1714,						/* U+0032A4 */
+	1715,						/* U+0032A5 */
+	1716,						/* U+0032A6 */
+	1847,						/* U+0032A7 */
+	1848,						/* U+0032A8 */
+	1849,						/* U+0032A9 */
+	1850,						/* U+0032AA */
+	1851,						/* U+0032AB */
+	1852,						/* U+0032AC */
+	1853,						/* U+0032AD */
+	1854,						/* U+0032AE */
+	1855,						/* U+0032AF */
+	1856,						/* U+0032B0 */
+	1857,						/* U+0032B1 */
+	1858,						/* U+0032B2 */
+	1859,						/* U+0032B3 */
+	1860,						/* U+0032B4 */
+	1861,						/* U+0032B5 */
+	1862,						/* U+0032B6 */
+	1863,						/* U+0032B7 */
+	1864,						/* U+0032B8 */
+	1865,						/* U+0032B9 */
+	1866,						/* U+0032BA */
+	1867,						/* U+0032BB */
+	1868,						/* U+0032BC */
+	1869,						/* U+0032BD */
+	1870,						/* U+0032BE */
+	1871,						/* U+0032BF */
+	1872,						/* U+0032C0 */
+	1873,						/* U+0032C1 */
+	1874,						/* U+0032C2 */
+	1875,						/* U+0032C3 */
+	1876,						/* U+0032C4 */
+	1877,						/* U+0032C5 */
+	1878,						/* U+0032C6 */
+	1879,						/* U+0032C7 */
+	1880,						/* U+0032C8 */
+	1881,						/* U+0032C9 */
+	1882,						/* U+0032CA */
+	1883,						/* U+0032CB */
+	1884,						/* U+0032CC */
+	1885,						/* U+0032CD */
+	1886,						/* U+0032CE */
+	1887,						/* U+0032CF */
+	1888,						/* U+0032D0 */
+	1889,						/* U+0032D1 */
+	1890,						/* U+0032D2 */
+	1891,						/* U+0032D3 */
+	1892,						/* U+0032D4 */
+	1893,						/* U+0032D5 */
+	1894,						/* U+0032D6 */
+	1895,						/* U+0032D7 */
+	1896,						/* U+0032D8 */
+	1897,						/* U+0032D9 */
+	1898,						/* U+0032DA */
+	1899,						/* U+0032DB */
+	1900,						/* U+0032DC */
+	1901,						/* U+0032DD */
+	1902,						/* U+0032DE */
+	1903,						/* U+0032DF */
+	1904,						/* U+0032E0 */
+	1905,						/* U+0032E1 */
+	1906,						/* U+0032E2 */
+	1907,						/* U+0032E3 */
+	1908,						/* U+0032E4 */
+	1909,						/* U+0032E5 */
+	1910,						/* U+0032E6 */
+	1911,						/* U+0032E7 */
+	1912,						/* U+0032E8 */
+	1913,						/* U+0032E9 */
+	1914,						/* U+0032EA */
+	1915,						/* U+0032EB */
+	1916,						/* U+0032EC */
+	1917,						/* U+0032ED */
+	1918,						/* U+0032EE */
+	1919,						/* U+0032EF */
+	1920,						/* U+0032F0 */
+	1921,						/* U+0032F1 */
+	1922,						/* U+0032F2 */
+	1923,						/* U+0032F3 */
+	1924,						/* U+0032F4 */
+	1925,						/* U+0032F5 */
+	1926,						/* U+0032F6 */
+	1927,						/* U+0032F7 */
+	1928,						/* U+0032F8 */
+	1929,						/* U+0032F9 */
+	1930,						/* U+0032FA */
+	1931,						/* U+0032FB */
+	1932,						/* U+0032FC */
+	1933,						/* U+0032FD */
+	1934,						/* U+0032FE */
+	1935,						/* U+0032FF */
+	1936,						/* U+003300 */
+	1937,						/* U+003301 */
+	1938,						/* U+003302 */
+	1939,						/* U+003303 */
+	1940,						/* U+003304 */
+	1941,						/* U+003305 */
+	1942,						/* U+003306 */
+	1943,						/* U+003307 */
+	1944,						/* U+003308 */
+	1945,						/* U+003309 */
+	1946,						/* U+00330A */
+	1947,						/* U+00330B */
+	1948,						/* U+00330C */
+	1949,						/* U+00330D */
+	1950,						/* U+00330E */
+	1951,						/* U+00330F */
+	1952,						/* U+003310 */
+	1953,						/* U+003311 */
+	1954,						/* U+003312 */
+	1955,						/* U+003313 */
+	1956,						/* U+003314 */
+	1957,						/* U+003315 */
+	1958,						/* U+003316 */
+	1959,						/* U+003317 */
+	1960,						/* U+003318 */
+	1961,						/* U+003319 */
+	1962,						/* U+00331A */
+	1963,						/* U+00331B */
+	1964,						/* U+00331C */
+	1965,						/* U+00331D */
+	1966,						/* U+00331E */
+	1967,						/* U+00331F */
+	1968,						/* U+003320 */
+	1969,						/* U+003321 */
+	1970,						/* U+003322 */
+	1971,						/* U+003323 */
+	1972,						/* U+003324 */
+	1973,						/* U+003325 */
+	1974,						/* U+003326 */
+	1975,						/* U+003327 */
+	1976,						/* U+003328 */
+	1977,						/* U+003329 */
+	1978,						/* U+00332A */
+	1979,						/* U+00332B */
+	1980,						/* U+00332C */
+	1981,						/* U+00332D */
+	1982,						/* U+00332E */
+	1983,						/* U+00332F */
+	1984,						/* U+003330 */
+	1985,						/* U+003331 */
+	1986,						/* U+003332 */
+	1987,						/* U+003333 */
+	1988,						/* U+003334 */
+	1989,						/* U+003335 */
+	1990,						/* U+003336 */
+	1991,						/* U+003337 */
+	1992,						/* U+003338 */
+	1993,						/* U+003339 */
+	1994,						/* U+00333A */
+	1995,						/* U+00333B */
+	1996,						/* U+00333C */
+	1997,						/* U+00333D */
+	1998,						/* U+00333E */
+	1999,						/* U+00333F */
+	2000,						/* U+003340 */
+	2001,						/* U+003341 */
+	2002,						/* U+003342 */
+	2003,						/* U+003343 */
+	2004,						/* U+003344 */
+	2005,						/* U+003345 */
+	2006,						/* U+003346 */
+	2007,						/* U+003347 */
+	2008,						/* U+003348 */
+	2009,						/* U+003349 */
+	2010,						/* U+00334A */
+	2011,						/* U+00334B */
+	2012,						/* U+00334C */
+	2013,						/* U+00334D */
+	2014,						/* U+00334E */
+	2015,						/* U+00334F */
+	2016,						/* U+003350 */
+	2017,						/* U+003351 */
+	2018,						/* U+003352 */
+	2019,						/* U+003353 */
+	2020,						/* U+003354 */
+	2021,						/* U+003355 */
+	2022,						/* U+003356 */
+	2023,						/* U+003357 */
+	2024,						/* U+003358 */
+	2025,						/* U+003359 */
+	2026,						/* U+00335A */
+	2027,						/* U+00335B */
+	2028,						/* U+00335C */
+	2029,						/* U+00335D */
+	2030,						/* U+00335E */
+	2031,						/* U+00335F */
+	2032,						/* U+003360 */
+	2033,						/* U+003361 */
+	2034,						/* U+003362 */
+	2035,						/* U+003363 */
+	2036,						/* U+003364 */
+	2037,						/* U+003365 */
+	2038,						/* U+003366 */
+	2039,						/* U+003367 */
+	2040,						/* U+003368 */
+	2041,						/* U+003369 */
+	2042,						/* U+00336A */
+	2043,						/* U+00336B */
+	2044,						/* U+00336C */
+	2045,						/* U+00336D */
+	2046,						/* U+00336E */
+	2047,						/* U+00336F */
+	2048,						/* U+003370 */
+	2049,						/* U+003371 */
+	2050,						/* U+003372 */
+	2051,						/* U+003373 */
+	2052,						/* U+003374 */
+	2053,						/* U+003375 */
+	2054,						/* U+003376 */
+	2055,						/* U+003377 */
+	2056,						/* U+003378 */
+	2057,						/* U+003379 */
+	2058,						/* U+00337A */
+	2059,						/* U+00337B */
+	2060,						/* U+00337C */
+	2061,						/* U+00337D */
+	2062,						/* U+00337E */
+	2063,						/* U+00337F */
+	2064,						/* U+003380 */
+	2065,						/* U+003381 */
+	2066,						/* U+003382 */
+	2067,						/* U+003383 */
+	2068,						/* U+003384 */
+	2069,						/* U+003385 */
+	2070,						/* U+003386 */
+	2071,						/* U+003387 */
+	2072,						/* U+003388 */
+	2073,						/* U+003389 */
+	2074,						/* U+00338A */
+	2075,						/* U+00338B */
+	2076,						/* U+00338C */
+	2077,						/* U+00338D */
+	2078,						/* U+00338E */
+	2079,						/* U+00338F */
+	2080,						/* U+003390 */
+	2081,						/* U+003391 */
+	2082,						/* U+003392 */
+	2083,						/* U+003393 */
+	2084,						/* U+003394 */
+	2085,						/* U+003395 */
+	2086,						/* U+003396 */
+	2087,						/* U+003397 */
+	2088,						/* U+003398 */
+	2089,						/* U+003399 */
+	2090,						/* U+00339A */
+	2091,						/* U+00339B */
+	2092,						/* U+00339C */
+	2093,						/* U+00339D */
+	2094,						/* U+00339E */
+	2095,						/* U+00339F */
+	2096,						/* U+0033A0 */
+	2097,						/* U+0033A1 */
+	2098,						/* U+0033A2 */
+	2099,						/* U+0033A3 */
+	2100,						/* U+0033A4 */
+	2101,						/* U+0033A5 */
+	2102,						/* U+0033A6 */
+	2103,						/* U+0033A7 */
+	2104,						/* U+0033A8 */
+	2105,						/* U+0033A9 */
+	2106,						/* U+0033AA */
+	2107,						/* U+0033AB */
+	2108,						/* U+0033AC */
+	2109,						/* U+0033AD */
+	2110,						/* U+0033AE */
+	2111,						/* U+0033AF */
+	2112,						/* U+0033B0 */
+	2113,						/* U+0033B1 */
+	2114,						/* U+0033B2 */
+	2115,						/* U+0033B3 */
+	2116,						/* U+0033B4 */
+	2117,						/* U+0033B5 */
+	2118,						/* U+0033B6 */
+	2119,						/* U+0033B7 */
+	2120,						/* U+0033B8 */
+	2121,						/* U+0033B9 */
+	2122,						/* U+0033BA */
+	2123,						/* U+0033BB */
+	2124,						/* U+0033BC */
+	2125,						/* U+0033BD */
+	2126,						/* U+0033BE */
+	2127,						/* U+0033BF */
+	2128,						/* U+0033C0 */
+	2129,						/* U+0033C1 */
+	2130,						/* U+0033C2 */
+	2131,						/* U+0033C3 */
+	2132,						/* U+0033C4 */
+	2133,						/* U+0033C5 */
+	2134,						/* U+0033C6 */
+	2135,						/* U+0033C7 */
+	2136,						/* U+0033C8 */
+	2137,						/* U+0033C9 */
+	2138,						/* U+0033CA */
+	2139,						/* U+0033CB */
+	2140,						/* U+0033CC */
+	2141,						/* U+0033CD */
+	2142,						/* U+0033CE */
+	2143,						/* U+0033CF */
+	2144,						/* U+0033D0 */
+	2145,						/* U+0033D1 */
+	2146,						/* U+0033D2 */
+	2147,						/* U+0033D3 */
+	2148,						/* U+0033D4 */
+	2149,						/* U+0033D5 */
+	2150,						/* U+0033D6 */
+	2151,						/* U+0033D7 */
+	2152,						/* U+0033D8 */
+	2153,						/* U+0033D9 */
+	2154,						/* U+0033DA */
+	2155,						/* U+0033DB */
+	2156,						/* U+0033DC */
+	2157,						/* U+0033DD */
+	2158,						/* U+0033DE */
+	2159,						/* U+0033DF */
+	2160,						/* U+0033E0 */
+	2161,						/* U+0033E1 */
+	2162,						/* U+0033E2 */
+	2163,						/* U+0033E3 */
+	2164,						/* U+0033E4 */
+	2165,						/* U+0033E5 */
+	2166,						/* U+0033E6 */
+	2167,						/* U+0033E7 */
+	2168,						/* U+0033E8 */
+	2169,						/* U+0033E9 */
+	2170,						/* U+0033EA */
+	2171,						/* U+0033EB */
+	2172,						/* U+0033EC */
+	2173,						/* U+0033ED */
+	2174,						/* U+0033EE */
+	2175,						/* U+0033EF */
+	2176,						/* U+0033F0 */
+	2177,						/* U+0033F1 */
+	2178,						/* U+0033F2 */
+	2179,						/* U+0033F3 */
+	2180,						/* U+0033F4 */
+	2181,						/* U+0033F5 */
+	2182,						/* U+0033F6 */
+	2183,						/* U+0033F7 */
+	2184,						/* U+0033F8 */
+	2185,						/* U+0033F9 */
+	2186,						/* U+0033FA */
+	2187,						/* U+0033FB */
+	2188,						/* U+0033FC */
+	2189,						/* U+0033FD */
+	2190,						/* U+0033FE */
+	2191,						/* U+0033FF */
+	304,						/* U+00A66F */
+	0,							/* U+00A670 */
+	0,							/* U+00A671 */
+	0,							/* U+00A672 */
+	0,							/* U+00A673 */
+	304,						/* U+00A674 */
+	304,						/* U+00A675 */
+	304,						/* U+00A676 */
+	304,						/* U+00A677 */
+	304,						/* U+00A678 */
+	304,						/* U+00A679 */
+	304,						/* U+00A67A */
+	304,						/* U+00A67B */
+	304,						/* U+00A67C */
+	304,						/* U+00A67D */
+	0,							/* U+00A67E */
+	0,							/* U+00A67F */
+	0,							/* U+00A680 */
+	0,							/* U+00A681 */
+	0,							/* U+00A682 */
+	0,							/* U+00A683 */
+	0,							/* U+00A684 */
+	0,							/* U+00A685 */
+	0,							/* U+00A686 */
+	0,							/* U+00A687 */
+	0,							/* U+00A688 */
+	0,							/* U+00A689 */
+	0,							/* U+00A68A */
+	0,							/* U+00A68B */
+	0,							/* U+00A68C */
+	0,							/* U+00A68D */
+	0,							/* U+00A68E */
+	0,							/* U+00A68F */
+	0,							/* U+00A690 */
+	0,							/* U+00A691 */
+	0,							/* U+00A692 */
+	0,							/* U+00A693 */
+	0,							/* U+00A694 */
+	0,							/* U+00A695 */
+	0,							/* U+00A696 */
+	0,							/* U+00A697 */
+	0,							/* U+00A698 */
+	0,							/* U+00A699 */
+	0,							/* U+00A69A */
+	0,							/* U+00A69B */
+	2192,						/* U+00A69C */
+	2193,						/* U+00A69D */
+	304,						/* U+00A69E */
+	304,						/* U+00A69F */
+	0,							/* U+00A6A0 */
+	0,							/* U+00A6A1 */
+	0,							/* U+00A6A2 */
+	0,							/* U+00A6A3 */
+	0,							/* U+00A6A4 */
+	0,							/* U+00A6A5 */
+	0,							/* U+00A6A6 */
+	0,							/* U+00A6A7 */
+	0,							/* U+00A6A8 */
+	0,							/* U+00A6A9 */
+	0,							/* U+00A6AA */
+	0,							/* U+00A6AB */
+	0,							/* U+00A6AC */
+	0,							/* U+00A6AD */
+	0,							/* U+00A6AE */
+	0,							/* U+00A6AF */
+	0,							/* U+00A6B0 */
+	0,							/* U+00A6B1 */
+	0,							/* U+00A6B2 */
+	0,							/* U+00A6B3 */
+	0,							/* U+00A6B4 */
+	0,							/* U+00A6B5 */
+	0,							/* U+00A6B6 */
+	0,							/* U+00A6B7 */
+	0,							/* U+00A6B8 */
+	0,							/* U+00A6B9 */
+	0,							/* U+00A6BA */
+	0,							/* U+00A6BB */
+	0,							/* U+00A6BC */
+	0,							/* U+00A6BD */
+	0,							/* U+00A6BE */
+	0,							/* U+00A6BF */
+	0,							/* U+00A6C0 */
+	0,							/* U+00A6C1 */
+	0,							/* U+00A6C2 */
+	0,							/* U+00A6C3 */
+	0,							/* U+00A6C4 */
+	0,							/* U+00A6C5 */
+	0,							/* U+00A6C6 */
+	0,							/* U+00A6C7 */
+	0,							/* U+00A6C8 */
+	0,							/* U+00A6C9 */
+	0,							/* U+00A6CA */
+	0,							/* U+00A6CB */
+	0,							/* U+00A6CC */
+	0,							/* U+00A6CD */
+	0,							/* U+00A6CE */
+	0,							/* U+00A6CF */
+	0,							/* U+00A6D0 */
+	0,							/* U+00A6D1 */
+	0,							/* U+00A6D2 */
+	0,							/* U+00A6D3 */
+	0,							/* U+00A6D4 */
+	0,							/* U+00A6D5 */
+	0,							/* U+00A6D6 */
+	0,							/* U+00A6D7 */
+	0,							/* U+00A6D8 */
+	0,							/* U+00A6D9 */
+	0,							/* U+00A6DA */
+	0,							/* U+00A6DB */
+	0,							/* U+00A6DC */
+	0,							/* U+00A6DD */
+	0,							/* U+00A6DE */
+	0,							/* U+00A6DF */
+	0,							/* U+00A6E0 */
+	0,							/* U+00A6E1 */
+	0,							/* U+00A6E2 */
+	0,							/* U+00A6E3 */
+	0,							/* U+00A6E4 */
+	0,							/* U+00A6E5 */
+	0,							/* U+00A6E6 */
+	0,							/* U+00A6E7 */
+	0,							/* U+00A6E8 */
+	0,							/* U+00A6E9 */
+	0,							/* U+00A6EA */
+	0,							/* U+00A6EB */
+	0,							/* U+00A6EC */
+	0,							/* U+00A6ED */
+	0,							/* U+00A6EE */
+	0,							/* U+00A6EF */
+	304,						/* U+00A6F0 */
+	304,						/* U+00A6F1 */
+	0,							/* U+00A6F2 */
+	0,							/* U+00A6F3 */
+	0,							/* U+00A6F4 */
+	0,							/* U+00A6F5 */
+	0,							/* U+00A6F6 */
+	0,							/* U+00A6F7 */
+	0,							/* U+00A6F8 */
+	0,							/* U+00A6F9 */
+	0,							/* U+00A6FA */
+	0,							/* U+00A6FB */
+	0,							/* U+00A6FC */
+	0,							/* U+00A6FD */
+	0,							/* U+00A6FE */
+	0,							/* U+00A6FF */
+	0,							/* U+00A700 */
+	0,							/* U+00A701 */
+	0,							/* U+00A702 */
+	0,							/* U+00A703 */
+	0,							/* U+00A704 */
+	0,							/* U+00A705 */
+	0,							/* U+00A706 */
+	0,							/* U+00A707 */
+	0,							/* U+00A708 */
+	0,							/* U+00A709 */
+	0,							/* U+00A70A */
+	0,							/* U+00A70B */
+	0,							/* U+00A70C */
+	0,							/* U+00A70D */
+	0,							/* U+00A70E */
+	0,							/* U+00A70F */
+	0,							/* U+00A710 */
+	0,							/* U+00A711 */
+	0,							/* U+00A712 */
+	0,							/* U+00A713 */
+	0,							/* U+00A714 */
+	0,							/* U+00A715 */
+	0,							/* U+00A716 */
+	0,							/* U+00A717 */
+	0,							/* U+00A718 */
+	0,							/* U+00A719 */
+	0,							/* U+00A71A */
+	0,							/* U+00A71B */
+	0,							/* U+00A71C */
+	0,							/* U+00A71D */
+	0,							/* U+00A71E */
+	0,							/* U+00A71F */
+	0,							/* U+00A720 */
+	0,							/* U+00A721 */
+	0,							/* U+00A722 */
+	0,							/* U+00A723 */
+	0,							/* U+00A724 */
+	0,							/* U+00A725 */
+	0,							/* U+00A726 */
+	0,							/* U+00A727 */
+	0,							/* U+00A728 */
+	0,							/* U+00A729 */
+	0,							/* U+00A72A */
+	0,							/* U+00A72B */
+	0,							/* U+00A72C */
+	0,							/* U+00A72D */
+	0,							/* U+00A72E */
+	0,							/* U+00A72F */
+	0,							/* U+00A730 */
+	0,							/* U+00A731 */
+	0,							/* U+00A732 */
+	0,							/* U+00A733 */
+	0,							/* U+00A734 */
+	0,							/* U+00A735 */
+	0,							/* U+00A736 */
+	0,							/* U+00A737 */
+	0,							/* U+00A738 */
+	0,							/* U+00A739 */
+	0,							/* U+00A73A */
+	0,							/* U+00A73B */
+	0,							/* U+00A73C */
+	0,							/* U+00A73D */
+	0,							/* U+00A73E */
+	0,							/* U+00A73F */
+	0,							/* U+00A740 */
+	0,							/* U+00A741 */
+	0,							/* U+00A742 */
+	0,							/* U+00A743 */
+	0,							/* U+00A744 */
+	0,							/* U+00A745 */
+	0,							/* U+00A746 */
+	0,							/* U+00A747 */
+	0,							/* U+00A748 */
+	0,							/* U+00A749 */
+	0,							/* U+00A74A */
+	0,							/* U+00A74B */
+	0,							/* U+00A74C */
+	0,							/* U+00A74D */
+	0,							/* U+00A74E */
+	0,							/* U+00A74F */
+	0,							/* U+00A750 */
+	0,							/* U+00A751 */
+	0,							/* U+00A752 */
+	0,							/* U+00A753 */
+	0,							/* U+00A754 */
+	0,							/* U+00A755 */
+	0,							/* U+00A756 */
+	0,							/* U+00A757 */
+	0,							/* U+00A758 */
+	0,							/* U+00A759 */
+	0,							/* U+00A75A */
+	0,							/* U+00A75B */
+	0,							/* U+00A75C */
+	0,							/* U+00A75D */
+	0,							/* U+00A75E */
+	0,							/* U+00A75F */
+	0,							/* U+00A760 */
+	0,							/* U+00A761 */
+	0,							/* U+00A762 */
+	0,							/* U+00A763 */
+	0,							/* U+00A764 */
+	0,							/* U+00A765 */
+	0,							/* U+00A766 */
+	0,							/* U+00A767 */
+	0,							/* U+00A768 */
+	0,							/* U+00A769 */
+	0,							/* U+00A76A */
+	0,							/* U+00A76B */
+	0,							/* U+00A76C */
+	0,							/* U+00A76D */
+	0,							/* U+00A76E */
+	0,							/* U+00A76F */
+	2194,						/* U+00A770 */
+	0,							/* U+00A771 */
+	0,							/* U+00A772 */
+	0,							/* U+00A773 */
+	0,							/* U+00A774 */
+	0,							/* U+00A775 */
+	0,							/* U+00A776 */
+	0,							/* U+00A777 */
+	0,							/* U+00A778 */
+	0,							/* U+00A779 */
+	0,							/* U+00A77A */
+	0,							/* U+00A77B */
+	0,							/* U+00A77C */
+	0,							/* U+00A77D */
+	0,							/* U+00A77E */
+	0,							/* U+00A77F */
+	0,							/* U+00A780 */
+	0,							/* U+00A781 */
+	0,							/* U+00A782 */
+	0,							/* U+00A783 */
+	0,							/* U+00A784 */
+	0,							/* U+00A785 */
+	0,							/* U+00A786 */
+	0,							/* U+00A787 */
+	0,							/* U+00A788 */
+	0,							/* U+00A789 */
+	0,							/* U+00A78A */
+	0,							/* U+00A78B */
+	0,							/* U+00A78C */
+	0,							/* U+00A78D */
+	0,							/* U+00A78E */
+	0,							/* U+00A78F */
+	0,							/* U+00A790 */
+	0,							/* U+00A791 */
+	0,							/* U+00A792 */
+	0,							/* U+00A793 */
+	0,							/* U+00A794 */
+	0,							/* U+00A795 */
+	0,							/* U+00A796 */
+	0,							/* U+00A797 */
+	0,							/* U+00A798 */
+	0,							/* U+00A799 */
+	0,							/* U+00A79A */
+	0,							/* U+00A79B */
+	0,							/* U+00A79C */
+	0,							/* U+00A79D */
+	0,							/* U+00A79E */
+	0,							/* U+00A79F */
+	0,							/* U+00A7A0 */
+	0,							/* U+00A7A1 */
+	0,							/* U+00A7A2 */
+	0,							/* U+00A7A3 */
+	0,							/* U+00A7A4 */
+	0,							/* U+00A7A5 */
+	0,							/* U+00A7A6 */
+	0,							/* U+00A7A7 */
+	0,							/* U+00A7A8 */
+	0,							/* U+00A7A9 */
+	0,							/* U+00A7AA */
+	0,							/* U+00A7AB */
+	0,							/* U+00A7AC */
+	0,							/* U+00A7AD */
+	0,							/* U+00A7AE */
+	0,							/* U+00A7AF */
+	0,							/* U+00A7B0 */
+	0,							/* U+00A7B1 */
+	0,							/* U+00A7B2 */
+	0,							/* U+00A7B3 */
+	0,							/* U+00A7B4 */
+	0,							/* U+00A7B5 */
+	0,							/* U+00A7B6 */
+	0,							/* U+00A7B7 */
+	0,							/* U+00A7B8 */
+	0,							/* U+00A7B9 */
+	0,							/* U+00A7BA */
+	0,							/* U+00A7BB */
+	0,							/* U+00A7BC */
+	0,							/* U+00A7BD */
+	0,							/* U+00A7BE */
+	0,							/* U+00A7BF */
+	0,							/* U+00A7C0 */
+	0,							/* U+00A7C1 */
+	0,							/* U+00A7C2 */
+	0,							/* U+00A7C3 */
+	0,							/* U+00A7C4 */
+	0,							/* U+00A7C5 */
+	0,							/* U+00A7C6 */
+	0,							/* U+00A7C7 */
+	0,							/* U+00A7C8 */
+	0,							/* U+00A7C9 */
+	0,							/* U+00A7CA */
+	0,							/* U+00A7CB */
+	0,							/* U+00A7CC */
+	0,							/* U+00A7CD */
+	0,							/* U+00A7CE */
+	0,							/* U+00A7CF */
+	0,							/* U+00A7D0 */
+	0,							/* U+00A7D1 */
+	0,							/* U+00A7D2 */
+	0,							/* U+00A7D3 */
+	0,							/* U+00A7D4 */
+	0,							/* U+00A7D5 */
+	0,							/* U+00A7D6 */
+	0,							/* U+00A7D7 */
+	0,							/* U+00A7D8 */
+	0,							/* U+00A7D9 */
+	0,							/* U+00A7DA */
+	0,							/* U+00A7DB */
+	0,							/* U+00A7DC */
+	0,							/* U+00A7DD */
+	0,							/* U+00A7DE */
+	0,							/* U+00A7DF */
+	0,							/* U+00A7E0 */
+	0,							/* U+00A7E1 */
+	0,							/* U+00A7E2 */
+	0,							/* U+00A7E3 */
+	0,							/* U+00A7E4 */
+	0,							/* U+00A7E5 */
+	0,							/* U+00A7E6 */
+	0,							/* U+00A7E7 */
+	0,							/* U+00A7E8 */
+	0,							/* U+00A7E9 */
+	0,							/* U+00A7EA */
+	0,							/* U+00A7EB */
+	0,							/* U+00A7EC */
+	0,							/* U+00A7ED */
+	0,							/* U+00A7EE */
+	0,							/* U+00A7EF */
+	0,							/* U+00A7F0 */
+	0,							/* U+00A7F1 */
+	1137,						/* U+00A7F2 */
+	1153,						/* U+00A7F3 */
+	1145,						/* U+00A7F4 */
+	0,							/* U+00A7F5 */
+	0,							/* U+00A7F6 */
+	0,							/* U+00A7F7 */
+	2195,						/* U+00A7F8 */
+	2196,						/* U+00A7F9 */
+	0,							/* U+00A7FA */
+	0,							/* U+00A7FB */
+	0,							/* U+00A7FC */
+	0,							/* U+00A7FD */
+	0,							/* U+00A7FE */
+	0,							/* U+00A7FF */
+	0,							/* U+00A800 */
+	0,							/* U+00A801 */
+	0,							/* U+00A802 */
+	0,							/* U+00A803 */
+	0,							/* U+00A804 */
+	0,							/* U+00A805 */
+	452,						/* U+00A806 */
+	0,							/* U+00A807 */
+	0,							/* U+00A808 */
+	0,							/* U+00A809 */
+	0,							/* U+00A80A */
+	0,							/* U+00A80B */
+	0,							/* U+00A80C */
+	0,							/* U+00A80D */
+	0,							/* U+00A80E */
+	0,							/* U+00A80F */
+	0,							/* U+00A810 */
+	0,							/* U+00A811 */
+	0,							/* U+00A812 */
+	0,							/* U+00A813 */
+	0,							/* U+00A814 */
+	0,							/* U+00A815 */
+	0,							/* U+00A816 */
+	0,							/* U+00A817 */
+	0,							/* U+00A818 */
+	0,							/* U+00A819 */
+	0,							/* U+00A81A */
+	0,							/* U+00A81B */
+	0,							/* U+00A81C */
+	0,							/* U+00A81D */
+	0,							/* U+00A81E */
+	0,							/* U+00A81F */
+	0,							/* U+00A820 */
+	0,							/* U+00A821 */
+	0,							/* U+00A822 */
+	0,							/* U+00A823 */
+	0,							/* U+00A824 */
+	0,							/* U+00A825 */
+	0,							/* U+00A826 */
+	0,							/* U+00A827 */
+	0,							/* U+00A828 */
+	0,							/* U+00A829 */
+	0,							/* U+00A82A */
+	0,							/* U+00A82B */
+	452,						/* U+00A82C */
+	0,							/* U+00A82D */
+	0,							/* U+00A82E */
+	0,							/* U+00A82F */
+	0,							/* U+00A830 */
+	0,							/* U+00A831 */
+	0,							/* U+00A832 */
+	0,							/* U+00A833 */
+	0,							/* U+00A834 */
+	0,							/* U+00A835 */
+	0,							/* U+00A836 */
+	0,							/* U+00A837 */
+	0,							/* U+00A838 */
+	0,							/* U+00A839 */
+	0,							/* U+00A83A */
+	0,							/* U+00A83B */
+	0,							/* U+00A83C */
+	0,							/* U+00A83D */
+	0,							/* U+00A83E */
+	0,							/* U+00A83F */
+	0,							/* U+00A840 */
+	0,							/* U+00A841 */
+	0,							/* U+00A842 */
+	0,							/* U+00A843 */
+	0,							/* U+00A844 */
+	0,							/* U+00A845 */
+	0,							/* U+00A846 */
+	0,							/* U+00A847 */
+	0,							/* U+00A848 */
+	0,							/* U+00A849 */
+	0,							/* U+00A84A */
+	0,							/* U+00A84B */
+	0,							/* U+00A84C */
+	0,							/* U+00A84D */
+	0,							/* U+00A84E */
+	0,							/* U+00A84F */
+	0,							/* U+00A850 */
+	0,							/* U+00A851 */
+	0,							/* U+00A852 */
+	0,							/* U+00A853 */
+	0,							/* U+00A854 */
+	0,							/* U+00A855 */
+	0,							/* U+00A856 */
+	0,							/* U+00A857 */
+	0,							/* U+00A858 */
+	0,							/* U+00A859 */
+	0,							/* U+00A85A */
+	0,							/* U+00A85B */
+	0,							/* U+00A85C */
+	0,							/* U+00A85D */
+	0,							/* U+00A85E */
+	0,							/* U+00A85F */
+	0,							/* U+00A860 */
+	0,							/* U+00A861 */
+	0,							/* U+00A862 */
+	0,							/* U+00A863 */
+	0,							/* U+00A864 */
+	0,							/* U+00A865 */
+	0,							/* U+00A866 */
+	0,							/* U+00A867 */
+	0,							/* U+00A868 */
+	0,							/* U+00A869 */
+	0,							/* U+00A86A */
+	0,							/* U+00A86B */
+	0,							/* U+00A86C */
+	0,							/* U+00A86D */
+	0,							/* U+00A86E */
+	0,							/* U+00A86F */
+	0,							/* U+00A870 */
+	0,							/* U+00A871 */
+	0,							/* U+00A872 */
+	0,							/* U+00A873 */
+	0,							/* U+00A874 */
+	0,							/* U+00A875 */
+	0,							/* U+00A876 */
+	0,							/* U+00A877 */
+	0,							/* U+00A878 */
+	0,							/* U+00A879 */
+	0,							/* U+00A87A */
+	0,							/* U+00A87B */
+	0,							/* U+00A87C */
+	0,							/* U+00A87D */
+	0,							/* U+00A87E */
+	0,							/* U+00A87F */
+	0,							/* U+00A880 */
+	0,							/* U+00A881 */
+	0,							/* U+00A882 */
+	0,							/* U+00A883 */
+	0,							/* U+00A884 */
+	0,							/* U+00A885 */
+	0,							/* U+00A886 */
+	0,							/* U+00A887 */
+	0,							/* U+00A888 */
+	0,							/* U+00A889 */
+	0,							/* U+00A88A */
+	0,							/* U+00A88B */
+	0,							/* U+00A88C */
+	0,							/* U+00A88D */
+	0,							/* U+00A88E */
+	0,							/* U+00A88F */
+	0,							/* U+00A890 */
+	0,							/* U+00A891 */
+	0,							/* U+00A892 */
+	0,							/* U+00A893 */
+	0,							/* U+00A894 */
+	0,							/* U+00A895 */
+	0,							/* U+00A896 */
+	0,							/* U+00A897 */
+	0,							/* U+00A898 */
+	0,							/* U+00A899 */
+	0,							/* U+00A89A */
+	0,							/* U+00A89B */
+	0,							/* U+00A89C */
+	0,							/* U+00A89D */
+	0,							/* U+00A89E */
+	0,							/* U+00A89F */
+	0,							/* U+00A8A0 */
+	0,							/* U+00A8A1 */
+	0,							/* U+00A8A2 */
+	0,							/* U+00A8A3 */
+	0,							/* U+00A8A4 */
+	0,							/* U+00A8A5 */
+	0,							/* U+00A8A6 */
+	0,							/* U+00A8A7 */
+	0,							/* U+00A8A8 */
+	0,							/* U+00A8A9 */
+	0,							/* U+00A8AA */
+	0,							/* U+00A8AB */
+	0,							/* U+00A8AC */
+	0,							/* U+00A8AD */
+	0,							/* U+00A8AE */
+	0,							/* U+00A8AF */
+	0,							/* U+00A8B0 */
+	0,							/* U+00A8B1 */
+	0,							/* U+00A8B2 */
+	0,							/* U+00A8B3 */
+	0,							/* U+00A8B4 */
+	0,							/* U+00A8B5 */
+	0,							/* U+00A8B6 */
+	0,							/* U+00A8B7 */
+	0,							/* U+00A8B8 */
+	0,							/* U+00A8B9 */
+	0,							/* U+00A8BA */
+	0,							/* U+00A8BB */
+	0,							/* U+00A8BC */
+	0,							/* U+00A8BD */
+	0,							/* U+00A8BE */
+	0,							/* U+00A8BF */
+	0,							/* U+00A8C0 */
+	0,							/* U+00A8C1 */
+	0,							/* U+00A8C2 */
+	0,							/* U+00A8C3 */
+	452,						/* U+00A8C4 */
+	0,							/* U+00A8C5 */
+	0,							/* U+00A8C6 */
+	0,							/* U+00A8C7 */
+	0,							/* U+00A8C8 */
+	0,							/* U+00A8C9 */
+	0,							/* U+00A8CA */
+	0,							/* U+00A8CB */
+	0,							/* U+00A8CC */
+	0,							/* U+00A8CD */
+	0,							/* U+00A8CE */
+	0,							/* U+00A8CF */
+	0,							/* U+00A8D0 */
+	0,							/* U+00A8D1 */
+	0,							/* U+00A8D2 */
+	0,							/* U+00A8D3 */
+	0,							/* U+00A8D4 */
+	0,							/* U+00A8D5 */
+	0,							/* U+00A8D6 */
+	0,							/* U+00A8D7 */
+	0,							/* U+00A8D8 */
+	0,							/* U+00A8D9 */
+	0,							/* U+00A8DA */
+	0,							/* U+00A8DB */
+	0,							/* U+00A8DC */
+	0,							/* U+00A8DD */
+	0,							/* U+00A8DE */
+	0,							/* U+00A8DF */
+	304,						/* U+00A8E0 */
+	304,						/* U+00A8E1 */
+	304,						/* U+00A8E2 */
+	304,						/* U+00A8E3 */
+	304,						/* U+00A8E4 */
+	304,						/* U+00A8E5 */
+	304,						/* U+00A8E6 */
+	304,						/* U+00A8E7 */
+	304,						/* U+00A8E8 */
+	304,						/* U+00A8E9 */
+	304,						/* U+00A8EA */
+	304,						/* U+00A8EB */
+	304,						/* U+00A8EC */
+	304,						/* U+00A8ED */
+	304,						/* U+00A8EE */
+	304,						/* U+00A8EF */
+	304,						/* U+00A8F0 */
+	304,						/* U+00A8F1 */
+	0,							/* U+00A8F2 */
+	0,							/* U+00A8F3 */
+	0,							/* U+00A8F4 */
+	0,							/* U+00A8F5 */
+	0,							/* U+00A8F6 */
+	0,							/* U+00A8F7 */
+	0,							/* U+00A8F8 */
+	0,							/* U+00A8F9 */
+	0,							/* U+00A8FA */
+	0,							/* U+00A8FB */
+	0,							/* U+00A8FC */
+	0,							/* U+00A8FD */
+	0,							/* U+00A8FE */
+	0,							/* U+00A8FF */
+	0,							/* U+00A900 */
+	0,							/* U+00A901 */
+	0,							/* U+00A902 */
+	0,							/* U+00A903 */
+	0,							/* U+00A904 */
+	0,							/* U+00A905 */
+	0,							/* U+00A906 */
+	0,							/* U+00A907 */
+	0,							/* U+00A908 */
+	0,							/* U+00A909 */
+	0,							/* U+00A90A */
+	0,							/* U+00A90B */
+	0,							/* U+00A90C */
+	0,							/* U+00A90D */
+	0,							/* U+00A90E */
+	0,							/* U+00A90F */
+	0,							/* U+00A910 */
+	0,							/* U+00A911 */
+	0,							/* U+00A912 */
+	0,							/* U+00A913 */
+	0,							/* U+00A914 */
+	0,							/* U+00A915 */
+	0,							/* U+00A916 */
+	0,							/* U+00A917 */
+	0,							/* U+00A918 */
+	0,							/* U+00A919 */
+	0,							/* U+00A91A */
+	0,							/* U+00A91B */
+	0,							/* U+00A91C */
+	0,							/* U+00A91D */
+	0,							/* U+00A91E */
+	0,							/* U+00A91F */
+	0,							/* U+00A920 */
+	0,							/* U+00A921 */
+	0,							/* U+00A922 */
+	0,							/* U+00A923 */
+	0,							/* U+00A924 */
+	0,							/* U+00A925 */
+	0,							/* U+00A926 */
+	0,							/* U+00A927 */
+	0,							/* U+00A928 */
+	0,							/* U+00A929 */
+	0,							/* U+00A92A */
+	306,						/* U+00A92B */
+	306,						/* U+00A92C */
+	306,						/* U+00A92D */
+	0,							/* U+00A92E */
+	0,							/* U+00A92F */
+	0,							/* U+00A930 */
+	0,							/* U+00A931 */
+	0,							/* U+00A932 */
+	0,							/* U+00A933 */
+	0,							/* U+00A934 */
+	0,							/* U+00A935 */
+	0,							/* U+00A936 */
+	0,							/* U+00A937 */
+	0,							/* U+00A938 */
+	0,							/* U+00A939 */
+	0,							/* U+00A93A */
+	0,							/* U+00A93B */
+	0,							/* U+00A93C */
+	0,							/* U+00A93D */
+	0,							/* U+00A93E */
+	0,							/* U+00A93F */
+	0,							/* U+00A940 */
+	0,							/* U+00A941 */
+	0,							/* U+00A942 */
+	0,							/* U+00A943 */
+	0,							/* U+00A944 */
+	0,							/* U+00A945 */
+	0,							/* U+00A946 */
+	0,							/* U+00A947 */
+	0,							/* U+00A948 */
+	0,							/* U+00A949 */
+	0,							/* U+00A94A */
+	0,							/* U+00A94B */
+	0,							/* U+00A94C */
+	0,							/* U+00A94D */
+	0,							/* U+00A94E */
+	0,							/* U+00A94F */
+	0,							/* U+00A950 */
+	0,							/* U+00A951 */
+	0,							/* U+00A952 */
+	452,						/* U+00A953 */
+	0,							/* U+00A954 */
+	0,							/* U+00A955 */
+	0,							/* U+00A956 */
+	0,							/* U+00A957 */
+	0,							/* U+00A958 */
+	0,							/* U+00A959 */
+	0,							/* U+00A95A */
+	0,							/* U+00A95B */
+	0,							/* U+00A95C */
+	0,							/* U+00A95D */
+	0,							/* U+00A95E */
+	0,							/* U+00A95F */
+	0,							/* U+00A960 */
+	0,							/* U+00A961 */
+	0,							/* U+00A962 */
+	0,							/* U+00A963 */
+	0,							/* U+00A964 */
+	0,							/* U+00A965 */
+	0,							/* U+00A966 */
+	0,							/* U+00A967 */
+	0,							/* U+00A968 */
+	0,							/* U+00A969 */
+	0,							/* U+00A96A */
+	0,							/* U+00A96B */
+	0,							/* U+00A96C */
+	0,							/* U+00A96D */
+	0,							/* U+00A96E */
+	0,							/* U+00A96F */
+	0,							/* U+00A970 */
+	0,							/* U+00A971 */
+	0,							/* U+00A972 */
+	0,							/* U+00A973 */
+	0,							/* U+00A974 */
+	0,							/* U+00A975 */
+	0,							/* U+00A976 */
+	0,							/* U+00A977 */
+	0,							/* U+00A978 */
+	0,							/* U+00A979 */
+	0,							/* U+00A97A */
+	0,							/* U+00A97B */
+	0,							/* U+00A97C */
+	0,							/* U+00A97D */
+	0,							/* U+00A97E */
+	0,							/* U+00A97F */
+	0,							/* U+00A980 */
+	0,							/* U+00A981 */
+	0,							/* U+00A982 */
+	0,							/* U+00A983 */
+	0,							/* U+00A984 */
+	0,							/* U+00A985 */
+	0,							/* U+00A986 */
+	0,							/* U+00A987 */
+	0,							/* U+00A988 */
+	0,							/* U+00A989 */
+	0,							/* U+00A98A */
+	0,							/* U+00A98B */
+	0,							/* U+00A98C */
+	0,							/* U+00A98D */
+	0,							/* U+00A98E */
+	0,							/* U+00A98F */
+	0,							/* U+00A990 */
+	0,							/* U+00A991 */
+	0,							/* U+00A992 */
+	0,							/* U+00A993 */
+	0,							/* U+00A994 */
+	0,							/* U+00A995 */
+	0,							/* U+00A996 */
+	0,							/* U+00A997 */
+	0,							/* U+00A998 */
+	0,							/* U+00A999 */
+	0,							/* U+00A99A */
+	0,							/* U+00A99B */
+	0,							/* U+00A99C */
+	0,							/* U+00A99D */
+	0,							/* U+00A99E */
+	0,							/* U+00A99F */
+	0,							/* U+00A9A0 */
+	0,							/* U+00A9A1 */
+	0,							/* U+00A9A2 */
+	0,							/* U+00A9A3 */
+	0,							/* U+00A9A4 */
+	0,							/* U+00A9A5 */
+	0,							/* U+00A9A6 */
+	0,							/* U+00A9A7 */
+	0,							/* U+00A9A8 */
+	0,							/* U+00A9A9 */
+	0,							/* U+00A9AA */
+	0,							/* U+00A9AB */
+	0,							/* U+00A9AC */
+	0,							/* U+00A9AD */
+	0,							/* U+00A9AE */
+	0,							/* U+00A9AF */
+	0,							/* U+00A9B0 */
+	0,							/* U+00A9B1 */
+	0,							/* U+00A9B2 */
+	451,						/* U+00A9B3 */
+	0,							/* U+00A9B4 */
+	0,							/* U+00A9B5 */
+	0,							/* U+00A9B6 */
+	0,							/* U+00A9B7 */
+	0,							/* U+00A9B8 */
+	0,							/* U+00A9B9 */
+	0,							/* U+00A9BA */
+	0,							/* U+00A9BB */
+	0,							/* U+00A9BC */
+	0,							/* U+00A9BD */
+	0,							/* U+00A9BE */
+	0,							/* U+00A9BF */
+	452,						/* U+00A9C0 */
+	0,							/* U+00A9C1 */
+	0,							/* U+00A9C2 */
+	0,							/* U+00A9C3 */
+	0,							/* U+00A9C4 */
+	0,							/* U+00A9C5 */
+	0,							/* U+00A9C6 */
+	0,							/* U+00A9C7 */
+	0,							/* U+00A9C8 */
+	0,							/* U+00A9C9 */
+	0,							/* U+00A9CA */
+	0,							/* U+00A9CB */
+	0,							/* U+00A9CC */
+	0,							/* U+00A9CD */
+	0,							/* U+00A9CE */
+	0,							/* U+00A9CF */
+	0,							/* U+00A9D0 */
+	0,							/* U+00A9D1 */
+	0,							/* U+00A9D2 */
+	0,							/* U+00A9D3 */
+	0,							/* U+00A9D4 */
+	0,							/* U+00A9D5 */
+	0,							/* U+00A9D6 */
+	0,							/* U+00A9D7 */
+	0,							/* U+00A9D8 */
+	0,							/* U+00A9D9 */
+	0,							/* U+00A9DA */
+	0,							/* U+00A9DB */
+	0,							/* U+00A9DC */
+	0,							/* U+00A9DD */
+	0,							/* U+00A9DE */
+	0,							/* U+00A9DF */
+	0,							/* U+00A9E0 */
+	0,							/* U+00A9E1 */
+	0,							/* U+00A9E2 */
+	0,							/* U+00A9E3 */
+	0,							/* U+00A9E4 */
+	0,							/* U+00A9E5 */
+	0,							/* U+00A9E6 */
+	0,							/* U+00A9E7 */
+	0,							/* U+00A9E8 */
+	0,							/* U+00A9E9 */
+	0,							/* U+00A9EA */
+	0,							/* U+00A9EB */
+	0,							/* U+00A9EC */
+	0,							/* U+00A9ED */
+	0,							/* U+00A9EE */
+	0,							/* U+00A9EF */
+	0,							/* U+00A9F0 */
+	0,							/* U+00A9F1 */
+	0,							/* U+00A9F2 */
+	0,							/* U+00A9F3 */
+	0,							/* U+00A9F4 */
+	0,							/* U+00A9F5 */
+	0,							/* U+00A9F6 */
+	0,							/* U+00A9F7 */
+	0,							/* U+00A9F8 */
+	0,							/* U+00A9F9 */
+	0,							/* U+00A9FA */
+	0,							/* U+00A9FB */
+	0,							/* U+00A9FC */
+	0,							/* U+00A9FD */
+	0,							/* U+00A9FE */
+	0,							/* U+00A9FF */
+	0,							/* U+00AA00 */
+	0,							/* U+00AA01 */
+	0,							/* U+00AA02 */
+	0,							/* U+00AA03 */
+	0,							/* U+00AA04 */
+	0,							/* U+00AA05 */
+	0,							/* U+00AA06 */
+	0,							/* U+00AA07 */
+	0,							/* U+00AA08 */
+	0,							/* U+00AA09 */
+	0,							/* U+00AA0A */
+	0,							/* U+00AA0B */
+	0,							/* U+00AA0C */
+	0,							/* U+00AA0D */
+	0,							/* U+00AA0E */
+	0,							/* U+00AA0F */
+	0,							/* U+00AA10 */
+	0,							/* U+00AA11 */
+	0,							/* U+00AA12 */
+	0,							/* U+00AA13 */
+	0,							/* U+00AA14 */
+	0,							/* U+00AA15 */
+	0,							/* U+00AA16 */
+	0,							/* U+00AA17 */
+	0,							/* U+00AA18 */
+	0,							/* U+00AA19 */
+	0,							/* U+00AA1A */
+	0,							/* U+00AA1B */
+	0,							/* U+00AA1C */
+	0,							/* U+00AA1D */
+	0,							/* U+00AA1E */
+	0,							/* U+00AA1F */
+	0,							/* U+00AA20 */
+	0,							/* U+00AA21 */
+	0,							/* U+00AA22 */
+	0,							/* U+00AA23 */
+	0,							/* U+00AA24 */
+	0,							/* U+00AA25 */
+	0,							/* U+00AA26 */
+	0,							/* U+00AA27 */
+	0,							/* U+00AA28 */
+	0,							/* U+00AA29 */
+	0,							/* U+00AA2A */
+	0,							/* U+00AA2B */
+	0,							/* U+00AA2C */
+	0,							/* U+00AA2D */
+	0,							/* U+00AA2E */
+	0,							/* U+00AA2F */
+	0,							/* U+00AA30 */
+	0,							/* U+00AA31 */
+	0,							/* U+00AA32 */
+	0,							/* U+00AA33 */
+	0,							/* U+00AA34 */
+	0,							/* U+00AA35 */
+	0,							/* U+00AA36 */
+	0,							/* U+00AA37 */
+	0,							/* U+00AA38 */
+	0,							/* U+00AA39 */
+	0,							/* U+00AA3A */
+	0,							/* U+00AA3B */
+	0,							/* U+00AA3C */
+	0,							/* U+00AA3D */
+	0,							/* U+00AA3E */
+	0,							/* U+00AA3F */
+	0,							/* U+00AA40 */
+	0,							/* U+00AA41 */
+	0,							/* U+00AA42 */
+	0,							/* U+00AA43 */
+	0,							/* U+00AA44 */
+	0,							/* U+00AA45 */
+	0,							/* U+00AA46 */
+	0,							/* U+00AA47 */
+	0,							/* U+00AA48 */
+	0,							/* U+00AA49 */
+	0,							/* U+00AA4A */
+	0,							/* U+00AA4B */
+	0,							/* U+00AA4C */
+	0,							/* U+00AA4D */
+	0,							/* U+00AA4E */
+	0,							/* U+00AA4F */
+	0,							/* U+00AA50 */
+	0,							/* U+00AA51 */
+	0,							/* U+00AA52 */
+	0,							/* U+00AA53 */
+	0,							/* U+00AA54 */
+	0,							/* U+00AA55 */
+	0,							/* U+00AA56 */
+	0,							/* U+00AA57 */
+	0,							/* U+00AA58 */
+	0,							/* U+00AA59 */
+	0,							/* U+00AA5A */
+	0,							/* U+00AA5B */
+	0,							/* U+00AA5C */
+	0,							/* U+00AA5D */
+	0,							/* U+00AA5E */
+	0,							/* U+00AA5F */
+	0,							/* U+00AA60 */
+	0,							/* U+00AA61 */
+	0,							/* U+00AA62 */
+	0,							/* U+00AA63 */
+	0,							/* U+00AA64 */
+	0,							/* U+00AA65 */
+	0,							/* U+00AA66 */
+	0,							/* U+00AA67 */
+	0,							/* U+00AA68 */
+	0,							/* U+00AA69 */
+	0,							/* U+00AA6A */
+	0,							/* U+00AA6B */
+	0,							/* U+00AA6C */
+	0,							/* U+00AA6D */
+	0,							/* U+00AA6E */
+	0,							/* U+00AA6F */
+	0,							/* U+00AA70 */
+	0,							/* U+00AA71 */
+	0,							/* U+00AA72 */
+	0,							/* U+00AA73 */
+	0,							/* U+00AA74 */
+	0,							/* U+00AA75 */
+	0,							/* U+00AA76 */
+	0,							/* U+00AA77 */
+	0,							/* U+00AA78 */
+	0,							/* U+00AA79 */
+	0,							/* U+00AA7A */
+	0,							/* U+00AA7B */
+	0,							/* U+00AA7C */
+	0,							/* U+00AA7D */
+	0,							/* U+00AA7E */
+	0,							/* U+00AA7F */
+	0,							/* U+00AA80 */
+	0,							/* U+00AA81 */
+	0,							/* U+00AA82 */
+	0,							/* U+00AA83 */
+	0,							/* U+00AA84 */
+	0,							/* U+00AA85 */
+	0,							/* U+00AA86 */
+	0,							/* U+00AA87 */
+	0,							/* U+00AA88 */
+	0,							/* U+00AA89 */
+	0,							/* U+00AA8A */
+	0,							/* U+00AA8B */
+	0,							/* U+00AA8C */
+	0,							/* U+00AA8D */
+	0,							/* U+00AA8E */
+	0,							/* U+00AA8F */
+	0,							/* U+00AA90 */
+	0,							/* U+00AA91 */
+	0,							/* U+00AA92 */
+	0,							/* U+00AA93 */
+	0,							/* U+00AA94 */
+	0,							/* U+00AA95 */
+	0,							/* U+00AA96 */
+	0,							/* U+00AA97 */
+	0,							/* U+00AA98 */
+	0,							/* U+00AA99 */
+	0,							/* U+00AA9A */
+	0,							/* U+00AA9B */
+	0,							/* U+00AA9C */
+	0,							/* U+00AA9D */
+	0,							/* U+00AA9E */
+	0,							/* U+00AA9F */
+	0,							/* U+00AAA0 */
+	0,							/* U+00AAA1 */
+	0,							/* U+00AAA2 */
+	0,							/* U+00AAA3 */
+	0,							/* U+00AAA4 */
+	0,							/* U+00AAA5 */
+	0,							/* U+00AAA6 */
+	0,							/* U+00AAA7 */
+	0,							/* U+00AAA8 */
+	0,							/* U+00AAA9 */
+	0,							/* U+00AAAA */
+	0,							/* U+00AAAB */
+	0,							/* U+00AAAC */
+	0,							/* U+00AAAD */
+	0,							/* U+00AAAE */
+	0,							/* U+00AAAF */
+	304,						/* U+00AAB0 */
+	0,							/* U+00AAB1 */
+	304,						/* U+00AAB2 */
+	304,						/* U+00AAB3 */
+	306,						/* U+00AAB4 */
+	0,							/* U+00AAB5 */
+	0,							/* U+00AAB6 */
+	304,						/* U+00AAB7 */
+	304,						/* U+00AAB8 */
+	0,							/* U+00AAB9 */
+	0,							/* U+00AABA */
+	0,							/* U+00AABB */
+	0,							/* U+00AABC */
+	0,							/* U+00AABD */
+	304,						/* U+00AABE */
+	304,						/* U+00AABF */
+	0,							/* U+00AAC0 */
+	304,						/* U+00AAC1 */
+	0,							/* U+00AAC2 */
+	0,							/* U+00AAC3 */
+	0,							/* U+00AAC4 */
+	0,							/* U+00AAC5 */
+	0,							/* U+00AAC6 */
+	0,							/* U+00AAC7 */
+	0,							/* U+00AAC8 */
+	0,							/* U+00AAC9 */
+	0,							/* U+00AACA */
+	0,							/* U+00AACB */
+	0,							/* U+00AACC */
+	0,							/* U+00AACD */
+	0,							/* U+00AACE */
+	0,							/* U+00AACF */
+	0,							/* U+00AAD0 */
+	0,							/* U+00AAD1 */
+	0,							/* U+00AAD2 */
+	0,							/* U+00AAD3 */
+	0,							/* U+00AAD4 */
+	0,							/* U+00AAD5 */
+	0,							/* U+00AAD6 */
+	0,							/* U+00AAD7 */
+	0,							/* U+00AAD8 */
+	0,							/* U+00AAD9 */
+	0,							/* U+00AADA */
+	0,							/* U+00AADB */
+	0,							/* U+00AADC */
+	0,							/* U+00AADD */
+	0,							/* U+00AADE */
+	0,							/* U+00AADF */
+	0,							/* U+00AAE0 */
+	0,							/* U+00AAE1 */
+	0,							/* U+00AAE2 */
+	0,							/* U+00AAE3 */
+	0,							/* U+00AAE4 */
+	0,							/* U+00AAE5 */
+	0,							/* U+00AAE6 */
+	0,							/* U+00AAE7 */
+	0,							/* U+00AAE8 */
+	0,							/* U+00AAE9 */
+	0,							/* U+00AAEA */
+	0,							/* U+00AAEB */
+	0,							/* U+00AAEC */
+	0,							/* U+00AAED */
+	0,							/* U+00AAEE */
+	0,							/* U+00AAEF */
+	0,							/* U+00AAF0 */
+	0,							/* U+00AAF1 */
+	0,							/* U+00AAF2 */
+	0,							/* U+00AAF3 */
+	0,							/* U+00AAF4 */
+	0,							/* U+00AAF5 */
+	452,						/* U+00AAF6 */
+	0,							/* U+00AAF7 */
+	0,							/* U+00AAF8 */
+	0,							/* U+00AAF9 */
+	0,							/* U+00AAFA */
+	0,							/* U+00AAFB */
+	0,							/* U+00AAFC */
+	0,							/* U+00AAFD */
+	0,							/* U+00AAFE */
+	0,							/* U+00AAFF */
+	0,							/* U+00AB00 */
+	0,							/* U+00AB01 */
+	0,							/* U+00AB02 */
+	0,							/* U+00AB03 */
+	0,							/* U+00AB04 */
+	0,							/* U+00AB05 */
+	0,							/* U+00AB06 */
+	0,							/* U+00AB07 */
+	0,							/* U+00AB08 */
+	0,							/* U+00AB09 */
+	0,							/* U+00AB0A */
+	0,							/* U+00AB0B */
+	0,							/* U+00AB0C */
+	0,							/* U+00AB0D */
+	0,							/* U+00AB0E */
+	0,							/* U+00AB0F */
+	0,							/* U+00AB10 */
+	0,							/* U+00AB11 */
+	0,							/* U+00AB12 */
+	0,							/* U+00AB13 */
+	0,							/* U+00AB14 */
+	0,							/* U+00AB15 */
+	0,							/* U+00AB16 */
+	0,							/* U+00AB17 */
+	0,							/* U+00AB18 */
+	0,							/* U+00AB19 */
+	0,							/* U+00AB1A */
+	0,							/* U+00AB1B */
+	0,							/* U+00AB1C */
+	0,							/* U+00AB1D */
+	0,							/* U+00AB1E */
+	0,							/* U+00AB1F */
+	0,							/* U+00AB20 */
+	0,							/* U+00AB21 */
+	0,							/* U+00AB22 */
+	0,							/* U+00AB23 */
+	0,							/* U+00AB24 */
+	0,							/* U+00AB25 */
+	0,							/* U+00AB26 */
+	0,							/* U+00AB27 */
+	0,							/* U+00AB28 */
+	0,							/* U+00AB29 */
+	0,							/* U+00AB2A */
+	0,							/* U+00AB2B */
+	0,							/* U+00AB2C */
+	0,							/* U+00AB2D */
+	0,							/* U+00AB2E */
+	0,							/* U+00AB2F */
+	0,							/* U+00AB30 */
+	0,							/* U+00AB31 */
+	0,							/* U+00AB32 */
+	0,							/* U+00AB33 */
+	0,							/* U+00AB34 */
+	0,							/* U+00AB35 */
+	0,							/* U+00AB36 */
+	0,							/* U+00AB37 */
+	0,							/* U+00AB38 */
+	0,							/* U+00AB39 */
+	0,							/* U+00AB3A */
+	0,							/* U+00AB3B */
+	0,							/* U+00AB3C */
+	0,							/* U+00AB3D */
+	0,							/* U+00AB3E */
+	0,							/* U+00AB3F */
+	0,							/* U+00AB40 */
+	0,							/* U+00AB41 */
+	0,							/* U+00AB42 */
+	0,							/* U+00AB43 */
+	0,							/* U+00AB44 */
+	0,							/* U+00AB45 */
+	0,							/* U+00AB46 */
+	0,							/* U+00AB47 */
+	0,							/* U+00AB48 */
+	0,							/* U+00AB49 */
+	0,							/* U+00AB4A */
+	0,							/* U+00AB4B */
+	0,							/* U+00AB4C */
+	0,							/* U+00AB4D */
+	0,							/* U+00AB4E */
+	0,							/* U+00AB4F */
+	0,							/* U+00AB50 */
+	0,							/* U+00AB51 */
+	0,							/* U+00AB52 */
+	0,							/* U+00AB53 */
+	0,							/* U+00AB54 */
+	0,							/* U+00AB55 */
+	0,							/* U+00AB56 */
+	0,							/* U+00AB57 */
+	0,							/* U+00AB58 */
+	0,							/* U+00AB59 */
+	0,							/* U+00AB5A */
+	0,							/* U+00AB5B */
+	2197,						/* U+00AB5C */
+	2198,						/* U+00AB5D */
+	2199,						/* U+00AB5E */
+	2200,						/* U+00AB5F */
+	0,							/* U+00AB60 */
+	0,							/* U+00AB61 */
+	0,							/* U+00AB62 */
+	0,							/* U+00AB63 */
+	0,							/* U+00AB64 */
+	0,							/* U+00AB65 */
+	0,							/* U+00AB66 */
+	0,							/* U+00AB67 */
+	0,							/* U+00AB68 */
+	2201,						/* U+00AB69 */
+	0,							/* U+00AB6A */
+	0,							/* U+00AB6B */
+	0,							/* U+00AB6C */
+	0,							/* U+00AB6D */
+	0,							/* U+00AB6E */
+	0,							/* U+00AB6F */
+	0,							/* U+00AB70 */
+	0,							/* U+00AB71 */
+	0,							/* U+00AB72 */
+	0,							/* U+00AB73 */
+	0,							/* U+00AB74 */
+	0,							/* U+00AB75 */
+	0,							/* U+00AB76 */
+	0,							/* U+00AB77 */
+	0,							/* U+00AB78 */
+	0,							/* U+00AB79 */
+	0,							/* U+00AB7A */
+	0,							/* U+00AB7B */
+	0,							/* U+00AB7C */
+	0,							/* U+00AB7D */
+	0,							/* U+00AB7E */
+	0,							/* U+00AB7F */
+	0,							/* U+00AB80 */
+	0,							/* U+00AB81 */
+	0,							/* U+00AB82 */
+	0,							/* U+00AB83 */
+	0,							/* U+00AB84 */
+	0,							/* U+00AB85 */
+	0,							/* U+00AB86 */
+	0,							/* U+00AB87 */
+	0,							/* U+00AB88 */
+	0,							/* U+00AB89 */
+	0,							/* U+00AB8A */
+	0,							/* U+00AB8B */
+	0,							/* U+00AB8C */
+	0,							/* U+00AB8D */
+	0,							/* U+00AB8E */
+	0,							/* U+00AB8F */
+	0,							/* U+00AB90 */
+	0,							/* U+00AB91 */
+	0,							/* U+00AB92 */
+	0,							/* U+00AB93 */
+	0,							/* U+00AB94 */
+	0,							/* U+00AB95 */
+	0,							/* U+00AB96 */
+	0,							/* U+00AB97 */
+	0,							/* U+00AB98 */
+	0,							/* U+00AB99 */
+	0,							/* U+00AB9A */
+	0,							/* U+00AB9B */
+	0,							/* U+00AB9C */
+	0,							/* U+00AB9D */
+	0,							/* U+00AB9E */
+	0,							/* U+00AB9F */
+	0,							/* U+00ABA0 */
+	0,							/* U+00ABA1 */
+	0,							/* U+00ABA2 */
+	0,							/* U+00ABA3 */
+	0,							/* U+00ABA4 */
+	0,							/* U+00ABA5 */
+	0,							/* U+00ABA6 */
+	0,							/* U+00ABA7 */
+	0,							/* U+00ABA8 */
+	0,							/* U+00ABA9 */
+	0,							/* U+00ABAA */
+	0,							/* U+00ABAB */
+	0,							/* U+00ABAC */
+	0,							/* U+00ABAD */
+	0,							/* U+00ABAE */
+	0,							/* U+00ABAF */
+	0,							/* U+00ABB0 */
+	0,							/* U+00ABB1 */
+	0,							/* U+00ABB2 */
+	0,							/* U+00ABB3 */
+	0,							/* U+00ABB4 */
+	0,							/* U+00ABB5 */
+	0,							/* U+00ABB6 */
+	0,							/* U+00ABB7 */
+	0,							/* U+00ABB8 */
+	0,							/* U+00ABB9 */
+	0,							/* U+00ABBA */
+	0,							/* U+00ABBB */
+	0,							/* U+00ABBC */
+	0,							/* U+00ABBD */
+	0,							/* U+00ABBE */
+	0,							/* U+00ABBF */
+	0,							/* U+00ABC0 */
+	0,							/* U+00ABC1 */
+	0,							/* U+00ABC2 */
+	0,							/* U+00ABC3 */
+	0,							/* U+00ABC4 */
+	0,							/* U+00ABC5 */
+	0,							/* U+00ABC6 */
+	0,							/* U+00ABC7 */
+	0,							/* U+00ABC8 */
+	0,							/* U+00ABC9 */
+	0,							/* U+00ABCA */
+	0,							/* U+00ABCB */
+	0,							/* U+00ABCC */
+	0,							/* U+00ABCD */
+	0,							/* U+00ABCE */
+	0,							/* U+00ABCF */
+	0,							/* U+00ABD0 */
+	0,							/* U+00ABD1 */
+	0,							/* U+00ABD2 */
+	0,							/* U+00ABD3 */
+	0,							/* U+00ABD4 */
+	0,							/* U+00ABD5 */
+	0,							/* U+00ABD6 */
+	0,							/* U+00ABD7 */
+	0,							/* U+00ABD8 */
+	0,							/* U+00ABD9 */
+	0,							/* U+00ABDA */
+	0,							/* U+00ABDB */
+	0,							/* U+00ABDC */
+	0,							/* U+00ABDD */
+	0,							/* U+00ABDE */
+	0,							/* U+00ABDF */
+	0,							/* U+00ABE0 */
+	0,							/* U+00ABE1 */
+	0,							/* U+00ABE2 */
+	0,							/* U+00ABE3 */
+	0,							/* U+00ABE4 */
+	0,							/* U+00ABE5 */
+	0,							/* U+00ABE6 */
+	0,							/* U+00ABE7 */
+	0,							/* U+00ABE8 */
+	0,							/* U+00ABE9 */
+	0,							/* U+00ABEA */
+	0,							/* U+00ABEB */
+	0,							/* U+00ABEC */
+	452,						/* U+00ABED */
+	2202,						/* U+00F900 */
+	2203,						/* U+00F901 */
+	2204,						/* U+00F902 */
+	2205,						/* U+00F903 */
+	2206,						/* U+00F904 */
+	2207,						/* U+00F905 */
+	2208,						/* U+00F906 */
+	2209,						/* U+00F907 */
+	2209,						/* U+00F908 */
+	2210,						/* U+00F909 */
+	2211,						/* U+00F90A */
+	2212,						/* U+00F90B */
+	2213,						/* U+00F90C */
+	2214,						/* U+00F90D */
+	2215,						/* U+00F90E */
+	2216,						/* U+00F90F */
+	2217,						/* U+00F910 */
+	2218,						/* U+00F911 */
+	2219,						/* U+00F912 */
+	2220,						/* U+00F913 */
+	2221,						/* U+00F914 */
+	2222,						/* U+00F915 */
+	2223,						/* U+00F916 */
+	2224,						/* U+00F917 */
+	2225,						/* U+00F918 */
+	2226,						/* U+00F919 */
+	2227,						/* U+00F91A */
+	2228,						/* U+00F91B */
+	2229,						/* U+00F91C */
+	2230,						/* U+00F91D */
+	2231,						/* U+00F91E */
+	2232,						/* U+00F91F */
+	2233,						/* U+00F920 */
+	2234,						/* U+00F921 */
+	2235,						/* U+00F922 */
+	2236,						/* U+00F923 */
+	2237,						/* U+00F924 */
+	2238,						/* U+00F925 */
+	2239,						/* U+00F926 */
+	2240,						/* U+00F927 */
+	2241,						/* U+00F928 */
+	2242,						/* U+00F929 */
+	2243,						/* U+00F92A */
+	2244,						/* U+00F92B */
+	2245,						/* U+00F92C */
+	2246,						/* U+00F92D */
+	2247,						/* U+00F92E */
+	2248,						/* U+00F92F */
+	2249,						/* U+00F930 */
+	2250,						/* U+00F931 */
+	2251,						/* U+00F932 */
+	2252,						/* U+00F933 */
+	2253,						/* U+00F934 */
+	2254,						/* U+00F935 */
+	2255,						/* U+00F936 */
+	2256,						/* U+00F937 */
+	2257,						/* U+00F938 */
+	2258,						/* U+00F939 */
+	2259,						/* U+00F93A */
+	2260,						/* U+00F93B */
+	2261,						/* U+00F93C */
+	2262,						/* U+00F93D */
+	2263,						/* U+00F93E */
+	2264,						/* U+00F93F */
+	2265,						/* U+00F940 */
+	2266,						/* U+00F941 */
+	2267,						/* U+00F942 */
+	2268,						/* U+00F943 */
+	2269,						/* U+00F944 */
+	2270,						/* U+00F945 */
+	2271,						/* U+00F946 */
+	2272,						/* U+00F947 */
+	2273,						/* U+00F948 */
+	2274,						/* U+00F949 */
+	2275,						/* U+00F94A */
+	2276,						/* U+00F94B */
+	2277,						/* U+00F94C */
+	2278,						/* U+00F94D */
+	2279,						/* U+00F94E */
+	2280,						/* U+00F94F */
+	2281,						/* U+00F950 */
+	2282,						/* U+00F951 */
+	2283,						/* U+00F952 */
+	2284,						/* U+00F953 */
+	2285,						/* U+00F954 */
+	2286,						/* U+00F955 */
+	2287,						/* U+00F956 */
+	2288,						/* U+00F957 */
+	2289,						/* U+00F958 */
+	2290,						/* U+00F959 */
+	2291,						/* U+00F95A */
+	2292,						/* U+00F95B */
+	2221,						/* U+00F95C */
+	2293,						/* U+00F95D */
+	2294,						/* U+00F95E */
+	2295,						/* U+00F95F */
+	2296,						/* U+00F960 */
+	2297,						/* U+00F961 */
+	2298,						/* U+00F962 */
+	2299,						/* U+00F963 */
+	2300,						/* U+00F964 */
+	2301,						/* U+00F965 */
+	2302,						/* U+00F966 */
+	2303,						/* U+00F967 */
+	2304,						/* U+00F968 */
+	2305,						/* U+00F969 */
+	2306,						/* U+00F96A */
+	2307,						/* U+00F96B */
+	2308,						/* U+00F96C */
+	2309,						/* U+00F96D */
+	2310,						/* U+00F96E */
+	2311,						/* U+00F96F */
+	2312,						/* U+00F970 */
+	2313,						/* U+00F971 */
+	2314,						/* U+00F972 */
+	2315,						/* U+00F973 */
+	2316,						/* U+00F974 */
+	2317,						/* U+00F975 */
+	2318,						/* U+00F976 */
+	2319,						/* U+00F977 */
+	2320,						/* U+00F978 */
+	2321,						/* U+00F979 */
+	2322,						/* U+00F97A */
+	2323,						/* U+00F97B */
+	2324,						/* U+00F97C */
+	2325,						/* U+00F97D */
+	2326,						/* U+00F97E */
+	2327,						/* U+00F97F */
+	2328,						/* U+00F980 */
+	2329,						/* U+00F981 */
+	2330,						/* U+00F982 */
+	2331,						/* U+00F983 */
+	2332,						/* U+00F984 */
+	2333,						/* U+00F985 */
+	2334,						/* U+00F986 */
+	2335,						/* U+00F987 */
+	2336,						/* U+00F988 */
+	2337,						/* U+00F989 */
+	2338,						/* U+00F98A */
+	2339,						/* U+00F98B */
+	2340,						/* U+00F98C */
+	2341,						/* U+00F98D */
+	2342,						/* U+00F98E */
+	2343,						/* U+00F98F */
+	2344,						/* U+00F990 */
+	2345,						/* U+00F991 */
+	2346,						/* U+00F992 */
+	2347,						/* U+00F993 */
+	2348,						/* U+00F994 */
+	2349,						/* U+00F995 */
+	2350,						/* U+00F996 */
+	2351,						/* U+00F997 */
+	2352,						/* U+00F998 */
+	2353,						/* U+00F999 */
+	2354,						/* U+00F99A */
+	2355,						/* U+00F99B */
+	2356,						/* U+00F99C */
+	2357,						/* U+00F99D */
+	2358,						/* U+00F99E */
+	2359,						/* U+00F99F */
+	2360,						/* U+00F9A0 */
+	2311,						/* U+00F9A1 */
+	2361,						/* U+00F9A2 */
+	2362,						/* U+00F9A3 */
+	2363,						/* U+00F9A4 */
+	2364,						/* U+00F9A5 */
+	2365,						/* U+00F9A6 */
+	2366,						/* U+00F9A7 */
+	2367,						/* U+00F9A8 */
+	2368,						/* U+00F9A9 */
+	2295,						/* U+00F9AA */
+	2369,						/* U+00F9AB */
+	2370,						/* U+00F9AC */
+	2371,						/* U+00F9AD */
+	2372,						/* U+00F9AE */
+	2373,						/* U+00F9AF */
+	2374,						/* U+00F9B0 */
+	2375,						/* U+00F9B1 */
+	2376,						/* U+00F9B2 */
+	2377,						/* U+00F9B3 */
+	2378,						/* U+00F9B4 */
+	2379,						/* U+00F9B5 */
+	2380,						/* U+00F9B6 */
+	2381,						/* U+00F9B7 */
+	2382,						/* U+00F9B8 */
+	2383,						/* U+00F9B9 */
+	2384,						/* U+00F9BA */
+	2385,						/* U+00F9BB */
+	2386,						/* U+00F9BC */
+	2387,						/* U+00F9BD */
+	2388,						/* U+00F9BE */
+	2221,						/* U+00F9BF */
+	2389,						/* U+00F9C0 */
+	2390,						/* U+00F9C1 */
+	2391,						/* U+00F9C2 */
+	2392,						/* U+00F9C3 */
+	2393,						/* U+00F9C4 */
+	2394,						/* U+00F9C5 */
+	2395,						/* U+00F9C6 */
+	2396,						/* U+00F9C7 */
+	2397,						/* U+00F9C8 */
+	2398,						/* U+00F9C9 */
+	2399,						/* U+00F9CA */
+	2400,						/* U+00F9CB */
+	2401,						/* U+00F9CC */
+	2402,						/* U+00F9CD */
+	2403,						/* U+00F9CE */
+	2404,						/* U+00F9CF */
+	2405,						/* U+00F9D0 */
+	2406,						/* U+00F9D1 */
+	2407,						/* U+00F9D2 */
+	2408,						/* U+00F9D3 */
+	2409,						/* U+00F9D4 */
+	2410,						/* U+00F9D5 */
+	2411,						/* U+00F9D6 */
+	2412,						/* U+00F9D7 */
+	2413,						/* U+00F9D8 */
+	2414,						/* U+00F9D9 */
+	2415,						/* U+00F9DA */
+	2297,						/* U+00F9DB */
+	2416,						/* U+00F9DC */
+	2417,						/* U+00F9DD */
+	2418,						/* U+00F9DE */
+	2419,						/* U+00F9DF */
+	2420,						/* U+00F9E0 */
+	2421,						/* U+00F9E1 */
+	2422,						/* U+00F9E2 */
+	2423,						/* U+00F9E3 */
+	2424,						/* U+00F9E4 */
+	2425,						/* U+00F9E5 */
+	2426,						/* U+00F9E6 */
+	2427,						/* U+00F9E7 */
+	2428,						/* U+00F9E8 */
+	2429,						/* U+00F9E9 */
+	2430,						/* U+00F9EA */
+	2431,						/* U+00F9EB */
+	2432,						/* U+00F9EC */
+	2433,						/* U+00F9ED */
+	2434,						/* U+00F9EE */
+	2435,						/* U+00F9EF */
+	2436,						/* U+00F9F0 */
+	2437,						/* U+00F9F1 */
+	2438,						/* U+00F9F2 */
+	2439,						/* U+00F9F3 */
+	2440,						/* U+00F9F4 */
+	2441,						/* U+00F9F5 */
+	2442,						/* U+00F9F6 */
+	2443,						/* U+00F9F7 */
+	2444,						/* U+00F9F8 */
+	2445,						/* U+00F9F9 */
+	2446,						/* U+00F9FA */
+	2447,						/* U+00F9FB */
+	2448,						/* U+00F9FC */
+	2449,						/* U+00F9FD */
+	2450,						/* U+00F9FE */
+	2451,						/* U+00F9FF */
+	2452,						/* U+00FA00 */
+	2453,						/* U+00FA01 */
+	2454,						/* U+00FA02 */
+	2455,						/* U+00FA03 */
+	2456,						/* U+00FA04 */
+	2457,						/* U+00FA05 */
+	2458,						/* U+00FA06 */
+	2459,						/* U+00FA07 */
+	2460,						/* U+00FA08 */
+	2461,						/* U+00FA09 */
+	2462,						/* U+00FA0A */
+	2463,						/* U+00FA0B */
+	2464,						/* U+00FA0C */
+	2465,						/* U+00FA0D */
+	0,							/* U+00FA0E */
+	0,							/* U+00FA0F */
+	2466,						/* U+00FA10 */
+	0,							/* U+00FA11 */
+	2467,						/* U+00FA12 */
+	0,							/* U+00FA13 */
+	0,							/* U+00FA14 */
+	2468,						/* U+00FA15 */
+	2469,						/* U+00FA16 */
+	2470,						/* U+00FA17 */
+	2471,						/* U+00FA18 */
+	2472,						/* U+00FA19 */
+	2473,						/* U+00FA1A */
+	2474,						/* U+00FA1B */
+	2475,						/* U+00FA1C */
+	2476,						/* U+00FA1D */
+	2477,						/* U+00FA1E */
+	0,							/* U+00FA1F */
+	2478,						/* U+00FA20 */
+	0,							/* U+00FA21 */
+	2479,						/* U+00FA22 */
+	0,							/* U+00FA23 */
+	0,							/* U+00FA24 */
+	2480,						/* U+00FA25 */
+	2481,						/* U+00FA26 */
+	0,							/* U+00FA27 */
+	0,							/* U+00FA28 */
+	0,							/* U+00FA29 */
+	2482,						/* U+00FA2A */
+	2483,						/* U+00FA2B */
+	2484,						/* U+00FA2C */
+	2485,						/* U+00FA2D */
+	2486,						/* U+00FA2E */
+	2487,						/* U+00FA2F */
+	2488,						/* U+00FA30 */
+	2489,						/* U+00FA31 */
+	2490,						/* U+00FA32 */
+	2491,						/* U+00FA33 */
+	2492,						/* U+00FA34 */
+	2493,						/* U+00FA35 */
+	2494,						/* U+00FA36 */
+	2495,						/* U+00FA37 */
+	2496,						/* U+00FA38 */
+	2497,						/* U+00FA39 */
+	2498,						/* U+00FA3A */
+	2499,						/* U+00FA3B */
+	2500,						/* U+00FA3C */
+	2501,						/* U+00FA3D */
+	2502,						/* U+00FA3E */
+	2503,						/* U+00FA3F */
+	2504,						/* U+00FA40 */
+	2505,						/* U+00FA41 */
+	2506,						/* U+00FA42 */
+	2507,						/* U+00FA43 */
+	2508,						/* U+00FA44 */
+	2509,						/* U+00FA45 */
+	2510,						/* U+00FA46 */
+	2511,						/* U+00FA47 */
+	2512,						/* U+00FA48 */
+	2513,						/* U+00FA49 */
+	2514,						/* U+00FA4A */
+	2515,						/* U+00FA4B */
+	2516,						/* U+00FA4C */
+	2517,						/* U+00FA4D */
+	2518,						/* U+00FA4E */
+	2519,						/* U+00FA4F */
+	2520,						/* U+00FA50 */
+	2521,						/* U+00FA51 */
+	2522,						/* U+00FA52 */
+	2523,						/* U+00FA53 */
+	2524,						/* U+00FA54 */
+	2525,						/* U+00FA55 */
+	2526,						/* U+00FA56 */
+	2350,						/* U+00FA57 */
+	2527,						/* U+00FA58 */
+	2528,						/* U+00FA59 */
+	2529,						/* U+00FA5A */
+	2530,						/* U+00FA5B */
+	2531,						/* U+00FA5C */
+	2532,						/* U+00FA5D */
+	2532,						/* U+00FA5E */
+	2533,						/* U+00FA5F */
+	2534,						/* U+00FA60 */
+	2535,						/* U+00FA61 */
+	2536,						/* U+00FA62 */
+	2537,						/* U+00FA63 */
+	2538,						/* U+00FA64 */
+	2539,						/* U+00FA65 */
+	2540,						/* U+00FA66 */
+	2480,						/* U+00FA67 */
+	2541,						/* U+00FA68 */
+	2542,						/* U+00FA69 */
+	2543,						/* U+00FA6A */
+	2544,						/* U+00FA6B */
+	2545,						/* U+00FA6C */
+	2546,						/* U+00FA6D */
+	0,							/* U+00FA6E */
+	0,							/* U+00FA6F */
+	2547,						/* U+00FA70 */
+	2548,						/* U+00FA71 */
+	2549,						/* U+00FA72 */
+	2550,						/* U+00FA73 */
+	2551,						/* U+00FA74 */
+	2552,						/* U+00FA75 */
+	2553,						/* U+00FA76 */
+	2554,						/* U+00FA77 */
+	2494,						/* U+00FA78 */
+	2555,						/* U+00FA79 */
+	2556,						/* U+00FA7A */
+	2557,						/* U+00FA7B */
+	2466,						/* U+00FA7C */
+	2558,						/* U+00FA7D */
+	2559,						/* U+00FA7E */
+	2560,						/* U+00FA7F */
+	2561,						/* U+00FA80 */
+	2562,						/* U+00FA81 */
+	2563,						/* U+00FA82 */
+	2564,						/* U+00FA83 */
+	2565,						/* U+00FA84 */
+	2566,						/* U+00FA85 */
+	2567,						/* U+00FA86 */
+	2568,						/* U+00FA87 */
+	2569,						/* U+00FA88 */
+	2503,						/* U+00FA89 */
+	2570,						/* U+00FA8A */
+	2504,						/* U+00FA8B */
+	2571,						/* U+00FA8C */
+	2572,						/* U+00FA8D */
+	2573,						/* U+00FA8E */
+	2574,						/* U+00FA8F */
+	2575,						/* U+00FA90 */
+	2467,						/* U+00FA91 */
+	2242,						/* U+00FA92 */
+	2576,						/* U+00FA93 */
+	2577,						/* U+00FA94 */
+	2578,						/* U+00FA95 */
+	2312,						/* U+00FA96 */
+	2399,						/* U+00FA97 */
+	2579,						/* U+00FA98 */
+	2580,						/* U+00FA99 */
+	2511,						/* U+00FA9A */
+	2581,						/* U+00FA9B */
+	2512,						/* U+00FA9C */
+	2582,						/* U+00FA9D */
+	2583,						/* U+00FA9E */
+	2584,						/* U+00FA9F */
+	2469,						/* U+00FAA0 */
+	2585,						/* U+00FAA1 */
+	2586,						/* U+00FAA2 */
+	2587,						/* U+00FAA3 */
+	2588,						/* U+00FAA4 */
+	2589,						/* U+00FAA5 */
+	2470,						/* U+00FAA6 */
+	2590,						/* U+00FAA7 */
+	2591,						/* U+00FAA8 */
+	2592,						/* U+00FAA9 */
+	2593,						/* U+00FAAA */
+	2594,						/* U+00FAAB */
+	2595,						/* U+00FAAC */
+	2526,						/* U+00FAAD */
+	2596,						/* U+00FAAE */
+	2597,						/* U+00FAAF */
+	2350,						/* U+00FAB0 */
+	2598,						/* U+00FAB1 */
+	2530,						/* U+00FAB2 */
+	2599,						/* U+00FAB3 */
+	2600,						/* U+00FAB4 */
+	2601,						/* U+00FAB5 */
+	2602,						/* U+00FAB6 */
+	2603,						/* U+00FAB7 */
+	2535,						/* U+00FAB8 */
+	2604,						/* U+00FAB9 */
+	2479,						/* U+00FABA */
+	2605,						/* U+00FABB */
+	2536,						/* U+00FABC */
+	2293,						/* U+00FABD */
+	2606,						/* U+00FABE */
+	2537,						/* U+00FABF */
+	2607,						/* U+00FAC0 */
+	2539,						/* U+00FAC1 */
+	2608,						/* U+00FAC2 */
+	2609,						/* U+00FAC3 */
+	2610,						/* U+00FAC4 */
+	2611,						/* U+00FAC5 */
+	2612,						/* U+00FAC6 */
+	2541,						/* U+00FAC7 */
+	2475,						/* U+00FAC8 */
+	2613,						/* U+00FAC9 */
+	2542,						/* U+00FACA */
+	2614,						/* U+00FACB */
+	2543,						/* U+00FACC */
+	2615,						/* U+00FACD */
+	2209,						/* U+00FACE */
+	2616,						/* U+00FACF */
+	2617,						/* U+00FAD0 */
+	2618,						/* U+00FAD1 */
+	2619,						/* U+00FAD2 */
+	2620,						/* U+00FAD3 */
+	2621,						/* U+00FAD4 */
+	2622,						/* U+00FAD5 */
+	2623,						/* U+00FAD6 */
+	2624,						/* U+00FAD7 */
+	2625,						/* U+00FAD8 */
+	2626,						/* U+00FAD9 */
+	0,							/* U+00FADA */
+	0,							/* U+00FADB */
+	0,							/* U+00FADC */
+	0,							/* U+00FADD */
+	0,							/* U+00FADE */
+	0,							/* U+00FADF */
+	0,							/* U+00FAE0 */
+	0,							/* U+00FAE1 */
+	0,							/* U+00FAE2 */
+	0,							/* U+00FAE3 */
+	0,							/* U+00FAE4 */
+	0,							/* U+00FAE5 */
+	0,							/* U+00FAE6 */
+	0,							/* U+00FAE7 */
+	0,							/* U+00FAE8 */
+	0,							/* U+00FAE9 */
+	0,							/* U+00FAEA */
+	0,							/* U+00FAEB */
+	0,							/* U+00FAEC */
+	0,							/* U+00FAED */
+	0,							/* U+00FAEE */
+	0,							/* U+00FAEF */
+	0,							/* U+00FAF0 */
+	0,							/* U+00FAF1 */
+	0,							/* U+00FAF2 */
+	0,							/* U+00FAF3 */
+	0,							/* U+00FAF4 */
+	0,							/* U+00FAF5 */
+	0,							/* U+00FAF6 */
+	0,							/* U+00FAF7 */
+	0,							/* U+00FAF8 */
+	0,							/* U+00FAF9 */
+	0,							/* U+00FAFA */
+	0,							/* U+00FAFB */
+	0,							/* U+00FAFC */
+	0,							/* U+00FAFD */
+	0,							/* U+00FAFE */
+	0,							/* U+00FAFF */
+	2627,						/* U+00FB00 */
+	2628,						/* U+00FB01 */
+	2629,						/* U+00FB02 */
+	2630,						/* U+00FB03 */
+	2631,						/* U+00FB04 */
+	2632,						/* U+00FB05 */
+	2633,						/* U+00FB06 */
+	0,							/* U+00FB07 */
+	0,							/* U+00FB08 */
+	0,							/* U+00FB09 */
+	0,							/* U+00FB0A */
+	0,							/* U+00FB0B */
+	0,							/* U+00FB0C */
+	0,							/* U+00FB0D */
+	0,							/* U+00FB0E */
+	0,							/* U+00FB0F */
+	0,							/* U+00FB10 */
+	0,							/* U+00FB11 */
+	0,							/* U+00FB12 */
+	2634,						/* U+00FB13 */
+	2635,						/* U+00FB14 */
+	2636,						/* U+00FB15 */
+	2637,						/* U+00FB16 */
+	2638,						/* U+00FB17 */
+	0,							/* U+00FB18 */
+	0,							/* U+00FB19 */
+	0,							/* U+00FB1A */
+	0,							/* U+00FB1B */
+	0,							/* U+00FB1C */
+	2639,						/* U+00FB1D */
+	2640,						/* U+00FB1E */
+	2641,						/* U+00FB1F */
+	2642,						/* U+00FB20 */
+	1154,						/* U+00FB21 */
+	1157,						/* U+00FB22 */
+	2643,						/* U+00FB23 */
+	2644,						/* U+00FB24 */
+	2645,						/* U+00FB25 */
+	2646,						/* U+00FB26 */
+	2647,						/* U+00FB27 */
+	2648,						/* U+00FB28 */
+	1128,						/* U+00FB29 */
+	2649,						/* U+00FB2A */
+	2650,						/* U+00FB2B */
+	2651,						/* U+00FB2C */
+	2652,						/* U+00FB2D */
+	2653,						/* U+00FB2E */
+	2654,						/* U+00FB2F */
+	2655,						/* U+00FB30 */
+	2656,						/* U+00FB31 */
+	2657,						/* U+00FB32 */
+	2658,						/* U+00FB33 */
+	2659,						/* U+00FB34 */
+	2660,						/* U+00FB35 */
+	2661,						/* U+00FB36 */
+	0,							/* U+00FB37 */
+	2662,						/* U+00FB38 */
+	2663,						/* U+00FB39 */
+	2664,						/* U+00FB3A */
+	2665,						/* U+00FB3B */
+	2666,						/* U+00FB3C */
+	0,							/* U+00FB3D */
+	2667,						/* U+00FB3E */
+	0,							/* U+00FB3F */
+	2668,						/* U+00FB40 */
+	2669,						/* U+00FB41 */
+	0,							/* U+00FB42 */
+	2670,						/* U+00FB43 */
+	2671,						/* U+00FB44 */
+	0,							/* U+00FB45 */
+	2672,						/* U+00FB46 */
+	2673,						/* U+00FB47 */
+	2674,						/* U+00FB48 */
+	2675,						/* U+00FB49 */
+	2676,						/* U+00FB4A */
+	2677,						/* U+00FB4B */
+	2678,						/* U+00FB4C */
+	2679,						/* U+00FB4D */
+	2680,						/* U+00FB4E */
+	2681,						/* U+00FB4F */
+	2682,						/* U+00FB50 */
+	2682,						/* U+00FB51 */
+	2683,						/* U+00FB52 */
+	2683,						/* U+00FB53 */
+	2683,						/* U+00FB54 */
+	2683,						/* U+00FB55 */
+	2684,						/* U+00FB56 */
+	2684,						/* U+00FB57 */
+	2684,						/* U+00FB58 */
+	2684,						/* U+00FB59 */
+	2685,						/* U+00FB5A */
+	2685,						/* U+00FB5B */
+	2685,						/* U+00FB5C */
+	2685,						/* U+00FB5D */
+	2686,						/* U+00FB5E */
+	2686,						/* U+00FB5F */
+	2686,						/* U+00FB60 */
+	2686,						/* U+00FB61 */
+	2687,						/* U+00FB62 */
+	2687,						/* U+00FB63 */
+	2687,						/* U+00FB64 */
+	2687,						/* U+00FB65 */
+	2688,						/* U+00FB66 */
+	2688,						/* U+00FB67 */
+	2688,						/* U+00FB68 */
+	2688,						/* U+00FB69 */
+	2689,						/* U+00FB6A */
+	2689,						/* U+00FB6B */
+	2689,						/* U+00FB6C */
+	2689,						/* U+00FB6D */
+	2690,						/* U+00FB6E */
+	2690,						/* U+00FB6F */
+	2690,						/* U+00FB70 */
+	2690,						/* U+00FB71 */
+	2691,						/* U+00FB72 */
+	2691,						/* U+00FB73 */
+	2691,						/* U+00FB74 */
+	2691,						/* U+00FB75 */
+	2692,						/* U+00FB76 */
+	2692,						/* U+00FB77 */
+	2692,						/* U+00FB78 */
+	2692,						/* U+00FB79 */
+	2693,						/* U+00FB7A */
+	2693,						/* U+00FB7B */
+	2693,						/* U+00FB7C */
+	2693,						/* U+00FB7D */
+	2694,						/* U+00FB7E */
+	2694,						/* U+00FB7F */
+	2694,						/* U+00FB80 */
+	2694,						/* U+00FB81 */
+	2695,						/* U+00FB82 */
+	2695,						/* U+00FB83 */
+	2696,						/* U+00FB84 */
+	2696,						/* U+00FB85 */
+	2697,						/* U+00FB86 */
+	2697,						/* U+00FB87 */
+	2698,						/* U+00FB88 */
+	2698,						/* U+00FB89 */
+	2699,						/* U+00FB8A */
+	2699,						/* U+00FB8B */
+	2700,						/* U+00FB8C */
+	2700,						/* U+00FB8D */
+	2701,						/* U+00FB8E */
+	2701,						/* U+00FB8F */
+	2701,						/* U+00FB90 */
+	2701,						/* U+00FB91 */
+	2702,						/* U+00FB92 */
+	2702,						/* U+00FB93 */
+	2702,						/* U+00FB94 */
+	2702,						/* U+00FB95 */
+	2703,						/* U+00FB96 */
+	2703,						/* U+00FB97 */
+	2703,						/* U+00FB98 */
+	2703,						/* U+00FB99 */
+	2704,						/* U+00FB9A */
+	2704,						/* U+00FB9B */
+	2704,						/* U+00FB9C */
+	2704,						/* U+00FB9D */
+	2705,						/* U+00FB9E */
+	2705,						/* U+00FB9F */
+	2706,						/* U+00FBA0 */
+	2706,						/* U+00FBA1 */
+	2706,						/* U+00FBA2 */
+	2706,						/* U+00FBA3 */
+	2707,						/* U+00FBA4 */
+	2707,						/* U+00FBA5 */
+	2708,						/* U+00FBA6 */
+	2708,						/* U+00FBA7 */
+	2708,						/* U+00FBA8 */
+	2708,						/* U+00FBA9 */
+	2709,						/* U+00FBAA */
+	2709,						/* U+00FBAB */
+	2709,						/* U+00FBAC */
+	2709,						/* U+00FBAD */
+	2710,						/* U+00FBAE */
+	2710,						/* U+00FBAF */
+	2711,						/* U+00FBB0 */
+	2711,						/* U+00FBB1 */
+	0,							/* U+00FBB2 */
+	0,							/* U+00FBB3 */
+	0,							/* U+00FBB4 */
+	0,							/* U+00FBB5 */
+	0,							/* U+00FBB6 */
+	0,							/* U+00FBB7 */
+	0,							/* U+00FBB8 */
+	0,							/* U+00FBB9 */
+	0,							/* U+00FBBA */
+	0,							/* U+00FBBB */
+	0,							/* U+00FBBC */
+	0,							/* U+00FBBD */
+	0,							/* U+00FBBE */
+	0,							/* U+00FBBF */
+	0,							/* U+00FBC0 */
+	0,							/* U+00FBC1 */
+	0,							/* U+00FBC2 */
+	0,							/* U+00FBC3 */
+	0,							/* U+00FBC4 */
+	0,							/* U+00FBC5 */
+	0,							/* U+00FBC6 */
+	0,							/* U+00FBC7 */
+	0,							/* U+00FBC8 */
+	0,							/* U+00FBC9 */
+	0,							/* U+00FBCA */
+	0,							/* U+00FBCB */
+	0,							/* U+00FBCC */
+	0,							/* U+00FBCD */
+	0,							/* U+00FBCE */
+	0,							/* U+00FBCF */
+	0,							/* U+00FBD0 */
+	0,							/* U+00FBD1 */
+	0,							/* U+00FBD2 */
+	2712,						/* U+00FBD3 */
+	2712,						/* U+00FBD4 */
+	2712,						/* U+00FBD5 */
+	2712,						/* U+00FBD6 */
+	2713,						/* U+00FBD7 */
+	2713,						/* U+00FBD8 */
+	2714,						/* U+00FBD9 */
+	2714,						/* U+00FBDA */
+	2715,						/* U+00FBDB */
+	2715,						/* U+00FBDC */
+	2716,						/* U+00FBDD */
+	2717,						/* U+00FBDE */
+	2717,						/* U+00FBDF */
+	2718,						/* U+00FBE0 */
+	2718,						/* U+00FBE1 */
+	2719,						/* U+00FBE2 */
+	2719,						/* U+00FBE3 */
+	2720,						/* U+00FBE4 */
+	2720,						/* U+00FBE5 */
+	2720,						/* U+00FBE6 */
+	2720,						/* U+00FBE7 */
+	2721,						/* U+00FBE8 */
+	2721,						/* U+00FBE9 */
+	2722,						/* U+00FBEA */
+	2722,						/* U+00FBEB */
+	2723,						/* U+00FBEC */
+	2723,						/* U+00FBED */
+	2724,						/* U+00FBEE */
+	2724,						/* U+00FBEF */
+	2725,						/* U+00FBF0 */
+	2725,						/* U+00FBF1 */
+	2726,						/* U+00FBF2 */
+	2726,						/* U+00FBF3 */
+	2727,						/* U+00FBF4 */
+	2727,						/* U+00FBF5 */
+	2728,						/* U+00FBF6 */
+	2728,						/* U+00FBF7 */
+	2728,						/* U+00FBF8 */
+	2729,						/* U+00FBF9 */
+	2729,						/* U+00FBFA */
+	2729,						/* U+00FBFB */
+	2730,						/* U+00FBFC */
+	2730,						/* U+00FBFD */
+	2730,						/* U+00FBFE */
+	2730,						/* U+00FBFF */
+	2731,						/* U+00FC00 */
+	2732,						/* U+00FC01 */
+	2733,						/* U+00FC02 */
+	2729,						/* U+00FC03 */
+	2734,						/* U+00FC04 */
+	2735,						/* U+00FC05 */
+	2736,						/* U+00FC06 */
+	2737,						/* U+00FC07 */
+	2738,						/* U+00FC08 */
+	2739,						/* U+00FC09 */
+	2740,						/* U+00FC0A */
+	2741,						/* U+00FC0B */
+	2742,						/* U+00FC0C */
+	2743,						/* U+00FC0D */
+	2744,						/* U+00FC0E */
+	2745,						/* U+00FC0F */
+	2746,						/* U+00FC10 */
+	2747,						/* U+00FC11 */
+	2748,						/* U+00FC12 */
+	2749,						/* U+00FC13 */
+	2750,						/* U+00FC14 */
+	2751,						/* U+00FC15 */
+	2752,						/* U+00FC16 */
+	2753,						/* U+00FC17 */
+	2754,						/* U+00FC18 */
+	2755,						/* U+00FC19 */
+	2756,						/* U+00FC1A */
+	2757,						/* U+00FC1B */
+	2758,						/* U+00FC1C */
+	2759,						/* U+00FC1D */
+	2760,						/* U+00FC1E */
+	2761,						/* U+00FC1F */
+	2762,						/* U+00FC20 */
+	2763,						/* U+00FC21 */
+	2764,						/* U+00FC22 */
+	2765,						/* U+00FC23 */
+	2766,						/* U+00FC24 */
+	2767,						/* U+00FC25 */
+	2768,						/* U+00FC26 */
+	2769,						/* U+00FC27 */
+	2770,						/* U+00FC28 */
+	2771,						/* U+00FC29 */
+	2772,						/* U+00FC2A */
+	2773,						/* U+00FC2B */
+	2774,						/* U+00FC2C */
+	2775,						/* U+00FC2D */
+	2776,						/* U+00FC2E */
+	2777,						/* U+00FC2F */
+	2778,						/* U+00FC30 */
+	2779,						/* U+00FC31 */
+	2780,						/* U+00FC32 */
+	2781,						/* U+00FC33 */
+	2782,						/* U+00FC34 */
+	2783,						/* U+00FC35 */
+	2784,						/* U+00FC36 */
+	2785,						/* U+00FC37 */
+	2786,						/* U+00FC38 */
+	2787,						/* U+00FC39 */
+	2788,						/* U+00FC3A */
+	2789,						/* U+00FC3B */
+	2790,						/* U+00FC3C */
+	2791,						/* U+00FC3D */
+	2792,						/* U+00FC3E */
+	2793,						/* U+00FC3F */
+	2794,						/* U+00FC40 */
+	2795,						/* U+00FC41 */
+	2796,						/* U+00FC42 */
+	2797,						/* U+00FC43 */
+	2798,						/* U+00FC44 */
+	2799,						/* U+00FC45 */
+	2800,						/* U+00FC46 */
+	2801,						/* U+00FC47 */
+	2802,						/* U+00FC48 */
+	2803,						/* U+00FC49 */
+	2804,						/* U+00FC4A */
+	2805,						/* U+00FC4B */
+	2806,						/* U+00FC4C */
+	2807,						/* U+00FC4D */
+	2808,						/* U+00FC4E */
+	2809,						/* U+00FC4F */
+	2810,						/* U+00FC50 */
+	2811,						/* U+00FC51 */
+	2812,						/* U+00FC52 */
+	2813,						/* U+00FC53 */
+	2814,						/* U+00FC54 */
+	2815,						/* U+00FC55 */
+	2816,						/* U+00FC56 */
+	2817,						/* U+00FC57 */
+	2818,						/* U+00FC58 */
+	2819,						/* U+00FC59 */
+	2820,						/* U+00FC5A */
+	2821,						/* U+00FC5B */
+	2822,						/* U+00FC5C */
+	2823,						/* U+00FC5D */
+	2824,						/* U+00FC5E */
+	2825,						/* U+00FC5F */
+	2826,						/* U+00FC60 */
+	2827,						/* U+00FC61 */
+	2828,						/* U+00FC62 */
+	2829,						/* U+00FC63 */
+	2830,						/* U+00FC64 */
+	2831,						/* U+00FC65 */
+	2733,						/* U+00FC66 */
+	2832,						/* U+00FC67 */
+	2729,						/* U+00FC68 */
+	2734,						/* U+00FC69 */
+	2833,						/* U+00FC6A */
+	2834,						/* U+00FC6B */
+	2738,						/* U+00FC6C */
+	2835,						/* U+00FC6D */
+	2739,						/* U+00FC6E */
+	2740,						/* U+00FC6F */
+	2836,						/* U+00FC70 */
+	2837,						/* U+00FC71 */
+	2744,						/* U+00FC72 */
+	2838,						/* U+00FC73 */
+	2745,						/* U+00FC74 */
+	2746,						/* U+00FC75 */
+	2839,						/* U+00FC76 */
+	2840,						/* U+00FC77 */
+	2748,						/* U+00FC78 */
+	2841,						/* U+00FC79 */
+	2749,						/* U+00FC7A */
+	2750,						/* U+00FC7B */
+	2779,						/* U+00FC7C */
+	2780,						/* U+00FC7D */
+	2783,						/* U+00FC7E */
+	2784,						/* U+00FC7F */
+	2785,						/* U+00FC80 */
+	2789,						/* U+00FC81 */
+	2790,						/* U+00FC82 */
+	2791,						/* U+00FC83 */
+	2792,						/* U+00FC84 */
+	2796,						/* U+00FC85 */
+	2797,						/* U+00FC86 */
+	2798,						/* U+00FC87 */
+	2842,						/* U+00FC88 */
+	2802,						/* U+00FC89 */
+	2843,						/* U+00FC8A */
+	2844,						/* U+00FC8B */
+	2808,						/* U+00FC8C */
+	2845,						/* U+00FC8D */
+	2809,						/* U+00FC8E */
+	2810,						/* U+00FC8F */
+	2823,						/* U+00FC90 */
+	2846,						/* U+00FC91 */
+	2847,						/* U+00FC92 */
+	2818,						/* U+00FC93 */
+	2848,						/* U+00FC94 */
+	2819,						/* U+00FC95 */
+	2820,						/* U+00FC96 */
+	2731,						/* U+00FC97 */
+	2732,						/* U+00FC98 */
+	2849,						/* U+00FC99 */
+	2733,						/* U+00FC9A */
+	2850,						/* U+00FC9B */
+	2735,						/* U+00FC9C */
+	2736,						/* U+00FC9D */
+	2737,						/* U+00FC9E */
+	2738,						/* U+00FC9F */
+	2851,						/* U+00FCA0 */
+	2741,						/* U+00FCA1 */
+	2742,						/* U+00FCA2 */
+	2743,						/* U+00FCA3 */
+	2744,						/* U+00FCA4 */
+	2852,						/* U+00FCA5 */
+	2748,						/* U+00FCA6 */
+	2751,						/* U+00FCA7 */
+	2752,						/* U+00FCA8 */
+	2753,						/* U+00FCA9 */
+	2754,						/* U+00FCAA */
+	2755,						/* U+00FCAB */
+	2757,						/* U+00FCAC */
+	2758,						/* U+00FCAD */
+	2759,						/* U+00FCAE */
+	2760,						/* U+00FCAF */
+	2761,						/* U+00FCB0 */
+	2762,						/* U+00FCB1 */
+	2853,						/* U+00FCB2 */
+	2763,						/* U+00FCB3 */
+	2764,						/* U+00FCB4 */
+	2765,						/* U+00FCB5 */
+	2766,						/* U+00FCB6 */
+	2767,						/* U+00FCB7 */
+	2768,						/* U+00FCB8 */
+	2770,						/* U+00FCB9 */
+	2771,						/* U+00FCBA */
+	2772,						/* U+00FCBB */
+	2773,						/* U+00FCBC */
+	2774,						/* U+00FCBD */
+	2775,						/* U+00FCBE */
+	2776,						/* U+00FCBF */
+	2777,						/* U+00FCC0 */
+	2778,						/* U+00FCC1 */
+	2781,						/* U+00FCC2 */
+	2782,						/* U+00FCC3 */
+	2786,						/* U+00FCC4 */
+	2787,						/* U+00FCC5 */
+	2788,						/* U+00FCC6 */
+	2789,						/* U+00FCC7 */
+	2790,						/* U+00FCC8 */
+	2793,						/* U+00FCC9 */
+	2794,						/* U+00FCCA */
+	2795,						/* U+00FCCB */
+	2796,						/* U+00FCCC */
+	2854,						/* U+00FCCD */
+	2799,						/* U+00FCCE */
+	2800,						/* U+00FCCF */
+	2801,						/* U+00FCD0 */
+	2802,						/* U+00FCD1 */
+	2805,						/* U+00FCD2 */
+	2806,						/* U+00FCD3 */
+	2807,						/* U+00FCD4 */
+	2808,						/* U+00FCD5 */
+	2855,						/* U+00FCD6 */
+	2811,						/* U+00FCD7 */
+	2812,						/* U+00FCD8 */
+	2856,						/* U+00FCD9 */
+	2815,						/* U+00FCDA */
+	2816,						/* U+00FCDB */
+	2817,						/* U+00FCDC */
+	2818,						/* U+00FCDD */
+	2857,						/* U+00FCDE */
+	2733,						/* U+00FCDF */
+	2850,						/* U+00FCE0 */
+	2738,						/* U+00FCE1 */
+	2851,						/* U+00FCE2 */
+	2744,						/* U+00FCE3 */
+	2852,						/* U+00FCE4 */
+	2748,						/* U+00FCE5 */
+	2858,						/* U+00FCE6 */
+	2761,						/* U+00FCE7 */
+	2859,						/* U+00FCE8 */
+	2860,						/* U+00FCE9 */
+	2861,						/* U+00FCEA */
+	2789,						/* U+00FCEB */
+	2790,						/* U+00FCEC */
+	2796,						/* U+00FCED */
+	2808,						/* U+00FCEE */
+	2855,						/* U+00FCEF */
+	2818,						/* U+00FCF0 */
+	2857,						/* U+00FCF1 */
+	2862,						/* U+00FCF2 */
+	2863,						/* U+00FCF3 */
+	2864,						/* U+00FCF4 */
+	2865,						/* U+00FCF5 */
+	2866,						/* U+00FCF6 */
+	2867,						/* U+00FCF7 */
+	2868,						/* U+00FCF8 */
+	2869,						/* U+00FCF9 */
+	2870,						/* U+00FCFA */
+	2871,						/* U+00FCFB */
+	2872,						/* U+00FCFC */
+	2873,						/* U+00FCFD */
+	2874,						/* U+00FCFE */
+	2875,						/* U+00FCFF */
+	2876,						/* U+00FD00 */
+	2877,						/* U+00FD01 */
+	2878,						/* U+00FD02 */
+	2879,						/* U+00FD03 */
+	2880,						/* U+00FD04 */
+	2881,						/* U+00FD05 */
+	2882,						/* U+00FD06 */
+	2883,						/* U+00FD07 */
+	2884,						/* U+00FD08 */
+	2885,						/* U+00FD09 */
+	2886,						/* U+00FD0A */
+	2887,						/* U+00FD0B */
+	2860,						/* U+00FD0C */
+	2888,						/* U+00FD0D */
+	2889,						/* U+00FD0E */
+	2890,						/* U+00FD0F */
+	2891,						/* U+00FD10 */
+	2865,						/* U+00FD11 */
+	2866,						/* U+00FD12 */
+	2867,						/* U+00FD13 */
+	2868,						/* U+00FD14 */
+	2869,						/* U+00FD15 */
+	2870,						/* U+00FD16 */
+	2871,						/* U+00FD17 */
+	2872,						/* U+00FD18 */
+	2873,						/* U+00FD19 */
+	2874,						/* U+00FD1A */
+	2875,						/* U+00FD1B */
+	2876,						/* U+00FD1C */
+	2877,						/* U+00FD1D */
+	2878,						/* U+00FD1E */
+	2879,						/* U+00FD1F */
+	2880,						/* U+00FD20 */
+	2881,						/* U+00FD21 */
+	2882,						/* U+00FD22 */
+	2883,						/* U+00FD23 */
+	2884,						/* U+00FD24 */
+	2885,						/* U+00FD25 */
+	2886,						/* U+00FD26 */
+	2887,						/* U+00FD27 */
+	2860,						/* U+00FD28 */
+	2888,						/* U+00FD29 */
+	2889,						/* U+00FD2A */
+	2890,						/* U+00FD2B */
+	2891,						/* U+00FD2C */
+	2885,						/* U+00FD2D */
+	2886,						/* U+00FD2E */
+	2887,						/* U+00FD2F */
+	2860,						/* U+00FD30 */
+	2859,						/* U+00FD31 */
+	2861,						/* U+00FD32 */
+	2769,						/* U+00FD33 */
+	2758,						/* U+00FD34 */
+	2759,						/* U+00FD35 */
+	2760,						/* U+00FD36 */
+	2885,						/* U+00FD37 */
+	2886,						/* U+00FD38 */
+	2887,						/* U+00FD39 */
+	2769,						/* U+00FD3A */
+	2770,						/* U+00FD3B */
+	2892,						/* U+00FD3C */
+	2892,						/* U+00FD3D */
+	0,							/* U+00FD3E */
+	0,							/* U+00FD3F */
+	0,							/* U+00FD40 */
+	0,							/* U+00FD41 */
+	0,							/* U+00FD42 */
+	0,							/* U+00FD43 */
+	0,							/* U+00FD44 */
+	0,							/* U+00FD45 */
+	0,							/* U+00FD46 */
+	0,							/* U+00FD47 */
+	0,							/* U+00FD48 */
+	0,							/* U+00FD49 */
+	0,							/* U+00FD4A */
+	0,							/* U+00FD4B */
+	0,							/* U+00FD4C */
+	0,							/* U+00FD4D */
+	0,							/* U+00FD4E */
+	0,							/* U+00FD4F */
+	2893,						/* U+00FD50 */
+	2894,						/* U+00FD51 */
+	2894,						/* U+00FD52 */
+	2895,						/* U+00FD53 */
+	2896,						/* U+00FD54 */
+	2897,						/* U+00FD55 */
+	2898,						/* U+00FD56 */
+	2899,						/* U+00FD57 */
+	2900,						/* U+00FD58 */
+	2900,						/* U+00FD59 */
+	2901,						/* U+00FD5A */
+	2902,						/* U+00FD5B */
+	2903,						/* U+00FD5C */
+	2904,						/* U+00FD5D */
+	2905,						/* U+00FD5E */
+	2906,						/* U+00FD5F */
+	2906,						/* U+00FD60 */
+	2907,						/* U+00FD61 */
+	2908,						/* U+00FD62 */
+	2908,						/* U+00FD63 */
+	2909,						/* U+00FD64 */
+	2909,						/* U+00FD65 */
+	2910,						/* U+00FD66 */
+	2911,						/* U+00FD67 */
+	2911,						/* U+00FD68 */
+	2912,						/* U+00FD69 */
+	2913,						/* U+00FD6A */
+	2913,						/* U+00FD6B */
+	2914,						/* U+00FD6C */
+	2914,						/* U+00FD6D */
+	2915,						/* U+00FD6E */
+	2916,						/* U+00FD6F */
+	2916,						/* U+00FD70 */
+	2917,						/* U+00FD71 */
+	2917,						/* U+00FD72 */
+	2918,						/* U+00FD73 */
+	2919,						/* U+00FD74 */
+	2920,						/* U+00FD75 */
+	2921,						/* U+00FD76 */
+	2921,						/* U+00FD77 */
+	2922,						/* U+00FD78 */
+	2923,						/* U+00FD79 */
+	2924,						/* U+00FD7A */
+	2925,						/* U+00FD7B */
+	2926,						/* U+00FD7C */
+	2926,						/* U+00FD7D */
+	2927,						/* U+00FD7E */
+	2928,						/* U+00FD7F */
+	2929,						/* U+00FD80 */
+	2930,						/* U+00FD81 */
+	2931,						/* U+00FD82 */
+	2932,						/* U+00FD83 */
+	2932,						/* U+00FD84 */
+	2933,						/* U+00FD85 */
+	2933,						/* U+00FD86 */
+	2934,						/* U+00FD87 */
+	2934,						/* U+00FD88 */
+	2935,						/* U+00FD89 */
+	2936,						/* U+00FD8A */
+	2937,						/* U+00FD8B */
+	2938,						/* U+00FD8C */
+	2939,						/* U+00FD8D */
+	2940,						/* U+00FD8E */
+	2941,						/* U+00FD8F */
+	0,							/* U+00FD90 */
+	0,							/* U+00FD91 */
+	2942,						/* U+00FD92 */
+	2943,						/* U+00FD93 */
+	2944,						/* U+00FD94 */
+	2945,						/* U+00FD95 */
+	2946,						/* U+00FD96 */
+	2947,						/* U+00FD97 */
+	2947,						/* U+00FD98 */
+	2948,						/* U+00FD99 */
+	2949,						/* U+00FD9A */
+	2950,						/* U+00FD9B */
+	2951,						/* U+00FD9C */
+	2951,						/* U+00FD9D */
+	2952,						/* U+00FD9E */
+	2953,						/* U+00FD9F */
+	2954,						/* U+00FDA0 */
+	2955,						/* U+00FDA1 */
+	2956,						/* U+00FDA2 */
+	2957,						/* U+00FDA3 */
+	2958,						/* U+00FDA4 */
+	2959,						/* U+00FDA5 */
+	2960,						/* U+00FDA6 */
+	2961,						/* U+00FDA7 */
+	2962,						/* U+00FDA8 */
+	2963,						/* U+00FDA9 */
+	2964,						/* U+00FDAA */
+	2965,						/* U+00FDAB */
+	2966,						/* U+00FDAC */
+	2967,						/* U+00FDAD */
+	2968,						/* U+00FDAE */
+	2969,						/* U+00FDAF */
+	2970,						/* U+00FDB0 */
+	2971,						/* U+00FDB1 */
+	2972,						/* U+00FDB2 */
+	2973,						/* U+00FDB3 */
+	2927,						/* U+00FDB4 */
+	2929,						/* U+00FDB5 */
+	2974,						/* U+00FDB6 */
+	2975,						/* U+00FDB7 */
+	2976,						/* U+00FDB8 */
+	2977,						/* U+00FDB9 */
+	2978,						/* U+00FDBA */
+	2979,						/* U+00FDBB */
+	2978,						/* U+00FDBC */
+	2976,						/* U+00FDBD */
+	2980,						/* U+00FDBE */
+	2981,						/* U+00FDBF */
+	2982,						/* U+00FDC0 */
+	2983,						/* U+00FDC1 */
+	2984,						/* U+00FDC2 */
+	2979,						/* U+00FDC3 */
+	2920,						/* U+00FDC4 */
+	2910,						/* U+00FDC5 */
+	2985,						/* U+00FDC6 */
+	2986,						/* U+00FDC7 */
+	0,							/* U+00FDC8 */
+	0,							/* U+00FDC9 */
+	0,							/* U+00FDCA */
+	0,							/* U+00FDCB */
+	0,							/* U+00FDCC */
+	0,							/* U+00FDCD */
+	0,							/* U+00FDCE */
+	0,							/* U+00FDCF */
+	0,							/* U+00FDD0 */
+	0,							/* U+00FDD1 */
+	0,							/* U+00FDD2 */
+	0,							/* U+00FDD3 */
+	0,							/* U+00FDD4 */
+	0,							/* U+00FDD5 */
+	0,							/* U+00FDD6 */
+	0,							/* U+00FDD7 */
+	0,							/* U+00FDD8 */
+	0,							/* U+00FDD9 */
+	0,							/* U+00FDDA */
+	0,							/* U+00FDDB */
+	0,							/* U+00FDDC */
+	0,							/* U+00FDDD */
+	0,							/* U+00FDDE */
+	0,							/* U+00FDDF */
+	0,							/* U+00FDE0 */
+	0,							/* U+00FDE1 */
+	0,							/* U+00FDE2 */
+	0,							/* U+00FDE3 */
+	0,							/* U+00FDE4 */
+	0,							/* U+00FDE5 */
+	0,							/* U+00FDE6 */
+	0,							/* U+00FDE7 */
+	0,							/* U+00FDE8 */
+	0,							/* U+00FDE9 */
+	0,							/* U+00FDEA */
+	0,							/* U+00FDEB */
+	0,							/* U+00FDEC */
+	0,							/* U+00FDED */
+	0,							/* U+00FDEE */
+	0,							/* U+00FDEF */
+	2987,						/* U+00FDF0 */
+	2988,						/* U+00FDF1 */
+	2989,						/* U+00FDF2 */
+	2990,						/* U+00FDF3 */
+	2991,						/* U+00FDF4 */
+	2992,						/* U+00FDF5 */
+	2993,						/* U+00FDF6 */
+	2994,						/* U+00FDF7 */
+	2995,						/* U+00FDF8 */
+	2996,						/* U+00FDF9 */
+	2997,						/* U+00FDFA */
+	2998,						/* U+00FDFB */
+	2999,						/* U+00FDFC */
+	0,							/* U+00FDFD */
+	0,							/* U+00FDFE */
+	0,							/* U+00FDFF */
+	0,							/* U+00FE00 */
+	0,							/* U+00FE01 */
+	0,							/* U+00FE02 */
+	0,							/* U+00FE03 */
+	0,							/* U+00FE04 */
+	0,							/* U+00FE05 */
+	0,							/* U+00FE06 */
+	0,							/* U+00FE07 */
+	0,							/* U+00FE08 */
+	0,							/* U+00FE09 */
+	0,							/* U+00FE0A */
+	0,							/* U+00FE0B */
+	0,							/* U+00FE0C */
+	0,							/* U+00FE0D */
+	0,							/* U+00FE0E */
+	0,							/* U+00FE0F */
+	3000,						/* U+00FE10 */
+	3001,						/* U+00FE11 */
+	3002,						/* U+00FE12 */
+	3003,						/* U+00FE13 */
+	3004,						/* U+00FE14 */
+	3005,						/* U+00FE15 */
+	3006,						/* U+00FE16 */
+	3007,						/* U+00FE17 */
+	3008,						/* U+00FE18 */
+	3009,						/* U+00FE19 */
+	0,							/* U+00FE1A */
+	0,							/* U+00FE1B */
+	0,							/* U+00FE1C */
+	0,							/* U+00FE1D */
+	0,							/* U+00FE1E */
+	0,							/* U+00FE1F */
+	304,						/* U+00FE20 */
+	304,						/* U+00FE21 */
+	304,						/* U+00FE22 */
+	304,						/* U+00FE23 */
+	304,						/* U+00FE24 */
+	304,						/* U+00FE25 */
+	304,						/* U+00FE26 */
+	306,						/* U+00FE27 */
+	306,						/* U+00FE28 */
+	306,						/* U+00FE29 */
+	306,						/* U+00FE2A */
+	306,						/* U+00FE2B */
+	306,						/* U+00FE2C */
+	306,						/* U+00FE2D */
+	304,						/* U+00FE2E */
+	304,						/* U+00FE2F */
+	3010,						/* U+00FE30 */
+	3011,						/* U+00FE31 */
+	3012,						/* U+00FE32 */
+	3013,						/* U+00FE33 */
+	3013,						/* U+00FE34 */
+	1131,						/* U+00FE35 */
+	1132,						/* U+00FE36 */
+	3014,						/* U+00FE37 */
+	3015,						/* U+00FE38 */
+	3016,						/* U+00FE39 */
+	3017,						/* U+00FE3A */
+	3018,						/* U+00FE3B */
+	3019,						/* U+00FE3C */
+	3020,						/* U+00FE3D */
+	3021,						/* U+00FE3E */
+	3022,						/* U+00FE3F */
+	3023,						/* U+00FE40 */
+	3024,						/* U+00FE41 */
+	3025,						/* U+00FE42 */
+	3026,						/* U+00FE43 */
+	3027,						/* U+00FE44 */
+	0,							/* U+00FE45 */
+	0,							/* U+00FE46 */
+	3028,						/* U+00FE47 */
+	3029,						/* U+00FE48 */
+	3030,						/* U+00FE49 */
+	3030,						/* U+00FE4A */
+	3030,						/* U+00FE4B */
+	3030,						/* U+00FE4C */
+	3013,						/* U+00FE4D */
+	3013,						/* U+00FE4E */
+	3013,						/* U+00FE4F */
+	3000,						/* U+00FE50 */
+	3001,						/* U+00FE51 */
+	1108,						/* U+00FE52 */
+	0,							/* U+00FE53 */
+	3004,						/* U+00FE54 */
+	3003,						/* U+00FE55 */
+	3006,						/* U+00FE56 */
+	3005,						/* U+00FE57 */
+	3011,						/* U+00FE58 */
+	1131,						/* U+00FE59 */
+	1132,						/* U+00FE5A */
+	3014,						/* U+00FE5B */
+	3015,						/* U+00FE5C */
+	3016,						/* U+00FE5D */
+	3017,						/* U+00FE5E */
+	3031,						/* U+00FE5F */
+	3032,						/* U+00FE60 */
+	3033,						/* U+00FE61 */
+	1128,						/* U+00FE62 */
+	3034,						/* U+00FE63 */
+	3035,						/* U+00FE64 */
+	3036,						/* U+00FE65 */
+	1130,						/* U+00FE66 */
+	0,							/* U+00FE67 */
+	3037,						/* U+00FE68 */
+	3038,						/* U+00FE69 */
+	3039,						/* U+00FE6A */
+	3040,						/* U+00FE6B */
+	0,							/* U+00FE6C */
+	0,							/* U+00FE6D */
+	0,							/* U+00FE6E */
+	0,							/* U+00FE6F */
+	3041,						/* U+00FE70 */
+	3042,						/* U+00FE71 */
+	3043,						/* U+00FE72 */
+	0,							/* U+00FE73 */
+	3044,						/* U+00FE74 */
+	0,							/* U+00FE75 */
+	3045,						/* U+00FE76 */
+	3046,						/* U+00FE77 */
+	3047,						/* U+00FE78 */
+	3048,						/* U+00FE79 */
+	3049,						/* U+00FE7A */
+	3050,						/* U+00FE7B */
+	3051,						/* U+00FE7C */
+	3052,						/* U+00FE7D */
+	3053,						/* U+00FE7E */
+	3054,						/* U+00FE7F */
+	3055,						/* U+00FE80 */
+	3056,						/* U+00FE81 */
+	3056,						/* U+00FE82 */
+	3057,						/* U+00FE83 */
+	3057,						/* U+00FE84 */
+	3058,						/* U+00FE85 */
+	3058,						/* U+00FE86 */
+	3059,						/* U+00FE87 */
+	3059,						/* U+00FE88 */
+	3060,						/* U+00FE89 */
+	3060,						/* U+00FE8A */
+	3060,						/* U+00FE8B */
+	3060,						/* U+00FE8C */
+	3061,						/* U+00FE8D */
+	3061,						/* U+00FE8E */
+	3062,						/* U+00FE8F */
+	3062,						/* U+00FE90 */
+	3062,						/* U+00FE91 */
+	3062,						/* U+00FE92 */
+	3063,						/* U+00FE93 */
+	3063,						/* U+00FE94 */
+	3064,						/* U+00FE95 */
+	3064,						/* U+00FE96 */
+	3064,						/* U+00FE97 */
+	3064,						/* U+00FE98 */
+	3065,						/* U+00FE99 */
+	3065,						/* U+00FE9A */
+	3065,						/* U+00FE9B */
+	3065,						/* U+00FE9C */
+	3066,						/* U+00FE9D */
+	3066,						/* U+00FE9E */
+	3066,						/* U+00FE9F */
+	3066,						/* U+00FEA0 */
+	3067,						/* U+00FEA1 */
+	3067,						/* U+00FEA2 */
+	3067,						/* U+00FEA3 */
+	3067,						/* U+00FEA4 */
+	3068,						/* U+00FEA5 */
+	3068,						/* U+00FEA6 */
+	3068,						/* U+00FEA7 */
+	3068,						/* U+00FEA8 */
+	3069,						/* U+00FEA9 */
+	3069,						/* U+00FEAA */
+	3070,						/* U+00FEAB */
+	3070,						/* U+00FEAC */
+	3071,						/* U+00FEAD */
+	3071,						/* U+00FEAE */
+	3072,						/* U+00FEAF */
+	3072,						/* U+00FEB0 */
+	3073,						/* U+00FEB1 */
+	3073,						/* U+00FEB2 */
+	3073,						/* U+00FEB3 */
+	3073,						/* U+00FEB4 */
+	3074,						/* U+00FEB5 */
+	3074,						/* U+00FEB6 */
+	3074,						/* U+00FEB7 */
+	3074,						/* U+00FEB8 */
+	3075,						/* U+00FEB9 */
+	3075,						/* U+00FEBA */
+	3075,						/* U+00FEBB */
+	3075,						/* U+00FEBC */
+	3076,						/* U+00FEBD */
+	3076,						/* U+00FEBE */
+	3076,						/* U+00FEBF */
+	3076,						/* U+00FEC0 */
+	3077,						/* U+00FEC1 */
+	3077,						/* U+00FEC2 */
+	3077,						/* U+00FEC3 */
+	3077,						/* U+00FEC4 */
+	3078,						/* U+00FEC5 */
+	3078,						/* U+00FEC6 */
+	3078,						/* U+00FEC7 */
+	3078,						/* U+00FEC8 */
+	3079,						/* U+00FEC9 */
+	3079,						/* U+00FECA */
+	3079,						/* U+00FECB */
+	3079,						/* U+00FECC */
+	3080,						/* U+00FECD */
+	3080,						/* U+00FECE */
+	3080,						/* U+00FECF */
+	3080,						/* U+00FED0 */
+	3081,						/* U+00FED1 */
+	3081,						/* U+00FED2 */
+	3081,						/* U+00FED3 */
+	3081,						/* U+00FED4 */
+	3082,						/* U+00FED5 */
+	3082,						/* U+00FED6 */
+	3082,						/* U+00FED7 */
+	3082,						/* U+00FED8 */
+	3083,						/* U+00FED9 */
+	3083,						/* U+00FEDA */
+	3083,						/* U+00FEDB */
+	3083,						/* U+00FEDC */
+	3084,						/* U+00FEDD */
+	3084,						/* U+00FEDE */
+	3084,						/* U+00FEDF */
+	3084,						/* U+00FEE0 */
+	3085,						/* U+00FEE1 */
+	3085,						/* U+00FEE2 */
+	3085,						/* U+00FEE3 */
+	3085,						/* U+00FEE4 */
+	3086,						/* U+00FEE5 */
+	3086,						/* U+00FEE6 */
+	3086,						/* U+00FEE7 */
+	3086,						/* U+00FEE8 */
+	3087,						/* U+00FEE9 */
+	3087,						/* U+00FEEA */
+	3087,						/* U+00FEEB */
+	3087,						/* U+00FEEC */
+	3088,						/* U+00FEED */
+	3088,						/* U+00FEEE */
+	2721,						/* U+00FEEF */
+	2721,						/* U+00FEF0 */
+	3089,						/* U+00FEF1 */
+	3089,						/* U+00FEF2 */
+	3089,						/* U+00FEF3 */
+	3089,						/* U+00FEF4 */
+	3090,						/* U+00FEF5 */
+	3090,						/* U+00FEF6 */
+	3091,						/* U+00FEF7 */
+	3091,						/* U+00FEF8 */
+	3092,						/* U+00FEF9 */
+	3092,						/* U+00FEFA */
+	3093,						/* U+00FEFB */
+	3093,						/* U+00FEFC */
+	0,							/* U+00FEFD */
+	0,							/* U+00FEFE */
+	0,							/* U+00FEFF */
+	0,							/* U+00FF00 */
+	3005,						/* U+00FF01 */
+	3094,						/* U+00FF02 */
+	3031,						/* U+00FF03 */
+	3038,						/* U+00FF04 */
+	3039,						/* U+00FF05 */
+	3032,						/* U+00FF06 */
+	3095,						/* U+00FF07 */
+	1131,						/* U+00FF08 */
+	1132,						/* U+00FF09 */
+	3033,						/* U+00FF0A */
+	1128,						/* U+00FF0B */
+	3000,						/* U+00FF0C */
+	3034,						/* U+00FF0D */
+	1108,						/* U+00FF0E */
+	3096,						/* U+00FF0F */
+	1121,						/* U+00FF10 */
+	10,							/* U+00FF11 */
+	5,							/* U+00FF12 */
+	6,							/* U+00FF13 */
+	1122,						/* U+00FF14 */
+	1123,						/* U+00FF15 */
+	1124,						/* U+00FF16 */
+	1125,						/* U+00FF17 */
+	1126,						/* U+00FF18 */
+	1127,						/* U+00FF19 */
+	3003,						/* U+00FF1A */
+	3004,						/* U+00FF1B */
+	3035,						/* U+00FF1C */
+	1130,						/* U+00FF1D */
+	3036,						/* U+00FF1E */
+	3006,						/* U+00FF1F */
+	3040,						/* U+00FF20 */
+	540,						/* U+00FF21 */
+	542,						/* U+00FF22 */
+	1137,						/* U+00FF23 */
+	543,						/* U+00FF24 */
+	544,						/* U+00FF25 */
+	1153,						/* U+00FF26 */
+	546,						/* U+00FF27 */
+	547,						/* U+00FF28 */
+	548,						/* U+00FF29 */
+	549,						/* U+00FF2A */
+	550,						/* U+00FF2B */
+	551,						/* U+00FF2C */
+	552,						/* U+00FF2D */
+	553,						/* U+00FF2E */
+	554,						/* U+00FF2F */
+	556,						/* U+00FF30 */
+	1145,						/* U+00FF31 */
+	557,						/* U+00FF32 */
+	1326,						/* U+00FF33 */
+	558,						/* U+00FF34 */
+	559,						/* U+00FF35 */
+	1181,						/* U+00FF36 */
+	560,						/* U+00FF37 */
+	1186,						/* U+00FF38 */
+	1327,						/* U+00FF39 */
+	1149,						/* U+00FF3A */
+	3028,						/* U+00FF3B */
+	3037,						/* U+00FF3C */
+	3029,						/* U+00FF3D */
+	3097,						/* U+00FF3E */
+	3013,						/* U+00FF3F */
+	3098,						/* U+00FF40 */
+	3,							/* U+00FF41 */
+	564,						/* U+00FF42 */
+	590,						/* U+00FF43 */
+	565,						/* U+00FF44 */
+	566,						/* U+00FF45 */
+	593,						/* U+00FF46 */
+	570,						/* U+00FF47 */
+	285,						/* U+00FF48 */
+	587,						/* U+00FF49 */
+	287,						/* U+00FF4A */
+	571,						/* U+00FF4B */
+	301,						/* U+00FF4C */
+	572,						/* U+00FF4D */
+	1133,						/* U+00FF4E */
+	11,							/* U+00FF4F */
+	577,						/* U+00FF50 */
+	1328,						/* U+00FF51 */
+	288,						/* U+00FF52 */
+	181,						/* U+00FF53 */
+	578,						/* U+00FF54 */
+	579,						/* U+00FF55 */
+	582,						/* U+00FF56 */
+	292,						/* U+00FF57 */
+	302,						/* U+00FF58 */
+	293,						/* U+00FF59 */
+	620,						/* U+00FF5A */
+	3014,						/* U+00FF5B */
+	3099,						/* U+00FF5C */
+	3015,						/* U+00FF5D */
+	3100,						/* U+00FF5E */
+	3101,						/* U+00FF5F */
+	3102,						/* U+00FF60 */
+	3002,						/* U+00FF61 */
+	3024,						/* U+00FF62 */
+	3025,						/* U+00FF63 */
+	3001,						/* U+00FF64 */
+	3103,						/* U+00FF65 */
+	1934,						/* U+00FF66 */
+	3104,						/* U+00FF67 */
+	3105,						/* U+00FF68 */
+	3106,						/* U+00FF69 */
+	3107,						/* U+00FF6A */
+	3108,						/* U+00FF6B */
+	3109,						/* U+00FF6C */
+	3110,						/* U+00FF6D */
+	3111,						/* U+00FF6E */
+	3112,						/* U+00FF6F */
+	3113,						/* U+00FF70 */
+	1888,						/* U+00FF71 */
+	1889,						/* U+00FF72 */
+	1890,						/* U+00FF73 */
+	1891,						/* U+00FF74 */
+	1892,						/* U+00FF75 */
+	1893,						/* U+00FF76 */
+	1894,						/* U+00FF77 */
+	1895,						/* U+00FF78 */
+	1896,						/* U+00FF79 */
+	1897,						/* U+00FF7A */
+	1898,						/* U+00FF7B */
+	1899,						/* U+00FF7C */
+	1900,						/* U+00FF7D */
+	1901,						/* U+00FF7E */
+	1902,						/* U+00FF7F */
+	1903,						/* U+00FF80 */
+	1904,						/* U+00FF81 */
+	1905,						/* U+00FF82 */
+	1906,						/* U+00FF83 */
+	1907,						/* U+00FF84 */
+	1908,						/* U+00FF85 */
+	1909,						/* U+00FF86 */
+	1910,						/* U+00FF87 */
+	1911,						/* U+00FF88 */
+	1912,						/* U+00FF89 */
+	1913,						/* U+00FF8A */
+	1914,						/* U+00FF8B */
+	1915,						/* U+00FF8C */
+	1916,						/* U+00FF8D */
+	1917,						/* U+00FF8E */
+	1918,						/* U+00FF8F */
+	1919,						/* U+00FF90 */
+	1920,						/* U+00FF91 */
+	1921,						/* U+00FF92 */
+	1922,						/* U+00FF93 */
+	1923,						/* U+00FF94 */
+	1924,						/* U+00FF95 */
+	1925,						/* U+00FF96 */
+	1926,						/* U+00FF97 */
+	1927,						/* U+00FF98 */
+	1928,						/* U+00FF99 */
+	1929,						/* U+00FF9A */
+	1930,						/* U+00FF9B */
+	1931,						/* U+00FF9C */
+	3114,						/* U+00FF9D */
+	3115,						/* U+00FF9E */
+	3116,						/* U+00FF9F */
+	3117,						/* U+00FFA0 */
+	3118,						/* U+00FFA1 */
+	3119,						/* U+00FFA2 */
+	3120,						/* U+00FFA3 */
+	3121,						/* U+00FFA4 */
+	3122,						/* U+00FFA5 */
+	3123,						/* U+00FFA6 */
+	3124,						/* U+00FFA7 */
+	3125,						/* U+00FFA8 */
+	3126,						/* U+00FFA9 */
+	3127,						/* U+00FFAA */
+	3128,						/* U+00FFAB */
+	3129,						/* U+00FFAC */
+	3130,						/* U+00FFAD */
+	3131,						/* U+00FFAE */
+	3132,						/* U+00FFAF */
+	3133,						/* U+00FFB0 */
+	3134,						/* U+00FFB1 */
+	3135,						/* U+00FFB2 */
+	3136,						/* U+00FFB3 */
+	3137,						/* U+00FFB4 */
+	3138,						/* U+00FFB5 */
+	3139,						/* U+00FFB6 */
+	3140,						/* U+00FFB7 */
+	3141,						/* U+00FFB8 */
+	3142,						/* U+00FFB9 */
+	3143,						/* U+00FFBA */
+	3144,						/* U+00FFBB */
+	3145,						/* U+00FFBC */
+	3146,						/* U+00FFBD */
+	3147,						/* U+00FFBE */
+	0,							/* U+00FFBF */
+	0,							/* U+00FFC0 */
+	0,							/* U+00FFC1 */
+	3148,						/* U+00FFC2 */
+	3149,						/* U+00FFC3 */
+	3150,						/* U+00FFC4 */
+	3151,						/* U+00FFC5 */
+	3152,						/* U+00FFC6 */
+	3153,						/* U+00FFC7 */
+	0,							/* U+00FFC8 */
+	0,							/* U+00FFC9 */
+	3154,						/* U+00FFCA */
+	3155,						/* U+00FFCB */
+	3156,						/* U+00FFCC */
+	3157,						/* U+00FFCD */
+	3158,						/* U+00FFCE */
+	3159,						/* U+00FFCF */
+	0,							/* U+00FFD0 */
+	0,							/* U+00FFD1 */
+	3160,						/* U+00FFD2 */
+	3161,						/* U+00FFD3 */
+	3162,						/* U+00FFD4 */
+	3163,						/* U+00FFD5 */
+	3164,						/* U+00FFD6 */
+	3165,						/* U+00FFD7 */
+	0,							/* U+00FFD8 */
+	0,							/* U+00FFD9 */
+	3166,						/* U+00FFDA */
+	3167,						/* U+00FFDB */
+	3168,						/* U+00FFDC */
+	0,							/* U+00FFDD */
+	0,							/* U+00FFDE */
+	0,							/* U+00FFDF */
+	3169,						/* U+00FFE0 */
+	3170,						/* U+00FFE1 */
+	3171,						/* U+00FFE2 */
+	3172,						/* U+00FFE3 */
+	3173,						/* U+00FFE4 */
+	3174,						/* U+00FFE5 */
+	3175,						/* U+00FFE6 */
+	0,							/* U+00FFE7 */
+	3176,						/* U+00FFE8 */
+	3177,						/* U+00FFE9 */
+	3178,						/* U+00FFEA */
+	3179,						/* U+00FFEB */
+	3180,						/* U+00FFEC */
+	3181,						/* U+00FFED */
+	3182,						/* U+00FFEE */
+	0,							/* U+00FFEF */
+	0,							/* U+00FFF0 */
+	0,							/* U+00FFF1 */
+	0,							/* U+00FFF2 */
+	0,							/* U+00FFF3 */
+	0,							/* U+00FFF4 */
+	0,							/* U+00FFF5 */
+	0,							/* U+00FFF6 */
+	0,							/* U+00FFF7 */
+	0,							/* U+00FFF8 */
+	0,							/* U+00FFF9 */
+	0,							/* U+00FFFA */
+	0,							/* U+00FFFB */
+	0,							/* U+00FFFC */
+	0,							/* U+00FFFD */
+	0,							/* U+00FFFE */
+	0,							/* U+00FFFF */
+	0,							/* U+010000 */
+	0,							/* U+010001 */
+	0,							/* U+010002 */
+	0,							/* U+010003 */
+	0,							/* U+010004 */
+	0,							/* U+010005 */
+	0,							/* U+010006 */
+	0,							/* U+010007 */
+	0,							/* U+010008 */
+	0,							/* U+010009 */
+	0,							/* U+01000A */
+	0,							/* U+01000B */
+	0,							/* U+01000C */
+	0,							/* U+01000D */
+	0,							/* U+01000E */
+	0,							/* U+01000F */
+	0,							/* U+010010 */
+	0,							/* U+010011 */
+	0,							/* U+010012 */
+	0,							/* U+010013 */
+	0,							/* U+010014 */
+	0,							/* U+010015 */
+	0,							/* U+010016 */
+	0,							/* U+010017 */
+	0,							/* U+010018 */
+	0,							/* U+010019 */
+	0,							/* U+01001A */
+	0,							/* U+01001B */
+	0,							/* U+01001C */
+	0,							/* U+01001D */
+	0,							/* U+01001E */
+	0,							/* U+01001F */
+	0,							/* U+010020 */
+	0,							/* U+010021 */
+	0,							/* U+010022 */
+	0,							/* U+010023 */
+	0,							/* U+010024 */
+	0,							/* U+010025 */
+	0,							/* U+010026 */
+	0,							/* U+010027 */
+	0,							/* U+010028 */
+	0,							/* U+010029 */
+	0,							/* U+01002A */
+	0,							/* U+01002B */
+	0,							/* U+01002C */
+	0,							/* U+01002D */
+	0,							/* U+01002E */
+	0,							/* U+01002F */
+	0,							/* U+010030 */
+	0,							/* U+010031 */
+	0,							/* U+010032 */
+	0,							/* U+010033 */
+	0,							/* U+010034 */
+	0,							/* U+010035 */
+	0,							/* U+010036 */
+	0,							/* U+010037 */
+	0,							/* U+010038 */
+	0,							/* U+010039 */
+	0,							/* U+01003A */
+	0,							/* U+01003B */
+	0,							/* U+01003C */
+	0,							/* U+01003D */
+	0,							/* U+01003E */
+	0,							/* U+01003F */
+	0,							/* U+010040 */
+	0,							/* U+010041 */
+	0,							/* U+010042 */
+	0,							/* U+010043 */
+	0,							/* U+010044 */
+	0,							/* U+010045 */
+	0,							/* U+010046 */
+	0,							/* U+010047 */
+	0,							/* U+010048 */
+	0,							/* U+010049 */
+	0,							/* U+01004A */
+	0,							/* U+01004B */
+	0,							/* U+01004C */
+	0,							/* U+01004D */
+	0,							/* U+01004E */
+	0,							/* U+01004F */
+	0,							/* U+010050 */
+	0,							/* U+010051 */
+	0,							/* U+010052 */
+	0,							/* U+010053 */
+	0,							/* U+010054 */
+	0,							/* U+010055 */
+	0,							/* U+010056 */
+	0,							/* U+010057 */
+	0,							/* U+010058 */
+	0,							/* U+010059 */
+	0,							/* U+01005A */
+	0,							/* U+01005B */
+	0,							/* U+01005C */
+	0,							/* U+01005D */
+	0,							/* U+01005E */
+	0,							/* U+01005F */
+	0,							/* U+010060 */
+	0,							/* U+010061 */
+	0,							/* U+010062 */
+	0,							/* U+010063 */
+	0,							/* U+010064 */
+	0,							/* U+010065 */
+	0,							/* U+010066 */
+	0,							/* U+010067 */
+	0,							/* U+010068 */
+	0,							/* U+010069 */
+	0,							/* U+01006A */
+	0,							/* U+01006B */
+	0,							/* U+01006C */
+	0,							/* U+01006D */
+	0,							/* U+01006E */
+	0,							/* U+01006F */
+	0,							/* U+010070 */
+	0,							/* U+010071 */
+	0,							/* U+010072 */
+	0,							/* U+010073 */
+	0,							/* U+010074 */
+	0,							/* U+010075 */
+	0,							/* U+010076 */
+	0,							/* U+010077 */
+	0,							/* U+010078 */
+	0,							/* U+010079 */
+	0,							/* U+01007A */
+	0,							/* U+01007B */
+	0,							/* U+01007C */
+	0,							/* U+01007D */
+	0,							/* U+01007E */
+	0,							/* U+01007F */
+	0,							/* U+010080 */
+	0,							/* U+010081 */
+	0,							/* U+010082 */
+	0,							/* U+010083 */
+	0,							/* U+010084 */
+	0,							/* U+010085 */
+	0,							/* U+010086 */
+	0,							/* U+010087 */
+	0,							/* U+010088 */
+	0,							/* U+010089 */
+	0,							/* U+01008A */
+	0,							/* U+01008B */
+	0,							/* U+01008C */
+	0,							/* U+01008D */
+	0,							/* U+01008E */
+	0,							/* U+01008F */
+	0,							/* U+010090 */
+	0,							/* U+010091 */
+	0,							/* U+010092 */
+	0,							/* U+010093 */
+	0,							/* U+010094 */
+	0,							/* U+010095 */
+	0,							/* U+010096 */
+	0,							/* U+010097 */
+	0,							/* U+010098 */
+	0,							/* U+010099 */
+	0,							/* U+01009A */
+	0,							/* U+01009B */
+	0,							/* U+01009C */
+	0,							/* U+01009D */
+	0,							/* U+01009E */
+	0,							/* U+01009F */
+	0,							/* U+0100A0 */
+	0,							/* U+0100A1 */
+	0,							/* U+0100A2 */
+	0,							/* U+0100A3 */
+	0,							/* U+0100A4 */
+	0,							/* U+0100A5 */
+	0,							/* U+0100A6 */
+	0,							/* U+0100A7 */
+	0,							/* U+0100A8 */
+	0,							/* U+0100A9 */
+	0,							/* U+0100AA */
+	0,							/* U+0100AB */
+	0,							/* U+0100AC */
+	0,							/* U+0100AD */
+	0,							/* U+0100AE */
+	0,							/* U+0100AF */
+	0,							/* U+0100B0 */
+	0,							/* U+0100B1 */
+	0,							/* U+0100B2 */
+	0,							/* U+0100B3 */
+	0,							/* U+0100B4 */
+	0,							/* U+0100B5 */
+	0,							/* U+0100B6 */
+	0,							/* U+0100B7 */
+	0,							/* U+0100B8 */
+	0,							/* U+0100B9 */
+	0,							/* U+0100BA */
+	0,							/* U+0100BB */
+	0,							/* U+0100BC */
+	0,							/* U+0100BD */
+	0,							/* U+0100BE */
+	0,							/* U+0100BF */
+	0,							/* U+0100C0 */
+	0,							/* U+0100C1 */
+	0,							/* U+0100C2 */
+	0,							/* U+0100C3 */
+	0,							/* U+0100C4 */
+	0,							/* U+0100C5 */
+	0,							/* U+0100C6 */
+	0,							/* U+0100C7 */
+	0,							/* U+0100C8 */
+	0,							/* U+0100C9 */
+	0,							/* U+0100CA */
+	0,							/* U+0100CB */
+	0,							/* U+0100CC */
+	0,							/* U+0100CD */
+	0,							/* U+0100CE */
+	0,							/* U+0100CF */
+	0,							/* U+0100D0 */
+	0,							/* U+0100D1 */
+	0,							/* U+0100D2 */
+	0,							/* U+0100D3 */
+	0,							/* U+0100D4 */
+	0,							/* U+0100D5 */
+	0,							/* U+0100D6 */
+	0,							/* U+0100D7 */
+	0,							/* U+0100D8 */
+	0,							/* U+0100D9 */
+	0,							/* U+0100DA */
+	0,							/* U+0100DB */
+	0,							/* U+0100DC */
+	0,							/* U+0100DD */
+	0,							/* U+0100DE */
+	0,							/* U+0100DF */
+	0,							/* U+0100E0 */
+	0,							/* U+0100E1 */
+	0,							/* U+0100E2 */
+	0,							/* U+0100E3 */
+	0,							/* U+0100E4 */
+	0,							/* U+0100E5 */
+	0,							/* U+0100E6 */
+	0,							/* U+0100E7 */
+	0,							/* U+0100E8 */
+	0,							/* U+0100E9 */
+	0,							/* U+0100EA */
+	0,							/* U+0100EB */
+	0,							/* U+0100EC */
+	0,							/* U+0100ED */
+	0,							/* U+0100EE */
+	0,							/* U+0100EF */
+	0,							/* U+0100F0 */
+	0,							/* U+0100F1 */
+	0,							/* U+0100F2 */
+	0,							/* U+0100F3 */
+	0,							/* U+0100F4 */
+	0,							/* U+0100F5 */
+	0,							/* U+0100F6 */
+	0,							/* U+0100F7 */
+	0,							/* U+0100F8 */
+	0,							/* U+0100F9 */
+	0,							/* U+0100FA */
+	0,							/* U+0100FB */
+	0,							/* U+0100FC */
+	0,							/* U+0100FD */
+	0,							/* U+0100FE */
+	0,							/* U+0100FF */
+	0,							/* U+010100 */
+	0,							/* U+010101 */
+	0,							/* U+010102 */
+	0,							/* U+010103 */
+	0,							/* U+010104 */
+	0,							/* U+010105 */
+	0,							/* U+010106 */
+	0,							/* U+010107 */
+	0,							/* U+010108 */
+	0,							/* U+010109 */
+	0,							/* U+01010A */
+	0,							/* U+01010B */
+	0,							/* U+01010C */
+	0,							/* U+01010D */
+	0,							/* U+01010E */
+	0,							/* U+01010F */
+	0,							/* U+010110 */
+	0,							/* U+010111 */
+	0,							/* U+010112 */
+	0,							/* U+010113 */
+	0,							/* U+010114 */
+	0,							/* U+010115 */
+	0,							/* U+010116 */
+	0,							/* U+010117 */
+	0,							/* U+010118 */
+	0,							/* U+010119 */
+	0,							/* U+01011A */
+	0,							/* U+01011B */
+	0,							/* U+01011C */
+	0,							/* U+01011D */
+	0,							/* U+01011E */
+	0,							/* U+01011F */
+	0,							/* U+010120 */
+	0,							/* U+010121 */
+	0,							/* U+010122 */
+	0,							/* U+010123 */
+	0,							/* U+010124 */
+	0,							/* U+010125 */
+	0,							/* U+010126 */
+	0,							/* U+010127 */
+	0,							/* U+010128 */
+	0,							/* U+010129 */
+	0,							/* U+01012A */
+	0,							/* U+01012B */
+	0,							/* U+01012C */
+	0,							/* U+01012D */
+	0,							/* U+01012E */
+	0,							/* U+01012F */
+	0,							/* U+010130 */
+	0,							/* U+010131 */
+	0,							/* U+010132 */
+	0,							/* U+010133 */
+	0,							/* U+010134 */
+	0,							/* U+010135 */
+	0,							/* U+010136 */
+	0,							/* U+010137 */
+	0,							/* U+010138 */
+	0,							/* U+010139 */
+	0,							/* U+01013A */
+	0,							/* U+01013B */
+	0,							/* U+01013C */
+	0,							/* U+01013D */
+	0,							/* U+01013E */
+	0,							/* U+01013F */
+	0,							/* U+010140 */
+	0,							/* U+010141 */
+	0,							/* U+010142 */
+	0,							/* U+010143 */
+	0,							/* U+010144 */
+	0,							/* U+010145 */
+	0,							/* U+010146 */
+	0,							/* U+010147 */
+	0,							/* U+010148 */
+	0,							/* U+010149 */
+	0,							/* U+01014A */
+	0,							/* U+01014B */
+	0,							/* U+01014C */
+	0,							/* U+01014D */
+	0,							/* U+01014E */
+	0,							/* U+01014F */
+	0,							/* U+010150 */
+	0,							/* U+010151 */
+	0,							/* U+010152 */
+	0,							/* U+010153 */
+	0,							/* U+010154 */
+	0,							/* U+010155 */
+	0,							/* U+010156 */
+	0,							/* U+010157 */
+	0,							/* U+010158 */
+	0,							/* U+010159 */
+	0,							/* U+01015A */
+	0,							/* U+01015B */
+	0,							/* U+01015C */
+	0,							/* U+01015D */
+	0,							/* U+01015E */
+	0,							/* U+01015F */
+	0,							/* U+010160 */
+	0,							/* U+010161 */
+	0,							/* U+010162 */
+	0,							/* U+010163 */
+	0,							/* U+010164 */
+	0,							/* U+010165 */
+	0,							/* U+010166 */
+	0,							/* U+010167 */
+	0,							/* U+010168 */
+	0,							/* U+010169 */
+	0,							/* U+01016A */
+	0,							/* U+01016B */
+	0,							/* U+01016C */
+	0,							/* U+01016D */
+	0,							/* U+01016E */
+	0,							/* U+01016F */
+	0,							/* U+010170 */
+	0,							/* U+010171 */
+	0,							/* U+010172 */
+	0,							/* U+010173 */
+	0,							/* U+010174 */
+	0,							/* U+010175 */
+	0,							/* U+010176 */
+	0,							/* U+010177 */
+	0,							/* U+010178 */
+	0,							/* U+010179 */
+	0,							/* U+01017A */
+	0,							/* U+01017B */
+	0,							/* U+01017C */
+	0,							/* U+01017D */
+	0,							/* U+01017E */
+	0,							/* U+01017F */
+	0,							/* U+010180 */
+	0,							/* U+010181 */
+	0,							/* U+010182 */
+	0,							/* U+010183 */
+	0,							/* U+010184 */
+	0,							/* U+010185 */
+	0,							/* U+010186 */
+	0,							/* U+010187 */
+	0,							/* U+010188 */
+	0,							/* U+010189 */
+	0,							/* U+01018A */
+	0,							/* U+01018B */
+	0,							/* U+01018C */
+	0,							/* U+01018D */
+	0,							/* U+01018E */
+	0,							/* U+01018F */
+	0,							/* U+010190 */
+	0,							/* U+010191 */
+	0,							/* U+010192 */
+	0,							/* U+010193 */
+	0,							/* U+010194 */
+	0,							/* U+010195 */
+	0,							/* U+010196 */
+	0,							/* U+010197 */
+	0,							/* U+010198 */
+	0,							/* U+010199 */
+	0,							/* U+01019A */
+	0,							/* U+01019B */
+	0,							/* U+01019C */
+	0,							/* U+01019D */
+	0,							/* U+01019E */
+	0,							/* U+01019F */
+	0,							/* U+0101A0 */
+	0,							/* U+0101A1 */
+	0,							/* U+0101A2 */
+	0,							/* U+0101A3 */
+	0,							/* U+0101A4 */
+	0,							/* U+0101A5 */
+	0,							/* U+0101A6 */
+	0,							/* U+0101A7 */
+	0,							/* U+0101A8 */
+	0,							/* U+0101A9 */
+	0,							/* U+0101AA */
+	0,							/* U+0101AB */
+	0,							/* U+0101AC */
+	0,							/* U+0101AD */
+	0,							/* U+0101AE */
+	0,							/* U+0101AF */
+	0,							/* U+0101B0 */
+	0,							/* U+0101B1 */
+	0,							/* U+0101B2 */
+	0,							/* U+0101B3 */
+	0,							/* U+0101B4 */
+	0,							/* U+0101B5 */
+	0,							/* U+0101B6 */
+	0,							/* U+0101B7 */
+	0,							/* U+0101B8 */
+	0,							/* U+0101B9 */
+	0,							/* U+0101BA */
+	0,							/* U+0101BB */
+	0,							/* U+0101BC */
+	0,							/* U+0101BD */
+	0,							/* U+0101BE */
+	0,							/* U+0101BF */
+	0,							/* U+0101C0 */
+	0,							/* U+0101C1 */
+	0,							/* U+0101C2 */
+	0,							/* U+0101C3 */
+	0,							/* U+0101C4 */
+	0,							/* U+0101C5 */
+	0,							/* U+0101C6 */
+	0,							/* U+0101C7 */
+	0,							/* U+0101C8 */
+	0,							/* U+0101C9 */
+	0,							/* U+0101CA */
+	0,							/* U+0101CB */
+	0,							/* U+0101CC */
+	0,							/* U+0101CD */
+	0,							/* U+0101CE */
+	0,							/* U+0101CF */
+	0,							/* U+0101D0 */
+	0,							/* U+0101D1 */
+	0,							/* U+0101D2 */
+	0,							/* U+0101D3 */
+	0,							/* U+0101D4 */
+	0,							/* U+0101D5 */
+	0,							/* U+0101D6 */
+	0,							/* U+0101D7 */
+	0,							/* U+0101D8 */
+	0,							/* U+0101D9 */
+	0,							/* U+0101DA */
+	0,							/* U+0101DB */
+	0,							/* U+0101DC */
+	0,							/* U+0101DD */
+	0,							/* U+0101DE */
+	0,							/* U+0101DF */
+	0,							/* U+0101E0 */
+	0,							/* U+0101E1 */
+	0,							/* U+0101E2 */
+	0,							/* U+0101E3 */
+	0,							/* U+0101E4 */
+	0,							/* U+0101E5 */
+	0,							/* U+0101E6 */
+	0,							/* U+0101E7 */
+	0,							/* U+0101E8 */
+	0,							/* U+0101E9 */
+	0,							/* U+0101EA */
+	0,							/* U+0101EB */
+	0,							/* U+0101EC */
+	0,							/* U+0101ED */
+	0,							/* U+0101EE */
+	0,							/* U+0101EF */
+	0,							/* U+0101F0 */
+	0,							/* U+0101F1 */
+	0,							/* U+0101F2 */
+	0,							/* U+0101F3 */
+	0,							/* U+0101F4 */
+	0,							/* U+0101F5 */
+	0,							/* U+0101F6 */
+	0,							/* U+0101F7 */
+	0,							/* U+0101F8 */
+	0,							/* U+0101F9 */
+	0,							/* U+0101FA */
+	0,							/* U+0101FB */
+	0,							/* U+0101FC */
+	306,						/* U+0101FD */
+	0,							/* U+0101FE */
+	0,							/* U+0101FF */
+	0,							/* U+010200 */
+	0,							/* U+010201 */
+	0,							/* U+010202 */
+	0,							/* U+010203 */
+	0,							/* U+010204 */
+	0,							/* U+010205 */
+	0,							/* U+010206 */
+	0,							/* U+010207 */
+	0,							/* U+010208 */
+	0,							/* U+010209 */
+	0,							/* U+01020A */
+	0,							/* U+01020B */
+	0,							/* U+01020C */
+	0,							/* U+01020D */
+	0,							/* U+01020E */
+	0,							/* U+01020F */
+	0,							/* U+010210 */
+	0,							/* U+010211 */
+	0,							/* U+010212 */
+	0,							/* U+010213 */
+	0,							/* U+010214 */
+	0,							/* U+010215 */
+	0,							/* U+010216 */
+	0,							/* U+010217 */
+	0,							/* U+010218 */
+	0,							/* U+010219 */
+	0,							/* U+01021A */
+	0,							/* U+01021B */
+	0,							/* U+01021C */
+	0,							/* U+01021D */
+	0,							/* U+01021E */
+	0,							/* U+01021F */
+	0,							/* U+010220 */
+	0,							/* U+010221 */
+	0,							/* U+010222 */
+	0,							/* U+010223 */
+	0,							/* U+010224 */
+	0,							/* U+010225 */
+	0,							/* U+010226 */
+	0,							/* U+010227 */
+	0,							/* U+010228 */
+	0,							/* U+010229 */
+	0,							/* U+01022A */
+	0,							/* U+01022B */
+	0,							/* U+01022C */
+	0,							/* U+01022D */
+	0,							/* U+01022E */
+	0,							/* U+01022F */
+	0,							/* U+010230 */
+	0,							/* U+010231 */
+	0,							/* U+010232 */
+	0,							/* U+010233 */
+	0,							/* U+010234 */
+	0,							/* U+010235 */
+	0,							/* U+010236 */
+	0,							/* U+010237 */
+	0,							/* U+010238 */
+	0,							/* U+010239 */
+	0,							/* U+01023A */
+	0,							/* U+01023B */
+	0,							/* U+01023C */
+	0,							/* U+01023D */
+	0,							/* U+01023E */
+	0,							/* U+01023F */
+	0,							/* U+010240 */
+	0,							/* U+010241 */
+	0,							/* U+010242 */
+	0,							/* U+010243 */
+	0,							/* U+010244 */
+	0,							/* U+010245 */
+	0,							/* U+010246 */
+	0,							/* U+010247 */
+	0,							/* U+010248 */
+	0,							/* U+010249 */
+	0,							/* U+01024A */
+	0,							/* U+01024B */
+	0,							/* U+01024C */
+	0,							/* U+01024D */
+	0,							/* U+01024E */
+	0,							/* U+01024F */
+	0,							/* U+010250 */
+	0,							/* U+010251 */
+	0,							/* U+010252 */
+	0,							/* U+010253 */
+	0,							/* U+010254 */
+	0,							/* U+010255 */
+	0,							/* U+010256 */
+	0,							/* U+010257 */
+	0,							/* U+010258 */
+	0,							/* U+010259 */
+	0,							/* U+01025A */
+	0,							/* U+01025B */
+	0,							/* U+01025C */
+	0,							/* U+01025D */
+	0,							/* U+01025E */
+	0,							/* U+01025F */
+	0,							/* U+010260 */
+	0,							/* U+010261 */
+	0,							/* U+010262 */
+	0,							/* U+010263 */
+	0,							/* U+010264 */
+	0,							/* U+010265 */
+	0,							/* U+010266 */
+	0,							/* U+010267 */
+	0,							/* U+010268 */
+	0,							/* U+010269 */
+	0,							/* U+01026A */
+	0,							/* U+01026B */
+	0,							/* U+01026C */
+	0,							/* U+01026D */
+	0,							/* U+01026E */
+	0,							/* U+01026F */
+	0,							/* U+010270 */
+	0,							/* U+010271 */
+	0,							/* U+010272 */
+	0,							/* U+010273 */
+	0,							/* U+010274 */
+	0,							/* U+010275 */
+	0,							/* U+010276 */
+	0,							/* U+010277 */
+	0,							/* U+010278 */
+	0,							/* U+010279 */
+	0,							/* U+01027A */
+	0,							/* U+01027B */
+	0,							/* U+01027C */
+	0,							/* U+01027D */
+	0,							/* U+01027E */
+	0,							/* U+01027F */
+	0,							/* U+010280 */
+	0,							/* U+010281 */
+	0,							/* U+010282 */
+	0,							/* U+010283 */
+	0,							/* U+010284 */
+	0,							/* U+010285 */
+	0,							/* U+010286 */
+	0,							/* U+010287 */
+	0,							/* U+010288 */
+	0,							/* U+010289 */
+	0,							/* U+01028A */
+	0,							/* U+01028B */
+	0,							/* U+01028C */
+	0,							/* U+01028D */
+	0,							/* U+01028E */
+	0,							/* U+01028F */
+	0,							/* U+010290 */
+	0,							/* U+010291 */
+	0,							/* U+010292 */
+	0,							/* U+010293 */
+	0,							/* U+010294 */
+	0,							/* U+010295 */
+	0,							/* U+010296 */
+	0,							/* U+010297 */
+	0,							/* U+010298 */
+	0,							/* U+010299 */
+	0,							/* U+01029A */
+	0,							/* U+01029B */
+	0,							/* U+01029C */
+	0,							/* U+01029D */
+	0,							/* U+01029E */
+	0,							/* U+01029F */
+	0,							/* U+0102A0 */
+	0,							/* U+0102A1 */
+	0,							/* U+0102A2 */
+	0,							/* U+0102A3 */
+	0,							/* U+0102A4 */
+	0,							/* U+0102A5 */
+	0,							/* U+0102A6 */
+	0,							/* U+0102A7 */
+	0,							/* U+0102A8 */
+	0,							/* U+0102A9 */
+	0,							/* U+0102AA */
+	0,							/* U+0102AB */
+	0,							/* U+0102AC */
+	0,							/* U+0102AD */
+	0,							/* U+0102AE */
+	0,							/* U+0102AF */
+	0,							/* U+0102B0 */
+	0,							/* U+0102B1 */
+	0,							/* U+0102B2 */
+	0,							/* U+0102B3 */
+	0,							/* U+0102B4 */
+	0,							/* U+0102B5 */
+	0,							/* U+0102B6 */
+	0,							/* U+0102B7 */
+	0,							/* U+0102B8 */
+	0,							/* U+0102B9 */
+	0,							/* U+0102BA */
+	0,							/* U+0102BB */
+	0,							/* U+0102BC */
+	0,							/* U+0102BD */
+	0,							/* U+0102BE */
+	0,							/* U+0102BF */
+	0,							/* U+0102C0 */
+	0,							/* U+0102C1 */
+	0,							/* U+0102C2 */
+	0,							/* U+0102C3 */
+	0,							/* U+0102C4 */
+	0,							/* U+0102C5 */
+	0,							/* U+0102C6 */
+	0,							/* U+0102C7 */
+	0,							/* U+0102C8 */
+	0,							/* U+0102C9 */
+	0,							/* U+0102CA */
+	0,							/* U+0102CB */
+	0,							/* U+0102CC */
+	0,							/* U+0102CD */
+	0,							/* U+0102CE */
+	0,							/* U+0102CF */
+	0,							/* U+0102D0 */
+	0,							/* U+0102D1 */
+	0,							/* U+0102D2 */
+	0,							/* U+0102D3 */
+	0,							/* U+0102D4 */
+	0,							/* U+0102D5 */
+	0,							/* U+0102D6 */
+	0,							/* U+0102D7 */
+	0,							/* U+0102D8 */
+	0,							/* U+0102D9 */
+	0,							/* U+0102DA */
+	0,							/* U+0102DB */
+	0,							/* U+0102DC */
+	0,							/* U+0102DD */
+	0,							/* U+0102DE */
+	0,							/* U+0102DF */
+	306,						/* U+0102E0 */
+	0,							/* U+0102E1 */
+	0,							/* U+0102E2 */
+	0,							/* U+0102E3 */
+	0,							/* U+0102E4 */
+	0,							/* U+0102E5 */
+	0,							/* U+0102E6 */
+	0,							/* U+0102E7 */
+	0,							/* U+0102E8 */
+	0,							/* U+0102E9 */
+	0,							/* U+0102EA */
+	0,							/* U+0102EB */
+	0,							/* U+0102EC */
+	0,							/* U+0102ED */
+	0,							/* U+0102EE */
+	0,							/* U+0102EF */
+	0,							/* U+0102F0 */
+	0,							/* U+0102F1 */
+	0,							/* U+0102F2 */
+	0,							/* U+0102F3 */
+	0,							/* U+0102F4 */
+	0,							/* U+0102F5 */
+	0,							/* U+0102F6 */
+	0,							/* U+0102F7 */
+	0,							/* U+0102F8 */
+	0,							/* U+0102F9 */
+	0,							/* U+0102FA */
+	0,							/* U+0102FB */
+	0,							/* U+0102FC */
+	0,							/* U+0102FD */
+	0,							/* U+0102FE */
+	0,							/* U+0102FF */
+	0,							/* U+010300 */
+	0,							/* U+010301 */
+	0,							/* U+010302 */
+	0,							/* U+010303 */
+	0,							/* U+010304 */
+	0,							/* U+010305 */
+	0,							/* U+010306 */
+	0,							/* U+010307 */
+	0,							/* U+010308 */
+	0,							/* U+010309 */
+	0,							/* U+01030A */
+	0,							/* U+01030B */
+	0,							/* U+01030C */
+	0,							/* U+01030D */
+	0,							/* U+01030E */
+	0,							/* U+01030F */
+	0,							/* U+010310 */
+	0,							/* U+010311 */
+	0,							/* U+010312 */
+	0,							/* U+010313 */
+	0,							/* U+010314 */
+	0,							/* U+010315 */
+	0,							/* U+010316 */
+	0,							/* U+010317 */
+	0,							/* U+010318 */
+	0,							/* U+010319 */
+	0,							/* U+01031A */
+	0,							/* U+01031B */
+	0,							/* U+01031C */
+	0,							/* U+01031D */
+	0,							/* U+01031E */
+	0,							/* U+01031F */
+	0,							/* U+010320 */
+	0,							/* U+010321 */
+	0,							/* U+010322 */
+	0,							/* U+010323 */
+	0,							/* U+010324 */
+	0,							/* U+010325 */
+	0,							/* U+010326 */
+	0,							/* U+010327 */
+	0,							/* U+010328 */
+	0,							/* U+010329 */
+	0,							/* U+01032A */
+	0,							/* U+01032B */
+	0,							/* U+01032C */
+	0,							/* U+01032D */
+	0,							/* U+01032E */
+	0,							/* U+01032F */
+	0,							/* U+010330 */
+	0,							/* U+010331 */
+	0,							/* U+010332 */
+	0,							/* U+010333 */
+	0,							/* U+010334 */
+	0,							/* U+010335 */
+	0,							/* U+010336 */
+	0,							/* U+010337 */
+	0,							/* U+010338 */
+	0,							/* U+010339 */
+	0,							/* U+01033A */
+	0,							/* U+01033B */
+	0,							/* U+01033C */
+	0,							/* U+01033D */
+	0,							/* U+01033E */
+	0,							/* U+01033F */
+	0,							/* U+010340 */
+	0,							/* U+010341 */
+	0,							/* U+010342 */
+	0,							/* U+010343 */
+	0,							/* U+010344 */
+	0,							/* U+010345 */
+	0,							/* U+010346 */
+	0,							/* U+010347 */
+	0,							/* U+010348 */
+	0,							/* U+010349 */
+	0,							/* U+01034A */
+	0,							/* U+01034B */
+	0,							/* U+01034C */
+	0,							/* U+01034D */
+	0,							/* U+01034E */
+	0,							/* U+01034F */
+	0,							/* U+010350 */
+	0,							/* U+010351 */
+	0,							/* U+010352 */
+	0,							/* U+010353 */
+	0,							/* U+010354 */
+	0,							/* U+010355 */
+	0,							/* U+010356 */
+	0,							/* U+010357 */
+	0,							/* U+010358 */
+	0,							/* U+010359 */
+	0,							/* U+01035A */
+	0,							/* U+01035B */
+	0,							/* U+01035C */
+	0,							/* U+01035D */
+	0,							/* U+01035E */
+	0,							/* U+01035F */
+	0,							/* U+010360 */
+	0,							/* U+010361 */
+	0,							/* U+010362 */
+	0,							/* U+010363 */
+	0,							/* U+010364 */
+	0,							/* U+010365 */
+	0,							/* U+010366 */
+	0,							/* U+010367 */
+	0,							/* U+010368 */
+	0,							/* U+010369 */
+	0,							/* U+01036A */
+	0,							/* U+01036B */
+	0,							/* U+01036C */
+	0,							/* U+01036D */
+	0,							/* U+01036E */
+	0,							/* U+01036F */
+	0,							/* U+010370 */
+	0,							/* U+010371 */
+	0,							/* U+010372 */
+	0,							/* U+010373 */
+	0,							/* U+010374 */
+	0,							/* U+010375 */
+	304,						/* U+010376 */
+	304,						/* U+010377 */
+	304,						/* U+010378 */
+	304,						/* U+010379 */
+	304,						/* U+01037A */
+	0,							/* U+01037B */
+	0,							/* U+01037C */
+	0,							/* U+01037D */
+	0,							/* U+01037E */
+	0,							/* U+01037F */
+	0,							/* U+010380 */
+	0,							/* U+010381 */
+	0,							/* U+010382 */
+	0,							/* U+010383 */
+	0,							/* U+010384 */
+	0,							/* U+010385 */
+	0,							/* U+010386 */
+	0,							/* U+010387 */
+	0,							/* U+010388 */
+	0,							/* U+010389 */
+	0,							/* U+01038A */
+	0,							/* U+01038B */
+	0,							/* U+01038C */
+	0,							/* U+01038D */
+	0,							/* U+01038E */
+	0,							/* U+01038F */
+	0,							/* U+010390 */
+	0,							/* U+010391 */
+	0,							/* U+010392 */
+	0,							/* U+010393 */
+	0,							/* U+010394 */
+	0,							/* U+010395 */
+	0,							/* U+010396 */
+	0,							/* U+010397 */
+	0,							/* U+010398 */
+	0,							/* U+010399 */
+	0,							/* U+01039A */
+	0,							/* U+01039B */
+	0,							/* U+01039C */
+	0,							/* U+01039D */
+	0,							/* U+01039E */
+	0,							/* U+01039F */
+	0,							/* U+0103A0 */
+	0,							/* U+0103A1 */
+	0,							/* U+0103A2 */
+	0,							/* U+0103A3 */
+	0,							/* U+0103A4 */
+	0,							/* U+0103A5 */
+	0,							/* U+0103A6 */
+	0,							/* U+0103A7 */
+	0,							/* U+0103A8 */
+	0,							/* U+0103A9 */
+	0,							/* U+0103AA */
+	0,							/* U+0103AB */
+	0,							/* U+0103AC */
+	0,							/* U+0103AD */
+	0,							/* U+0103AE */
+	0,							/* U+0103AF */
+	0,							/* U+0103B0 */
+	0,							/* U+0103B1 */
+	0,							/* U+0103B2 */
+	0,							/* U+0103B3 */
+	0,							/* U+0103B4 */
+	0,							/* U+0103B5 */
+	0,							/* U+0103B6 */
+	0,							/* U+0103B7 */
+	0,							/* U+0103B8 */
+	0,							/* U+0103B9 */
+	0,							/* U+0103BA */
+	0,							/* U+0103BB */
+	0,							/* U+0103BC */
+	0,							/* U+0103BD */
+	0,							/* U+0103BE */
+	0,							/* U+0103BF */
+	0,							/* U+0103C0 */
+	0,							/* U+0103C1 */
+	0,							/* U+0103C2 */
+	0,							/* U+0103C3 */
+	0,							/* U+0103C4 */
+	0,							/* U+0103C5 */
+	0,							/* U+0103C6 */
+	0,							/* U+0103C7 */
+	0,							/* U+0103C8 */
+	0,							/* U+0103C9 */
+	0,							/* U+0103CA */
+	0,							/* U+0103CB */
+	0,							/* U+0103CC */
+	0,							/* U+0103CD */
+	0,							/* U+0103CE */
+	0,							/* U+0103CF */
+	0,							/* U+0103D0 */
+	0,							/* U+0103D1 */
+	0,							/* U+0103D2 */
+	0,							/* U+0103D3 */
+	0,							/* U+0103D4 */
+	0,							/* U+0103D5 */
+	0,							/* U+0103D6 */
+	0,							/* U+0103D7 */
+	0,							/* U+0103D8 */
+	0,							/* U+0103D9 */
+	0,							/* U+0103DA */
+	0,							/* U+0103DB */
+	0,							/* U+0103DC */
+	0,							/* U+0103DD */
+	0,							/* U+0103DE */
+	0,							/* U+0103DF */
+	0,							/* U+0103E0 */
+	0,							/* U+0103E1 */
+	0,							/* U+0103E2 */
+	0,							/* U+0103E3 */
+	0,							/* U+0103E4 */
+	0,							/* U+0103E5 */
+	0,							/* U+0103E6 */
+	0,							/* U+0103E7 */
+	0,							/* U+0103E8 */
+	0,							/* U+0103E9 */
+	0,							/* U+0103EA */
+	0,							/* U+0103EB */
+	0,							/* U+0103EC */
+	0,							/* U+0103ED */
+	0,							/* U+0103EE */
+	0,							/* U+0103EF */
+	0,							/* U+0103F0 */
+	0,							/* U+0103F1 */
+	0,							/* U+0103F2 */
+	0,							/* U+0103F3 */
+	0,							/* U+0103F4 */
+	0,							/* U+0103F5 */
+	0,							/* U+0103F6 */
+	0,							/* U+0103F7 */
+	0,							/* U+0103F8 */
+	0,							/* U+0103F9 */
+	0,							/* U+0103FA */
+	0,							/* U+0103FB */
+	0,							/* U+0103FC */
+	0,							/* U+0103FD */
+	0,							/* U+0103FE */
+	0,							/* U+0103FF */
+	0,							/* U+010400 */
+	0,							/* U+010401 */
+	0,							/* U+010402 */
+	0,							/* U+010403 */
+	0,							/* U+010404 */
+	0,							/* U+010405 */
+	0,							/* U+010406 */
+	0,							/* U+010407 */
+	0,							/* U+010408 */
+	0,							/* U+010409 */
+	0,							/* U+01040A */
+	0,							/* U+01040B */
+	0,							/* U+01040C */
+	0,							/* U+01040D */
+	0,							/* U+01040E */
+	0,							/* U+01040F */
+	0,							/* U+010410 */
+	0,							/* U+010411 */
+	0,							/* U+010412 */
+	0,							/* U+010413 */
+	0,							/* U+010414 */
+	0,							/* U+010415 */
+	0,							/* U+010416 */
+	0,							/* U+010417 */
+	0,							/* U+010418 */
+	0,							/* U+010419 */
+	0,							/* U+01041A */
+	0,							/* U+01041B */
+	0,							/* U+01041C */
+	0,							/* U+01041D */
+	0,							/* U+01041E */
+	0,							/* U+01041F */
+	0,							/* U+010420 */
+	0,							/* U+010421 */
+	0,							/* U+010422 */
+	0,							/* U+010423 */
+	0,							/* U+010424 */
+	0,							/* U+010425 */
+	0,							/* U+010426 */
+	0,							/* U+010427 */
+	0,							/* U+010428 */
+	0,							/* U+010429 */
+	0,							/* U+01042A */
+	0,							/* U+01042B */
+	0,							/* U+01042C */
+	0,							/* U+01042D */
+	0,							/* U+01042E */
+	0,							/* U+01042F */
+	0,							/* U+010430 */
+	0,							/* U+010431 */
+	0,							/* U+010432 */
+	0,							/* U+010433 */
+	0,							/* U+010434 */
+	0,							/* U+010435 */
+	0,							/* U+010436 */
+	0,							/* U+010437 */
+	0,							/* U+010438 */
+	0,							/* U+010439 */
+	0,							/* U+01043A */
+	0,							/* U+01043B */
+	0,							/* U+01043C */
+	0,							/* U+01043D */
+	0,							/* U+01043E */
+	0,							/* U+01043F */
+	0,							/* U+010440 */
+	0,							/* U+010441 */
+	0,							/* U+010442 */
+	0,							/* U+010443 */
+	0,							/* U+010444 */
+	0,							/* U+010445 */
+	0,							/* U+010446 */
+	0,							/* U+010447 */
+	0,							/* U+010448 */
+	0,							/* U+010449 */
+	0,							/* U+01044A */
+	0,							/* U+01044B */
+	0,							/* U+01044C */
+	0,							/* U+01044D */
+	0,							/* U+01044E */
+	0,							/* U+01044F */
+	0,							/* U+010450 */
+	0,							/* U+010451 */
+	0,							/* U+010452 */
+	0,							/* U+010453 */
+	0,							/* U+010454 */
+	0,							/* U+010455 */
+	0,							/* U+010456 */
+	0,							/* U+010457 */
+	0,							/* U+010458 */
+	0,							/* U+010459 */
+	0,							/* U+01045A */
+	0,							/* U+01045B */
+	0,							/* U+01045C */
+	0,							/* U+01045D */
+	0,							/* U+01045E */
+	0,							/* U+01045F */
+	0,							/* U+010460 */
+	0,							/* U+010461 */
+	0,							/* U+010462 */
+	0,							/* U+010463 */
+	0,							/* U+010464 */
+	0,							/* U+010465 */
+	0,							/* U+010466 */
+	0,							/* U+010467 */
+	0,							/* U+010468 */
+	0,							/* U+010469 */
+	0,							/* U+01046A */
+	0,							/* U+01046B */
+	0,							/* U+01046C */
+	0,							/* U+01046D */
+	0,							/* U+01046E */
+	0,							/* U+01046F */
+	0,							/* U+010470 */
+	0,							/* U+010471 */
+	0,							/* U+010472 */
+	0,							/* U+010473 */
+	0,							/* U+010474 */
+	0,							/* U+010475 */
+	0,							/* U+010476 */
+	0,							/* U+010477 */
+	0,							/* U+010478 */
+	0,							/* U+010479 */
+	0,							/* U+01047A */
+	0,							/* U+01047B */
+	0,							/* U+01047C */
+	0,							/* U+01047D */
+	0,							/* U+01047E */
+	0,							/* U+01047F */
+	0,							/* U+010480 */
+	0,							/* U+010481 */
+	0,							/* U+010482 */
+	0,							/* U+010483 */
+	0,							/* U+010484 */
+	0,							/* U+010485 */
+	0,							/* U+010486 */
+	0,							/* U+010487 */
+	0,							/* U+010488 */
+	0,							/* U+010489 */
+	0,							/* U+01048A */
+	0,							/* U+01048B */
+	0,							/* U+01048C */
+	0,							/* U+01048D */
+	0,							/* U+01048E */
+	0,							/* U+01048F */
+	0,							/* U+010490 */
+	0,							/* U+010491 */
+	0,							/* U+010492 */
+	0,							/* U+010493 */
+	0,							/* U+010494 */
+	0,							/* U+010495 */
+	0,							/* U+010496 */
+	0,							/* U+010497 */
+	0,							/* U+010498 */
+	0,							/* U+010499 */
+	0,							/* U+01049A */
+	0,							/* U+01049B */
+	0,							/* U+01049C */
+	0,							/* U+01049D */
+	0,							/* U+01049E */
+	0,							/* U+01049F */
+	0,							/* U+0104A0 */
+	0,							/* U+0104A1 */
+	0,							/* U+0104A2 */
+	0,							/* U+0104A3 */
+	0,							/* U+0104A4 */
+	0,							/* U+0104A5 */
+	0,							/* U+0104A6 */
+	0,							/* U+0104A7 */
+	0,							/* U+0104A8 */
+	0,							/* U+0104A9 */
+	0,							/* U+0104AA */
+	0,							/* U+0104AB */
+	0,							/* U+0104AC */
+	0,							/* U+0104AD */
+	0,							/* U+0104AE */
+	0,							/* U+0104AF */
+	0,							/* U+0104B0 */
+	0,							/* U+0104B1 */
+	0,							/* U+0104B2 */
+	0,							/* U+0104B3 */
+	0,							/* U+0104B4 */
+	0,							/* U+0104B5 */
+	0,							/* U+0104B6 */
+	0,							/* U+0104B7 */
+	0,							/* U+0104B8 */
+	0,							/* U+0104B9 */
+	0,							/* U+0104BA */
+	0,							/* U+0104BB */
+	0,							/* U+0104BC */
+	0,							/* U+0104BD */
+	0,							/* U+0104BE */
+	0,							/* U+0104BF */
+	0,							/* U+0104C0 */
+	0,							/* U+0104C1 */
+	0,							/* U+0104C2 */
+	0,							/* U+0104C3 */
+	0,							/* U+0104C4 */
+	0,							/* U+0104C5 */
+	0,							/* U+0104C6 */
+	0,							/* U+0104C7 */
+	0,							/* U+0104C8 */
+	0,							/* U+0104C9 */
+	0,							/* U+0104CA */
+	0,							/* U+0104CB */
+	0,							/* U+0104CC */
+	0,							/* U+0104CD */
+	0,							/* U+0104CE */
+	0,							/* U+0104CF */
+	0,							/* U+0104D0 */
+	0,							/* U+0104D1 */
+	0,							/* U+0104D2 */
+	0,							/* U+0104D3 */
+	0,							/* U+0104D4 */
+	0,							/* U+0104D5 */
+	0,							/* U+0104D6 */
+	0,							/* U+0104D7 */
+	0,							/* U+0104D8 */
+	0,							/* U+0104D9 */
+	0,							/* U+0104DA */
+	0,							/* U+0104DB */
+	0,							/* U+0104DC */
+	0,							/* U+0104DD */
+	0,							/* U+0104DE */
+	0,							/* U+0104DF */
+	0,							/* U+0104E0 */
+	0,							/* U+0104E1 */
+	0,							/* U+0104E2 */
+	0,							/* U+0104E3 */
+	0,							/* U+0104E4 */
+	0,							/* U+0104E5 */
+	0,							/* U+0104E6 */
+	0,							/* U+0104E7 */
+	0,							/* U+0104E8 */
+	0,							/* U+0104E9 */
+	0,							/* U+0104EA */
+	0,							/* U+0104EB */
+	0,							/* U+0104EC */
+	0,							/* U+0104ED */
+	0,							/* U+0104EE */
+	0,							/* U+0104EF */
+	0,							/* U+0104F0 */
+	0,							/* U+0104F1 */
+	0,							/* U+0104F2 */
+	0,							/* U+0104F3 */
+	0,							/* U+0104F4 */
+	0,							/* U+0104F5 */
+	0,							/* U+0104F6 */
+	0,							/* U+0104F7 */
+	0,							/* U+0104F8 */
+	0,							/* U+0104F9 */
+	0,							/* U+0104FA */
+	0,							/* U+0104FB */
+	0,							/* U+0104FC */
+	0,							/* U+0104FD */
+	0,							/* U+0104FE */
+	0,							/* U+0104FF */
+	0,							/* U+010500 */
+	0,							/* U+010501 */
+	0,							/* U+010502 */
+	0,							/* U+010503 */
+	0,							/* U+010504 */
+	0,							/* U+010505 */
+	0,							/* U+010506 */
+	0,							/* U+010507 */
+	0,							/* U+010508 */
+	0,							/* U+010509 */
+	0,							/* U+01050A */
+	0,							/* U+01050B */
+	0,							/* U+01050C */
+	0,							/* U+01050D */
+	0,							/* U+01050E */
+	0,							/* U+01050F */
+	0,							/* U+010510 */
+	0,							/* U+010511 */
+	0,							/* U+010512 */
+	0,							/* U+010513 */
+	0,							/* U+010514 */
+	0,							/* U+010515 */
+	0,							/* U+010516 */
+	0,							/* U+010517 */
+	0,							/* U+010518 */
+	0,							/* U+010519 */
+	0,							/* U+01051A */
+	0,							/* U+01051B */
+	0,							/* U+01051C */
+	0,							/* U+01051D */
+	0,							/* U+01051E */
+	0,							/* U+01051F */
+	0,							/* U+010520 */
+	0,							/* U+010521 */
+	0,							/* U+010522 */
+	0,							/* U+010523 */
+	0,							/* U+010524 */
+	0,							/* U+010525 */
+	0,							/* U+010526 */
+	0,							/* U+010527 */
+	0,							/* U+010528 */
+	0,							/* U+010529 */
+	0,							/* U+01052A */
+	0,							/* U+01052B */
+	0,							/* U+01052C */
+	0,							/* U+01052D */
+	0,							/* U+01052E */
+	0,							/* U+01052F */
+	0,							/* U+010530 */
+	0,							/* U+010531 */
+	0,							/* U+010532 */
+	0,							/* U+010533 */
+	0,							/* U+010534 */
+	0,							/* U+010535 */
+	0,							/* U+010536 */
+	0,							/* U+010537 */
+	0,							/* U+010538 */
+	0,							/* U+010539 */
+	0,							/* U+01053A */
+	0,							/* U+01053B */
+	0,							/* U+01053C */
+	0,							/* U+01053D */
+	0,							/* U+01053E */
+	0,							/* U+01053F */
+	0,							/* U+010540 */
+	0,							/* U+010541 */
+	0,							/* U+010542 */
+	0,							/* U+010543 */
+	0,							/* U+010544 */
+	0,							/* U+010545 */
+	0,							/* U+010546 */
+	0,							/* U+010547 */
+	0,							/* U+010548 */
+	0,							/* U+010549 */
+	0,							/* U+01054A */
+	0,							/* U+01054B */
+	0,							/* U+01054C */
+	0,							/* U+01054D */
+	0,							/* U+01054E */
+	0,							/* U+01054F */
+	0,							/* U+010550 */
+	0,							/* U+010551 */
+	0,							/* U+010552 */
+	0,							/* U+010553 */
+	0,							/* U+010554 */
+	0,							/* U+010555 */
+	0,							/* U+010556 */
+	0,							/* U+010557 */
+	0,							/* U+010558 */
+	0,							/* U+010559 */
+	0,							/* U+01055A */
+	0,							/* U+01055B */
+	0,							/* U+01055C */
+	0,							/* U+01055D */
+	0,							/* U+01055E */
+	0,							/* U+01055F */
+	0,							/* U+010560 */
+	0,							/* U+010561 */
+	0,							/* U+010562 */
+	0,							/* U+010563 */
+	0,							/* U+010564 */
+	0,							/* U+010565 */
+	0,							/* U+010566 */
+	0,							/* U+010567 */
+	0,							/* U+010568 */
+	0,							/* U+010569 */
+	0,							/* U+01056A */
+	0,							/* U+01056B */
+	0,							/* U+01056C */
+	0,							/* U+01056D */
+	0,							/* U+01056E */
+	0,							/* U+01056F */
+	0,							/* U+010570 */
+	0,							/* U+010571 */
+	0,							/* U+010572 */
+	0,							/* U+010573 */
+	0,							/* U+010574 */
+	0,							/* U+010575 */
+	0,							/* U+010576 */
+	0,							/* U+010577 */
+	0,							/* U+010578 */
+	0,							/* U+010579 */
+	0,							/* U+01057A */
+	0,							/* U+01057B */
+	0,							/* U+01057C */
+	0,							/* U+01057D */
+	0,							/* U+01057E */
+	0,							/* U+01057F */
+	0,							/* U+010580 */
+	0,							/* U+010581 */
+	0,							/* U+010582 */
+	0,							/* U+010583 */
+	0,							/* U+010584 */
+	0,							/* U+010585 */
+	0,							/* U+010586 */
+	0,							/* U+010587 */
+	0,							/* U+010588 */
+	0,							/* U+010589 */
+	0,							/* U+01058A */
+	0,							/* U+01058B */
+	0,							/* U+01058C */
+	0,							/* U+01058D */
+	0,							/* U+01058E */
+	0,							/* U+01058F */
+	0,							/* U+010590 */
+	0,							/* U+010591 */
+	0,							/* U+010592 */
+	0,							/* U+010593 */
+	0,							/* U+010594 */
+	0,							/* U+010595 */
+	0,							/* U+010596 */
+	0,							/* U+010597 */
+	0,							/* U+010598 */
+	0,							/* U+010599 */
+	0,							/* U+01059A */
+	0,							/* U+01059B */
+	0,							/* U+01059C */
+	0,							/* U+01059D */
+	0,							/* U+01059E */
+	0,							/* U+01059F */
+	0,							/* U+0105A0 */
+	0,							/* U+0105A1 */
+	0,							/* U+0105A2 */
+	0,							/* U+0105A3 */
+	0,							/* U+0105A4 */
+	0,							/* U+0105A5 */
+	0,							/* U+0105A6 */
+	0,							/* U+0105A7 */
+	0,							/* U+0105A8 */
+	0,							/* U+0105A9 */
+	0,							/* U+0105AA */
+	0,							/* U+0105AB */
+	0,							/* U+0105AC */
+	0,							/* U+0105AD */
+	0,							/* U+0105AE */
+	0,							/* U+0105AF */
+	0,							/* U+0105B0 */
+	0,							/* U+0105B1 */
+	0,							/* U+0105B2 */
+	0,							/* U+0105B3 */
+	0,							/* U+0105B4 */
+	0,							/* U+0105B5 */
+	0,							/* U+0105B6 */
+	0,							/* U+0105B7 */
+	0,							/* U+0105B8 */
+	0,							/* U+0105B9 */
+	0,							/* U+0105BA */
+	0,							/* U+0105BB */
+	0,							/* U+0105BC */
+	0,							/* U+0105BD */
+	0,							/* U+0105BE */
+	0,							/* U+0105BF */
+	0,							/* U+0105C0 */
+	0,							/* U+0105C1 */
+	0,							/* U+0105C2 */
+	0,							/* U+0105C3 */
+	0,							/* U+0105C4 */
+	0,							/* U+0105C5 */
+	0,							/* U+0105C6 */
+	0,							/* U+0105C7 */
+	0,							/* U+0105C8 */
+	3183,						/* U+0105C9 */
+	0,							/* U+0105CA */
+	0,							/* U+0105CB */
+	0,							/* U+0105CC */
+	0,							/* U+0105CD */
+	0,							/* U+0105CE */
+	0,							/* U+0105CF */
+	0,							/* U+0105D0 */
+	0,							/* U+0105D1 */
+	0,							/* U+0105D2 */
+	0,							/* U+0105D3 */
+	0,							/* U+0105D4 */
+	0,							/* U+0105D5 */
+	0,							/* U+0105D6 */
+	0,							/* U+0105D7 */
+	0,							/* U+0105D8 */
+	0,							/* U+0105D9 */
+	0,							/* U+0105DA */
+	0,							/* U+0105DB */
+	0,							/* U+0105DC */
+	0,							/* U+0105DD */
+	0,							/* U+0105DE */
+	0,							/* U+0105DF */
+	0,							/* U+0105E0 */
+	0,							/* U+0105E1 */
+	0,							/* U+0105E2 */
+	0,							/* U+0105E3 */
+	3184,						/* U+0105E4 */
+	0,							/* U+0105E5 */
+	0,							/* U+0105E6 */
+	0,							/* U+0105E7 */
+	0,							/* U+0105E8 */
+	0,							/* U+0105E9 */
+	0,							/* U+0105EA */
+	0,							/* U+0105EB */
+	0,							/* U+0105EC */
+	0,							/* U+0105ED */
+	0,							/* U+0105EE */
+	0,							/* U+0105EF */
+	0,							/* U+0105F0 */
+	0,							/* U+0105F1 */
+	0,							/* U+0105F2 */
+	0,							/* U+0105F3 */
+	0,							/* U+0105F4 */
+	0,							/* U+0105F5 */
+	0,							/* U+0105F6 */
+	0,							/* U+0105F7 */
+	0,							/* U+0105F8 */
+	0,							/* U+0105F9 */
+	0,							/* U+0105FA */
+	0,							/* U+0105FB */
+	0,							/* U+0105FC */
+	0,							/* U+0105FD */
+	0,							/* U+0105FE */
+	0,							/* U+0105FF */
+	0,							/* U+010600 */
+	0,							/* U+010601 */
+	0,							/* U+010602 */
+	0,							/* U+010603 */
+	0,							/* U+010604 */
+	0,							/* U+010605 */
+	0,							/* U+010606 */
+	0,							/* U+010607 */
+	0,							/* U+010608 */
+	0,							/* U+010609 */
+	0,							/* U+01060A */
+	0,							/* U+01060B */
+	0,							/* U+01060C */
+	0,							/* U+01060D */
+	0,							/* U+01060E */
+	0,							/* U+01060F */
+	0,							/* U+010610 */
+	0,							/* U+010611 */
+	0,							/* U+010612 */
+	0,							/* U+010613 */
+	0,							/* U+010614 */
+	0,							/* U+010615 */
+	0,							/* U+010616 */
+	0,							/* U+010617 */
+	0,							/* U+010618 */
+	0,							/* U+010619 */
+	0,							/* U+01061A */
+	0,							/* U+01061B */
+	0,							/* U+01061C */
+	0,							/* U+01061D */
+	0,							/* U+01061E */
+	0,							/* U+01061F */
+	0,							/* U+010620 */
+	0,							/* U+010621 */
+	0,							/* U+010622 */
+	0,							/* U+010623 */
+	0,							/* U+010624 */
+	0,							/* U+010625 */
+	0,							/* U+010626 */
+	0,							/* U+010627 */
+	0,							/* U+010628 */
+	0,							/* U+010629 */
+	0,							/* U+01062A */
+	0,							/* U+01062B */
+	0,							/* U+01062C */
+	0,							/* U+01062D */
+	0,							/* U+01062E */
+	0,							/* U+01062F */
+	0,							/* U+010630 */
+	0,							/* U+010631 */
+	0,							/* U+010632 */
+	0,							/* U+010633 */
+	0,							/* U+010634 */
+	0,							/* U+010635 */
+	0,							/* U+010636 */
+	0,							/* U+010637 */
+	0,							/* U+010638 */
+	0,							/* U+010639 */
+	0,							/* U+01063A */
+	0,							/* U+01063B */
+	0,							/* U+01063C */
+	0,							/* U+01063D */
+	0,							/* U+01063E */
+	0,							/* U+01063F */
+	0,							/* U+010640 */
+	0,							/* U+010641 */
+	0,							/* U+010642 */
+	0,							/* U+010643 */
+	0,							/* U+010644 */
+	0,							/* U+010645 */
+	0,							/* U+010646 */
+	0,							/* U+010647 */
+	0,							/* U+010648 */
+	0,							/* U+010649 */
+	0,							/* U+01064A */
+	0,							/* U+01064B */
+	0,							/* U+01064C */
+	0,							/* U+01064D */
+	0,							/* U+01064E */
+	0,							/* U+01064F */
+	0,							/* U+010650 */
+	0,							/* U+010651 */
+	0,							/* U+010652 */
+	0,							/* U+010653 */
+	0,							/* U+010654 */
+	0,							/* U+010655 */
+	0,							/* U+010656 */
+	0,							/* U+010657 */
+	0,							/* U+010658 */
+	0,							/* U+010659 */
+	0,							/* U+01065A */
+	0,							/* U+01065B */
+	0,							/* U+01065C */
+	0,							/* U+01065D */
+	0,							/* U+01065E */
+	0,							/* U+01065F */
+	0,							/* U+010660 */
+	0,							/* U+010661 */
+	0,							/* U+010662 */
+	0,							/* U+010663 */
+	0,							/* U+010664 */
+	0,							/* U+010665 */
+	0,							/* U+010666 */
+	0,							/* U+010667 */
+	0,							/* U+010668 */
+	0,							/* U+010669 */
+	0,							/* U+01066A */
+	0,							/* U+01066B */
+	0,							/* U+01066C */
+	0,							/* U+01066D */
+	0,							/* U+01066E */
+	0,							/* U+01066F */
+	0,							/* U+010670 */
+	0,							/* U+010671 */
+	0,							/* U+010672 */
+	0,							/* U+010673 */
+	0,							/* U+010674 */
+	0,							/* U+010675 */
+	0,							/* U+010676 */
+	0,							/* U+010677 */
+	0,							/* U+010678 */
+	0,							/* U+010679 */
+	0,							/* U+01067A */
+	0,							/* U+01067B */
+	0,							/* U+01067C */
+	0,							/* U+01067D */
+	0,							/* U+01067E */
+	0,							/* U+01067F */
+	0,							/* U+010680 */
+	0,							/* U+010681 */
+	0,							/* U+010682 */
+	0,							/* U+010683 */
+	0,							/* U+010684 */
+	0,							/* U+010685 */
+	0,							/* U+010686 */
+	0,							/* U+010687 */
+	0,							/* U+010688 */
+	0,							/* U+010689 */
+	0,							/* U+01068A */
+	0,							/* U+01068B */
+	0,							/* U+01068C */
+	0,							/* U+01068D */
+	0,							/* U+01068E */
+	0,							/* U+01068F */
+	0,							/* U+010690 */
+	0,							/* U+010691 */
+	0,							/* U+010692 */
+	0,							/* U+010693 */
+	0,							/* U+010694 */
+	0,							/* U+010695 */
+	0,							/* U+010696 */
+	0,							/* U+010697 */
+	0,							/* U+010698 */
+	0,							/* U+010699 */
+	0,							/* U+01069A */
+	0,							/* U+01069B */
+	0,							/* U+01069C */
+	0,							/* U+01069D */
+	0,							/* U+01069E */
+	0,							/* U+01069F */
+	0,							/* U+0106A0 */
+	0,							/* U+0106A1 */
+	0,							/* U+0106A2 */
+	0,							/* U+0106A3 */
+	0,							/* U+0106A4 */
+	0,							/* U+0106A5 */
+	0,							/* U+0106A6 */
+	0,							/* U+0106A7 */
+	0,							/* U+0106A8 */
+	0,							/* U+0106A9 */
+	0,							/* U+0106AA */
+	0,							/* U+0106AB */
+	0,							/* U+0106AC */
+	0,							/* U+0106AD */
+	0,							/* U+0106AE */
+	0,							/* U+0106AF */
+	0,							/* U+0106B0 */
+	0,							/* U+0106B1 */
+	0,							/* U+0106B2 */
+	0,							/* U+0106B3 */
+	0,							/* U+0106B4 */
+	0,							/* U+0106B5 */
+	0,							/* U+0106B6 */
+	0,							/* U+0106B7 */
+	0,							/* U+0106B8 */
+	0,							/* U+0106B9 */
+	0,							/* U+0106BA */
+	0,							/* U+0106BB */
+	0,							/* U+0106BC */
+	0,							/* U+0106BD */
+	0,							/* U+0106BE */
+	0,							/* U+0106BF */
+	0,							/* U+0106C0 */
+	0,							/* U+0106C1 */
+	0,							/* U+0106C2 */
+	0,							/* U+0106C3 */
+	0,							/* U+0106C4 */
+	0,							/* U+0106C5 */
+	0,							/* U+0106C6 */
+	0,							/* U+0106C7 */
+	0,							/* U+0106C8 */
+	0,							/* U+0106C9 */
+	0,							/* U+0106CA */
+	0,							/* U+0106CB */
+	0,							/* U+0106CC */
+	0,							/* U+0106CD */
+	0,							/* U+0106CE */
+	0,							/* U+0106CF */
+	0,							/* U+0106D0 */
+	0,							/* U+0106D1 */
+	0,							/* U+0106D2 */
+	0,							/* U+0106D3 */
+	0,							/* U+0106D4 */
+	0,							/* U+0106D5 */
+	0,							/* U+0106D6 */
+	0,							/* U+0106D7 */
+	0,							/* U+0106D8 */
+	0,							/* U+0106D9 */
+	0,							/* U+0106DA */
+	0,							/* U+0106DB */
+	0,							/* U+0106DC */
+	0,							/* U+0106DD */
+	0,							/* U+0106DE */
+	0,							/* U+0106DF */
+	0,							/* U+0106E0 */
+	0,							/* U+0106E1 */
+	0,							/* U+0106E2 */
+	0,							/* U+0106E3 */
+	0,							/* U+0106E4 */
+	0,							/* U+0106E5 */
+	0,							/* U+0106E6 */
+	0,							/* U+0106E7 */
+	0,							/* U+0106E8 */
+	0,							/* U+0106E9 */
+	0,							/* U+0106EA */
+	0,							/* U+0106EB */
+	0,							/* U+0106EC */
+	0,							/* U+0106ED */
+	0,							/* U+0106EE */
+	0,							/* U+0106EF */
+	0,							/* U+0106F0 */
+	0,							/* U+0106F1 */
+	0,							/* U+0106F2 */
+	0,							/* U+0106F3 */
+	0,							/* U+0106F4 */
+	0,							/* U+0106F5 */
+	0,							/* U+0106F6 */
+	0,							/* U+0106F7 */
+	0,							/* U+0106F8 */
+	0,							/* U+0106F9 */
+	0,							/* U+0106FA */
+	0,							/* U+0106FB */
+	0,							/* U+0106FC */
+	0,							/* U+0106FD */
+	0,							/* U+0106FE */
+	0,							/* U+0106FF */
+	0,							/* U+010700 */
+	0,							/* U+010701 */
+	0,							/* U+010702 */
+	0,							/* U+010703 */
+	0,							/* U+010704 */
+	0,							/* U+010705 */
+	0,							/* U+010706 */
+	0,							/* U+010707 */
+	0,							/* U+010708 */
+	0,							/* U+010709 */
+	0,							/* U+01070A */
+	0,							/* U+01070B */
+	0,							/* U+01070C */
+	0,							/* U+01070D */
+	0,							/* U+01070E */
+	0,							/* U+01070F */
+	0,							/* U+010710 */
+	0,							/* U+010711 */
+	0,							/* U+010712 */
+	0,							/* U+010713 */
+	0,							/* U+010714 */
+	0,							/* U+010715 */
+	0,							/* U+010716 */
+	0,							/* U+010717 */
+	0,							/* U+010718 */
+	0,							/* U+010719 */
+	0,							/* U+01071A */
+	0,							/* U+01071B */
+	0,							/* U+01071C */
+	0,							/* U+01071D */
+	0,							/* U+01071E */
+	0,							/* U+01071F */
+	0,							/* U+010720 */
+	0,							/* U+010721 */
+	0,							/* U+010722 */
+	0,							/* U+010723 */
+	0,							/* U+010724 */
+	0,							/* U+010725 */
+	0,							/* U+010726 */
+	0,							/* U+010727 */
+	0,							/* U+010728 */
+	0,							/* U+010729 */
+	0,							/* U+01072A */
+	0,							/* U+01072B */
+	0,							/* U+01072C */
+	0,							/* U+01072D */
+	0,							/* U+01072E */
+	0,							/* U+01072F */
+	0,							/* U+010730 */
+	0,							/* U+010731 */
+	0,							/* U+010732 */
+	0,							/* U+010733 */
+	0,							/* U+010734 */
+	0,							/* U+010735 */
+	0,							/* U+010736 */
+	0,							/* U+010737 */
+	0,							/* U+010738 */
+	0,							/* U+010739 */
+	0,							/* U+01073A */
+	0,							/* U+01073B */
+	0,							/* U+01073C */
+	0,							/* U+01073D */
+	0,							/* U+01073E */
+	0,							/* U+01073F */
+	0,							/* U+010740 */
+	0,							/* U+010741 */
+	0,							/* U+010742 */
+	0,							/* U+010743 */
+	0,							/* U+010744 */
+	0,							/* U+010745 */
+	0,							/* U+010746 */
+	0,							/* U+010747 */
+	0,							/* U+010748 */
+	0,							/* U+010749 */
+	0,							/* U+01074A */
+	0,							/* U+01074B */
+	0,							/* U+01074C */
+	0,							/* U+01074D */
+	0,							/* U+01074E */
+	0,							/* U+01074F */
+	0,							/* U+010750 */
+	0,							/* U+010751 */
+	0,							/* U+010752 */
+	0,							/* U+010753 */
+	0,							/* U+010754 */
+	0,							/* U+010755 */
+	0,							/* U+010756 */
+	0,							/* U+010757 */
+	0,							/* U+010758 */
+	0,							/* U+010759 */
+	0,							/* U+01075A */
+	0,							/* U+01075B */
+	0,							/* U+01075C */
+	0,							/* U+01075D */
+	0,							/* U+01075E */
+	0,							/* U+01075F */
+	0,							/* U+010760 */
+	0,							/* U+010761 */
+	0,							/* U+010762 */
+	0,							/* U+010763 */
+	0,							/* U+010764 */
+	0,							/* U+010765 */
+	0,							/* U+010766 */
+	0,							/* U+010767 */
+	0,							/* U+010768 */
+	0,							/* U+010769 */
+	0,							/* U+01076A */
+	0,							/* U+01076B */
+	0,							/* U+01076C */
+	0,							/* U+01076D */
+	0,							/* U+01076E */
+	0,							/* U+01076F */
+	0,							/* U+010770 */
+	0,							/* U+010771 */
+	0,							/* U+010772 */
+	0,							/* U+010773 */
+	0,							/* U+010774 */
+	0,							/* U+010775 */
+	0,							/* U+010776 */
+	0,							/* U+010777 */
+	0,							/* U+010778 */
+	0,							/* U+010779 */
+	0,							/* U+01077A */
+	0,							/* U+01077B */
+	0,							/* U+01077C */
+	0,							/* U+01077D */
+	0,							/* U+01077E */
+	0,							/* U+01077F */
+	0,							/* U+010780 */
+	3185,						/* U+010781 */
+	3186,						/* U+010782 */
+	3187,						/* U+010783 */
+	3188,						/* U+010784 */
+	3189,						/* U+010785 */
+	0,							/* U+010786 */
+	3190,						/* U+010787 */
+	3191,						/* U+010788 */
+	3192,						/* U+010789 */
+	3193,						/* U+01078A */
+	3194,						/* U+01078B */
+	3195,						/* U+01078C */
+	3196,						/* U+01078D */
+	3197,						/* U+01078E */
+	3198,						/* U+01078F */
+	3199,						/* U+010790 */
+	3200,						/* U+010791 */
+	3201,						/* U+010792 */
+	3202,						/* U+010793 */
+	3203,						/* U+010794 */
+	1143,						/* U+010795 */
+	3204,						/* U+010796 */
+	3205,						/* U+010797 */
+	3206,						/* U+010798 */
+	3207,						/* U+010799 */
+	3208,						/* U+01079A */
+	3209,						/* U+01079B */
+	3210,						/* U+01079C */
+	3211,						/* U+01079D */
+	3212,						/* U+01079E */
+	3213,						/* U+01079F */
+	3214,						/* U+0107A0 */
+	3215,						/* U+0107A1 */
+	3216,						/* U+0107A2 */
+	3217,						/* U+0107A3 */
+	3218,						/* U+0107A4 */
+	1328,						/* U+0107A5 */
+	3219,						/* U+0107A6 */
+	3220,						/* U+0107A7 */
+	3221,						/* U+0107A8 */
+	3222,						/* U+0107A9 */
+	3223,						/* U+0107AA */
+	3224,						/* U+0107AB */
+	3225,						/* U+0107AC */
+	3226,						/* U+0107AD */
+	3227,						/* U+0107AE */
+	3228,						/* U+0107AF */
+	3229,						/* U+0107B0 */
+	0,							/* U+0107B1 */
+	3230,						/* U+0107B2 */
+	3231,						/* U+0107B3 */
+	3232,						/* U+0107B4 */
+	3233,						/* U+0107B5 */
+	3234,						/* U+0107B6 */
+	3235,						/* U+0107B7 */
+	3236,						/* U+0107B8 */
+	3237,						/* U+0107B9 */
+	3238,						/* U+0107BA */
+	0,							/* U+0107BB */
+	0,							/* U+0107BC */
+	0,							/* U+0107BD */
+	0,							/* U+0107BE */
+	0,							/* U+0107BF */
+	0,							/* U+0107C0 */
+	0,							/* U+0107C1 */
+	0,							/* U+0107C2 */
+	0,							/* U+0107C3 */
+	0,							/* U+0107C4 */
+	0,							/* U+0107C5 */
+	0,							/* U+0107C6 */
+	0,							/* U+0107C7 */
+	0,							/* U+0107C8 */
+	0,							/* U+0107C9 */
+	0,							/* U+0107CA */
+	0,							/* U+0107CB */
+	0,							/* U+0107CC */
+	0,							/* U+0107CD */
+	0,							/* U+0107CE */
+	0,							/* U+0107CF */
+	0,							/* U+0107D0 */
+	0,							/* U+0107D1 */
+	0,							/* U+0107D2 */
+	0,							/* U+0107D3 */
+	0,							/* U+0107D4 */
+	0,							/* U+0107D5 */
+	0,							/* U+0107D6 */
+	0,							/* U+0107D7 */
+	0,							/* U+0107D8 */
+	0,							/* U+0107D9 */
+	0,							/* U+0107DA */
+	0,							/* U+0107DB */
+	0,							/* U+0107DC */
+	0,							/* U+0107DD */
+	0,							/* U+0107DE */
+	0,							/* U+0107DF */
+	0,							/* U+0107E0 */
+	0,							/* U+0107E1 */
+	0,							/* U+0107E2 */
+	0,							/* U+0107E3 */
+	0,							/* U+0107E4 */
+	0,							/* U+0107E5 */
+	0,							/* U+0107E6 */
+	0,							/* U+0107E7 */
+	0,							/* U+0107E8 */
+	0,							/* U+0107E9 */
+	0,							/* U+0107EA */
+	0,							/* U+0107EB */
+	0,							/* U+0107EC */
+	0,							/* U+0107ED */
+	0,							/* U+0107EE */
+	0,							/* U+0107EF */
+	0,							/* U+0107F0 */
+	0,							/* U+0107F1 */
+	0,							/* U+0107F2 */
+	0,							/* U+0107F3 */
+	0,							/* U+0107F4 */
+	0,							/* U+0107F5 */
+	0,							/* U+0107F6 */
+	0,							/* U+0107F7 */
+	0,							/* U+0107F8 */
+	0,							/* U+0107F9 */
+	0,							/* U+0107FA */
+	0,							/* U+0107FB */
+	0,							/* U+0107FC */
+	0,							/* U+0107FD */
+	0,							/* U+0107FE */
+	0,							/* U+0107FF */
+	0,							/* U+010800 */
+	0,							/* U+010801 */
+	0,							/* U+010802 */
+	0,							/* U+010803 */
+	0,							/* U+010804 */
+	0,							/* U+010805 */
+	0,							/* U+010806 */
+	0,							/* U+010807 */
+	0,							/* U+010808 */
+	0,							/* U+010809 */
+	0,							/* U+01080A */
+	0,							/* U+01080B */
+	0,							/* U+01080C */
+	0,							/* U+01080D */
+	0,							/* U+01080E */
+	0,							/* U+01080F */
+	0,							/* U+010810 */
+	0,							/* U+010811 */
+	0,							/* U+010812 */
+	0,							/* U+010813 */
+	0,							/* U+010814 */
+	0,							/* U+010815 */
+	0,							/* U+010816 */
+	0,							/* U+010817 */
+	0,							/* U+010818 */
+	0,							/* U+010819 */
+	0,							/* U+01081A */
+	0,							/* U+01081B */
+	0,							/* U+01081C */
+	0,							/* U+01081D */
+	0,							/* U+01081E */
+	0,							/* U+01081F */
+	0,							/* U+010820 */
+	0,							/* U+010821 */
+	0,							/* U+010822 */
+	0,							/* U+010823 */
+	0,							/* U+010824 */
+	0,							/* U+010825 */
+	0,							/* U+010826 */
+	0,							/* U+010827 */
+	0,							/* U+010828 */
+	0,							/* U+010829 */
+	0,							/* U+01082A */
+	0,							/* U+01082B */
+	0,							/* U+01082C */
+	0,							/* U+01082D */
+	0,							/* U+01082E */
+	0,							/* U+01082F */
+	0,							/* U+010830 */
+	0,							/* U+010831 */
+	0,							/* U+010832 */
+	0,							/* U+010833 */
+	0,							/* U+010834 */
+	0,							/* U+010835 */
+	0,							/* U+010836 */
+	0,							/* U+010837 */
+	0,							/* U+010838 */
+	0,							/* U+010839 */
+	0,							/* U+01083A */
+	0,							/* U+01083B */
+	0,							/* U+01083C */
+	0,							/* U+01083D */
+	0,							/* U+01083E */
+	0,							/* U+01083F */
+	0,							/* U+010840 */
+	0,							/* U+010841 */
+	0,							/* U+010842 */
+	0,							/* U+010843 */
+	0,							/* U+010844 */
+	0,							/* U+010845 */
+	0,							/* U+010846 */
+	0,							/* U+010847 */
+	0,							/* U+010848 */
+	0,							/* U+010849 */
+	0,							/* U+01084A */
+	0,							/* U+01084B */
+	0,							/* U+01084C */
+	0,							/* U+01084D */
+	0,							/* U+01084E */
+	0,							/* U+01084F */
+	0,							/* U+010850 */
+	0,							/* U+010851 */
+	0,							/* U+010852 */
+	0,							/* U+010853 */
+	0,							/* U+010854 */
+	0,							/* U+010855 */
+	0,							/* U+010856 */
+	0,							/* U+010857 */
+	0,							/* U+010858 */
+	0,							/* U+010859 */
+	0,							/* U+01085A */
+	0,							/* U+01085B */
+	0,							/* U+01085C */
+	0,							/* U+01085D */
+	0,							/* U+01085E */
+	0,							/* U+01085F */
+	0,							/* U+010860 */
+	0,							/* U+010861 */
+	0,							/* U+010862 */
+	0,							/* U+010863 */
+	0,							/* U+010864 */
+	0,							/* U+010865 */
+	0,							/* U+010866 */
+	0,							/* U+010867 */
+	0,							/* U+010868 */
+	0,							/* U+010869 */
+	0,							/* U+01086A */
+	0,							/* U+01086B */
+	0,							/* U+01086C */
+	0,							/* U+01086D */
+	0,							/* U+01086E */
+	0,							/* U+01086F */
+	0,							/* U+010870 */
+	0,							/* U+010871 */
+	0,							/* U+010872 */
+	0,							/* U+010873 */
+	0,							/* U+010874 */
+	0,							/* U+010875 */
+	0,							/* U+010876 */
+	0,							/* U+010877 */
+	0,							/* U+010878 */
+	0,							/* U+010879 */
+	0,							/* U+01087A */
+	0,							/* U+01087B */
+	0,							/* U+01087C */
+	0,							/* U+01087D */
+	0,							/* U+01087E */
+	0,							/* U+01087F */
+	0,							/* U+010880 */
+	0,							/* U+010881 */
+	0,							/* U+010882 */
+	0,							/* U+010883 */
+	0,							/* U+010884 */
+	0,							/* U+010885 */
+	0,							/* U+010886 */
+	0,							/* U+010887 */
+	0,							/* U+010888 */
+	0,							/* U+010889 */
+	0,							/* U+01088A */
+	0,							/* U+01088B */
+	0,							/* U+01088C */
+	0,							/* U+01088D */
+	0,							/* U+01088E */
+	0,							/* U+01088F */
+	0,							/* U+010890 */
+	0,							/* U+010891 */
+	0,							/* U+010892 */
+	0,							/* U+010893 */
+	0,							/* U+010894 */
+	0,							/* U+010895 */
+	0,							/* U+010896 */
+	0,							/* U+010897 */
+	0,							/* U+010898 */
+	0,							/* U+010899 */
+	0,							/* U+01089A */
+	0,							/* U+01089B */
+	0,							/* U+01089C */
+	0,							/* U+01089D */
+	0,							/* U+01089E */
+	0,							/* U+01089F */
+	0,							/* U+0108A0 */
+	0,							/* U+0108A1 */
+	0,							/* U+0108A2 */
+	0,							/* U+0108A3 */
+	0,							/* U+0108A4 */
+	0,							/* U+0108A5 */
+	0,							/* U+0108A6 */
+	0,							/* U+0108A7 */
+	0,							/* U+0108A8 */
+	0,							/* U+0108A9 */
+	0,							/* U+0108AA */
+	0,							/* U+0108AB */
+	0,							/* U+0108AC */
+	0,							/* U+0108AD */
+	0,							/* U+0108AE */
+	0,							/* U+0108AF */
+	0,							/* U+0108B0 */
+	0,							/* U+0108B1 */
+	0,							/* U+0108B2 */
+	0,							/* U+0108B3 */
+	0,							/* U+0108B4 */
+	0,							/* U+0108B5 */
+	0,							/* U+0108B6 */
+	0,							/* U+0108B7 */
+	0,							/* U+0108B8 */
+	0,							/* U+0108B9 */
+	0,							/* U+0108BA */
+	0,							/* U+0108BB */
+	0,							/* U+0108BC */
+	0,							/* U+0108BD */
+	0,							/* U+0108BE */
+	0,							/* U+0108BF */
+	0,							/* U+0108C0 */
+	0,							/* U+0108C1 */
+	0,							/* U+0108C2 */
+	0,							/* U+0108C3 */
+	0,							/* U+0108C4 */
+	0,							/* U+0108C5 */
+	0,							/* U+0108C6 */
+	0,							/* U+0108C7 */
+	0,							/* U+0108C8 */
+	0,							/* U+0108C9 */
+	0,							/* U+0108CA */
+	0,							/* U+0108CB */
+	0,							/* U+0108CC */
+	0,							/* U+0108CD */
+	0,							/* U+0108CE */
+	0,							/* U+0108CF */
+	0,							/* U+0108D0 */
+	0,							/* U+0108D1 */
+	0,							/* U+0108D2 */
+	0,							/* U+0108D3 */
+	0,							/* U+0108D4 */
+	0,							/* U+0108D5 */
+	0,							/* U+0108D6 */
+	0,							/* U+0108D7 */
+	0,							/* U+0108D8 */
+	0,							/* U+0108D9 */
+	0,							/* U+0108DA */
+	0,							/* U+0108DB */
+	0,							/* U+0108DC */
+	0,							/* U+0108DD */
+	0,							/* U+0108DE */
+	0,							/* U+0108DF */
+	0,							/* U+0108E0 */
+	0,							/* U+0108E1 */
+	0,							/* U+0108E2 */
+	0,							/* U+0108E3 */
+	0,							/* U+0108E4 */
+	0,							/* U+0108E5 */
+	0,							/* U+0108E6 */
+	0,							/* U+0108E7 */
+	0,							/* U+0108E8 */
+	0,							/* U+0108E9 */
+	0,							/* U+0108EA */
+	0,							/* U+0108EB */
+	0,							/* U+0108EC */
+	0,							/* U+0108ED */
+	0,							/* U+0108EE */
+	0,							/* U+0108EF */
+	0,							/* U+0108F0 */
+	0,							/* U+0108F1 */
+	0,							/* U+0108F2 */
+	0,							/* U+0108F3 */
+	0,							/* U+0108F4 */
+	0,							/* U+0108F5 */
+	0,							/* U+0108F6 */
+	0,							/* U+0108F7 */
+	0,							/* U+0108F8 */
+	0,							/* U+0108F9 */
+	0,							/* U+0108FA */
+	0,							/* U+0108FB */
+	0,							/* U+0108FC */
+	0,							/* U+0108FD */
+	0,							/* U+0108FE */
+	0,							/* U+0108FF */
+	0,							/* U+010900 */
+	0,							/* U+010901 */
+	0,							/* U+010902 */
+	0,							/* U+010903 */
+	0,							/* U+010904 */
+	0,							/* U+010905 */
+	0,							/* U+010906 */
+	0,							/* U+010907 */
+	0,							/* U+010908 */
+	0,							/* U+010909 */
+	0,							/* U+01090A */
+	0,							/* U+01090B */
+	0,							/* U+01090C */
+	0,							/* U+01090D */
+	0,							/* U+01090E */
+	0,							/* U+01090F */
+	0,							/* U+010910 */
+	0,							/* U+010911 */
+	0,							/* U+010912 */
+	0,							/* U+010913 */
+	0,							/* U+010914 */
+	0,							/* U+010915 */
+	0,							/* U+010916 */
+	0,							/* U+010917 */
+	0,							/* U+010918 */
+	0,							/* U+010919 */
+	0,							/* U+01091A */
+	0,							/* U+01091B */
+	0,							/* U+01091C */
+	0,							/* U+01091D */
+	0,							/* U+01091E */
+	0,							/* U+01091F */
+	0,							/* U+010920 */
+	0,							/* U+010921 */
+	0,							/* U+010922 */
+	0,							/* U+010923 */
+	0,							/* U+010924 */
+	0,							/* U+010925 */
+	0,							/* U+010926 */
+	0,							/* U+010927 */
+	0,							/* U+010928 */
+	0,							/* U+010929 */
+	0,							/* U+01092A */
+	0,							/* U+01092B */
+	0,							/* U+01092C */
+	0,							/* U+01092D */
+	0,							/* U+01092E */
+	0,							/* U+01092F */
+	0,							/* U+010930 */
+	0,							/* U+010931 */
+	0,							/* U+010932 */
+	0,							/* U+010933 */
+	0,							/* U+010934 */
+	0,							/* U+010935 */
+	0,							/* U+010936 */
+	0,							/* U+010937 */
+	0,							/* U+010938 */
+	0,							/* U+010939 */
+	0,							/* U+01093A */
+	0,							/* U+01093B */
+	0,							/* U+01093C */
+	0,							/* U+01093D */
+	0,							/* U+01093E */
+	0,							/* U+01093F */
+	0,							/* U+010940 */
+	0,							/* U+010941 */
+	0,							/* U+010942 */
+	0,							/* U+010943 */
+	0,							/* U+010944 */
+	0,							/* U+010945 */
+	0,							/* U+010946 */
+	0,							/* U+010947 */
+	0,							/* U+010948 */
+	0,							/* U+010949 */
+	0,							/* U+01094A */
+	0,							/* U+01094B */
+	0,							/* U+01094C */
+	0,							/* U+01094D */
+	0,							/* U+01094E */
+	0,							/* U+01094F */
+	0,							/* U+010950 */
+	0,							/* U+010951 */
+	0,							/* U+010952 */
+	0,							/* U+010953 */
+	0,							/* U+010954 */
+	0,							/* U+010955 */
+	0,							/* U+010956 */
+	0,							/* U+010957 */
+	0,							/* U+010958 */
+	0,							/* U+010959 */
+	0,							/* U+01095A */
+	0,							/* U+01095B */
+	0,							/* U+01095C */
+	0,							/* U+01095D */
+	0,							/* U+01095E */
+	0,							/* U+01095F */
+	0,							/* U+010960 */
+	0,							/* U+010961 */
+	0,							/* U+010962 */
+	0,							/* U+010963 */
+	0,							/* U+010964 */
+	0,							/* U+010965 */
+	0,							/* U+010966 */
+	0,							/* U+010967 */
+	0,							/* U+010968 */
+	0,							/* U+010969 */
+	0,							/* U+01096A */
+	0,							/* U+01096B */
+	0,							/* U+01096C */
+	0,							/* U+01096D */
+	0,							/* U+01096E */
+	0,							/* U+01096F */
+	0,							/* U+010970 */
+	0,							/* U+010971 */
+	0,							/* U+010972 */
+	0,							/* U+010973 */
+	0,							/* U+010974 */
+	0,							/* U+010975 */
+	0,							/* U+010976 */
+	0,							/* U+010977 */
+	0,							/* U+010978 */
+	0,							/* U+010979 */
+	0,							/* U+01097A */
+	0,							/* U+01097B */
+	0,							/* U+01097C */
+	0,							/* U+01097D */
+	0,							/* U+01097E */
+	0,							/* U+01097F */
+	0,							/* U+010980 */
+	0,							/* U+010981 */
+	0,							/* U+010982 */
+	0,							/* U+010983 */
+	0,							/* U+010984 */
+	0,							/* U+010985 */
+	0,							/* U+010986 */
+	0,							/* U+010987 */
+	0,							/* U+010988 */
+	0,							/* U+010989 */
+	0,							/* U+01098A */
+	0,							/* U+01098B */
+	0,							/* U+01098C */
+	0,							/* U+01098D */
+	0,							/* U+01098E */
+	0,							/* U+01098F */
+	0,							/* U+010990 */
+	0,							/* U+010991 */
+	0,							/* U+010992 */
+	0,							/* U+010993 */
+	0,							/* U+010994 */
+	0,							/* U+010995 */
+	0,							/* U+010996 */
+	0,							/* U+010997 */
+	0,							/* U+010998 */
+	0,							/* U+010999 */
+	0,							/* U+01099A */
+	0,							/* U+01099B */
+	0,							/* U+01099C */
+	0,							/* U+01099D */
+	0,							/* U+01099E */
+	0,							/* U+01099F */
+	0,							/* U+0109A0 */
+	0,							/* U+0109A1 */
+	0,							/* U+0109A2 */
+	0,							/* U+0109A3 */
+	0,							/* U+0109A4 */
+	0,							/* U+0109A5 */
+	0,							/* U+0109A6 */
+	0,							/* U+0109A7 */
+	0,							/* U+0109A8 */
+	0,							/* U+0109A9 */
+	0,							/* U+0109AA */
+	0,							/* U+0109AB */
+	0,							/* U+0109AC */
+	0,							/* U+0109AD */
+	0,							/* U+0109AE */
+	0,							/* U+0109AF */
+	0,							/* U+0109B0 */
+	0,							/* U+0109B1 */
+	0,							/* U+0109B2 */
+	0,							/* U+0109B3 */
+	0,							/* U+0109B4 */
+	0,							/* U+0109B5 */
+	0,							/* U+0109B6 */
+	0,							/* U+0109B7 */
+	0,							/* U+0109B8 */
+	0,							/* U+0109B9 */
+	0,							/* U+0109BA */
+	0,							/* U+0109BB */
+	0,							/* U+0109BC */
+	0,							/* U+0109BD */
+	0,							/* U+0109BE */
+	0,							/* U+0109BF */
+	0,							/* U+0109C0 */
+	0,							/* U+0109C1 */
+	0,							/* U+0109C2 */
+	0,							/* U+0109C3 */
+	0,							/* U+0109C4 */
+	0,							/* U+0109C5 */
+	0,							/* U+0109C6 */
+	0,							/* U+0109C7 */
+	0,							/* U+0109C8 */
+	0,							/* U+0109C9 */
+	0,							/* U+0109CA */
+	0,							/* U+0109CB */
+	0,							/* U+0109CC */
+	0,							/* U+0109CD */
+	0,							/* U+0109CE */
+	0,							/* U+0109CF */
+	0,							/* U+0109D0 */
+	0,							/* U+0109D1 */
+	0,							/* U+0109D2 */
+	0,							/* U+0109D3 */
+	0,							/* U+0109D4 */
+	0,							/* U+0109D5 */
+	0,							/* U+0109D6 */
+	0,							/* U+0109D7 */
+	0,							/* U+0109D8 */
+	0,							/* U+0109D9 */
+	0,							/* U+0109DA */
+	0,							/* U+0109DB */
+	0,							/* U+0109DC */
+	0,							/* U+0109DD */
+	0,							/* U+0109DE */
+	0,							/* U+0109DF */
+	0,							/* U+0109E0 */
+	0,							/* U+0109E1 */
+	0,							/* U+0109E2 */
+	0,							/* U+0109E3 */
+	0,							/* U+0109E4 */
+	0,							/* U+0109E5 */
+	0,							/* U+0109E6 */
+	0,							/* U+0109E7 */
+	0,							/* U+0109E8 */
+	0,							/* U+0109E9 */
+	0,							/* U+0109EA */
+	0,							/* U+0109EB */
+	0,							/* U+0109EC */
+	0,							/* U+0109ED */
+	0,							/* U+0109EE */
+	0,							/* U+0109EF */
+	0,							/* U+0109F0 */
+	0,							/* U+0109F1 */
+	0,							/* U+0109F2 */
+	0,							/* U+0109F3 */
+	0,							/* U+0109F4 */
+	0,							/* U+0109F5 */
+	0,							/* U+0109F6 */
+	0,							/* U+0109F7 */
+	0,							/* U+0109F8 */
+	0,							/* U+0109F9 */
+	0,							/* U+0109FA */
+	0,							/* U+0109FB */
+	0,							/* U+0109FC */
+	0,							/* U+0109FD */
+	0,							/* U+0109FE */
+	0,							/* U+0109FF */
+	0,							/* U+010A00 */
+	0,							/* U+010A01 */
+	0,							/* U+010A02 */
+	0,							/* U+010A03 */
+	0,							/* U+010A04 */
+	0,							/* U+010A05 */
+	0,							/* U+010A06 */
+	0,							/* U+010A07 */
+	0,							/* U+010A08 */
+	0,							/* U+010A09 */
+	0,							/* U+010A0A */
+	0,							/* U+010A0B */
+	0,							/* U+010A0C */
+	306,						/* U+010A0D */
+	0,							/* U+010A0E */
+	304,						/* U+010A0F */
+	0,							/* U+010A10 */
+	0,							/* U+010A11 */
+	0,							/* U+010A12 */
+	0,							/* U+010A13 */
+	0,							/* U+010A14 */
+	0,							/* U+010A15 */
+	0,							/* U+010A16 */
+	0,							/* U+010A17 */
+	0,							/* U+010A18 */
+	0,							/* U+010A19 */
+	0,							/* U+010A1A */
+	0,							/* U+010A1B */
+	0,							/* U+010A1C */
+	0,							/* U+010A1D */
+	0,							/* U+010A1E */
+	0,							/* U+010A1F */
+	0,							/* U+010A20 */
+	0,							/* U+010A21 */
+	0,							/* U+010A22 */
+	0,							/* U+010A23 */
+	0,							/* U+010A24 */
+	0,							/* U+010A25 */
+	0,							/* U+010A26 */
+	0,							/* U+010A27 */
+	0,							/* U+010A28 */
+	0,							/* U+010A29 */
+	0,							/* U+010A2A */
+	0,							/* U+010A2B */
+	0,							/* U+010A2C */
+	0,							/* U+010A2D */
+	0,							/* U+010A2E */
+	0,							/* U+010A2F */
+	0,							/* U+010A30 */
+	0,							/* U+010A31 */
+	0,							/* U+010A32 */
+	0,							/* U+010A33 */
+	0,							/* U+010A34 */
+	0,							/* U+010A35 */
+	0,							/* U+010A36 */
+	0,							/* U+010A37 */
+	304,						/* U+010A38 */
+	309,						/* U+010A39 */
+	306,						/* U+010A3A */
+	0,							/* U+010A3B */
+	0,							/* U+010A3C */
+	0,							/* U+010A3D */
+	0,							/* U+010A3E */
+	452,						/* U+010A3F */
+	0,							/* U+010A40 */
+	0,							/* U+010A41 */
+	0,							/* U+010A42 */
+	0,							/* U+010A43 */
+	0,							/* U+010A44 */
+	0,							/* U+010A45 */
+	0,							/* U+010A46 */
+	0,							/* U+010A47 */
+	0,							/* U+010A48 */
+	0,							/* U+010A49 */
+	0,							/* U+010A4A */
+	0,							/* U+010A4B */
+	0,							/* U+010A4C */
+	0,							/* U+010A4D */
+	0,							/* U+010A4E */
+	0,							/* U+010A4F */
+	0,							/* U+010A50 */
+	0,							/* U+010A51 */
+	0,							/* U+010A52 */
+	0,							/* U+010A53 */
+	0,							/* U+010A54 */
+	0,							/* U+010A55 */
+	0,							/* U+010A56 */
+	0,							/* U+010A57 */
+	0,							/* U+010A58 */
+	0,							/* U+010A59 */
+	0,							/* U+010A5A */
+	0,							/* U+010A5B */
+	0,							/* U+010A5C */
+	0,							/* U+010A5D */
+	0,							/* U+010A5E */
+	0,							/* U+010A5F */
+	0,							/* U+010A60 */
+	0,							/* U+010A61 */
+	0,							/* U+010A62 */
+	0,							/* U+010A63 */
+	0,							/* U+010A64 */
+	0,							/* U+010A65 */
+	0,							/* U+010A66 */
+	0,							/* U+010A67 */
+	0,							/* U+010A68 */
+	0,							/* U+010A69 */
+	0,							/* U+010A6A */
+	0,							/* U+010A6B */
+	0,							/* U+010A6C */
+	0,							/* U+010A6D */
+	0,							/* U+010A6E */
+	0,							/* U+010A6F */
+	0,							/* U+010A70 */
+	0,							/* U+010A71 */
+	0,							/* U+010A72 */
+	0,							/* U+010A73 */
+	0,							/* U+010A74 */
+	0,							/* U+010A75 */
+	0,							/* U+010A76 */
+	0,							/* U+010A77 */
+	0,							/* U+010A78 */
+	0,							/* U+010A79 */
+	0,							/* U+010A7A */
+	0,							/* U+010A7B */
+	0,							/* U+010A7C */
+	0,							/* U+010A7D */
+	0,							/* U+010A7E */
+	0,							/* U+010A7F */
+	0,							/* U+010A80 */
+	0,							/* U+010A81 */
+	0,							/* U+010A82 */
+	0,							/* U+010A83 */
+	0,							/* U+010A84 */
+	0,							/* U+010A85 */
+	0,							/* U+010A86 */
+	0,							/* U+010A87 */
+	0,							/* U+010A88 */
+	0,							/* U+010A89 */
+	0,							/* U+010A8A */
+	0,							/* U+010A8B */
+	0,							/* U+010A8C */
+	0,							/* U+010A8D */
+	0,							/* U+010A8E */
+	0,							/* U+010A8F */
+	0,							/* U+010A90 */
+	0,							/* U+010A91 */
+	0,							/* U+010A92 */
+	0,							/* U+010A93 */
+	0,							/* U+010A94 */
+	0,							/* U+010A95 */
+	0,							/* U+010A96 */
+	0,							/* U+010A97 */
+	0,							/* U+010A98 */
+	0,							/* U+010A99 */
+	0,							/* U+010A9A */
+	0,							/* U+010A9B */
+	0,							/* U+010A9C */
+	0,							/* U+010A9D */
+	0,							/* U+010A9E */
+	0,							/* U+010A9F */
+	0,							/* U+010AA0 */
+	0,							/* U+010AA1 */
+	0,							/* U+010AA2 */
+	0,							/* U+010AA3 */
+	0,							/* U+010AA4 */
+	0,							/* U+010AA5 */
+	0,							/* U+010AA6 */
+	0,							/* U+010AA7 */
+	0,							/* U+010AA8 */
+	0,							/* U+010AA9 */
+	0,							/* U+010AAA */
+	0,							/* U+010AAB */
+	0,							/* U+010AAC */
+	0,							/* U+010AAD */
+	0,							/* U+010AAE */
+	0,							/* U+010AAF */
+	0,							/* U+010AB0 */
+	0,							/* U+010AB1 */
+	0,							/* U+010AB2 */
+	0,							/* U+010AB3 */
+	0,							/* U+010AB4 */
+	0,							/* U+010AB5 */
+	0,							/* U+010AB6 */
+	0,							/* U+010AB7 */
+	0,							/* U+010AB8 */
+	0,							/* U+010AB9 */
+	0,							/* U+010ABA */
+	0,							/* U+010ABB */
+	0,							/* U+010ABC */
+	0,							/* U+010ABD */
+	0,							/* U+010ABE */
+	0,							/* U+010ABF */
+	0,							/* U+010AC0 */
+	0,							/* U+010AC1 */
+	0,							/* U+010AC2 */
+	0,							/* U+010AC3 */
+	0,							/* U+010AC4 */
+	0,							/* U+010AC5 */
+	0,							/* U+010AC6 */
+	0,							/* U+010AC7 */
+	0,							/* U+010AC8 */
+	0,							/* U+010AC9 */
+	0,							/* U+010ACA */
+	0,							/* U+010ACB */
+	0,							/* U+010ACC */
+	0,							/* U+010ACD */
+	0,							/* U+010ACE */
+	0,							/* U+010ACF */
+	0,							/* U+010AD0 */
+	0,							/* U+010AD1 */
+	0,							/* U+010AD2 */
+	0,							/* U+010AD3 */
+	0,							/* U+010AD4 */
+	0,							/* U+010AD5 */
+	0,							/* U+010AD6 */
+	0,							/* U+010AD7 */
+	0,							/* U+010AD8 */
+	0,							/* U+010AD9 */
+	0,							/* U+010ADA */
+	0,							/* U+010ADB */
+	0,							/* U+010ADC */
+	0,							/* U+010ADD */
+	0,							/* U+010ADE */
+	0,							/* U+010ADF */
+	0,							/* U+010AE0 */
+	0,							/* U+010AE1 */
+	0,							/* U+010AE2 */
+	0,							/* U+010AE3 */
+	0,							/* U+010AE4 */
+	304,						/* U+010AE5 */
+	306,						/* U+010AE6 */
+	0,							/* U+010AE7 */
+	0,							/* U+010AE8 */
+	0,							/* U+010AE9 */
+	0,							/* U+010AEA */
+	0,							/* U+010AEB */
+	0,							/* U+010AEC */
+	0,							/* U+010AED */
+	0,							/* U+010AEE */
+	0,							/* U+010AEF */
+	0,							/* U+010AF0 */
+	0,							/* U+010AF1 */
+	0,							/* U+010AF2 */
+	0,							/* U+010AF3 */
+	0,							/* U+010AF4 */
+	0,							/* U+010AF5 */
+	0,							/* U+010AF6 */
+	0,							/* U+010AF7 */
+	0,							/* U+010AF8 */
+	0,							/* U+010AF9 */
+	0,							/* U+010AFA */
+	0,							/* U+010AFB */
+	0,							/* U+010AFC */
+	0,							/* U+010AFD */
+	0,							/* U+010AFE */
+	0,							/* U+010AFF */
+	0,							/* U+010B00 */
+	0,							/* U+010B01 */
+	0,							/* U+010B02 */
+	0,							/* U+010B03 */
+	0,							/* U+010B04 */
+	0,							/* U+010B05 */
+	0,							/* U+010B06 */
+	0,							/* U+010B07 */
+	0,							/* U+010B08 */
+	0,							/* U+010B09 */
+	0,							/* U+010B0A */
+	0,							/* U+010B0B */
+	0,							/* U+010B0C */
+	0,							/* U+010B0D */
+	0,							/* U+010B0E */
+	0,							/* U+010B0F */
+	0,							/* U+010B10 */
+	0,							/* U+010B11 */
+	0,							/* U+010B12 */
+	0,							/* U+010B13 */
+	0,							/* U+010B14 */
+	0,							/* U+010B15 */
+	0,							/* U+010B16 */
+	0,							/* U+010B17 */
+	0,							/* U+010B18 */
+	0,							/* U+010B19 */
+	0,							/* U+010B1A */
+	0,							/* U+010B1B */
+	0,							/* U+010B1C */
+	0,							/* U+010B1D */
+	0,							/* U+010B1E */
+	0,							/* U+010B1F */
+	0,							/* U+010B20 */
+	0,							/* U+010B21 */
+	0,							/* U+010B22 */
+	0,							/* U+010B23 */
+	0,							/* U+010B24 */
+	0,							/* U+010B25 */
+	0,							/* U+010B26 */
+	0,							/* U+010B27 */
+	0,							/* U+010B28 */
+	0,							/* U+010B29 */
+	0,							/* U+010B2A */
+	0,							/* U+010B2B */
+	0,							/* U+010B2C */
+	0,							/* U+010B2D */
+	0,							/* U+010B2E */
+	0,							/* U+010B2F */
+	0,							/* U+010B30 */
+	0,							/* U+010B31 */
+	0,							/* U+010B32 */
+	0,							/* U+010B33 */
+	0,							/* U+010B34 */
+	0,							/* U+010B35 */
+	0,							/* U+010B36 */
+	0,							/* U+010B37 */
+	0,							/* U+010B38 */
+	0,							/* U+010B39 */
+	0,							/* U+010B3A */
+	0,							/* U+010B3B */
+	0,							/* U+010B3C */
+	0,							/* U+010B3D */
+	0,							/* U+010B3E */
+	0,							/* U+010B3F */
+	0,							/* U+010B40 */
+	0,							/* U+010B41 */
+	0,							/* U+010B42 */
+	0,							/* U+010B43 */
+	0,							/* U+010B44 */
+	0,							/* U+010B45 */
+	0,							/* U+010B46 */
+	0,							/* U+010B47 */
+	0,							/* U+010B48 */
+	0,							/* U+010B49 */
+	0,							/* U+010B4A */
+	0,							/* U+010B4B */
+	0,							/* U+010B4C */
+	0,							/* U+010B4D */
+	0,							/* U+010B4E */
+	0,							/* U+010B4F */
+	0,							/* U+010B50 */
+	0,							/* U+010B51 */
+	0,							/* U+010B52 */
+	0,							/* U+010B53 */
+	0,							/* U+010B54 */
+	0,							/* U+010B55 */
+	0,							/* U+010B56 */
+	0,							/* U+010B57 */
+	0,							/* U+010B58 */
+	0,							/* U+010B59 */
+	0,							/* U+010B5A */
+	0,							/* U+010B5B */
+	0,							/* U+010B5C */
+	0,							/* U+010B5D */
+	0,							/* U+010B5E */
+	0,							/* U+010B5F */
+	0,							/* U+010B60 */
+	0,							/* U+010B61 */
+	0,							/* U+010B62 */
+	0,							/* U+010B63 */
+	0,							/* U+010B64 */
+	0,							/* U+010B65 */
+	0,							/* U+010B66 */
+	0,							/* U+010B67 */
+	0,							/* U+010B68 */
+	0,							/* U+010B69 */
+	0,							/* U+010B6A */
+	0,							/* U+010B6B */
+	0,							/* U+010B6C */
+	0,							/* U+010B6D */
+	0,							/* U+010B6E */
+	0,							/* U+010B6F */
+	0,							/* U+010B70 */
+	0,							/* U+010B71 */
+	0,							/* U+010B72 */
+	0,							/* U+010B73 */
+	0,							/* U+010B74 */
+	0,							/* U+010B75 */
+	0,							/* U+010B76 */
+	0,							/* U+010B77 */
+	0,							/* U+010B78 */
+	0,							/* U+010B79 */
+	0,							/* U+010B7A */
+	0,							/* U+010B7B */
+	0,							/* U+010B7C */
+	0,							/* U+010B7D */
+	0,							/* U+010B7E */
+	0,							/* U+010B7F */
+	0,							/* U+010B80 */
+	0,							/* U+010B81 */
+	0,							/* U+010B82 */
+	0,							/* U+010B83 */
+	0,							/* U+010B84 */
+	0,							/* U+010B85 */
+	0,							/* U+010B86 */
+	0,							/* U+010B87 */
+	0,							/* U+010B88 */
+	0,							/* U+010B89 */
+	0,							/* U+010B8A */
+	0,							/* U+010B8B */
+	0,							/* U+010B8C */
+	0,							/* U+010B8D */
+	0,							/* U+010B8E */
+	0,							/* U+010B8F */
+	0,							/* U+010B90 */
+	0,							/* U+010B91 */
+	0,							/* U+010B92 */
+	0,							/* U+010B93 */
+	0,							/* U+010B94 */
+	0,							/* U+010B95 */
+	0,							/* U+010B96 */
+	0,							/* U+010B97 */
+	0,							/* U+010B98 */
+	0,							/* U+010B99 */
+	0,							/* U+010B9A */
+	0,							/* U+010B9B */
+	0,							/* U+010B9C */
+	0,							/* U+010B9D */
+	0,							/* U+010B9E */
+	0,							/* U+010B9F */
+	0,							/* U+010BA0 */
+	0,							/* U+010BA1 */
+	0,							/* U+010BA2 */
+	0,							/* U+010BA3 */
+	0,							/* U+010BA4 */
+	0,							/* U+010BA5 */
+	0,							/* U+010BA6 */
+	0,							/* U+010BA7 */
+	0,							/* U+010BA8 */
+	0,							/* U+010BA9 */
+	0,							/* U+010BAA */
+	0,							/* U+010BAB */
+	0,							/* U+010BAC */
+	0,							/* U+010BAD */
+	0,							/* U+010BAE */
+	0,							/* U+010BAF */
+	0,							/* U+010BB0 */
+	0,							/* U+010BB1 */
+	0,							/* U+010BB2 */
+	0,							/* U+010BB3 */
+	0,							/* U+010BB4 */
+	0,							/* U+010BB5 */
+	0,							/* U+010BB6 */
+	0,							/* U+010BB7 */
+	0,							/* U+010BB8 */
+	0,							/* U+010BB9 */
+	0,							/* U+010BBA */
+	0,							/* U+010BBB */
+	0,							/* U+010BBC */
+	0,							/* U+010BBD */
+	0,							/* U+010BBE */
+	0,							/* U+010BBF */
+	0,							/* U+010BC0 */
+	0,							/* U+010BC1 */
+	0,							/* U+010BC2 */
+	0,							/* U+010BC3 */
+	0,							/* U+010BC4 */
+	0,							/* U+010BC5 */
+	0,							/* U+010BC6 */
+	0,							/* U+010BC7 */
+	0,							/* U+010BC8 */
+	0,							/* U+010BC9 */
+	0,							/* U+010BCA */
+	0,							/* U+010BCB */
+	0,							/* U+010BCC */
+	0,							/* U+010BCD */
+	0,							/* U+010BCE */
+	0,							/* U+010BCF */
+	0,							/* U+010BD0 */
+	0,							/* U+010BD1 */
+	0,							/* U+010BD2 */
+	0,							/* U+010BD3 */
+	0,							/* U+010BD4 */
+	0,							/* U+010BD5 */
+	0,							/* U+010BD6 */
+	0,							/* U+010BD7 */
+	0,							/* U+010BD8 */
+	0,							/* U+010BD9 */
+	0,							/* U+010BDA */
+	0,							/* U+010BDB */
+	0,							/* U+010BDC */
+	0,							/* U+010BDD */
+	0,							/* U+010BDE */
+	0,							/* U+010BDF */
+	0,							/* U+010BE0 */
+	0,							/* U+010BE1 */
+	0,							/* U+010BE2 */
+	0,							/* U+010BE3 */
+	0,							/* U+010BE4 */
+	0,							/* U+010BE5 */
+	0,							/* U+010BE6 */
+	0,							/* U+010BE7 */
+	0,							/* U+010BE8 */
+	0,							/* U+010BE9 */
+	0,							/* U+010BEA */
+	0,							/* U+010BEB */
+	0,							/* U+010BEC */
+	0,							/* U+010BED */
+	0,							/* U+010BEE */
+	0,							/* U+010BEF */
+	0,							/* U+010BF0 */
+	0,							/* U+010BF1 */
+	0,							/* U+010BF2 */
+	0,							/* U+010BF3 */
+	0,							/* U+010BF4 */
+	0,							/* U+010BF5 */
+	0,							/* U+010BF6 */
+	0,							/* U+010BF7 */
+	0,							/* U+010BF8 */
+	0,							/* U+010BF9 */
+	0,							/* U+010BFA */
+	0,							/* U+010BFB */
+	0,							/* U+010BFC */
+	0,							/* U+010BFD */
+	0,							/* U+010BFE */
+	0,							/* U+010BFF */
+	0,							/* U+010C00 */
+	0,							/* U+010C01 */
+	0,							/* U+010C02 */
+	0,							/* U+010C03 */
+	0,							/* U+010C04 */
+	0,							/* U+010C05 */
+	0,							/* U+010C06 */
+	0,							/* U+010C07 */
+	0,							/* U+010C08 */
+	0,							/* U+010C09 */
+	0,							/* U+010C0A */
+	0,							/* U+010C0B */
+	0,							/* U+010C0C */
+	0,							/* U+010C0D */
+	0,							/* U+010C0E */
+	0,							/* U+010C0F */
+	0,							/* U+010C10 */
+	0,							/* U+010C11 */
+	0,							/* U+010C12 */
+	0,							/* U+010C13 */
+	0,							/* U+010C14 */
+	0,							/* U+010C15 */
+	0,							/* U+010C16 */
+	0,							/* U+010C17 */
+	0,							/* U+010C18 */
+	0,							/* U+010C19 */
+	0,							/* U+010C1A */
+	0,							/* U+010C1B */
+	0,							/* U+010C1C */
+	0,							/* U+010C1D */
+	0,							/* U+010C1E */
+	0,							/* U+010C1F */
+	0,							/* U+010C20 */
+	0,							/* U+010C21 */
+	0,							/* U+010C22 */
+	0,							/* U+010C23 */
+	0,							/* U+010C24 */
+	0,							/* U+010C25 */
+	0,							/* U+010C26 */
+	0,							/* U+010C27 */
+	0,							/* U+010C28 */
+	0,							/* U+010C29 */
+	0,							/* U+010C2A */
+	0,							/* U+010C2B */
+	0,							/* U+010C2C */
+	0,							/* U+010C2D */
+	0,							/* U+010C2E */
+	0,							/* U+010C2F */
+	0,							/* U+010C30 */
+	0,							/* U+010C31 */
+	0,							/* U+010C32 */
+	0,							/* U+010C33 */
+	0,							/* U+010C34 */
+	0,							/* U+010C35 */
+	0,							/* U+010C36 */
+	0,							/* U+010C37 */
+	0,							/* U+010C38 */
+	0,							/* U+010C39 */
+	0,							/* U+010C3A */
+	0,							/* U+010C3B */
+	0,							/* U+010C3C */
+	0,							/* U+010C3D */
+	0,							/* U+010C3E */
+	0,							/* U+010C3F */
+	0,							/* U+010C40 */
+	0,							/* U+010C41 */
+	0,							/* U+010C42 */
+	0,							/* U+010C43 */
+	0,							/* U+010C44 */
+	0,							/* U+010C45 */
+	0,							/* U+010C46 */
+	0,							/* U+010C47 */
+	0,							/* U+010C48 */
+	0,							/* U+010C49 */
+	0,							/* U+010C4A */
+	0,							/* U+010C4B */
+	0,							/* U+010C4C */
+	0,							/* U+010C4D */
+	0,							/* U+010C4E */
+	0,							/* U+010C4F */
+	0,							/* U+010C50 */
+	0,							/* U+010C51 */
+	0,							/* U+010C52 */
+	0,							/* U+010C53 */
+	0,							/* U+010C54 */
+	0,							/* U+010C55 */
+	0,							/* U+010C56 */
+	0,							/* U+010C57 */
+	0,							/* U+010C58 */
+	0,							/* U+010C59 */
+	0,							/* U+010C5A */
+	0,							/* U+010C5B */
+	0,							/* U+010C5C */
+	0,							/* U+010C5D */
+	0,							/* U+010C5E */
+	0,							/* U+010C5F */
+	0,							/* U+010C60 */
+	0,							/* U+010C61 */
+	0,							/* U+010C62 */
+	0,							/* U+010C63 */
+	0,							/* U+010C64 */
+	0,							/* U+010C65 */
+	0,							/* U+010C66 */
+	0,							/* U+010C67 */
+	0,							/* U+010C68 */
+	0,							/* U+010C69 */
+	0,							/* U+010C6A */
+	0,							/* U+010C6B */
+	0,							/* U+010C6C */
+	0,							/* U+010C6D */
+	0,							/* U+010C6E */
+	0,							/* U+010C6F */
+	0,							/* U+010C70 */
+	0,							/* U+010C71 */
+	0,							/* U+010C72 */
+	0,							/* U+010C73 */
+	0,							/* U+010C74 */
+	0,							/* U+010C75 */
+	0,							/* U+010C76 */
+	0,							/* U+010C77 */
+	0,							/* U+010C78 */
+	0,							/* U+010C79 */
+	0,							/* U+010C7A */
+	0,							/* U+010C7B */
+	0,							/* U+010C7C */
+	0,							/* U+010C7D */
+	0,							/* U+010C7E */
+	0,							/* U+010C7F */
+	0,							/* U+010C80 */
+	0,							/* U+010C81 */
+	0,							/* U+010C82 */
+	0,							/* U+010C83 */
+	0,							/* U+010C84 */
+	0,							/* U+010C85 */
+	0,							/* U+010C86 */
+	0,							/* U+010C87 */
+	0,							/* U+010C88 */
+	0,							/* U+010C89 */
+	0,							/* U+010C8A */
+	0,							/* U+010C8B */
+	0,							/* U+010C8C */
+	0,							/* U+010C8D */
+	0,							/* U+010C8E */
+	0,							/* U+010C8F */
+	0,							/* U+010C90 */
+	0,							/* U+010C91 */
+	0,							/* U+010C92 */
+	0,							/* U+010C93 */
+	0,							/* U+010C94 */
+	0,							/* U+010C95 */
+	0,							/* U+010C96 */
+	0,							/* U+010C97 */
+	0,							/* U+010C98 */
+	0,							/* U+010C99 */
+	0,							/* U+010C9A */
+	0,							/* U+010C9B */
+	0,							/* U+010C9C */
+	0,							/* U+010C9D */
+	0,							/* U+010C9E */
+	0,							/* U+010C9F */
+	0,							/* U+010CA0 */
+	0,							/* U+010CA1 */
+	0,							/* U+010CA2 */
+	0,							/* U+010CA3 */
+	0,							/* U+010CA4 */
+	0,							/* U+010CA5 */
+	0,							/* U+010CA6 */
+	0,							/* U+010CA7 */
+	0,							/* U+010CA8 */
+	0,							/* U+010CA9 */
+	0,							/* U+010CAA */
+	0,							/* U+010CAB */
+	0,							/* U+010CAC */
+	0,							/* U+010CAD */
+	0,							/* U+010CAE */
+	0,							/* U+010CAF */
+	0,							/* U+010CB0 */
+	0,							/* U+010CB1 */
+	0,							/* U+010CB2 */
+	0,							/* U+010CB3 */
+	0,							/* U+010CB4 */
+	0,							/* U+010CB5 */
+	0,							/* U+010CB6 */
+	0,							/* U+010CB7 */
+	0,							/* U+010CB8 */
+	0,							/* U+010CB9 */
+	0,							/* U+010CBA */
+	0,							/* U+010CBB */
+	0,							/* U+010CBC */
+	0,							/* U+010CBD */
+	0,							/* U+010CBE */
+	0,							/* U+010CBF */
+	0,							/* U+010CC0 */
+	0,							/* U+010CC1 */
+	0,							/* U+010CC2 */
+	0,							/* U+010CC3 */
+	0,							/* U+010CC4 */
+	0,							/* U+010CC5 */
+	0,							/* U+010CC6 */
+	0,							/* U+010CC7 */
+	0,							/* U+010CC8 */
+	0,							/* U+010CC9 */
+	0,							/* U+010CCA */
+	0,							/* U+010CCB */
+	0,							/* U+010CCC */
+	0,							/* U+010CCD */
+	0,							/* U+010CCE */
+	0,							/* U+010CCF */
+	0,							/* U+010CD0 */
+	0,							/* U+010CD1 */
+	0,							/* U+010CD2 */
+	0,							/* U+010CD3 */
+	0,							/* U+010CD4 */
+	0,							/* U+010CD5 */
+	0,							/* U+010CD6 */
+	0,							/* U+010CD7 */
+	0,							/* U+010CD8 */
+	0,							/* U+010CD9 */
+	0,							/* U+010CDA */
+	0,							/* U+010CDB */
+	0,							/* U+010CDC */
+	0,							/* U+010CDD */
+	0,							/* U+010CDE */
+	0,							/* U+010CDF */
+	0,							/* U+010CE0 */
+	0,							/* U+010CE1 */
+	0,							/* U+010CE2 */
+	0,							/* U+010CE3 */
+	0,							/* U+010CE4 */
+	0,							/* U+010CE5 */
+	0,							/* U+010CE6 */
+	0,							/* U+010CE7 */
+	0,							/* U+010CE8 */
+	0,							/* U+010CE9 */
+	0,							/* U+010CEA */
+	0,							/* U+010CEB */
+	0,							/* U+010CEC */
+	0,							/* U+010CED */
+	0,							/* U+010CEE */
+	0,							/* U+010CEF */
+	0,							/* U+010CF0 */
+	0,							/* U+010CF1 */
+	0,							/* U+010CF2 */
+	0,							/* U+010CF3 */
+	0,							/* U+010CF4 */
+	0,							/* U+010CF5 */
+	0,							/* U+010CF6 */
+	0,							/* U+010CF7 */
+	0,							/* U+010CF8 */
+	0,							/* U+010CF9 */
+	0,							/* U+010CFA */
+	0,							/* U+010CFB */
+	0,							/* U+010CFC */
+	0,							/* U+010CFD */
+	0,							/* U+010CFE */
+	0,							/* U+010CFF */
+	0,							/* U+010D00 */
+	0,							/* U+010D01 */
+	0,							/* U+010D02 */
+	0,							/* U+010D03 */
+	0,							/* U+010D04 */
+	0,							/* U+010D05 */
+	0,							/* U+010D06 */
+	0,							/* U+010D07 */
+	0,							/* U+010D08 */
+	0,							/* U+010D09 */
+	0,							/* U+010D0A */
+	0,							/* U+010D0B */
+	0,							/* U+010D0C */
+	0,							/* U+010D0D */
+	0,							/* U+010D0E */
+	0,							/* U+010D0F */
+	0,							/* U+010D10 */
+	0,							/* U+010D11 */
+	0,							/* U+010D12 */
+	0,							/* U+010D13 */
+	0,							/* U+010D14 */
+	0,							/* U+010D15 */
+	0,							/* U+010D16 */
+	0,							/* U+010D17 */
+	0,							/* U+010D18 */
+	0,							/* U+010D19 */
+	0,							/* U+010D1A */
+	0,							/* U+010D1B */
+	0,							/* U+010D1C */
+	0,							/* U+010D1D */
+	0,							/* U+010D1E */
+	0,							/* U+010D1F */
+	0,							/* U+010D20 */
+	0,							/* U+010D21 */
+	0,							/* U+010D22 */
+	0,							/* U+010D23 */
+	304,						/* U+010D24 */
+	304,						/* U+010D25 */
+	304,						/* U+010D26 */
+	304,						/* U+010D27 */
+	0,							/* U+010D28 */
+	0,							/* U+010D29 */
+	0,							/* U+010D2A */
+	0,							/* U+010D2B */
+	0,							/* U+010D2C */
+	0,							/* U+010D2D */
+	0,							/* U+010D2E */
+	0,							/* U+010D2F */
+	0,							/* U+010D30 */
+	0,							/* U+010D31 */
+	0,							/* U+010D32 */
+	0,							/* U+010D33 */
+	0,							/* U+010D34 */
+	0,							/* U+010D35 */
+	0,							/* U+010D36 */
+	0,							/* U+010D37 */
+	0,							/* U+010D38 */
+	0,							/* U+010D39 */
+	0,							/* U+010D3A */
+	0,							/* U+010D3B */
+	0,							/* U+010D3C */
+	0,							/* U+010D3D */
+	0,							/* U+010D3E */
+	0,							/* U+010D3F */
+	0,							/* U+010D40 */
+	0,							/* U+010D41 */
+	0,							/* U+010D42 */
+	0,							/* U+010D43 */
+	0,							/* U+010D44 */
+	0,							/* U+010D45 */
+	0,							/* U+010D46 */
+	0,							/* U+010D47 */
+	0,							/* U+010D48 */
+	0,							/* U+010D49 */
+	0,							/* U+010D4A */
+	0,							/* U+010D4B */
+	0,							/* U+010D4C */
+	0,							/* U+010D4D */
+	0,							/* U+010D4E */
+	0,							/* U+010D4F */
+	0,							/* U+010D50 */
+	0,							/* U+010D51 */
+	0,							/* U+010D52 */
+	0,							/* U+010D53 */
+	0,							/* U+010D54 */
+	0,							/* U+010D55 */
+	0,							/* U+010D56 */
+	0,							/* U+010D57 */
+	0,							/* U+010D58 */
+	0,							/* U+010D59 */
+	0,							/* U+010D5A */
+	0,							/* U+010D5B */
+	0,							/* U+010D5C */
+	0,							/* U+010D5D */
+	0,							/* U+010D5E */
+	0,							/* U+010D5F */
+	0,							/* U+010D60 */
+	0,							/* U+010D61 */
+	0,							/* U+010D62 */
+	0,							/* U+010D63 */
+	0,							/* U+010D64 */
+	0,							/* U+010D65 */
+	0,							/* U+010D66 */
+	0,							/* U+010D67 */
+	0,							/* U+010D68 */
+	304,						/* U+010D69 */
+	304,						/* U+010D6A */
+	304,						/* U+010D6B */
+	304,						/* U+010D6C */
+	304,						/* U+010D6D */
+	0,							/* U+010D6E */
+	0,							/* U+010D6F */
+	0,							/* U+010D70 */
+	0,							/* U+010D71 */
+	0,							/* U+010D72 */
+	0,							/* U+010D73 */
+	0,							/* U+010D74 */
+	0,							/* U+010D75 */
+	0,							/* U+010D76 */
+	0,							/* U+010D77 */
+	0,							/* U+010D78 */
+	0,							/* U+010D79 */
+	0,							/* U+010D7A */
+	0,							/* U+010D7B */
+	0,							/* U+010D7C */
+	0,							/* U+010D7D */
+	0,							/* U+010D7E */
+	0,							/* U+010D7F */
+	0,							/* U+010D80 */
+	0,							/* U+010D81 */
+	0,							/* U+010D82 */
+	0,							/* U+010D83 */
+	0,							/* U+010D84 */
+	0,							/* U+010D85 */
+	0,							/* U+010D86 */
+	0,							/* U+010D87 */
+	0,							/* U+010D88 */
+	0,							/* U+010D89 */
+	0,							/* U+010D8A */
+	0,							/* U+010D8B */
+	0,							/* U+010D8C */
+	0,							/* U+010D8D */
+	0,							/* U+010D8E */
+	0,							/* U+010D8F */
+	0,							/* U+010D90 */
+	0,							/* U+010D91 */
+	0,							/* U+010D92 */
+	0,							/* U+010D93 */
+	0,							/* U+010D94 */
+	0,							/* U+010D95 */
+	0,							/* U+010D96 */
+	0,							/* U+010D97 */
+	0,							/* U+010D98 */
+	0,							/* U+010D99 */
+	0,							/* U+010D9A */
+	0,							/* U+010D9B */
+	0,							/* U+010D9C */
+	0,							/* U+010D9D */
+	0,							/* U+010D9E */
+	0,							/* U+010D9F */
+	0,							/* U+010DA0 */
+	0,							/* U+010DA1 */
+	0,							/* U+010DA2 */
+	0,							/* U+010DA3 */
+	0,							/* U+010DA4 */
+	0,							/* U+010DA5 */
+	0,							/* U+010DA6 */
+	0,							/* U+010DA7 */
+	0,							/* U+010DA8 */
+	0,							/* U+010DA9 */
+	0,							/* U+010DAA */
+	0,							/* U+010DAB */
+	0,							/* U+010DAC */
+	0,							/* U+010DAD */
+	0,							/* U+010DAE */
+	0,							/* U+010DAF */
+	0,							/* U+010DB0 */
+	0,							/* U+010DB1 */
+	0,							/* U+010DB2 */
+	0,							/* U+010DB3 */
+	0,							/* U+010DB4 */
+	0,							/* U+010DB5 */
+	0,							/* U+010DB6 */
+	0,							/* U+010DB7 */
+	0,							/* U+010DB8 */
+	0,							/* U+010DB9 */
+	0,							/* U+010DBA */
+	0,							/* U+010DBB */
+	0,							/* U+010DBC */
+	0,							/* U+010DBD */
+	0,							/* U+010DBE */
+	0,							/* U+010DBF */
+	0,							/* U+010DC0 */
+	0,							/* U+010DC1 */
+	0,							/* U+010DC2 */
+	0,							/* U+010DC3 */
+	0,							/* U+010DC4 */
+	0,							/* U+010DC5 */
+	0,							/* U+010DC6 */
+	0,							/* U+010DC7 */
+	0,							/* U+010DC8 */
+	0,							/* U+010DC9 */
+	0,							/* U+010DCA */
+	0,							/* U+010DCB */
+	0,							/* U+010DCC */
+	0,							/* U+010DCD */
+	0,							/* U+010DCE */
+	0,							/* U+010DCF */
+	0,							/* U+010DD0 */
+	0,							/* U+010DD1 */
+	0,							/* U+010DD2 */
+	0,							/* U+010DD3 */
+	0,							/* U+010DD4 */
+	0,							/* U+010DD5 */
+	0,							/* U+010DD6 */
+	0,							/* U+010DD7 */
+	0,							/* U+010DD8 */
+	0,							/* U+010DD9 */
+	0,							/* U+010DDA */
+	0,							/* U+010DDB */
+	0,							/* U+010DDC */
+	0,							/* U+010DDD */
+	0,							/* U+010DDE */
+	0,							/* U+010DDF */
+	0,							/* U+010DE0 */
+	0,							/* U+010DE1 */
+	0,							/* U+010DE2 */
+	0,							/* U+010DE3 */
+	0,							/* U+010DE4 */
+	0,							/* U+010DE5 */
+	0,							/* U+010DE6 */
+	0,							/* U+010DE7 */
+	0,							/* U+010DE8 */
+	0,							/* U+010DE9 */
+	0,							/* U+010DEA */
+	0,							/* U+010DEB */
+	0,							/* U+010DEC */
+	0,							/* U+010DED */
+	0,							/* U+010DEE */
+	0,							/* U+010DEF */
+	0,							/* U+010DF0 */
+	0,							/* U+010DF1 */
+	0,							/* U+010DF2 */
+	0,							/* U+010DF3 */
+	0,							/* U+010DF4 */
+	0,							/* U+010DF5 */
+	0,							/* U+010DF6 */
+	0,							/* U+010DF7 */
+	0,							/* U+010DF8 */
+	0,							/* U+010DF9 */
+	0,							/* U+010DFA */
+	0,							/* U+010DFB */
+	0,							/* U+010DFC */
+	0,							/* U+010DFD */
+	0,							/* U+010DFE */
+	0,							/* U+010DFF */
+	0,							/* U+010E00 */
+	0,							/* U+010E01 */
+	0,							/* U+010E02 */
+	0,							/* U+010E03 */
+	0,							/* U+010E04 */
+	0,							/* U+010E05 */
+	0,							/* U+010E06 */
+	0,							/* U+010E07 */
+	0,							/* U+010E08 */
+	0,							/* U+010E09 */
+	0,							/* U+010E0A */
+	0,							/* U+010E0B */
+	0,							/* U+010E0C */
+	0,							/* U+010E0D */
+	0,							/* U+010E0E */
+	0,							/* U+010E0F */
+	0,							/* U+010E10 */
+	0,							/* U+010E11 */
+	0,							/* U+010E12 */
+	0,							/* U+010E13 */
+	0,							/* U+010E14 */
+	0,							/* U+010E15 */
+	0,							/* U+010E16 */
+	0,							/* U+010E17 */
+	0,							/* U+010E18 */
+	0,							/* U+010E19 */
+	0,							/* U+010E1A */
+	0,							/* U+010E1B */
+	0,							/* U+010E1C */
+	0,							/* U+010E1D */
+	0,							/* U+010E1E */
+	0,							/* U+010E1F */
+	0,							/* U+010E20 */
+	0,							/* U+010E21 */
+	0,							/* U+010E22 */
+	0,							/* U+010E23 */
+	0,							/* U+010E24 */
+	0,							/* U+010E25 */
+	0,							/* U+010E26 */
+	0,							/* U+010E27 */
+	0,							/* U+010E28 */
+	0,							/* U+010E29 */
+	0,							/* U+010E2A */
+	0,							/* U+010E2B */
+	0,							/* U+010E2C */
+	0,							/* U+010E2D */
+	0,							/* U+010E2E */
+	0,							/* U+010E2F */
+	0,							/* U+010E30 */
+	0,							/* U+010E31 */
+	0,							/* U+010E32 */
+	0,							/* U+010E33 */
+	0,							/* U+010E34 */
+	0,							/* U+010E35 */
+	0,							/* U+010E36 */
+	0,							/* U+010E37 */
+	0,							/* U+010E38 */
+	0,							/* U+010E39 */
+	0,							/* U+010E3A */
+	0,							/* U+010E3B */
+	0,							/* U+010E3C */
+	0,							/* U+010E3D */
+	0,							/* U+010E3E */
+	0,							/* U+010E3F */
+	0,							/* U+010E40 */
+	0,							/* U+010E41 */
+	0,							/* U+010E42 */
+	0,							/* U+010E43 */
+	0,							/* U+010E44 */
+	0,							/* U+010E45 */
+	0,							/* U+010E46 */
+	0,							/* U+010E47 */
+	0,							/* U+010E48 */
+	0,							/* U+010E49 */
+	0,							/* U+010E4A */
+	0,							/* U+010E4B */
+	0,							/* U+010E4C */
+	0,							/* U+010E4D */
+	0,							/* U+010E4E */
+	0,							/* U+010E4F */
+	0,							/* U+010E50 */
+	0,							/* U+010E51 */
+	0,							/* U+010E52 */
+	0,							/* U+010E53 */
+	0,							/* U+010E54 */
+	0,							/* U+010E55 */
+	0,							/* U+010E56 */
+	0,							/* U+010E57 */
+	0,							/* U+010E58 */
+	0,							/* U+010E59 */
+	0,							/* U+010E5A */
+	0,							/* U+010E5B */
+	0,							/* U+010E5C */
+	0,							/* U+010E5D */
+	0,							/* U+010E5E */
+	0,							/* U+010E5F */
+	0,							/* U+010E60 */
+	0,							/* U+010E61 */
+	0,							/* U+010E62 */
+	0,							/* U+010E63 */
+	0,							/* U+010E64 */
+	0,							/* U+010E65 */
+	0,							/* U+010E66 */
+	0,							/* U+010E67 */
+	0,							/* U+010E68 */
+	0,							/* U+010E69 */
+	0,							/* U+010E6A */
+	0,							/* U+010E6B */
+	0,							/* U+010E6C */
+	0,							/* U+010E6D */
+	0,							/* U+010E6E */
+	0,							/* U+010E6F */
+	0,							/* U+010E70 */
+	0,							/* U+010E71 */
+	0,							/* U+010E72 */
+	0,							/* U+010E73 */
+	0,							/* U+010E74 */
+	0,							/* U+010E75 */
+	0,							/* U+010E76 */
+	0,							/* U+010E77 */
+	0,							/* U+010E78 */
+	0,							/* U+010E79 */
+	0,							/* U+010E7A */
+	0,							/* U+010E7B */
+	0,							/* U+010E7C */
+	0,							/* U+010E7D */
+	0,							/* U+010E7E */
+	0,							/* U+010E7F */
+	0,							/* U+010E80 */
+	0,							/* U+010E81 */
+	0,							/* U+010E82 */
+	0,							/* U+010E83 */
+	0,							/* U+010E84 */
+	0,							/* U+010E85 */
+	0,							/* U+010E86 */
+	0,							/* U+010E87 */
+	0,							/* U+010E88 */
+	0,							/* U+010E89 */
+	0,							/* U+010E8A */
+	0,							/* U+010E8B */
+	0,							/* U+010E8C */
+	0,							/* U+010E8D */
+	0,							/* U+010E8E */
+	0,							/* U+010E8F */
+	0,							/* U+010E90 */
+	0,							/* U+010E91 */
+	0,							/* U+010E92 */
+	0,							/* U+010E93 */
+	0,							/* U+010E94 */
+	0,							/* U+010E95 */
+	0,							/* U+010E96 */
+	0,							/* U+010E97 */
+	0,							/* U+010E98 */
+	0,							/* U+010E99 */
+	0,							/* U+010E9A */
+	0,							/* U+010E9B */
+	0,							/* U+010E9C */
+	0,							/* U+010E9D */
+	0,							/* U+010E9E */
+	0,							/* U+010E9F */
+	0,							/* U+010EA0 */
+	0,							/* U+010EA1 */
+	0,							/* U+010EA2 */
+	0,							/* U+010EA3 */
+	0,							/* U+010EA4 */
+	0,							/* U+010EA5 */
+	0,							/* U+010EA6 */
+	0,							/* U+010EA7 */
+	0,							/* U+010EA8 */
+	0,							/* U+010EA9 */
+	0,							/* U+010EAA */
+	304,						/* U+010EAB */
+	304,						/* U+010EAC */
+	0,							/* U+010EAD */
+	0,							/* U+010EAE */
+	0,							/* U+010EAF */
+	0,							/* U+010EB0 */
+	0,							/* U+010EB1 */
+	0,							/* U+010EB2 */
+	0,							/* U+010EB3 */
+	0,							/* U+010EB4 */
+	0,							/* U+010EB5 */
+	0,							/* U+010EB6 */
+	0,							/* U+010EB7 */
+	0,							/* U+010EB8 */
+	0,							/* U+010EB9 */
+	0,							/* U+010EBA */
+	0,							/* U+010EBB */
+	0,							/* U+010EBC */
+	0,							/* U+010EBD */
+	0,							/* U+010EBE */
+	0,							/* U+010EBF */
+	0,							/* U+010EC0 */
+	0,							/* U+010EC1 */
+	0,							/* U+010EC2 */
+	0,							/* U+010EC3 */
+	0,							/* U+010EC4 */
+	0,							/* U+010EC5 */
+	0,							/* U+010EC6 */
+	0,							/* U+010EC7 */
+	0,							/* U+010EC8 */
+	0,							/* U+010EC9 */
+	0,							/* U+010ECA */
+	0,							/* U+010ECB */
+	0,							/* U+010ECC */
+	0,							/* U+010ECD */
+	0,							/* U+010ECE */
+	0,							/* U+010ECF */
+	0,							/* U+010ED0 */
+	0,							/* U+010ED1 */
+	0,							/* U+010ED2 */
+	0,							/* U+010ED3 */
+	0,							/* U+010ED4 */
+	0,							/* U+010ED5 */
+	0,							/* U+010ED6 */
+	0,							/* U+010ED7 */
+	0,							/* U+010ED8 */
+	0,							/* U+010ED9 */
+	0,							/* U+010EDA */
+	0,							/* U+010EDB */
+	0,							/* U+010EDC */
+	0,							/* U+010EDD */
+	0,							/* U+010EDE */
+	0,							/* U+010EDF */
+	0,							/* U+010EE0 */
+	0,							/* U+010EE1 */
+	0,							/* U+010EE2 */
+	0,							/* U+010EE3 */
+	0,							/* U+010EE4 */
+	0,							/* U+010EE5 */
+	0,							/* U+010EE6 */
+	0,							/* U+010EE7 */
+	0,							/* U+010EE8 */
+	0,							/* U+010EE9 */
+	0,							/* U+010EEA */
+	0,							/* U+010EEB */
+	0,							/* U+010EEC */
+	0,							/* U+010EED */
+	0,							/* U+010EEE */
+	0,							/* U+010EEF */
+	0,							/* U+010EF0 */
+	0,							/* U+010EF1 */
+	0,							/* U+010EF2 */
+	0,							/* U+010EF3 */
+	0,							/* U+010EF4 */
+	0,							/* U+010EF5 */
+	0,							/* U+010EF6 */
+	0,							/* U+010EF7 */
+	0,							/* U+010EF8 */
+	0,							/* U+010EF9 */
+	0,							/* U+010EFA */
+	0,							/* U+010EFB */
+	0,							/* U+010EFC */
+	306,						/* U+010EFD */
+	306,						/* U+010EFE */
+	306,						/* U+010EFF */
+	0,							/* U+010F00 */
+	0,							/* U+010F01 */
+	0,							/* U+010F02 */
+	0,							/* U+010F03 */
+	0,							/* U+010F04 */
+	0,							/* U+010F05 */
+	0,							/* U+010F06 */
+	0,							/* U+010F07 */
+	0,							/* U+010F08 */
+	0,							/* U+010F09 */
+	0,							/* U+010F0A */
+	0,							/* U+010F0B */
+	0,							/* U+010F0C */
+	0,							/* U+010F0D */
+	0,							/* U+010F0E */
+	0,							/* U+010F0F */
+	0,							/* U+010F10 */
+	0,							/* U+010F11 */
+	0,							/* U+010F12 */
+	0,							/* U+010F13 */
+	0,							/* U+010F14 */
+	0,							/* U+010F15 */
+	0,							/* U+010F16 */
+	0,							/* U+010F17 */
+	0,							/* U+010F18 */
+	0,							/* U+010F19 */
+	0,							/* U+010F1A */
+	0,							/* U+010F1B */
+	0,							/* U+010F1C */
+	0,							/* U+010F1D */
+	0,							/* U+010F1E */
+	0,							/* U+010F1F */
+	0,							/* U+010F20 */
+	0,							/* U+010F21 */
+	0,							/* U+010F22 */
+	0,							/* U+010F23 */
+	0,							/* U+010F24 */
+	0,							/* U+010F25 */
+	0,							/* U+010F26 */
+	0,							/* U+010F27 */
+	0,							/* U+010F28 */
+	0,							/* U+010F29 */
+	0,							/* U+010F2A */
+	0,							/* U+010F2B */
+	0,							/* U+010F2C */
+	0,							/* U+010F2D */
+	0,							/* U+010F2E */
+	0,							/* U+010F2F */
+	0,							/* U+010F30 */
+	0,							/* U+010F31 */
+	0,							/* U+010F32 */
+	0,							/* U+010F33 */
+	0,							/* U+010F34 */
+	0,							/* U+010F35 */
+	0,							/* U+010F36 */
+	0,							/* U+010F37 */
+	0,							/* U+010F38 */
+	0,							/* U+010F39 */
+	0,							/* U+010F3A */
+	0,							/* U+010F3B */
+	0,							/* U+010F3C */
+	0,							/* U+010F3D */
+	0,							/* U+010F3E */
+	0,							/* U+010F3F */
+	0,							/* U+010F40 */
+	0,							/* U+010F41 */
+	0,							/* U+010F42 */
+	0,							/* U+010F43 */
+	0,							/* U+010F44 */
+	0,							/* U+010F45 */
+	306,						/* U+010F46 */
+	306,						/* U+010F47 */
+	304,						/* U+010F48 */
+	304,						/* U+010F49 */
+	304,						/* U+010F4A */
+	306,						/* U+010F4B */
+	304,						/* U+010F4C */
+	306,						/* U+010F4D */
+	306,						/* U+010F4E */
+	306,						/* U+010F4F */
+	306,						/* U+010F50 */
+	0,							/* U+010F51 */
+	0,							/* U+010F52 */
+	0,							/* U+010F53 */
+	0,							/* U+010F54 */
+	0,							/* U+010F55 */
+	0,							/* U+010F56 */
+	0,							/* U+010F57 */
+	0,							/* U+010F58 */
+	0,							/* U+010F59 */
+	0,							/* U+010F5A */
+	0,							/* U+010F5B */
+	0,							/* U+010F5C */
+	0,							/* U+010F5D */
+	0,							/* U+010F5E */
+	0,							/* U+010F5F */
+	0,							/* U+010F60 */
+	0,							/* U+010F61 */
+	0,							/* U+010F62 */
+	0,							/* U+010F63 */
+	0,							/* U+010F64 */
+	0,							/* U+010F65 */
+	0,							/* U+010F66 */
+	0,							/* U+010F67 */
+	0,							/* U+010F68 */
+	0,							/* U+010F69 */
+	0,							/* U+010F6A */
+	0,							/* U+010F6B */
+	0,							/* U+010F6C */
+	0,							/* U+010F6D */
+	0,							/* U+010F6E */
+	0,							/* U+010F6F */
+	0,							/* U+010F70 */
+	0,							/* U+010F71 */
+	0,							/* U+010F72 */
+	0,							/* U+010F73 */
+	0,							/* U+010F74 */
+	0,							/* U+010F75 */
+	0,							/* U+010F76 */
+	0,							/* U+010F77 */
+	0,							/* U+010F78 */
+	0,							/* U+010F79 */
+	0,							/* U+010F7A */
+	0,							/* U+010F7B */
+	0,							/* U+010F7C */
+	0,							/* U+010F7D */
+	0,							/* U+010F7E */
+	0,							/* U+010F7F */
+	0,							/* U+010F80 */
+	0,							/* U+010F81 */
+	304,						/* U+010F82 */
+	306,						/* U+010F83 */
+	304,						/* U+010F84 */
+	306,						/* U+010F85 */
+	0,							/* U+010F86 */
+	0,							/* U+010F87 */
+	0,							/* U+010F88 */
+	0,							/* U+010F89 */
+	0,							/* U+010F8A */
+	0,							/* U+010F8B */
+	0,							/* U+010F8C */
+	0,							/* U+010F8D */
+	0,							/* U+010F8E */
+	0,							/* U+010F8F */
+	0,							/* U+010F90 */
+	0,							/* U+010F91 */
+	0,							/* U+010F92 */
+	0,							/* U+010F93 */
+	0,							/* U+010F94 */
+	0,							/* U+010F95 */
+	0,							/* U+010F96 */
+	0,							/* U+010F97 */
+	0,							/* U+010F98 */
+	0,							/* U+010F99 */
+	0,							/* U+010F9A */
+	0,							/* U+010F9B */
+	0,							/* U+010F9C */
+	0,							/* U+010F9D */
+	0,							/* U+010F9E */
+	0,							/* U+010F9F */
+	0,							/* U+010FA0 */
+	0,							/* U+010FA1 */
+	0,							/* U+010FA2 */
+	0,							/* U+010FA3 */
+	0,							/* U+010FA4 */
+	0,							/* U+010FA5 */
+	0,							/* U+010FA6 */
+	0,							/* U+010FA7 */
+	0,							/* U+010FA8 */
+	0,							/* U+010FA9 */
+	0,							/* U+010FAA */
+	0,							/* U+010FAB */
+	0,							/* U+010FAC */
+	0,							/* U+010FAD */
+	0,							/* U+010FAE */
+	0,							/* U+010FAF */
+	0,							/* U+010FB0 */
+	0,							/* U+010FB1 */
+	0,							/* U+010FB2 */
+	0,							/* U+010FB3 */
+	0,							/* U+010FB4 */
+	0,							/* U+010FB5 */
+	0,							/* U+010FB6 */
+	0,							/* U+010FB7 */
+	0,							/* U+010FB8 */
+	0,							/* U+010FB9 */
+	0,							/* U+010FBA */
+	0,							/* U+010FBB */
+	0,							/* U+010FBC */
+	0,							/* U+010FBD */
+	0,							/* U+010FBE */
+	0,							/* U+010FBF */
+	0,							/* U+010FC0 */
+	0,							/* U+010FC1 */
+	0,							/* U+010FC2 */
+	0,							/* U+010FC3 */
+	0,							/* U+010FC4 */
+	0,							/* U+010FC5 */
+	0,							/* U+010FC6 */
+	0,							/* U+010FC7 */
+	0,							/* U+010FC8 */
+	0,							/* U+010FC9 */
+	0,							/* U+010FCA */
+	0,							/* U+010FCB */
+	0,							/* U+010FCC */
+	0,							/* U+010FCD */
+	0,							/* U+010FCE */
+	0,							/* U+010FCF */
+	0,							/* U+010FD0 */
+	0,							/* U+010FD1 */
+	0,							/* U+010FD2 */
+	0,							/* U+010FD3 */
+	0,							/* U+010FD4 */
+	0,							/* U+010FD5 */
+	0,							/* U+010FD6 */
+	0,							/* U+010FD7 */
+	0,							/* U+010FD8 */
+	0,							/* U+010FD9 */
+	0,							/* U+010FDA */
+	0,							/* U+010FDB */
+	0,							/* U+010FDC */
+	0,							/* U+010FDD */
+	0,							/* U+010FDE */
+	0,							/* U+010FDF */
+	0,							/* U+010FE0 */
+	0,							/* U+010FE1 */
+	0,							/* U+010FE2 */
+	0,							/* U+010FE3 */
+	0,							/* U+010FE4 */
+	0,							/* U+010FE5 */
+	0,							/* U+010FE6 */
+	0,							/* U+010FE7 */
+	0,							/* U+010FE8 */
+	0,							/* U+010FE9 */
+	0,							/* U+010FEA */
+	0,							/* U+010FEB */
+	0,							/* U+010FEC */
+	0,							/* U+010FED */
+	0,							/* U+010FEE */
+	0,							/* U+010FEF */
+	0,							/* U+010FF0 */
+	0,							/* U+010FF1 */
+	0,							/* U+010FF2 */
+	0,							/* U+010FF3 */
+	0,							/* U+010FF4 */
+	0,							/* U+010FF5 */
+	0,							/* U+010FF6 */
+	0,							/* U+010FF7 */
+	0,							/* U+010FF8 */
+	0,							/* U+010FF9 */
+	0,							/* U+010FFA */
+	0,							/* U+010FFB */
+	0,							/* U+010FFC */
+	0,							/* U+010FFD */
+	0,							/* U+010FFE */
+	0,							/* U+010FFF */
+	0,							/* U+011000 */
+	0,							/* U+011001 */
+	0,							/* U+011002 */
+	0,							/* U+011003 */
+	0,							/* U+011004 */
+	0,							/* U+011005 */
+	0,							/* U+011006 */
+	0,							/* U+011007 */
+	0,							/* U+011008 */
+	0,							/* U+011009 */
+	0,							/* U+01100A */
+	0,							/* U+01100B */
+	0,							/* U+01100C */
+	0,							/* U+01100D */
+	0,							/* U+01100E */
+	0,							/* U+01100F */
+	0,							/* U+011010 */
+	0,							/* U+011011 */
+	0,							/* U+011012 */
+	0,							/* U+011013 */
+	0,							/* U+011014 */
+	0,							/* U+011015 */
+	0,							/* U+011016 */
+	0,							/* U+011017 */
+	0,							/* U+011018 */
+	0,							/* U+011019 */
+	0,							/* U+01101A */
+	0,							/* U+01101B */
+	0,							/* U+01101C */
+	0,							/* U+01101D */
+	0,							/* U+01101E */
+	0,							/* U+01101F */
+	0,							/* U+011020 */
+	0,							/* U+011021 */
+	0,							/* U+011022 */
+	0,							/* U+011023 */
+	0,							/* U+011024 */
+	0,							/* U+011025 */
+	0,							/* U+011026 */
+	0,							/* U+011027 */
+	0,							/* U+011028 */
+	0,							/* U+011029 */
+	0,							/* U+01102A */
+	0,							/* U+01102B */
+	0,							/* U+01102C */
+	0,							/* U+01102D */
+	0,							/* U+01102E */
+	0,							/* U+01102F */
+	0,							/* U+011030 */
+	0,							/* U+011031 */
+	0,							/* U+011032 */
+	0,							/* U+011033 */
+	0,							/* U+011034 */
+	0,							/* U+011035 */
+	0,							/* U+011036 */
+	0,							/* U+011037 */
+	0,							/* U+011038 */
+	0,							/* U+011039 */
+	0,							/* U+01103A */
+	0,							/* U+01103B */
+	0,							/* U+01103C */
+	0,							/* U+01103D */
+	0,							/* U+01103E */
+	0,							/* U+01103F */
+	0,							/* U+011040 */
+	0,							/* U+011041 */
+	0,							/* U+011042 */
+	0,							/* U+011043 */
+	0,							/* U+011044 */
+	0,							/* U+011045 */
+	452,						/* U+011046 */
+	0,							/* U+011047 */
+	0,							/* U+011048 */
+	0,							/* U+011049 */
+	0,							/* U+01104A */
+	0,							/* U+01104B */
+	0,							/* U+01104C */
+	0,							/* U+01104D */
+	0,							/* U+01104E */
+	0,							/* U+01104F */
+	0,							/* U+011050 */
+	0,							/* U+011051 */
+	0,							/* U+011052 */
+	0,							/* U+011053 */
+	0,							/* U+011054 */
+	0,							/* U+011055 */
+	0,							/* U+011056 */
+	0,							/* U+011057 */
+	0,							/* U+011058 */
+	0,							/* U+011059 */
+	0,							/* U+01105A */
+	0,							/* U+01105B */
+	0,							/* U+01105C */
+	0,							/* U+01105D */
+	0,							/* U+01105E */
+	0,							/* U+01105F */
+	0,							/* U+011060 */
+	0,							/* U+011061 */
+	0,							/* U+011062 */
+	0,							/* U+011063 */
+	0,							/* U+011064 */
+	0,							/* U+011065 */
+	0,							/* U+011066 */
+	0,							/* U+011067 */
+	0,							/* U+011068 */
+	0,							/* U+011069 */
+	0,							/* U+01106A */
+	0,							/* U+01106B */
+	0,							/* U+01106C */
+	0,							/* U+01106D */
+	0,							/* U+01106E */
+	0,							/* U+01106F */
+	452,						/* U+011070 */
+	0,							/* U+011071 */
+	0,							/* U+011072 */
+	0,							/* U+011073 */
+	0,							/* U+011074 */
+	0,							/* U+011075 */
+	0,							/* U+011076 */
+	0,							/* U+011077 */
+	0,							/* U+011078 */
+	0,							/* U+011079 */
+	0,							/* U+01107A */
+	0,							/* U+01107B */
+	0,							/* U+01107C */
+	0,							/* U+01107D */
+	0,							/* U+01107E */
+	452,						/* U+01107F */
+	0,							/* U+011080 */
+	0,							/* U+011081 */
+	0,							/* U+011082 */
+	0,							/* U+011083 */
+	0,							/* U+011084 */
+	0,							/* U+011085 */
+	0,							/* U+011086 */
+	0,							/* U+011087 */
+	0,							/* U+011088 */
+	0,							/* U+011089 */
+	0,							/* U+01108A */
+	0,							/* U+01108B */
+	0,							/* U+01108C */
+	0,							/* U+01108D */
+	0,							/* U+01108E */
+	0,							/* U+01108F */
+	0,							/* U+011090 */
+	0,							/* U+011091 */
+	0,							/* U+011092 */
+	0,							/* U+011093 */
+	0,							/* U+011094 */
+	0,							/* U+011095 */
+	0,							/* U+011096 */
+	0,							/* U+011097 */
+	0,							/* U+011098 */
+	0,							/* U+011099 */
+	3239,						/* U+01109A */
+	0,							/* U+01109B */
+	3240,						/* U+01109C */
+	0,							/* U+01109D */
+	0,							/* U+01109E */
+	0,							/* U+01109F */
+	0,							/* U+0110A0 */
+	0,							/* U+0110A1 */
+	0,							/* U+0110A2 */
+	0,							/* U+0110A3 */
+	0,							/* U+0110A4 */
+	0,							/* U+0110A5 */
+	0,							/* U+0110A6 */
+	0,							/* U+0110A7 */
+	0,							/* U+0110A8 */
+	0,							/* U+0110A9 */
+	0,							/* U+0110AA */
+	3241,						/* U+0110AB */
+	0,							/* U+0110AC */
+	0,							/* U+0110AD */
+	0,							/* U+0110AE */
+	0,							/* U+0110AF */
+	0,							/* U+0110B0 */
+	0,							/* U+0110B1 */
+	0,							/* U+0110B2 */
+	0,							/* U+0110B3 */
+	0,							/* U+0110B4 */
+	0,							/* U+0110B5 */
+	0,							/* U+0110B6 */
+	0,							/* U+0110B7 */
+	0,							/* U+0110B8 */
+	452,						/* U+0110B9 */
+	451,						/* U+0110BA */
+	0,							/* U+0110BB */
+	0,							/* U+0110BC */
+	0,							/* U+0110BD */
+	0,							/* U+0110BE */
+	0,							/* U+0110BF */
+	0,							/* U+0110C0 */
+	0,							/* U+0110C1 */
+	0,							/* U+0110C2 */
+	0,							/* U+0110C3 */
+	0,							/* U+0110C4 */
+	0,							/* U+0110C5 */
+	0,							/* U+0110C6 */
+	0,							/* U+0110C7 */
+	0,							/* U+0110C8 */
+	0,							/* U+0110C9 */
+	0,							/* U+0110CA */
+	0,							/* U+0110CB */
+	0,							/* U+0110CC */
+	0,							/* U+0110CD */
+	0,							/* U+0110CE */
+	0,							/* U+0110CF */
+	0,							/* U+0110D0 */
+	0,							/* U+0110D1 */
+	0,							/* U+0110D2 */
+	0,							/* U+0110D3 */
+	0,							/* U+0110D4 */
+	0,							/* U+0110D5 */
+	0,							/* U+0110D6 */
+	0,							/* U+0110D7 */
+	0,							/* U+0110D8 */
+	0,							/* U+0110D9 */
+	0,							/* U+0110DA */
+	0,							/* U+0110DB */
+	0,							/* U+0110DC */
+	0,							/* U+0110DD */
+	0,							/* U+0110DE */
+	0,							/* U+0110DF */
+	0,							/* U+0110E0 */
+	0,							/* U+0110E1 */
+	0,							/* U+0110E2 */
+	0,							/* U+0110E3 */
+	0,							/* U+0110E4 */
+	0,							/* U+0110E5 */
+	0,							/* U+0110E6 */
+	0,							/* U+0110E7 */
+	0,							/* U+0110E8 */
+	0,							/* U+0110E9 */
+	0,							/* U+0110EA */
+	0,							/* U+0110EB */
+	0,							/* U+0110EC */
+	0,							/* U+0110ED */
+	0,							/* U+0110EE */
+	0,							/* U+0110EF */
+	0,							/* U+0110F0 */
+	0,							/* U+0110F1 */
+	0,							/* U+0110F2 */
+	0,							/* U+0110F3 */
+	0,							/* U+0110F4 */
+	0,							/* U+0110F5 */
+	0,							/* U+0110F6 */
+	0,							/* U+0110F7 */
+	0,							/* U+0110F8 */
+	0,							/* U+0110F9 */
+	0,							/* U+0110FA */
+	0,							/* U+0110FB */
+	0,							/* U+0110FC */
+	0,							/* U+0110FD */
+	0,							/* U+0110FE */
+	0,							/* U+0110FF */
+	304,						/* U+011100 */
+	304,						/* U+011101 */
+	304,						/* U+011102 */
+	0,							/* U+011103 */
+	0,							/* U+011104 */
+	0,							/* U+011105 */
+	0,							/* U+011106 */
+	0,							/* U+011107 */
+	0,							/* U+011108 */
+	0,							/* U+011109 */
+	0,							/* U+01110A */
+	0,							/* U+01110B */
+	0,							/* U+01110C */
+	0,							/* U+01110D */
+	0,							/* U+01110E */
+	0,							/* U+01110F */
+	0,							/* U+011110 */
+	0,							/* U+011111 */
+	0,							/* U+011112 */
+	0,							/* U+011113 */
+	0,							/* U+011114 */
+	0,							/* U+011115 */
+	0,							/* U+011116 */
+	0,							/* U+011117 */
+	0,							/* U+011118 */
+	0,							/* U+011119 */
+	0,							/* U+01111A */
+	0,							/* U+01111B */
+	0,							/* U+01111C */
+	0,							/* U+01111D */
+	0,							/* U+01111E */
+	0,							/* U+01111F */
+	0,							/* U+011120 */
+	0,							/* U+011121 */
+	0,							/* U+011122 */
+	0,							/* U+011123 */
+	0,							/* U+011124 */
+	0,							/* U+011125 */
+	0,							/* U+011126 */
+	0,							/* U+011127 */
+	0,							/* U+011128 */
+	0,							/* U+011129 */
+	0,							/* U+01112A */
+	0,							/* U+01112B */
+	0,							/* U+01112C */
+	0,							/* U+01112D */
+	3242,						/* U+01112E */
+	3243,						/* U+01112F */
+	0,							/* U+011130 */
+	0,							/* U+011131 */
+	0,							/* U+011132 */
+	452,						/* U+011133 */
+	452,						/* U+011134 */
+	0,							/* U+011135 */
+	0,							/* U+011136 */
+	0,							/* U+011137 */
+	0,							/* U+011138 */
+	0,							/* U+011139 */
+	0,							/* U+01113A */
+	0,							/* U+01113B */
+	0,							/* U+01113C */
+	0,							/* U+01113D */
+	0,							/* U+01113E */
+	0,							/* U+01113F */
+	0,							/* U+011140 */
+	0,							/* U+011141 */
+	0,							/* U+011142 */
+	0,							/* U+011143 */
+	0,							/* U+011144 */
+	0,							/* U+011145 */
+	0,							/* U+011146 */
+	0,							/* U+011147 */
+	0,							/* U+011148 */
+	0,							/* U+011149 */
+	0,							/* U+01114A */
+	0,							/* U+01114B */
+	0,							/* U+01114C */
+	0,							/* U+01114D */
+	0,							/* U+01114E */
+	0,							/* U+01114F */
+	0,							/* U+011150 */
+	0,							/* U+011151 */
+	0,							/* U+011152 */
+	0,							/* U+011153 */
+	0,							/* U+011154 */
+	0,							/* U+011155 */
+	0,							/* U+011156 */
+	0,							/* U+011157 */
+	0,							/* U+011158 */
+	0,							/* U+011159 */
+	0,							/* U+01115A */
+	0,							/* U+01115B */
+	0,							/* U+01115C */
+	0,							/* U+01115D */
+	0,							/* U+01115E */
+	0,							/* U+01115F */
+	0,							/* U+011160 */
+	0,							/* U+011161 */
+	0,							/* U+011162 */
+	0,							/* U+011163 */
+	0,							/* U+011164 */
+	0,							/* U+011165 */
+	0,							/* U+011166 */
+	0,							/* U+011167 */
+	0,							/* U+011168 */
+	0,							/* U+011169 */
+	0,							/* U+01116A */
+	0,							/* U+01116B */
+	0,							/* U+01116C */
+	0,							/* U+01116D */
+	0,							/* U+01116E */
+	0,							/* U+01116F */
+	0,							/* U+011170 */
+	0,							/* U+011171 */
+	0,							/* U+011172 */
+	451,						/* U+011173 */
+	0,							/* U+011174 */
+	0,							/* U+011175 */
+	0,							/* U+011176 */
+	0,							/* U+011177 */
+	0,							/* U+011178 */
+	0,							/* U+011179 */
+	0,							/* U+01117A */
+	0,							/* U+01117B */
+	0,							/* U+01117C */
+	0,							/* U+01117D */
+	0,							/* U+01117E */
+	0,							/* U+01117F */
+	0,							/* U+011180 */
+	0,							/* U+011181 */
+	0,							/* U+011182 */
+	0,							/* U+011183 */
+	0,							/* U+011184 */
+	0,							/* U+011185 */
+	0,							/* U+011186 */
+	0,							/* U+011187 */
+	0,							/* U+011188 */
+	0,							/* U+011189 */
+	0,							/* U+01118A */
+	0,							/* U+01118B */
+	0,							/* U+01118C */
+	0,							/* U+01118D */
+	0,							/* U+01118E */
+	0,							/* U+01118F */
+	0,							/* U+011190 */
+	0,							/* U+011191 */
+	0,							/* U+011192 */
+	0,							/* U+011193 */
+	0,							/* U+011194 */
+	0,							/* U+011195 */
+	0,							/* U+011196 */
+	0,							/* U+011197 */
+	0,							/* U+011198 */
+	0,							/* U+011199 */
+	0,							/* U+01119A */
+	0,							/* U+01119B */
+	0,							/* U+01119C */
+	0,							/* U+01119D */
+	0,							/* U+01119E */
+	0,							/* U+01119F */
+	0,							/* U+0111A0 */
+	0,							/* U+0111A1 */
+	0,							/* U+0111A2 */
+	0,							/* U+0111A3 */
+	0,							/* U+0111A4 */
+	0,							/* U+0111A5 */
+	0,							/* U+0111A6 */
+	0,							/* U+0111A7 */
+	0,							/* U+0111A8 */
+	0,							/* U+0111A9 */
+	0,							/* U+0111AA */
+	0,							/* U+0111AB */
+	0,							/* U+0111AC */
+	0,							/* U+0111AD */
+	0,							/* U+0111AE */
+	0,							/* U+0111AF */
+	0,							/* U+0111B0 */
+	0,							/* U+0111B1 */
+	0,							/* U+0111B2 */
+	0,							/* U+0111B3 */
+	0,							/* U+0111B4 */
+	0,							/* U+0111B5 */
+	0,							/* U+0111B6 */
+	0,							/* U+0111B7 */
+	0,							/* U+0111B8 */
+	0,							/* U+0111B9 */
+	0,							/* U+0111BA */
+	0,							/* U+0111BB */
+	0,							/* U+0111BC */
+	0,							/* U+0111BD */
+	0,							/* U+0111BE */
+	0,							/* U+0111BF */
+	452,						/* U+0111C0 */
+	0,							/* U+0111C1 */
+	0,							/* U+0111C2 */
+	0,							/* U+0111C3 */
+	0,							/* U+0111C4 */
+	0,							/* U+0111C5 */
+	0,							/* U+0111C6 */
+	0,							/* U+0111C7 */
+	0,							/* U+0111C8 */
+	0,							/* U+0111C9 */
+	451,						/* U+0111CA */
+	0,							/* U+0111CB */
+	0,							/* U+0111CC */
+	0,							/* U+0111CD */
+	0,							/* U+0111CE */
+	0,							/* U+0111CF */
+	0,							/* U+0111D0 */
+	0,							/* U+0111D1 */
+	0,							/* U+0111D2 */
+	0,							/* U+0111D3 */
+	0,							/* U+0111D4 */
+	0,							/* U+0111D5 */
+	0,							/* U+0111D6 */
+	0,							/* U+0111D7 */
+	0,							/* U+0111D8 */
+	0,							/* U+0111D9 */
+	0,							/* U+0111DA */
+	0,							/* U+0111DB */
+	0,							/* U+0111DC */
+	0,							/* U+0111DD */
+	0,							/* U+0111DE */
+	0,							/* U+0111DF */
+	0,							/* U+0111E0 */
+	0,							/* U+0111E1 */
+	0,							/* U+0111E2 */
+	0,							/* U+0111E3 */
+	0,							/* U+0111E4 */
+	0,							/* U+0111E5 */
+	0,							/* U+0111E6 */
+	0,							/* U+0111E7 */
+	0,							/* U+0111E8 */
+	0,							/* U+0111E9 */
+	0,							/* U+0111EA */
+	0,							/* U+0111EB */
+	0,							/* U+0111EC */
+	0,							/* U+0111ED */
+	0,							/* U+0111EE */
+	0,							/* U+0111EF */
+	0,							/* U+0111F0 */
+	0,							/* U+0111F1 */
+	0,							/* U+0111F2 */
+	0,							/* U+0111F3 */
+	0,							/* U+0111F4 */
+	0,							/* U+0111F5 */
+	0,							/* U+0111F6 */
+	0,							/* U+0111F7 */
+	0,							/* U+0111F8 */
+	0,							/* U+0111F9 */
+	0,							/* U+0111FA */
+	0,							/* U+0111FB */
+	0,							/* U+0111FC */
+	0,							/* U+0111FD */
+	0,							/* U+0111FE */
+	0,							/* U+0111FF */
+	0,							/* U+011200 */
+	0,							/* U+011201 */
+	0,							/* U+011202 */
+	0,							/* U+011203 */
+	0,							/* U+011204 */
+	0,							/* U+011205 */
+	0,							/* U+011206 */
+	0,							/* U+011207 */
+	0,							/* U+011208 */
+	0,							/* U+011209 */
+	0,							/* U+01120A */
+	0,							/* U+01120B */
+	0,							/* U+01120C */
+	0,							/* U+01120D */
+	0,							/* U+01120E */
+	0,							/* U+01120F */
+	0,							/* U+011210 */
+	0,							/* U+011211 */
+	0,							/* U+011212 */
+	0,							/* U+011213 */
+	0,							/* U+011214 */
+	0,							/* U+011215 */
+	0,							/* U+011216 */
+	0,							/* U+011217 */
+	0,							/* U+011218 */
+	0,							/* U+011219 */
+	0,							/* U+01121A */
+	0,							/* U+01121B */
+	0,							/* U+01121C */
+	0,							/* U+01121D */
+	0,							/* U+01121E */
+	0,							/* U+01121F */
+	0,							/* U+011220 */
+	0,							/* U+011221 */
+	0,							/* U+011222 */
+	0,							/* U+011223 */
+	0,							/* U+011224 */
+	0,							/* U+011225 */
+	0,							/* U+011226 */
+	0,							/* U+011227 */
+	0,							/* U+011228 */
+	0,							/* U+011229 */
+	0,							/* U+01122A */
+	0,							/* U+01122B */
+	0,							/* U+01122C */
+	0,							/* U+01122D */
+	0,							/* U+01122E */
+	0,							/* U+01122F */
+	0,							/* U+011230 */
+	0,							/* U+011231 */
+	0,							/* U+011232 */
+	0,							/* U+011233 */
+	0,							/* U+011234 */
+	452,						/* U+011235 */
+	451,						/* U+011236 */
+	0,							/* U+011237 */
+	0,							/* U+011238 */
+	0,							/* U+011239 */
+	0,							/* U+01123A */
+	0,							/* U+01123B */
+	0,							/* U+01123C */
+	0,							/* U+01123D */
+	0,							/* U+01123E */
+	0,							/* U+01123F */
+	0,							/* U+011240 */
+	0,							/* U+011241 */
+	0,							/* U+011242 */
+	0,							/* U+011243 */
+	0,							/* U+011244 */
+	0,							/* U+011245 */
+	0,							/* U+011246 */
+	0,							/* U+011247 */
+	0,							/* U+011248 */
+	0,							/* U+011249 */
+	0,							/* U+01124A */
+	0,							/* U+01124B */
+	0,							/* U+01124C */
+	0,							/* U+01124D */
+	0,							/* U+01124E */
+	0,							/* U+01124F */
+	0,							/* U+011250 */
+	0,							/* U+011251 */
+	0,							/* U+011252 */
+	0,							/* U+011253 */
+	0,							/* U+011254 */
+	0,							/* U+011255 */
+	0,							/* U+011256 */
+	0,							/* U+011257 */
+	0,							/* U+011258 */
+	0,							/* U+011259 */
+	0,							/* U+01125A */
+	0,							/* U+01125B */
+	0,							/* U+01125C */
+	0,							/* U+01125D */
+	0,							/* U+01125E */
+	0,							/* U+01125F */
+	0,							/* U+011260 */
+	0,							/* U+011261 */
+	0,							/* U+011262 */
+	0,							/* U+011263 */
+	0,							/* U+011264 */
+	0,							/* U+011265 */
+	0,							/* U+011266 */
+	0,							/* U+011267 */
+	0,							/* U+011268 */
+	0,							/* U+011269 */
+	0,							/* U+01126A */
+	0,							/* U+01126B */
+	0,							/* U+01126C */
+	0,							/* U+01126D */
+	0,							/* U+01126E */
+	0,							/* U+01126F */
+	0,							/* U+011270 */
+	0,							/* U+011271 */
+	0,							/* U+011272 */
+	0,							/* U+011273 */
+	0,							/* U+011274 */
+	0,							/* U+011275 */
+	0,							/* U+011276 */
+	0,							/* U+011277 */
+	0,							/* U+011278 */
+	0,							/* U+011279 */
+	0,							/* U+01127A */
+	0,							/* U+01127B */
+	0,							/* U+01127C */
+	0,							/* U+01127D */
+	0,							/* U+01127E */
+	0,							/* U+01127F */
+	0,							/* U+011280 */
+	0,							/* U+011281 */
+	0,							/* U+011282 */
+	0,							/* U+011283 */
+	0,							/* U+011284 */
+	0,							/* U+011285 */
+	0,							/* U+011286 */
+	0,							/* U+011287 */
+	0,							/* U+011288 */
+	0,							/* U+011289 */
+	0,							/* U+01128A */
+	0,							/* U+01128B */
+	0,							/* U+01128C */
+	0,							/* U+01128D */
+	0,							/* U+01128E */
+	0,							/* U+01128F */
+	0,							/* U+011290 */
+	0,							/* U+011291 */
+	0,							/* U+011292 */
+	0,							/* U+011293 */
+	0,							/* U+011294 */
+	0,							/* U+011295 */
+	0,							/* U+011296 */
+	0,							/* U+011297 */
+	0,							/* U+011298 */
+	0,							/* U+011299 */
+	0,							/* U+01129A */
+	0,							/* U+01129B */
+	0,							/* U+01129C */
+	0,							/* U+01129D */
+	0,							/* U+01129E */
+	0,							/* U+01129F */
+	0,							/* U+0112A0 */
+	0,							/* U+0112A1 */
+	0,							/* U+0112A2 */
+	0,							/* U+0112A3 */
+	0,							/* U+0112A4 */
+	0,							/* U+0112A5 */
+	0,							/* U+0112A6 */
+	0,							/* U+0112A7 */
+	0,							/* U+0112A8 */
+	0,							/* U+0112A9 */
+	0,							/* U+0112AA */
+	0,							/* U+0112AB */
+	0,							/* U+0112AC */
+	0,							/* U+0112AD */
+	0,							/* U+0112AE */
+	0,							/* U+0112AF */
+	0,							/* U+0112B0 */
+	0,							/* U+0112B1 */
+	0,							/* U+0112B2 */
+	0,							/* U+0112B3 */
+	0,							/* U+0112B4 */
+	0,							/* U+0112B5 */
+	0,							/* U+0112B6 */
+	0,							/* U+0112B7 */
+	0,							/* U+0112B8 */
+	0,							/* U+0112B9 */
+	0,							/* U+0112BA */
+	0,							/* U+0112BB */
+	0,							/* U+0112BC */
+	0,							/* U+0112BD */
+	0,							/* U+0112BE */
+	0,							/* U+0112BF */
+	0,							/* U+0112C0 */
+	0,							/* U+0112C1 */
+	0,							/* U+0112C2 */
+	0,							/* U+0112C3 */
+	0,							/* U+0112C4 */
+	0,							/* U+0112C5 */
+	0,							/* U+0112C6 */
+	0,							/* U+0112C7 */
+	0,							/* U+0112C8 */
+	0,							/* U+0112C9 */
+	0,							/* U+0112CA */
+	0,							/* U+0112CB */
+	0,							/* U+0112CC */
+	0,							/* U+0112CD */
+	0,							/* U+0112CE */
+	0,							/* U+0112CF */
+	0,							/* U+0112D0 */
+	0,							/* U+0112D1 */
+	0,							/* U+0112D2 */
+	0,							/* U+0112D3 */
+	0,							/* U+0112D4 */
+	0,							/* U+0112D5 */
+	0,							/* U+0112D6 */
+	0,							/* U+0112D7 */
+	0,							/* U+0112D8 */
+	0,							/* U+0112D9 */
+	0,							/* U+0112DA */
+	0,							/* U+0112DB */
+	0,							/* U+0112DC */
+	0,							/* U+0112DD */
+	0,							/* U+0112DE */
+	0,							/* U+0112DF */
+	0,							/* U+0112E0 */
+	0,							/* U+0112E1 */
+	0,							/* U+0112E2 */
+	0,							/* U+0112E3 */
+	0,							/* U+0112E4 */
+	0,							/* U+0112E5 */
+	0,							/* U+0112E6 */
+	0,							/* U+0112E7 */
+	0,							/* U+0112E8 */
+	451,						/* U+0112E9 */
+	452,						/* U+0112EA */
+	0,							/* U+0112EB */
+	0,							/* U+0112EC */
+	0,							/* U+0112ED */
+	0,							/* U+0112EE */
+	0,							/* U+0112EF */
+	0,							/* U+0112F0 */
+	0,							/* U+0112F1 */
+	0,							/* U+0112F2 */
+	0,							/* U+0112F3 */
+	0,							/* U+0112F4 */
+	0,							/* U+0112F5 */
+	0,							/* U+0112F6 */
+	0,							/* U+0112F7 */
+	0,							/* U+0112F8 */
+	0,							/* U+0112F9 */
+	0,							/* U+0112FA */
+	0,							/* U+0112FB */
+	0,							/* U+0112FC */
+	0,							/* U+0112FD */
+	0,							/* U+0112FE */
+	0,							/* U+0112FF */
+	0,							/* U+011300 */
+	0,							/* U+011301 */
+	0,							/* U+011302 */
+	0,							/* U+011303 */
+	0,							/* U+011304 */
+	0,							/* U+011305 */
+	0,							/* U+011306 */
+	0,							/* U+011307 */
+	0,							/* U+011308 */
+	0,							/* U+011309 */
+	0,							/* U+01130A */
+	0,							/* U+01130B */
+	0,							/* U+01130C */
+	0,							/* U+01130D */
+	0,							/* U+01130E */
+	0,							/* U+01130F */
+	0,							/* U+011310 */
+	0,							/* U+011311 */
+	0,							/* U+011312 */
+	0,							/* U+011313 */
+	0,							/* U+011314 */
+	0,							/* U+011315 */
+	0,							/* U+011316 */
+	0,							/* U+011317 */
+	0,							/* U+011318 */
+	0,							/* U+011319 */
+	0,							/* U+01131A */
+	0,							/* U+01131B */
+	0,							/* U+01131C */
+	0,							/* U+01131D */
+	0,							/* U+01131E */
+	0,							/* U+01131F */
+	0,							/* U+011320 */
+	0,							/* U+011321 */
+	0,							/* U+011322 */
+	0,							/* U+011323 */
+	0,							/* U+011324 */
+	0,							/* U+011325 */
+	0,							/* U+011326 */
+	0,							/* U+011327 */
+	0,							/* U+011328 */
+	0,							/* U+011329 */
+	0,							/* U+01132A */
+	0,							/* U+01132B */
+	0,							/* U+01132C */
+	0,							/* U+01132D */
+	0,							/* U+01132E */
+	0,							/* U+01132F */
+	0,							/* U+011330 */
+	0,							/* U+011331 */
+	0,							/* U+011332 */
+	0,							/* U+011333 */
+	0,							/* U+011334 */
+	0,							/* U+011335 */
+	0,							/* U+011336 */
+	0,							/* U+011337 */
+	0,							/* U+011338 */
+	0,							/* U+011339 */
+	0,							/* U+01133A */
+	451,						/* U+01133B */
+	451,						/* U+01133C */
+	0,							/* U+01133D */
+	0,							/* U+01133E */
+	0,							/* U+01133F */
+	0,							/* U+011340 */
+	0,							/* U+011341 */
+	0,							/* U+011342 */
+	0,							/* U+011343 */
+	0,							/* U+011344 */
+	0,							/* U+011345 */
+	0,							/* U+011346 */
+	0,							/* U+011347 */
+	0,							/* U+011348 */
+	0,							/* U+011349 */
+	0,							/* U+01134A */
+	3244,						/* U+01134B */
+	3245,						/* U+01134C */
+	452,						/* U+01134D */
+	0,							/* U+01134E */
+	0,							/* U+01134F */
+	0,							/* U+011350 */
+	0,							/* U+011351 */
+	0,							/* U+011352 */
+	0,							/* U+011353 */
+	0,							/* U+011354 */
+	0,							/* U+011355 */
+	0,							/* U+011356 */
+	0,							/* U+011357 */
+	0,							/* U+011358 */
+	0,							/* U+011359 */
+	0,							/* U+01135A */
+	0,							/* U+01135B */
+	0,							/* U+01135C */
+	0,							/* U+01135D */
+	0,							/* U+01135E */
+	0,							/* U+01135F */
+	0,							/* U+011360 */
+	0,							/* U+011361 */
+	0,							/* U+011362 */
+	0,							/* U+011363 */
+	0,							/* U+011364 */
+	0,							/* U+011365 */
+	304,						/* U+011366 */
+	304,						/* U+011367 */
+	304,						/* U+011368 */
+	304,						/* U+011369 */
+	304,						/* U+01136A */
+	304,						/* U+01136B */
+	304,						/* U+01136C */
+	0,							/* U+01136D */
+	0,							/* U+01136E */
+	0,							/* U+01136F */
+	304,						/* U+011370 */
+	304,						/* U+011371 */
+	304,						/* U+011372 */
+	304,						/* U+011373 */
+	304,						/* U+011374 */
+	0,							/* U+011375 */
+	0,							/* U+011376 */
+	0,							/* U+011377 */
+	0,							/* U+011378 */
+	0,							/* U+011379 */
+	0,							/* U+01137A */
+	0,							/* U+01137B */
+	0,							/* U+01137C */
+	0,							/* U+01137D */
+	0,							/* U+01137E */
+	0,							/* U+01137F */
+	0,							/* U+011380 */
+	0,							/* U+011381 */
+	0,							/* U+011382 */
+	3246,						/* U+011383 */
+	0,							/* U+011384 */
+	3247,						/* U+011385 */
+	0,							/* U+011386 */
+	0,							/* U+011387 */
+	0,							/* U+011388 */
+	0,							/* U+011389 */
+	0,							/* U+01138A */
+	0,							/* U+01138B */
+	0,							/* U+01138C */
+	0,							/* U+01138D */
+	3248,						/* U+01138E */
+	0,							/* U+01138F */
+	0,							/* U+011390 */
+	3249,						/* U+011391 */
+	0,							/* U+011392 */
+	0,							/* U+011393 */
+	0,							/* U+011394 */
+	0,							/* U+011395 */
+	0,							/* U+011396 */
+	0,							/* U+011397 */
+	0,							/* U+011398 */
+	0,							/* U+011399 */
+	0,							/* U+01139A */
+	0,							/* U+01139B */
+	0,							/* U+01139C */
+	0,							/* U+01139D */
+	0,							/* U+01139E */
+	0,							/* U+01139F */
+	0,							/* U+0113A0 */
+	0,							/* U+0113A1 */
+	0,							/* U+0113A2 */
+	0,							/* U+0113A3 */
+	0,							/* U+0113A4 */
+	0,							/* U+0113A5 */
+	0,							/* U+0113A6 */
+	0,							/* U+0113A7 */
+	0,							/* U+0113A8 */
+	0,							/* U+0113A9 */
+	0,							/* U+0113AA */
+	0,							/* U+0113AB */
+	0,							/* U+0113AC */
+	0,							/* U+0113AD */
+	0,							/* U+0113AE */
+	0,							/* U+0113AF */
+	0,							/* U+0113B0 */
+	0,							/* U+0113B1 */
+	0,							/* U+0113B2 */
+	0,							/* U+0113B3 */
+	0,							/* U+0113B4 */
+	0,							/* U+0113B5 */
+	0,							/* U+0113B6 */
+	0,							/* U+0113B7 */
+	0,							/* U+0113B8 */
+	0,							/* U+0113B9 */
+	0,							/* U+0113BA */
+	0,							/* U+0113BB */
+	0,							/* U+0113BC */
+	0,							/* U+0113BD */
+	0,							/* U+0113BE */
+	0,							/* U+0113BF */
+	0,							/* U+0113C0 */
+	0,							/* U+0113C1 */
+	0,							/* U+0113C2 */
+	0,							/* U+0113C3 */
+	0,							/* U+0113C4 */
+	3250,						/* U+0113C5 */
+	0,							/* U+0113C6 */
+	3251,						/* U+0113C7 */
+	3252,						/* U+0113C8 */
+	0,							/* U+0113C9 */
+	0,							/* U+0113CA */
+	0,							/* U+0113CB */
+	0,							/* U+0113CC */
+	0,							/* U+0113CD */
+	452,						/* U+0113CE */
+	452,						/* U+0113CF */
+	452,						/* U+0113D0 */
+	0,							/* U+0113D1 */
+	0,							/* U+0113D2 */
+	0,							/* U+0113D3 */
+	0,							/* U+0113D4 */
+	0,							/* U+0113D5 */
+	0,							/* U+0113D6 */
+	0,							/* U+0113D7 */
+	0,							/* U+0113D8 */
+	0,							/* U+0113D9 */
+	0,							/* U+0113DA */
+	0,							/* U+0113DB */
+	0,							/* U+0113DC */
+	0,							/* U+0113DD */
+	0,							/* U+0113DE */
+	0,							/* U+0113DF */
+	0,							/* U+0113E0 */
+	0,							/* U+0113E1 */
+	0,							/* U+0113E2 */
+	0,							/* U+0113E3 */
+	0,							/* U+0113E4 */
+	0,							/* U+0113E5 */
+	0,							/* U+0113E6 */
+	0,							/* U+0113E7 */
+	0,							/* U+0113E8 */
+	0,							/* U+0113E9 */
+	0,							/* U+0113EA */
+	0,							/* U+0113EB */
+	0,							/* U+0113EC */
+	0,							/* U+0113ED */
+	0,							/* U+0113EE */
+	0,							/* U+0113EF */
+	0,							/* U+0113F0 */
+	0,							/* U+0113F1 */
+	0,							/* U+0113F2 */
+	0,							/* U+0113F3 */
+	0,							/* U+0113F4 */
+	0,							/* U+0113F5 */
+	0,							/* U+0113F6 */
+	0,							/* U+0113F7 */
+	0,							/* U+0113F8 */
+	0,							/* U+0113F9 */
+	0,							/* U+0113FA */
+	0,							/* U+0113FB */
+	0,							/* U+0113FC */
+	0,							/* U+0113FD */
+	0,							/* U+0113FE */
+	0,							/* U+0113FF */
+	0,							/* U+011400 */
+	0,							/* U+011401 */
+	0,							/* U+011402 */
+	0,							/* U+011403 */
+	0,							/* U+011404 */
+	0,							/* U+011405 */
+	0,							/* U+011406 */
+	0,							/* U+011407 */
+	0,							/* U+011408 */
+	0,							/* U+011409 */
+	0,							/* U+01140A */
+	0,							/* U+01140B */
+	0,							/* U+01140C */
+	0,							/* U+01140D */
+	0,							/* U+01140E */
+	0,							/* U+01140F */
+	0,							/* U+011410 */
+	0,							/* U+011411 */
+	0,							/* U+011412 */
+	0,							/* U+011413 */
+	0,							/* U+011414 */
+	0,							/* U+011415 */
+	0,							/* U+011416 */
+	0,							/* U+011417 */
+	0,							/* U+011418 */
+	0,							/* U+011419 */
+	0,							/* U+01141A */
+	0,							/* U+01141B */
+	0,							/* U+01141C */
+	0,							/* U+01141D */
+	0,							/* U+01141E */
+	0,							/* U+01141F */
+	0,							/* U+011420 */
+	0,							/* U+011421 */
+	0,							/* U+011422 */
+	0,							/* U+011423 */
+	0,							/* U+011424 */
+	0,							/* U+011425 */
+	0,							/* U+011426 */
+	0,							/* U+011427 */
+	0,							/* U+011428 */
+	0,							/* U+011429 */
+	0,							/* U+01142A */
+	0,							/* U+01142B */
+	0,							/* U+01142C */
+	0,							/* U+01142D */
+	0,							/* U+01142E */
+	0,							/* U+01142F */
+	0,							/* U+011430 */
+	0,							/* U+011431 */
+	0,							/* U+011432 */
+	0,							/* U+011433 */
+	0,							/* U+011434 */
+	0,							/* U+011435 */
+	0,							/* U+011436 */
+	0,							/* U+011437 */
+	0,							/* U+011438 */
+	0,							/* U+011439 */
+	0,							/* U+01143A */
+	0,							/* U+01143B */
+	0,							/* U+01143C */
+	0,							/* U+01143D */
+	0,							/* U+01143E */
+	0,							/* U+01143F */
+	0,							/* U+011440 */
+	0,							/* U+011441 */
+	452,						/* U+011442 */
+	0,							/* U+011443 */
+	0,							/* U+011444 */
+	0,							/* U+011445 */
+	451,						/* U+011446 */
+	0,							/* U+011447 */
+	0,							/* U+011448 */
+	0,							/* U+011449 */
+	0,							/* U+01144A */
+	0,							/* U+01144B */
+	0,							/* U+01144C */
+	0,							/* U+01144D */
+	0,							/* U+01144E */
+	0,							/* U+01144F */
+	0,							/* U+011450 */
+	0,							/* U+011451 */
+	0,							/* U+011452 */
+	0,							/* U+011453 */
+	0,							/* U+011454 */
+	0,							/* U+011455 */
+	0,							/* U+011456 */
+	0,							/* U+011457 */
+	0,							/* U+011458 */
+	0,							/* U+011459 */
+	0,							/* U+01145A */
+	0,							/* U+01145B */
+	0,							/* U+01145C */
+	0,							/* U+01145D */
+	304,						/* U+01145E */
+	0,							/* U+01145F */
+	0,							/* U+011460 */
+	0,							/* U+011461 */
+	0,							/* U+011462 */
+	0,							/* U+011463 */
+	0,							/* U+011464 */
+	0,							/* U+011465 */
+	0,							/* U+011466 */
+	0,							/* U+011467 */
+	0,							/* U+011468 */
+	0,							/* U+011469 */
+	0,							/* U+01146A */
+	0,							/* U+01146B */
+	0,							/* U+01146C */
+	0,							/* U+01146D */
+	0,							/* U+01146E */
+	0,							/* U+01146F */
+	0,							/* U+011470 */
+	0,							/* U+011471 */
+	0,							/* U+011472 */
+	0,							/* U+011473 */
+	0,							/* U+011474 */
+	0,							/* U+011475 */
+	0,							/* U+011476 */
+	0,							/* U+011477 */
+	0,							/* U+011478 */
+	0,							/* U+011479 */
+	0,							/* U+01147A */
+	0,							/* U+01147B */
+	0,							/* U+01147C */
+	0,							/* U+01147D */
+	0,							/* U+01147E */
+	0,							/* U+01147F */
+	0,							/* U+011480 */
+	0,							/* U+011481 */
+	0,							/* U+011482 */
+	0,							/* U+011483 */
+	0,							/* U+011484 */
+	0,							/* U+011485 */
+	0,							/* U+011486 */
+	0,							/* U+011487 */
+	0,							/* U+011488 */
+	0,							/* U+011489 */
+	0,							/* U+01148A */
+	0,							/* U+01148B */
+	0,							/* U+01148C */
+	0,							/* U+01148D */
+	0,							/* U+01148E */
+	0,							/* U+01148F */
+	0,							/* U+011490 */
+	0,							/* U+011491 */
+	0,							/* U+011492 */
+	0,							/* U+011493 */
+	0,							/* U+011494 */
+	0,							/* U+011495 */
+	0,							/* U+011496 */
+	0,							/* U+011497 */
+	0,							/* U+011498 */
+	0,							/* U+011499 */
+	0,							/* U+01149A */
+	0,							/* U+01149B */
+	0,							/* U+01149C */
+	0,							/* U+01149D */
+	0,							/* U+01149E */
+	0,							/* U+01149F */
+	0,							/* U+0114A0 */
+	0,							/* U+0114A1 */
+	0,							/* U+0114A2 */
+	0,							/* U+0114A3 */
+	0,							/* U+0114A4 */
+	0,							/* U+0114A5 */
+	0,							/* U+0114A6 */
+	0,							/* U+0114A7 */
+	0,							/* U+0114A8 */
+	0,							/* U+0114A9 */
+	0,							/* U+0114AA */
+	0,							/* U+0114AB */
+	0,							/* U+0114AC */
+	0,							/* U+0114AD */
+	0,							/* U+0114AE */
+	0,							/* U+0114AF */
+	0,							/* U+0114B0 */
+	0,							/* U+0114B1 */
+	0,							/* U+0114B2 */
+	0,							/* U+0114B3 */
+	0,							/* U+0114B4 */
+	0,							/* U+0114B5 */
+	0,							/* U+0114B6 */
+	0,							/* U+0114B7 */
+	0,							/* U+0114B8 */
+	0,							/* U+0114B9 */
+	0,							/* U+0114BA */
+	3253,						/* U+0114BB */
+	3254,						/* U+0114BC */
+	0,							/* U+0114BD */
+	3255,						/* U+0114BE */
+	0,							/* U+0114BF */
+	0,							/* U+0114C0 */
+	0,							/* U+0114C1 */
+	452,						/* U+0114C2 */
+	451,						/* U+0114C3 */
+	0,							/* U+0114C4 */
+	0,							/* U+0114C5 */
+	0,							/* U+0114C6 */
+	0,							/* U+0114C7 */
+	0,							/* U+0114C8 */
+	0,							/* U+0114C9 */
+	0,							/* U+0114CA */
+	0,							/* U+0114CB */
+	0,							/* U+0114CC */
+	0,							/* U+0114CD */
+	0,							/* U+0114CE */
+	0,							/* U+0114CF */
+	0,							/* U+0114D0 */
+	0,							/* U+0114D1 */
+	0,							/* U+0114D2 */
+	0,							/* U+0114D3 */
+	0,							/* U+0114D4 */
+	0,							/* U+0114D5 */
+	0,							/* U+0114D6 */
+	0,							/* U+0114D7 */
+	0,							/* U+0114D8 */
+	0,							/* U+0114D9 */
+	0,							/* U+0114DA */
+	0,							/* U+0114DB */
+	0,							/* U+0114DC */
+	0,							/* U+0114DD */
+	0,							/* U+0114DE */
+	0,							/* U+0114DF */
+	0,							/* U+0114E0 */
+	0,							/* U+0114E1 */
+	0,							/* U+0114E2 */
+	0,							/* U+0114E3 */
+	0,							/* U+0114E4 */
+	0,							/* U+0114E5 */
+	0,							/* U+0114E6 */
+	0,							/* U+0114E7 */
+	0,							/* U+0114E8 */
+	0,							/* U+0114E9 */
+	0,							/* U+0114EA */
+	0,							/* U+0114EB */
+	0,							/* U+0114EC */
+	0,							/* U+0114ED */
+	0,							/* U+0114EE */
+	0,							/* U+0114EF */
+	0,							/* U+0114F0 */
+	0,							/* U+0114F1 */
+	0,							/* U+0114F2 */
+	0,							/* U+0114F3 */
+	0,							/* U+0114F4 */
+	0,							/* U+0114F5 */
+	0,							/* U+0114F6 */
+	0,							/* U+0114F7 */
+	0,							/* U+0114F8 */
+	0,							/* U+0114F9 */
+	0,							/* U+0114FA */
+	0,							/* U+0114FB */
+	0,							/* U+0114FC */
+	0,							/* U+0114FD */
+	0,							/* U+0114FE */
+	0,							/* U+0114FF */
+	0,							/* U+011500 */
+	0,							/* U+011501 */
+	0,							/* U+011502 */
+	0,							/* U+011503 */
+	0,							/* U+011504 */
+	0,							/* U+011505 */
+	0,							/* U+011506 */
+	0,							/* U+011507 */
+	0,							/* U+011508 */
+	0,							/* U+011509 */
+	0,							/* U+01150A */
+	0,							/* U+01150B */
+	0,							/* U+01150C */
+	0,							/* U+01150D */
+	0,							/* U+01150E */
+	0,							/* U+01150F */
+	0,							/* U+011510 */
+	0,							/* U+011511 */
+	0,							/* U+011512 */
+	0,							/* U+011513 */
+	0,							/* U+011514 */
+	0,							/* U+011515 */
+	0,							/* U+011516 */
+	0,							/* U+011517 */
+	0,							/* U+011518 */
+	0,							/* U+011519 */
+	0,							/* U+01151A */
+	0,							/* U+01151B */
+	0,							/* U+01151C */
+	0,							/* U+01151D */
+	0,							/* U+01151E */
+	0,							/* U+01151F */
+	0,							/* U+011520 */
+	0,							/* U+011521 */
+	0,							/* U+011522 */
+	0,							/* U+011523 */
+	0,							/* U+011524 */
+	0,							/* U+011525 */
+	0,							/* U+011526 */
+	0,							/* U+011527 */
+	0,							/* U+011528 */
+	0,							/* U+011529 */
+	0,							/* U+01152A */
+	0,							/* U+01152B */
+	0,							/* U+01152C */
+	0,							/* U+01152D */
+	0,							/* U+01152E */
+	0,							/* U+01152F */
+	0,							/* U+011530 */
+	0,							/* U+011531 */
+	0,							/* U+011532 */
+	0,							/* U+011533 */
+	0,							/* U+011534 */
+	0,							/* U+011535 */
+	0,							/* U+011536 */
+	0,							/* U+011537 */
+	0,							/* U+011538 */
+	0,							/* U+011539 */
+	0,							/* U+01153A */
+	0,							/* U+01153B */
+	0,							/* U+01153C */
+	0,							/* U+01153D */
+	0,							/* U+01153E */
+	0,							/* U+01153F */
+	0,							/* U+011540 */
+	0,							/* U+011541 */
+	0,							/* U+011542 */
+	0,							/* U+011543 */
+	0,							/* U+011544 */
+	0,							/* U+011545 */
+	0,							/* U+011546 */
+	0,							/* U+011547 */
+	0,							/* U+011548 */
+	0,							/* U+011549 */
+	0,							/* U+01154A */
+	0,							/* U+01154B */
+	0,							/* U+01154C */
+	0,							/* U+01154D */
+	0,							/* U+01154E */
+	0,							/* U+01154F */
+	0,							/* U+011550 */
+	0,							/* U+011551 */
+	0,							/* U+011552 */
+	0,							/* U+011553 */
+	0,							/* U+011554 */
+	0,							/* U+011555 */
+	0,							/* U+011556 */
+	0,							/* U+011557 */
+	0,							/* U+011558 */
+	0,							/* U+011559 */
+	0,							/* U+01155A */
+	0,							/* U+01155B */
+	0,							/* U+01155C */
+	0,							/* U+01155D */
+	0,							/* U+01155E */
+	0,							/* U+01155F */
+	0,							/* U+011560 */
+	0,							/* U+011561 */
+	0,							/* U+011562 */
+	0,							/* U+011563 */
+	0,							/* U+011564 */
+	0,							/* U+011565 */
+	0,							/* U+011566 */
+	0,							/* U+011567 */
+	0,							/* U+011568 */
+	0,							/* U+011569 */
+	0,							/* U+01156A */
+	0,							/* U+01156B */
+	0,							/* U+01156C */
+	0,							/* U+01156D */
+	0,							/* U+01156E */
+	0,							/* U+01156F */
+	0,							/* U+011570 */
+	0,							/* U+011571 */
+	0,							/* U+011572 */
+	0,							/* U+011573 */
+	0,							/* U+011574 */
+	0,							/* U+011575 */
+	0,							/* U+011576 */
+	0,							/* U+011577 */
+	0,							/* U+011578 */
+	0,							/* U+011579 */
+	0,							/* U+01157A */
+	0,							/* U+01157B */
+	0,							/* U+01157C */
+	0,							/* U+01157D */
+	0,							/* U+01157E */
+	0,							/* U+01157F */
+	0,							/* U+011580 */
+	0,							/* U+011581 */
+	0,							/* U+011582 */
+	0,							/* U+011583 */
+	0,							/* U+011584 */
+	0,							/* U+011585 */
+	0,							/* U+011586 */
+	0,							/* U+011587 */
+	0,							/* U+011588 */
+	0,							/* U+011589 */
+	0,							/* U+01158A */
+	0,							/* U+01158B */
+	0,							/* U+01158C */
+	0,							/* U+01158D */
+	0,							/* U+01158E */
+	0,							/* U+01158F */
+	0,							/* U+011590 */
+	0,							/* U+011591 */
+	0,							/* U+011592 */
+	0,							/* U+011593 */
+	0,							/* U+011594 */
+	0,							/* U+011595 */
+	0,							/* U+011596 */
+	0,							/* U+011597 */
+	0,							/* U+011598 */
+	0,							/* U+011599 */
+	0,							/* U+01159A */
+	0,							/* U+01159B */
+	0,							/* U+01159C */
+	0,							/* U+01159D */
+	0,							/* U+01159E */
+	0,							/* U+01159F */
+	0,							/* U+0115A0 */
+	0,							/* U+0115A1 */
+	0,							/* U+0115A2 */
+	0,							/* U+0115A3 */
+	0,							/* U+0115A4 */
+	0,							/* U+0115A5 */
+	0,							/* U+0115A6 */
+	0,							/* U+0115A7 */
+	0,							/* U+0115A8 */
+	0,							/* U+0115A9 */
+	0,							/* U+0115AA */
+	0,							/* U+0115AB */
+	0,							/* U+0115AC */
+	0,							/* U+0115AD */
+	0,							/* U+0115AE */
+	0,							/* U+0115AF */
+	0,							/* U+0115B0 */
+	0,							/* U+0115B1 */
+	0,							/* U+0115B2 */
+	0,							/* U+0115B3 */
+	0,							/* U+0115B4 */
+	0,							/* U+0115B5 */
+	0,							/* U+0115B6 */
+	0,							/* U+0115B7 */
+	0,							/* U+0115B8 */
+	0,							/* U+0115B9 */
+	3256,						/* U+0115BA */
+	3257,						/* U+0115BB */
+	0,							/* U+0115BC */
+	0,							/* U+0115BD */
+	0,							/* U+0115BE */
+	452,						/* U+0115BF */
+	451,						/* U+0115C0 */
+	0,							/* U+0115C1 */
+	0,							/* U+0115C2 */
+	0,							/* U+0115C3 */
+	0,							/* U+0115C4 */
+	0,							/* U+0115C5 */
+	0,							/* U+0115C6 */
+	0,							/* U+0115C7 */
+	0,							/* U+0115C8 */
+	0,							/* U+0115C9 */
+	0,							/* U+0115CA */
+	0,							/* U+0115CB */
+	0,							/* U+0115CC */
+	0,							/* U+0115CD */
+	0,							/* U+0115CE */
+	0,							/* U+0115CF */
+	0,							/* U+0115D0 */
+	0,							/* U+0115D1 */
+	0,							/* U+0115D2 */
+	0,							/* U+0115D3 */
+	0,							/* U+0115D4 */
+	0,							/* U+0115D5 */
+	0,							/* U+0115D6 */
+	0,							/* U+0115D7 */
+	0,							/* U+0115D8 */
+	0,							/* U+0115D9 */
+	0,							/* U+0115DA */
+	0,							/* U+0115DB */
+	0,							/* U+0115DC */
+	0,							/* U+0115DD */
+	0,							/* U+0115DE */
+	0,							/* U+0115DF */
+	0,							/* U+0115E0 */
+	0,							/* U+0115E1 */
+	0,							/* U+0115E2 */
+	0,							/* U+0115E3 */
+	0,							/* U+0115E4 */
+	0,							/* U+0115E5 */
+	0,							/* U+0115E6 */
+	0,							/* U+0115E7 */
+	0,							/* U+0115E8 */
+	0,							/* U+0115E9 */
+	0,							/* U+0115EA */
+	0,							/* U+0115EB */
+	0,							/* U+0115EC */
+	0,							/* U+0115ED */
+	0,							/* U+0115EE */
+	0,							/* U+0115EF */
+	0,							/* U+0115F0 */
+	0,							/* U+0115F1 */
+	0,							/* U+0115F2 */
+	0,							/* U+0115F3 */
+	0,							/* U+0115F4 */
+	0,							/* U+0115F5 */
+	0,							/* U+0115F6 */
+	0,							/* U+0115F7 */
+	0,							/* U+0115F8 */
+	0,							/* U+0115F9 */
+	0,							/* U+0115FA */
+	0,							/* U+0115FB */
+	0,							/* U+0115FC */
+	0,							/* U+0115FD */
+	0,							/* U+0115FE */
+	0,							/* U+0115FF */
+	0,							/* U+011600 */
+	0,							/* U+011601 */
+	0,							/* U+011602 */
+	0,							/* U+011603 */
+	0,							/* U+011604 */
+	0,							/* U+011605 */
+	0,							/* U+011606 */
+	0,							/* U+011607 */
+	0,							/* U+011608 */
+	0,							/* U+011609 */
+	0,							/* U+01160A */
+	0,							/* U+01160B */
+	0,							/* U+01160C */
+	0,							/* U+01160D */
+	0,							/* U+01160E */
+	0,							/* U+01160F */
+	0,							/* U+011610 */
+	0,							/* U+011611 */
+	0,							/* U+011612 */
+	0,							/* U+011613 */
+	0,							/* U+011614 */
+	0,							/* U+011615 */
+	0,							/* U+011616 */
+	0,							/* U+011617 */
+	0,							/* U+011618 */
+	0,							/* U+011619 */
+	0,							/* U+01161A */
+	0,							/* U+01161B */
+	0,							/* U+01161C */
+	0,							/* U+01161D */
+	0,							/* U+01161E */
+	0,							/* U+01161F */
+	0,							/* U+011620 */
+	0,							/* U+011621 */
+	0,							/* U+011622 */
+	0,							/* U+011623 */
+	0,							/* U+011624 */
+	0,							/* U+011625 */
+	0,							/* U+011626 */
+	0,							/* U+011627 */
+	0,							/* U+011628 */
+	0,							/* U+011629 */
+	0,							/* U+01162A */
+	0,							/* U+01162B */
+	0,							/* U+01162C */
+	0,							/* U+01162D */
+	0,							/* U+01162E */
+	0,							/* U+01162F */
+	0,							/* U+011630 */
+	0,							/* U+011631 */
+	0,							/* U+011632 */
+	0,							/* U+011633 */
+	0,							/* U+011634 */
+	0,							/* U+011635 */
+	0,							/* U+011636 */
+	0,							/* U+011637 */
+	0,							/* U+011638 */
+	0,							/* U+011639 */
+	0,							/* U+01163A */
+	0,							/* U+01163B */
+	0,							/* U+01163C */
+	0,							/* U+01163D */
+	0,							/* U+01163E */
+	452,						/* U+01163F */
+	0,							/* U+011640 */
+	0,							/* U+011641 */
+	0,							/* U+011642 */
+	0,							/* U+011643 */
+	0,							/* U+011644 */
+	0,							/* U+011645 */
+	0,							/* U+011646 */
+	0,							/* U+011647 */
+	0,							/* U+011648 */
+	0,							/* U+011649 */
+	0,							/* U+01164A */
+	0,							/* U+01164B */
+	0,							/* U+01164C */
+	0,							/* U+01164D */
+	0,							/* U+01164E */
+	0,							/* U+01164F */
+	0,							/* U+011650 */
+	0,							/* U+011651 */
+	0,							/* U+011652 */
+	0,							/* U+011653 */
+	0,							/* U+011654 */
+	0,							/* U+011655 */
+	0,							/* U+011656 */
+	0,							/* U+011657 */
+	0,							/* U+011658 */
+	0,							/* U+011659 */
+	0,							/* U+01165A */
+	0,							/* U+01165B */
+	0,							/* U+01165C */
+	0,							/* U+01165D */
+	0,							/* U+01165E */
+	0,							/* U+01165F */
+	0,							/* U+011660 */
+	0,							/* U+011661 */
+	0,							/* U+011662 */
+	0,							/* U+011663 */
+	0,							/* U+011664 */
+	0,							/* U+011665 */
+	0,							/* U+011666 */
+	0,							/* U+011667 */
+	0,							/* U+011668 */
+	0,							/* U+011669 */
+	0,							/* U+01166A */
+	0,							/* U+01166B */
+	0,							/* U+01166C */
+	0,							/* U+01166D */
+	0,							/* U+01166E */
+	0,							/* U+01166F */
+	0,							/* U+011670 */
+	0,							/* U+011671 */
+	0,							/* U+011672 */
+	0,							/* U+011673 */
+	0,							/* U+011674 */
+	0,							/* U+011675 */
+	0,							/* U+011676 */
+	0,							/* U+011677 */
+	0,							/* U+011678 */
+	0,							/* U+011679 */
+	0,							/* U+01167A */
+	0,							/* U+01167B */
+	0,							/* U+01167C */
+	0,							/* U+01167D */
+	0,							/* U+01167E */
+	0,							/* U+01167F */
+	0,							/* U+011680 */
+	0,							/* U+011681 */
+	0,							/* U+011682 */
+	0,							/* U+011683 */
+	0,							/* U+011684 */
+	0,							/* U+011685 */
+	0,							/* U+011686 */
+	0,							/* U+011687 */
+	0,							/* U+011688 */
+	0,							/* U+011689 */
+	0,							/* U+01168A */
+	0,							/* U+01168B */
+	0,							/* U+01168C */
+	0,							/* U+01168D */
+	0,							/* U+01168E */
+	0,							/* U+01168F */
+	0,							/* U+011690 */
+	0,							/* U+011691 */
+	0,							/* U+011692 */
+	0,							/* U+011693 */
+	0,							/* U+011694 */
+	0,							/* U+011695 */
+	0,							/* U+011696 */
+	0,							/* U+011697 */
+	0,							/* U+011698 */
+	0,							/* U+011699 */
+	0,							/* U+01169A */
+	0,							/* U+01169B */
+	0,							/* U+01169C */
+	0,							/* U+01169D */
+	0,							/* U+01169E */
+	0,							/* U+01169F */
+	0,							/* U+0116A0 */
+	0,							/* U+0116A1 */
+	0,							/* U+0116A2 */
+	0,							/* U+0116A3 */
+	0,							/* U+0116A4 */
+	0,							/* U+0116A5 */
+	0,							/* U+0116A6 */
+	0,							/* U+0116A7 */
+	0,							/* U+0116A8 */
+	0,							/* U+0116A9 */
+	0,							/* U+0116AA */
+	0,							/* U+0116AB */
+	0,							/* U+0116AC */
+	0,							/* U+0116AD */
+	0,							/* U+0116AE */
+	0,							/* U+0116AF */
+	0,							/* U+0116B0 */
+	0,							/* U+0116B1 */
+	0,							/* U+0116B2 */
+	0,							/* U+0116B3 */
+	0,							/* U+0116B4 */
+	0,							/* U+0116B5 */
+	452,						/* U+0116B6 */
+	451,						/* U+0116B7 */
+	0,							/* U+0116B8 */
+	0,							/* U+0116B9 */
+	0,							/* U+0116BA */
+	0,							/* U+0116BB */
+	0,							/* U+0116BC */
+	0,							/* U+0116BD */
+	0,							/* U+0116BE */
+	0,							/* U+0116BF */
+	0,							/* U+0116C0 */
+	0,							/* U+0116C1 */
+	0,							/* U+0116C2 */
+	0,							/* U+0116C3 */
+	0,							/* U+0116C4 */
+	0,							/* U+0116C5 */
+	0,							/* U+0116C6 */
+	0,							/* U+0116C7 */
+	0,							/* U+0116C8 */
+	0,							/* U+0116C9 */
+	0,							/* U+0116CA */
+	0,							/* U+0116CB */
+	0,							/* U+0116CC */
+	0,							/* U+0116CD */
+	0,							/* U+0116CE */
+	0,							/* U+0116CF */
+	0,							/* U+0116D0 */
+	0,							/* U+0116D1 */
+	0,							/* U+0116D2 */
+	0,							/* U+0116D3 */
+	0,							/* U+0116D4 */
+	0,							/* U+0116D5 */
+	0,							/* U+0116D6 */
+	0,							/* U+0116D7 */
+	0,							/* U+0116D8 */
+	0,							/* U+0116D9 */
+	0,							/* U+0116DA */
+	0,							/* U+0116DB */
+	0,							/* U+0116DC */
+	0,							/* U+0116DD */
+	0,							/* U+0116DE */
+	0,							/* U+0116DF */
+	0,							/* U+0116E0 */
+	0,							/* U+0116E1 */
+	0,							/* U+0116E2 */
+	0,							/* U+0116E3 */
+	0,							/* U+0116E4 */
+	0,							/* U+0116E5 */
+	0,							/* U+0116E6 */
+	0,							/* U+0116E7 */
+	0,							/* U+0116E8 */
+	0,							/* U+0116E9 */
+	0,							/* U+0116EA */
+	0,							/* U+0116EB */
+	0,							/* U+0116EC */
+	0,							/* U+0116ED */
+	0,							/* U+0116EE */
+	0,							/* U+0116EF */
+	0,							/* U+0116F0 */
+	0,							/* U+0116F1 */
+	0,							/* U+0116F2 */
+	0,							/* U+0116F3 */
+	0,							/* U+0116F4 */
+	0,							/* U+0116F5 */
+	0,							/* U+0116F6 */
+	0,							/* U+0116F7 */
+	0,							/* U+0116F8 */
+	0,							/* U+0116F9 */
+	0,							/* U+0116FA */
+	0,							/* U+0116FB */
+	0,							/* U+0116FC */
+	0,							/* U+0116FD */
+	0,							/* U+0116FE */
+	0,							/* U+0116FF */
+	0,							/* U+011700 */
+	0,							/* U+011701 */
+	0,							/* U+011702 */
+	0,							/* U+011703 */
+	0,							/* U+011704 */
+	0,							/* U+011705 */
+	0,							/* U+011706 */
+	0,							/* U+011707 */
+	0,							/* U+011708 */
+	0,							/* U+011709 */
+	0,							/* U+01170A */
+	0,							/* U+01170B */
+	0,							/* U+01170C */
+	0,							/* U+01170D */
+	0,							/* U+01170E */
+	0,							/* U+01170F */
+	0,							/* U+011710 */
+	0,							/* U+011711 */
+	0,							/* U+011712 */
+	0,							/* U+011713 */
+	0,							/* U+011714 */
+	0,							/* U+011715 */
+	0,							/* U+011716 */
+	0,							/* U+011717 */
+	0,							/* U+011718 */
+	0,							/* U+011719 */
+	0,							/* U+01171A */
+	0,							/* U+01171B */
+	0,							/* U+01171C */
+	0,							/* U+01171D */
+	0,							/* U+01171E */
+	0,							/* U+01171F */
+	0,							/* U+011720 */
+	0,							/* U+011721 */
+	0,							/* U+011722 */
+	0,							/* U+011723 */
+	0,							/* U+011724 */
+	0,							/* U+011725 */
+	0,							/* U+011726 */
+	0,							/* U+011727 */
+	0,							/* U+011728 */
+	0,							/* U+011729 */
+	0,							/* U+01172A */
+	452,						/* U+01172B */
+	0,							/* U+01172C */
+	0,							/* U+01172D */
+	0,							/* U+01172E */
+	0,							/* U+01172F */
+	0,							/* U+011730 */
+	0,							/* U+011731 */
+	0,							/* U+011732 */
+	0,							/* U+011733 */
+	0,							/* U+011734 */
+	0,							/* U+011735 */
+	0,							/* U+011736 */
+	0,							/* U+011737 */
+	0,							/* U+011738 */
+	0,							/* U+011739 */
+	0,							/* U+01173A */
+	0,							/* U+01173B */
+	0,							/* U+01173C */
+	0,							/* U+01173D */
+	0,							/* U+01173E */
+	0,							/* U+01173F */
+	0,							/* U+011740 */
+	0,							/* U+011741 */
+	0,							/* U+011742 */
+	0,							/* U+011743 */
+	0,							/* U+011744 */
+	0,							/* U+011745 */
+	0,							/* U+011746 */
+	0,							/* U+011747 */
+	0,							/* U+011748 */
+	0,							/* U+011749 */
+	0,							/* U+01174A */
+	0,							/* U+01174B */
+	0,							/* U+01174C */
+	0,							/* U+01174D */
+	0,							/* U+01174E */
+	0,							/* U+01174F */
+	0,							/* U+011750 */
+	0,							/* U+011751 */
+	0,							/* U+011752 */
+	0,							/* U+011753 */
+	0,							/* U+011754 */
+	0,							/* U+011755 */
+	0,							/* U+011756 */
+	0,							/* U+011757 */
+	0,							/* U+011758 */
+	0,							/* U+011759 */
+	0,							/* U+01175A */
+	0,							/* U+01175B */
+	0,							/* U+01175C */
+	0,							/* U+01175D */
+	0,							/* U+01175E */
+	0,							/* U+01175F */
+	0,							/* U+011760 */
+	0,							/* U+011761 */
+	0,							/* U+011762 */
+	0,							/* U+011763 */
+	0,							/* U+011764 */
+	0,							/* U+011765 */
+	0,							/* U+011766 */
+	0,							/* U+011767 */
+	0,							/* U+011768 */
+	0,							/* U+011769 */
+	0,							/* U+01176A */
+	0,							/* U+01176B */
+	0,							/* U+01176C */
+	0,							/* U+01176D */
+	0,							/* U+01176E */
+	0,							/* U+01176F */
+	0,							/* U+011770 */
+	0,							/* U+011771 */
+	0,							/* U+011772 */
+	0,							/* U+011773 */
+	0,							/* U+011774 */
+	0,							/* U+011775 */
+	0,							/* U+011776 */
+	0,							/* U+011777 */
+	0,							/* U+011778 */
+	0,							/* U+011779 */
+	0,							/* U+01177A */
+	0,							/* U+01177B */
+	0,							/* U+01177C */
+	0,							/* U+01177D */
+	0,							/* U+01177E */
+	0,							/* U+01177F */
+	0,							/* U+011780 */
+	0,							/* U+011781 */
+	0,							/* U+011782 */
+	0,							/* U+011783 */
+	0,							/* U+011784 */
+	0,							/* U+011785 */
+	0,							/* U+011786 */
+	0,							/* U+011787 */
+	0,							/* U+011788 */
+	0,							/* U+011789 */
+	0,							/* U+01178A */
+	0,							/* U+01178B */
+	0,							/* U+01178C */
+	0,							/* U+01178D */
+	0,							/* U+01178E */
+	0,							/* U+01178F */
+	0,							/* U+011790 */
+	0,							/* U+011791 */
+	0,							/* U+011792 */
+	0,							/* U+011793 */
+	0,							/* U+011794 */
+	0,							/* U+011795 */
+	0,							/* U+011796 */
+	0,							/* U+011797 */
+	0,							/* U+011798 */
+	0,							/* U+011799 */
+	0,							/* U+01179A */
+	0,							/* U+01179B */
+	0,							/* U+01179C */
+	0,							/* U+01179D */
+	0,							/* U+01179E */
+	0,							/* U+01179F */
+	0,							/* U+0117A0 */
+	0,							/* U+0117A1 */
+	0,							/* U+0117A2 */
+	0,							/* U+0117A3 */
+	0,							/* U+0117A4 */
+	0,							/* U+0117A5 */
+	0,							/* U+0117A6 */
+	0,							/* U+0117A7 */
+	0,							/* U+0117A8 */
+	0,							/* U+0117A9 */
+	0,							/* U+0117AA */
+	0,							/* U+0117AB */
+	0,							/* U+0117AC */
+	0,							/* U+0117AD */
+	0,							/* U+0117AE */
+	0,							/* U+0117AF */
+	0,							/* U+0117B0 */
+	0,							/* U+0117B1 */
+	0,							/* U+0117B2 */
+	0,							/* U+0117B3 */
+	0,							/* U+0117B4 */
+	0,							/* U+0117B5 */
+	0,							/* U+0117B6 */
+	0,							/* U+0117B7 */
+	0,							/* U+0117B8 */
+	0,							/* U+0117B9 */
+	0,							/* U+0117BA */
+	0,							/* U+0117BB */
+	0,							/* U+0117BC */
+	0,							/* U+0117BD */
+	0,							/* U+0117BE */
+	0,							/* U+0117BF */
+	0,							/* U+0117C0 */
+	0,							/* U+0117C1 */
+	0,							/* U+0117C2 */
+	0,							/* U+0117C3 */
+	0,							/* U+0117C4 */
+	0,							/* U+0117C5 */
+	0,							/* U+0117C6 */
+	0,							/* U+0117C7 */
+	0,							/* U+0117C8 */
+	0,							/* U+0117C9 */
+	0,							/* U+0117CA */
+	0,							/* U+0117CB */
+	0,							/* U+0117CC */
+	0,							/* U+0117CD */
+	0,							/* U+0117CE */
+	0,							/* U+0117CF */
+	0,							/* U+0117D0 */
+	0,							/* U+0117D1 */
+	0,							/* U+0117D2 */
+	0,							/* U+0117D3 */
+	0,							/* U+0117D4 */
+	0,							/* U+0117D5 */
+	0,							/* U+0117D6 */
+	0,							/* U+0117D7 */
+	0,							/* U+0117D8 */
+	0,							/* U+0117D9 */
+	0,							/* U+0117DA */
+	0,							/* U+0117DB */
+	0,							/* U+0117DC */
+	0,							/* U+0117DD */
+	0,							/* U+0117DE */
+	0,							/* U+0117DF */
+	0,							/* U+0117E0 */
+	0,							/* U+0117E1 */
+	0,							/* U+0117E2 */
+	0,							/* U+0117E3 */
+	0,							/* U+0117E4 */
+	0,							/* U+0117E5 */
+	0,							/* U+0117E6 */
+	0,							/* U+0117E7 */
+	0,							/* U+0117E8 */
+	0,							/* U+0117E9 */
+	0,							/* U+0117EA */
+	0,							/* U+0117EB */
+	0,							/* U+0117EC */
+	0,							/* U+0117ED */
+	0,							/* U+0117EE */
+	0,							/* U+0117EF */
+	0,							/* U+0117F0 */
+	0,							/* U+0117F1 */
+	0,							/* U+0117F2 */
+	0,							/* U+0117F3 */
+	0,							/* U+0117F4 */
+	0,							/* U+0117F5 */
+	0,							/* U+0117F6 */
+	0,							/* U+0117F7 */
+	0,							/* U+0117F8 */
+	0,							/* U+0117F9 */
+	0,							/* U+0117FA */
+	0,							/* U+0117FB */
+	0,							/* U+0117FC */
+	0,							/* U+0117FD */
+	0,							/* U+0117FE */
+	0,							/* U+0117FF */
+	0,							/* U+011800 */
+	0,							/* U+011801 */
+	0,							/* U+011802 */
+	0,							/* U+011803 */
+	0,							/* U+011804 */
+	0,							/* U+011805 */
+	0,							/* U+011806 */
+	0,							/* U+011807 */
+	0,							/* U+011808 */
+	0,							/* U+011809 */
+	0,							/* U+01180A */
+	0,							/* U+01180B */
+	0,							/* U+01180C */
+	0,							/* U+01180D */
+	0,							/* U+01180E */
+	0,							/* U+01180F */
+	0,							/* U+011810 */
+	0,							/* U+011811 */
+	0,							/* U+011812 */
+	0,							/* U+011813 */
+	0,							/* U+011814 */
+	0,							/* U+011815 */
+	0,							/* U+011816 */
+	0,							/* U+011817 */
+	0,							/* U+011818 */
+	0,							/* U+011819 */
+	0,							/* U+01181A */
+	0,							/* U+01181B */
+	0,							/* U+01181C */
+	0,							/* U+01181D */
+	0,							/* U+01181E */
+	0,							/* U+01181F */
+	0,							/* U+011820 */
+	0,							/* U+011821 */
+	0,							/* U+011822 */
+	0,							/* U+011823 */
+	0,							/* U+011824 */
+	0,							/* U+011825 */
+	0,							/* U+011826 */
+	0,							/* U+011827 */
+	0,							/* U+011828 */
+	0,							/* U+011829 */
+	0,							/* U+01182A */
+	0,							/* U+01182B */
+	0,							/* U+01182C */
+	0,							/* U+01182D */
+	0,							/* U+01182E */
+	0,							/* U+01182F */
+	0,							/* U+011830 */
+	0,							/* U+011831 */
+	0,							/* U+011832 */
+	0,							/* U+011833 */
+	0,							/* U+011834 */
+	0,							/* U+011835 */
+	0,							/* U+011836 */
+	0,							/* U+011837 */
+	0,							/* U+011838 */
+	452,						/* U+011839 */
+	451,						/* U+01183A */
+	0,							/* U+01183B */
+	0,							/* U+01183C */
+	0,							/* U+01183D */
+	0,							/* U+01183E */
+	0,							/* U+01183F */
+	0,							/* U+011840 */
+	0,							/* U+011841 */
+	0,							/* U+011842 */
+	0,							/* U+011843 */
+	0,							/* U+011844 */
+	0,							/* U+011845 */
+	0,							/* U+011846 */
+	0,							/* U+011847 */
+	0,							/* U+011848 */
+	0,							/* U+011849 */
+	0,							/* U+01184A */
+	0,							/* U+01184B */
+	0,							/* U+01184C */
+	0,							/* U+01184D */
+	0,							/* U+01184E */
+	0,							/* U+01184F */
+	0,							/* U+011850 */
+	0,							/* U+011851 */
+	0,							/* U+011852 */
+	0,							/* U+011853 */
+	0,							/* U+011854 */
+	0,							/* U+011855 */
+	0,							/* U+011856 */
+	0,							/* U+011857 */
+	0,							/* U+011858 */
+	0,							/* U+011859 */
+	0,							/* U+01185A */
+	0,							/* U+01185B */
+	0,							/* U+01185C */
+	0,							/* U+01185D */
+	0,							/* U+01185E */
+	0,							/* U+01185F */
+	0,							/* U+011860 */
+	0,							/* U+011861 */
+	0,							/* U+011862 */
+	0,							/* U+011863 */
+	0,							/* U+011864 */
+	0,							/* U+011865 */
+	0,							/* U+011866 */
+	0,							/* U+011867 */
+	0,							/* U+011868 */
+	0,							/* U+011869 */
+	0,							/* U+01186A */
+	0,							/* U+01186B */
+	0,							/* U+01186C */
+	0,							/* U+01186D */
+	0,							/* U+01186E */
+	0,							/* U+01186F */
+	0,							/* U+011870 */
+	0,							/* U+011871 */
+	0,							/* U+011872 */
+	0,							/* U+011873 */
+	0,							/* U+011874 */
+	0,							/* U+011875 */
+	0,							/* U+011876 */
+	0,							/* U+011877 */
+	0,							/* U+011878 */
+	0,							/* U+011879 */
+	0,							/* U+01187A */
+	0,							/* U+01187B */
+	0,							/* U+01187C */
+	0,							/* U+01187D */
+	0,							/* U+01187E */
+	0,							/* U+01187F */
+	0,							/* U+011880 */
+	0,							/* U+011881 */
+	0,							/* U+011882 */
+	0,							/* U+011883 */
+	0,							/* U+011884 */
+	0,							/* U+011885 */
+	0,							/* U+011886 */
+	0,							/* U+011887 */
+	0,							/* U+011888 */
+	0,							/* U+011889 */
+	0,							/* U+01188A */
+	0,							/* U+01188B */
+	0,							/* U+01188C */
+	0,							/* U+01188D */
+	0,							/* U+01188E */
+	0,							/* U+01188F */
+	0,							/* U+011890 */
+	0,							/* U+011891 */
+	0,							/* U+011892 */
+	0,							/* U+011893 */
+	0,							/* U+011894 */
+	0,							/* U+011895 */
+	0,							/* U+011896 */
+	0,							/* U+011897 */
+	0,							/* U+011898 */
+	0,							/* U+011899 */
+	0,							/* U+01189A */
+	0,							/* U+01189B */
+	0,							/* U+01189C */
+	0,							/* U+01189D */
+	0,							/* U+01189E */
+	0,							/* U+01189F */
+	0,							/* U+0118A0 */
+	0,							/* U+0118A1 */
+	0,							/* U+0118A2 */
+	0,							/* U+0118A3 */
+	0,							/* U+0118A4 */
+	0,							/* U+0118A5 */
+	0,							/* U+0118A6 */
+	0,							/* U+0118A7 */
+	0,							/* U+0118A8 */
+	0,							/* U+0118A9 */
+	0,							/* U+0118AA */
+	0,							/* U+0118AB */
+	0,							/* U+0118AC */
+	0,							/* U+0118AD */
+	0,							/* U+0118AE */
+	0,							/* U+0118AF */
+	0,							/* U+0118B0 */
+	0,							/* U+0118B1 */
+	0,							/* U+0118B2 */
+	0,							/* U+0118B3 */
+	0,							/* U+0118B4 */
+	0,							/* U+0118B5 */
+	0,							/* U+0118B6 */
+	0,							/* U+0118B7 */
+	0,							/* U+0118B8 */
+	0,							/* U+0118B9 */
+	0,							/* U+0118BA */
+	0,							/* U+0118BB */
+	0,							/* U+0118BC */
+	0,							/* U+0118BD */
+	0,							/* U+0118BE */
+	0,							/* U+0118BF */
+	0,							/* U+0118C0 */
+	0,							/* U+0118C1 */
+	0,							/* U+0118C2 */
+	0,							/* U+0118C3 */
+	0,							/* U+0118C4 */
+	0,							/* U+0118C5 */
+	0,							/* U+0118C6 */
+	0,							/* U+0118C7 */
+	0,							/* U+0118C8 */
+	0,							/* U+0118C9 */
+	0,							/* U+0118CA */
+	0,							/* U+0118CB */
+	0,							/* U+0118CC */
+	0,							/* U+0118CD */
+	0,							/* U+0118CE */
+	0,							/* U+0118CF */
+	0,							/* U+0118D0 */
+	0,							/* U+0118D1 */
+	0,							/* U+0118D2 */
+	0,							/* U+0118D3 */
+	0,							/* U+0118D4 */
+	0,							/* U+0118D5 */
+	0,							/* U+0118D6 */
+	0,							/* U+0118D7 */
+	0,							/* U+0118D8 */
+	0,							/* U+0118D9 */
+	0,							/* U+0118DA */
+	0,							/* U+0118DB */
+	0,							/* U+0118DC */
+	0,							/* U+0118DD */
+	0,							/* U+0118DE */
+	0,							/* U+0118DF */
+	0,							/* U+0118E0 */
+	0,							/* U+0118E1 */
+	0,							/* U+0118E2 */
+	0,							/* U+0118E3 */
+	0,							/* U+0118E4 */
+	0,							/* U+0118E5 */
+	0,							/* U+0118E6 */
+	0,							/* U+0118E7 */
+	0,							/* U+0118E8 */
+	0,							/* U+0118E9 */
+	0,							/* U+0118EA */
+	0,							/* U+0118EB */
+	0,							/* U+0118EC */
+	0,							/* U+0118ED */
+	0,							/* U+0118EE */
+	0,							/* U+0118EF */
+	0,							/* U+0118F0 */
+	0,							/* U+0118F1 */
+	0,							/* U+0118F2 */
+	0,							/* U+0118F3 */
+	0,							/* U+0118F4 */
+	0,							/* U+0118F5 */
+	0,							/* U+0118F6 */
+	0,							/* U+0118F7 */
+	0,							/* U+0118F8 */
+	0,							/* U+0118F9 */
+	0,							/* U+0118FA */
+	0,							/* U+0118FB */
+	0,							/* U+0118FC */
+	0,							/* U+0118FD */
+	0,							/* U+0118FE */
+	0,							/* U+0118FF */
+	0,							/* U+011900 */
+	0,							/* U+011901 */
+	0,							/* U+011902 */
+	0,							/* U+011903 */
+	0,							/* U+011904 */
+	0,							/* U+011905 */
+	0,							/* U+011906 */
+	0,							/* U+011907 */
+	0,							/* U+011908 */
+	0,							/* U+011909 */
+	0,							/* U+01190A */
+	0,							/* U+01190B */
+	0,							/* U+01190C */
+	0,							/* U+01190D */
+	0,							/* U+01190E */
+	0,							/* U+01190F */
+	0,							/* U+011910 */
+	0,							/* U+011911 */
+	0,							/* U+011912 */
+	0,							/* U+011913 */
+	0,							/* U+011914 */
+	0,							/* U+011915 */
+	0,							/* U+011916 */
+	0,							/* U+011917 */
+	0,							/* U+011918 */
+	0,							/* U+011919 */
+	0,							/* U+01191A */
+	0,							/* U+01191B */
+	0,							/* U+01191C */
+	0,							/* U+01191D */
+	0,							/* U+01191E */
+	0,							/* U+01191F */
+	0,							/* U+011920 */
+	0,							/* U+011921 */
+	0,							/* U+011922 */
+	0,							/* U+011923 */
+	0,							/* U+011924 */
+	0,							/* U+011925 */
+	0,							/* U+011926 */
+	0,							/* U+011927 */
+	0,							/* U+011928 */
+	0,							/* U+011929 */
+	0,							/* U+01192A */
+	0,							/* U+01192B */
+	0,							/* U+01192C */
+	0,							/* U+01192D */
+	0,							/* U+01192E */
+	0,							/* U+01192F */
+	0,							/* U+011930 */
+	0,							/* U+011931 */
+	0,							/* U+011932 */
+	0,							/* U+011933 */
+	0,							/* U+011934 */
+	0,							/* U+011935 */
+	0,							/* U+011936 */
+	0,							/* U+011937 */
+	3258,						/* U+011938 */
+	0,							/* U+011939 */
+	0,							/* U+01193A */
+	0,							/* U+01193B */
+	0,							/* U+01193C */
+	452,						/* U+01193D */
+	452,						/* U+01193E */
+	0,							/* U+01193F */
+	0,							/* U+011940 */
+	0,							/* U+011941 */
+	0,							/* U+011942 */
+	451,						/* U+011943 */
+	0,							/* U+011944 */
+	0,							/* U+011945 */
+	0,							/* U+011946 */
+	0,							/* U+011947 */
+	0,							/* U+011948 */
+	0,							/* U+011949 */
+	0,							/* U+01194A */
+	0,							/* U+01194B */
+	0,							/* U+01194C */
+	0,							/* U+01194D */
+	0,							/* U+01194E */
+	0,							/* U+01194F */
+	0,							/* U+011950 */
+	0,							/* U+011951 */
+	0,							/* U+011952 */
+	0,							/* U+011953 */
+	0,							/* U+011954 */
+	0,							/* U+011955 */
+	0,							/* U+011956 */
+	0,							/* U+011957 */
+	0,							/* U+011958 */
+	0,							/* U+011959 */
+	0,							/* U+01195A */
+	0,							/* U+01195B */
+	0,							/* U+01195C */
+	0,							/* U+01195D */
+	0,							/* U+01195E */
+	0,							/* U+01195F */
+	0,							/* U+011960 */
+	0,							/* U+011961 */
+	0,							/* U+011962 */
+	0,							/* U+011963 */
+	0,							/* U+011964 */
+	0,							/* U+011965 */
+	0,							/* U+011966 */
+	0,							/* U+011967 */
+	0,							/* U+011968 */
+	0,							/* U+011969 */
+	0,							/* U+01196A */
+	0,							/* U+01196B */
+	0,							/* U+01196C */
+	0,							/* U+01196D */
+	0,							/* U+01196E */
+	0,							/* U+01196F */
+	0,							/* U+011970 */
+	0,							/* U+011971 */
+	0,							/* U+011972 */
+	0,							/* U+011973 */
+	0,							/* U+011974 */
+	0,							/* U+011975 */
+	0,							/* U+011976 */
+	0,							/* U+011977 */
+	0,							/* U+011978 */
+	0,							/* U+011979 */
+	0,							/* U+01197A */
+	0,							/* U+01197B */
+	0,							/* U+01197C */
+	0,							/* U+01197D */
+	0,							/* U+01197E */
+	0,							/* U+01197F */
+	0,							/* U+011980 */
+	0,							/* U+011981 */
+	0,							/* U+011982 */
+	0,							/* U+011983 */
+	0,							/* U+011984 */
+	0,							/* U+011985 */
+	0,							/* U+011986 */
+	0,							/* U+011987 */
+	0,							/* U+011988 */
+	0,							/* U+011989 */
+	0,							/* U+01198A */
+	0,							/* U+01198B */
+	0,							/* U+01198C */
+	0,							/* U+01198D */
+	0,							/* U+01198E */
+	0,							/* U+01198F */
+	0,							/* U+011990 */
+	0,							/* U+011991 */
+	0,							/* U+011992 */
+	0,							/* U+011993 */
+	0,							/* U+011994 */
+	0,							/* U+011995 */
+	0,							/* U+011996 */
+	0,							/* U+011997 */
+	0,							/* U+011998 */
+	0,							/* U+011999 */
+	0,							/* U+01199A */
+	0,							/* U+01199B */
+	0,							/* U+01199C */
+	0,							/* U+01199D */
+	0,							/* U+01199E */
+	0,							/* U+01199F */
+	0,							/* U+0119A0 */
+	0,							/* U+0119A1 */
+	0,							/* U+0119A2 */
+	0,							/* U+0119A3 */
+	0,							/* U+0119A4 */
+	0,							/* U+0119A5 */
+	0,							/* U+0119A6 */
+	0,							/* U+0119A7 */
+	0,							/* U+0119A8 */
+	0,							/* U+0119A9 */
+	0,							/* U+0119AA */
+	0,							/* U+0119AB */
+	0,							/* U+0119AC */
+	0,							/* U+0119AD */
+	0,							/* U+0119AE */
+	0,							/* U+0119AF */
+	0,							/* U+0119B0 */
+	0,							/* U+0119B1 */
+	0,							/* U+0119B2 */
+	0,							/* U+0119B3 */
+	0,							/* U+0119B4 */
+	0,							/* U+0119B5 */
+	0,							/* U+0119B6 */
+	0,							/* U+0119B7 */
+	0,							/* U+0119B8 */
+	0,							/* U+0119B9 */
+	0,							/* U+0119BA */
+	0,							/* U+0119BB */
+	0,							/* U+0119BC */
+	0,							/* U+0119BD */
+	0,							/* U+0119BE */
+	0,							/* U+0119BF */
+	0,							/* U+0119C0 */
+	0,							/* U+0119C1 */
+	0,							/* U+0119C2 */
+	0,							/* U+0119C3 */
+	0,							/* U+0119C4 */
+	0,							/* U+0119C5 */
+	0,							/* U+0119C6 */
+	0,							/* U+0119C7 */
+	0,							/* U+0119C8 */
+	0,							/* U+0119C9 */
+	0,							/* U+0119CA */
+	0,							/* U+0119CB */
+	0,							/* U+0119CC */
+	0,							/* U+0119CD */
+	0,							/* U+0119CE */
+	0,							/* U+0119CF */
+	0,							/* U+0119D0 */
+	0,							/* U+0119D1 */
+	0,							/* U+0119D2 */
+	0,							/* U+0119D3 */
+	0,							/* U+0119D4 */
+	0,							/* U+0119D5 */
+	0,							/* U+0119D6 */
+	0,							/* U+0119D7 */
+	0,							/* U+0119D8 */
+	0,							/* U+0119D9 */
+	0,							/* U+0119DA */
+	0,							/* U+0119DB */
+	0,							/* U+0119DC */
+	0,							/* U+0119DD */
+	0,							/* U+0119DE */
+	0,							/* U+0119DF */
+	452,						/* U+0119E0 */
+	0,							/* U+0119E1 */
+	0,							/* U+0119E2 */
+	0,							/* U+0119E3 */
+	0,							/* U+0119E4 */
+	0,							/* U+0119E5 */
+	0,							/* U+0119E6 */
+	0,							/* U+0119E7 */
+	0,							/* U+0119E8 */
+	0,							/* U+0119E9 */
+	0,							/* U+0119EA */
+	0,							/* U+0119EB */
+	0,							/* U+0119EC */
+	0,							/* U+0119ED */
+	0,							/* U+0119EE */
+	0,							/* U+0119EF */
+	0,							/* U+0119F0 */
+	0,							/* U+0119F1 */
+	0,							/* U+0119F2 */
+	0,							/* U+0119F3 */
+	0,							/* U+0119F4 */
+	0,							/* U+0119F5 */
+	0,							/* U+0119F6 */
+	0,							/* U+0119F7 */
+	0,							/* U+0119F8 */
+	0,							/* U+0119F9 */
+	0,							/* U+0119FA */
+	0,							/* U+0119FB */
+	0,							/* U+0119FC */
+	0,							/* U+0119FD */
+	0,							/* U+0119FE */
+	0,							/* U+0119FF */
+	0,							/* U+011A00 */
+	0,							/* U+011A01 */
+	0,							/* U+011A02 */
+	0,							/* U+011A03 */
+	0,							/* U+011A04 */
+	0,							/* U+011A05 */
+	0,							/* U+011A06 */
+	0,							/* U+011A07 */
+	0,							/* U+011A08 */
+	0,							/* U+011A09 */
+	0,							/* U+011A0A */
+	0,							/* U+011A0B */
+	0,							/* U+011A0C */
+	0,							/* U+011A0D */
+	0,							/* U+011A0E */
+	0,							/* U+011A0F */
+	0,							/* U+011A10 */
+	0,							/* U+011A11 */
+	0,							/* U+011A12 */
+	0,							/* U+011A13 */
+	0,							/* U+011A14 */
+	0,							/* U+011A15 */
+	0,							/* U+011A16 */
+	0,							/* U+011A17 */
+	0,							/* U+011A18 */
+	0,							/* U+011A19 */
+	0,							/* U+011A1A */
+	0,							/* U+011A1B */
+	0,							/* U+011A1C */
+	0,							/* U+011A1D */
+	0,							/* U+011A1E */
+	0,							/* U+011A1F */
+	0,							/* U+011A20 */
+	0,							/* U+011A21 */
+	0,							/* U+011A22 */
+	0,							/* U+011A23 */
+	0,							/* U+011A24 */
+	0,							/* U+011A25 */
+	0,							/* U+011A26 */
+	0,							/* U+011A27 */
+	0,							/* U+011A28 */
+	0,							/* U+011A29 */
+	0,							/* U+011A2A */
+	0,							/* U+011A2B */
+	0,							/* U+011A2C */
+	0,							/* U+011A2D */
+	0,							/* U+011A2E */
+	0,							/* U+011A2F */
+	0,							/* U+011A30 */
+	0,							/* U+011A31 */
+	0,							/* U+011A32 */
+	0,							/* U+011A33 */
+	452,						/* U+011A34 */
+	0,							/* U+011A35 */
+	0,							/* U+011A36 */
+	0,							/* U+011A37 */
+	0,							/* U+011A38 */
+	0,							/* U+011A39 */
+	0,							/* U+011A3A */
+	0,							/* U+011A3B */
+	0,							/* U+011A3C */
+	0,							/* U+011A3D */
+	0,							/* U+011A3E */
+	0,							/* U+011A3F */
+	0,							/* U+011A40 */
+	0,							/* U+011A41 */
+	0,							/* U+011A42 */
+	0,							/* U+011A43 */
+	0,							/* U+011A44 */
+	0,							/* U+011A45 */
+	0,							/* U+011A46 */
+	452,						/* U+011A47 */
+	0,							/* U+011A48 */
+	0,							/* U+011A49 */
+	0,							/* U+011A4A */
+	0,							/* U+011A4B */
+	0,							/* U+011A4C */
+	0,							/* U+011A4D */
+	0,							/* U+011A4E */
+	0,							/* U+011A4F */
+	0,							/* U+011A50 */
+	0,							/* U+011A51 */
+	0,							/* U+011A52 */
+	0,							/* U+011A53 */
+	0,							/* U+011A54 */
+	0,							/* U+011A55 */
+	0,							/* U+011A56 */
+	0,							/* U+011A57 */
+	0,							/* U+011A58 */
+	0,							/* U+011A59 */
+	0,							/* U+011A5A */
+	0,							/* U+011A5B */
+	0,							/* U+011A5C */
+	0,							/* U+011A5D */
+	0,							/* U+011A5E */
+	0,							/* U+011A5F */
+	0,							/* U+011A60 */
+	0,							/* U+011A61 */
+	0,							/* U+011A62 */
+	0,							/* U+011A63 */
+	0,							/* U+011A64 */
+	0,							/* U+011A65 */
+	0,							/* U+011A66 */
+	0,							/* U+011A67 */
+	0,							/* U+011A68 */
+	0,							/* U+011A69 */
+	0,							/* U+011A6A */
+	0,							/* U+011A6B */
+	0,							/* U+011A6C */
+	0,							/* U+011A6D */
+	0,							/* U+011A6E */
+	0,							/* U+011A6F */
+	0,							/* U+011A70 */
+	0,							/* U+011A71 */
+	0,							/* U+011A72 */
+	0,							/* U+011A73 */
+	0,							/* U+011A74 */
+	0,							/* U+011A75 */
+	0,							/* U+011A76 */
+	0,							/* U+011A77 */
+	0,							/* U+011A78 */
+	0,							/* U+011A79 */
+	0,							/* U+011A7A */
+	0,							/* U+011A7B */
+	0,							/* U+011A7C */
+	0,							/* U+011A7D */
+	0,							/* U+011A7E */
+	0,							/* U+011A7F */
+	0,							/* U+011A80 */
+	0,							/* U+011A81 */
+	0,							/* U+011A82 */
+	0,							/* U+011A83 */
+	0,							/* U+011A84 */
+	0,							/* U+011A85 */
+	0,							/* U+011A86 */
+	0,							/* U+011A87 */
+	0,							/* U+011A88 */
+	0,							/* U+011A89 */
+	0,							/* U+011A8A */
+	0,							/* U+011A8B */
+	0,							/* U+011A8C */
+	0,							/* U+011A8D */
+	0,							/* U+011A8E */
+	0,							/* U+011A8F */
+	0,							/* U+011A90 */
+	0,							/* U+011A91 */
+	0,							/* U+011A92 */
+	0,							/* U+011A93 */
+	0,							/* U+011A94 */
+	0,							/* U+011A95 */
+	0,							/* U+011A96 */
+	0,							/* U+011A97 */
+	0,							/* U+011A98 */
+	452,						/* U+011A99 */
+	0,							/* U+011A9A */
+	0,							/* U+011A9B */
+	0,							/* U+011A9C */
+	0,							/* U+011A9D */
+	0,							/* U+011A9E */
+	0,							/* U+011A9F */
+	0,							/* U+011AA0 */
+	0,							/* U+011AA1 */
+	0,							/* U+011AA2 */
+	0,							/* U+011AA3 */
+	0,							/* U+011AA4 */
+	0,							/* U+011AA5 */
+	0,							/* U+011AA6 */
+	0,							/* U+011AA7 */
+	0,							/* U+011AA8 */
+	0,							/* U+011AA9 */
+	0,							/* U+011AAA */
+	0,							/* U+011AAB */
+	0,							/* U+011AAC */
+	0,							/* U+011AAD */
+	0,							/* U+011AAE */
+	0,							/* U+011AAF */
+	0,							/* U+011AB0 */
+	0,							/* U+011AB1 */
+	0,							/* U+011AB2 */
+	0,							/* U+011AB3 */
+	0,							/* U+011AB4 */
+	0,							/* U+011AB5 */
+	0,							/* U+011AB6 */
+	0,							/* U+011AB7 */
+	0,							/* U+011AB8 */
+	0,							/* U+011AB9 */
+	0,							/* U+011ABA */
+	0,							/* U+011ABB */
+	0,							/* U+011ABC */
+	0,							/* U+011ABD */
+	0,							/* U+011ABE */
+	0,							/* U+011ABF */
+	0,							/* U+011AC0 */
+	0,							/* U+011AC1 */
+	0,							/* U+011AC2 */
+	0,							/* U+011AC3 */
+	0,							/* U+011AC4 */
+	0,							/* U+011AC5 */
+	0,							/* U+011AC6 */
+	0,							/* U+011AC7 */
+	0,							/* U+011AC8 */
+	0,							/* U+011AC9 */
+	0,							/* U+011ACA */
+	0,							/* U+011ACB */
+	0,							/* U+011ACC */
+	0,							/* U+011ACD */
+	0,							/* U+011ACE */
+	0,							/* U+011ACF */
+	0,							/* U+011AD0 */
+	0,							/* U+011AD1 */
+	0,							/* U+011AD2 */
+	0,							/* U+011AD3 */
+	0,							/* U+011AD4 */
+	0,							/* U+011AD5 */
+	0,							/* U+011AD6 */
+	0,							/* U+011AD7 */
+	0,							/* U+011AD8 */
+	0,							/* U+011AD9 */
+	0,							/* U+011ADA */
+	0,							/* U+011ADB */
+	0,							/* U+011ADC */
+	0,							/* U+011ADD */
+	0,							/* U+011ADE */
+	0,							/* U+011ADF */
+	0,							/* U+011AE0 */
+	0,							/* U+011AE1 */
+	0,							/* U+011AE2 */
+	0,							/* U+011AE3 */
+	0,							/* U+011AE4 */
+	0,							/* U+011AE5 */
+	0,							/* U+011AE6 */
+	0,							/* U+011AE7 */
+	0,							/* U+011AE8 */
+	0,							/* U+011AE9 */
+	0,							/* U+011AEA */
+	0,							/* U+011AEB */
+	0,							/* U+011AEC */
+	0,							/* U+011AED */
+	0,							/* U+011AEE */
+	0,							/* U+011AEF */
+	0,							/* U+011AF0 */
+	0,							/* U+011AF1 */
+	0,							/* U+011AF2 */
+	0,							/* U+011AF3 */
+	0,							/* U+011AF4 */
+	0,							/* U+011AF5 */
+	0,							/* U+011AF6 */
+	0,							/* U+011AF7 */
+	0,							/* U+011AF8 */
+	0,							/* U+011AF9 */
+	0,							/* U+011AFA */
+	0,							/* U+011AFB */
+	0,							/* U+011AFC */
+	0,							/* U+011AFD */
+	0,							/* U+011AFE */
+	0,							/* U+011AFF */
+	0,							/* U+011B00 */
+	0,							/* U+011B01 */
+	0,							/* U+011B02 */
+	0,							/* U+011B03 */
+	0,							/* U+011B04 */
+	0,							/* U+011B05 */
+	0,							/* U+011B06 */
+	0,							/* U+011B07 */
+	0,							/* U+011B08 */
+	0,							/* U+011B09 */
+	0,							/* U+011B0A */
+	0,							/* U+011B0B */
+	0,							/* U+011B0C */
+	0,							/* U+011B0D */
+	0,							/* U+011B0E */
+	0,							/* U+011B0F */
+	0,							/* U+011B10 */
+	0,							/* U+011B11 */
+	0,							/* U+011B12 */
+	0,							/* U+011B13 */
+	0,							/* U+011B14 */
+	0,							/* U+011B15 */
+	0,							/* U+011B16 */
+	0,							/* U+011B17 */
+	0,							/* U+011B18 */
+	0,							/* U+011B19 */
+	0,							/* U+011B1A */
+	0,							/* U+011B1B */
+	0,							/* U+011B1C */
+	0,							/* U+011B1D */
+	0,							/* U+011B1E */
+	0,							/* U+011B1F */
+	0,							/* U+011B20 */
+	0,							/* U+011B21 */
+	0,							/* U+011B22 */
+	0,							/* U+011B23 */
+	0,							/* U+011B24 */
+	0,							/* U+011B25 */
+	0,							/* U+011B26 */
+	0,							/* U+011B27 */
+	0,							/* U+011B28 */
+	0,							/* U+011B29 */
+	0,							/* U+011B2A */
+	0,							/* U+011B2B */
+	0,							/* U+011B2C */
+	0,							/* U+011B2D */
+	0,							/* U+011B2E */
+	0,							/* U+011B2F */
+	0,							/* U+011B30 */
+	0,							/* U+011B31 */
+	0,							/* U+011B32 */
+	0,							/* U+011B33 */
+	0,							/* U+011B34 */
+	0,							/* U+011B35 */
+	0,							/* U+011B36 */
+	0,							/* U+011B37 */
+	0,							/* U+011B38 */
+	0,							/* U+011B39 */
+	0,							/* U+011B3A */
+	0,							/* U+011B3B */
+	0,							/* U+011B3C */
+	0,							/* U+011B3D */
+	0,							/* U+011B3E */
+	0,							/* U+011B3F */
+	0,							/* U+011B40 */
+	0,							/* U+011B41 */
+	0,							/* U+011B42 */
+	0,							/* U+011B43 */
+	0,							/* U+011B44 */
+	0,							/* U+011B45 */
+	0,							/* U+011B46 */
+	0,							/* U+011B47 */
+	0,							/* U+011B48 */
+	0,							/* U+011B49 */
+	0,							/* U+011B4A */
+	0,							/* U+011B4B */
+	0,							/* U+011B4C */
+	0,							/* U+011B4D */
+	0,							/* U+011B4E */
+	0,							/* U+011B4F */
+	0,							/* U+011B50 */
+	0,							/* U+011B51 */
+	0,							/* U+011B52 */
+	0,							/* U+011B53 */
+	0,							/* U+011B54 */
+	0,							/* U+011B55 */
+	0,							/* U+011B56 */
+	0,							/* U+011B57 */
+	0,							/* U+011B58 */
+	0,							/* U+011B59 */
+	0,							/* U+011B5A */
+	0,							/* U+011B5B */
+	0,							/* U+011B5C */
+	0,							/* U+011B5D */
+	0,							/* U+011B5E */
+	0,							/* U+011B5F */
+	0,							/* U+011B60 */
+	0,							/* U+011B61 */
+	0,							/* U+011B62 */
+	0,							/* U+011B63 */
+	0,							/* U+011B64 */
+	0,							/* U+011B65 */
+	0,							/* U+011B66 */
+	0,							/* U+011B67 */
+	0,							/* U+011B68 */
+	0,							/* U+011B69 */
+	0,							/* U+011B6A */
+	0,							/* U+011B6B */
+	0,							/* U+011B6C */
+	0,							/* U+011B6D */
+	0,							/* U+011B6E */
+	0,							/* U+011B6F */
+	0,							/* U+011B70 */
+	0,							/* U+011B71 */
+	0,							/* U+011B72 */
+	0,							/* U+011B73 */
+	0,							/* U+011B74 */
+	0,							/* U+011B75 */
+	0,							/* U+011B76 */
+	0,							/* U+011B77 */
+	0,							/* U+011B78 */
+	0,							/* U+011B79 */
+	0,							/* U+011B7A */
+	0,							/* U+011B7B */
+	0,							/* U+011B7C */
+	0,							/* U+011B7D */
+	0,							/* U+011B7E */
+	0,							/* U+011B7F */
+	0,							/* U+011B80 */
+	0,							/* U+011B81 */
+	0,							/* U+011B82 */
+	0,							/* U+011B83 */
+	0,							/* U+011B84 */
+	0,							/* U+011B85 */
+	0,							/* U+011B86 */
+	0,							/* U+011B87 */
+	0,							/* U+011B88 */
+	0,							/* U+011B89 */
+	0,							/* U+011B8A */
+	0,							/* U+011B8B */
+	0,							/* U+011B8C */
+	0,							/* U+011B8D */
+	0,							/* U+011B8E */
+	0,							/* U+011B8F */
+	0,							/* U+011B90 */
+	0,							/* U+011B91 */
+	0,							/* U+011B92 */
+	0,							/* U+011B93 */
+	0,							/* U+011B94 */
+	0,							/* U+011B95 */
+	0,							/* U+011B96 */
+	0,							/* U+011B97 */
+	0,							/* U+011B98 */
+	0,							/* U+011B99 */
+	0,							/* U+011B9A */
+	0,							/* U+011B9B */
+	0,							/* U+011B9C */
+	0,							/* U+011B9D */
+	0,							/* U+011B9E */
+	0,							/* U+011B9F */
+	0,							/* U+011BA0 */
+	0,							/* U+011BA1 */
+	0,							/* U+011BA2 */
+	0,							/* U+011BA3 */
+	0,							/* U+011BA4 */
+	0,							/* U+011BA5 */
+	0,							/* U+011BA6 */
+	0,							/* U+011BA7 */
+	0,							/* U+011BA8 */
+	0,							/* U+011BA9 */
+	0,							/* U+011BAA */
+	0,							/* U+011BAB */
+	0,							/* U+011BAC */
+	0,							/* U+011BAD */
+	0,							/* U+011BAE */
+	0,							/* U+011BAF */
+	0,							/* U+011BB0 */
+	0,							/* U+011BB1 */
+	0,							/* U+011BB2 */
+	0,							/* U+011BB3 */
+	0,							/* U+011BB4 */
+	0,							/* U+011BB5 */
+	0,							/* U+011BB6 */
+	0,							/* U+011BB7 */
+	0,							/* U+011BB8 */
+	0,							/* U+011BB9 */
+	0,							/* U+011BBA */
+	0,							/* U+011BBB */
+	0,							/* U+011BBC */
+	0,							/* U+011BBD */
+	0,							/* U+011BBE */
+	0,							/* U+011BBF */
+	0,							/* U+011BC0 */
+	0,							/* U+011BC1 */
+	0,							/* U+011BC2 */
+	0,							/* U+011BC3 */
+	0,							/* U+011BC4 */
+	0,							/* U+011BC5 */
+	0,							/* U+011BC6 */
+	0,							/* U+011BC7 */
+	0,							/* U+011BC8 */
+	0,							/* U+011BC9 */
+	0,							/* U+011BCA */
+	0,							/* U+011BCB */
+	0,							/* U+011BCC */
+	0,							/* U+011BCD */
+	0,							/* U+011BCE */
+	0,							/* U+011BCF */
+	0,							/* U+011BD0 */
+	0,							/* U+011BD1 */
+	0,							/* U+011BD2 */
+	0,							/* U+011BD3 */
+	0,							/* U+011BD4 */
+	0,							/* U+011BD5 */
+	0,							/* U+011BD6 */
+	0,							/* U+011BD7 */
+	0,							/* U+011BD8 */
+	0,							/* U+011BD9 */
+	0,							/* U+011BDA */
+	0,							/* U+011BDB */
+	0,							/* U+011BDC */
+	0,							/* U+011BDD */
+	0,							/* U+011BDE */
+	0,							/* U+011BDF */
+	0,							/* U+011BE0 */
+	0,							/* U+011BE1 */
+	0,							/* U+011BE2 */
+	0,							/* U+011BE3 */
+	0,							/* U+011BE4 */
+	0,							/* U+011BE5 */
+	0,							/* U+011BE6 */
+	0,							/* U+011BE7 */
+	0,							/* U+011BE8 */
+	0,							/* U+011BE9 */
+	0,							/* U+011BEA */
+	0,							/* U+011BEB */
+	0,							/* U+011BEC */
+	0,							/* U+011BED */
+	0,							/* U+011BEE */
+	0,							/* U+011BEF */
+	0,							/* U+011BF0 */
+	0,							/* U+011BF1 */
+	0,							/* U+011BF2 */
+	0,							/* U+011BF3 */
+	0,							/* U+011BF4 */
+	0,							/* U+011BF5 */
+	0,							/* U+011BF6 */
+	0,							/* U+011BF7 */
+	0,							/* U+011BF8 */
+	0,							/* U+011BF9 */
+	0,							/* U+011BFA */
+	0,							/* U+011BFB */
+	0,							/* U+011BFC */
+	0,							/* U+011BFD */
+	0,							/* U+011BFE */
+	0,							/* U+011BFF */
+	0,							/* U+011C00 */
+	0,							/* U+011C01 */
+	0,							/* U+011C02 */
+	0,							/* U+011C03 */
+	0,							/* U+011C04 */
+	0,							/* U+011C05 */
+	0,							/* U+011C06 */
+	0,							/* U+011C07 */
+	0,							/* U+011C08 */
+	0,							/* U+011C09 */
+	0,							/* U+011C0A */
+	0,							/* U+011C0B */
+	0,							/* U+011C0C */
+	0,							/* U+011C0D */
+	0,							/* U+011C0E */
+	0,							/* U+011C0F */
+	0,							/* U+011C10 */
+	0,							/* U+011C11 */
+	0,							/* U+011C12 */
+	0,							/* U+011C13 */
+	0,							/* U+011C14 */
+	0,							/* U+011C15 */
+	0,							/* U+011C16 */
+	0,							/* U+011C17 */
+	0,							/* U+011C18 */
+	0,							/* U+011C19 */
+	0,							/* U+011C1A */
+	0,							/* U+011C1B */
+	0,							/* U+011C1C */
+	0,							/* U+011C1D */
+	0,							/* U+011C1E */
+	0,							/* U+011C1F */
+	0,							/* U+011C20 */
+	0,							/* U+011C21 */
+	0,							/* U+011C22 */
+	0,							/* U+011C23 */
+	0,							/* U+011C24 */
+	0,							/* U+011C25 */
+	0,							/* U+011C26 */
+	0,							/* U+011C27 */
+	0,							/* U+011C28 */
+	0,							/* U+011C29 */
+	0,							/* U+011C2A */
+	0,							/* U+011C2B */
+	0,							/* U+011C2C */
+	0,							/* U+011C2D */
+	0,							/* U+011C2E */
+	0,							/* U+011C2F */
+	0,							/* U+011C30 */
+	0,							/* U+011C31 */
+	0,							/* U+011C32 */
+	0,							/* U+011C33 */
+	0,							/* U+011C34 */
+	0,							/* U+011C35 */
+	0,							/* U+011C36 */
+	0,							/* U+011C37 */
+	0,							/* U+011C38 */
+	0,							/* U+011C39 */
+	0,							/* U+011C3A */
+	0,							/* U+011C3B */
+	0,							/* U+011C3C */
+	0,							/* U+011C3D */
+	0,							/* U+011C3E */
+	452,						/* U+011C3F */
+	0,							/* U+011C40 */
+	0,							/* U+011C41 */
+	0,							/* U+011C42 */
+	0,							/* U+011C43 */
+	0,							/* U+011C44 */
+	0,							/* U+011C45 */
+	0,							/* U+011C46 */
+	0,							/* U+011C47 */
+	0,							/* U+011C48 */
+	0,							/* U+011C49 */
+	0,							/* U+011C4A */
+	0,							/* U+011C4B */
+	0,							/* U+011C4C */
+	0,							/* U+011C4D */
+	0,							/* U+011C4E */
+	0,							/* U+011C4F */
+	0,							/* U+011C50 */
+	0,							/* U+011C51 */
+	0,							/* U+011C52 */
+	0,							/* U+011C53 */
+	0,							/* U+011C54 */
+	0,							/* U+011C55 */
+	0,							/* U+011C56 */
+	0,							/* U+011C57 */
+	0,							/* U+011C58 */
+	0,							/* U+011C59 */
+	0,							/* U+011C5A */
+	0,							/* U+011C5B */
+	0,							/* U+011C5C */
+	0,							/* U+011C5D */
+	0,							/* U+011C5E */
+	0,							/* U+011C5F */
+	0,							/* U+011C60 */
+	0,							/* U+011C61 */
+	0,							/* U+011C62 */
+	0,							/* U+011C63 */
+	0,							/* U+011C64 */
+	0,							/* U+011C65 */
+	0,							/* U+011C66 */
+	0,							/* U+011C67 */
+	0,							/* U+011C68 */
+	0,							/* U+011C69 */
+	0,							/* U+011C6A */
+	0,							/* U+011C6B */
+	0,							/* U+011C6C */
+	0,							/* U+011C6D */
+	0,							/* U+011C6E */
+	0,							/* U+011C6F */
+	0,							/* U+011C70 */
+	0,							/* U+011C71 */
+	0,							/* U+011C72 */
+	0,							/* U+011C73 */
+	0,							/* U+011C74 */
+	0,							/* U+011C75 */
+	0,							/* U+011C76 */
+	0,							/* U+011C77 */
+	0,							/* U+011C78 */
+	0,							/* U+011C79 */
+	0,							/* U+011C7A */
+	0,							/* U+011C7B */
+	0,							/* U+011C7C */
+	0,							/* U+011C7D */
+	0,							/* U+011C7E */
+	0,							/* U+011C7F */
+	0,							/* U+011C80 */
+	0,							/* U+011C81 */
+	0,							/* U+011C82 */
+	0,							/* U+011C83 */
+	0,							/* U+011C84 */
+	0,							/* U+011C85 */
+	0,							/* U+011C86 */
+	0,							/* U+011C87 */
+	0,							/* U+011C88 */
+	0,							/* U+011C89 */
+	0,							/* U+011C8A */
+	0,							/* U+011C8B */
+	0,							/* U+011C8C */
+	0,							/* U+011C8D */
+	0,							/* U+011C8E */
+	0,							/* U+011C8F */
+	0,							/* U+011C90 */
+	0,							/* U+011C91 */
+	0,							/* U+011C92 */
+	0,							/* U+011C93 */
+	0,							/* U+011C94 */
+	0,							/* U+011C95 */
+	0,							/* U+011C96 */
+	0,							/* U+011C97 */
+	0,							/* U+011C98 */
+	0,							/* U+011C99 */
+	0,							/* U+011C9A */
+	0,							/* U+011C9B */
+	0,							/* U+011C9C */
+	0,							/* U+011C9D */
+	0,							/* U+011C9E */
+	0,							/* U+011C9F */
+	0,							/* U+011CA0 */
+	0,							/* U+011CA1 */
+	0,							/* U+011CA2 */
+	0,							/* U+011CA3 */
+	0,							/* U+011CA4 */
+	0,							/* U+011CA5 */
+	0,							/* U+011CA6 */
+	0,							/* U+011CA7 */
+	0,							/* U+011CA8 */
+	0,							/* U+011CA9 */
+	0,							/* U+011CAA */
+	0,							/* U+011CAB */
+	0,							/* U+011CAC */
+	0,							/* U+011CAD */
+	0,							/* U+011CAE */
+	0,							/* U+011CAF */
+	0,							/* U+011CB0 */
+	0,							/* U+011CB1 */
+	0,							/* U+011CB2 */
+	0,							/* U+011CB3 */
+	0,							/* U+011CB4 */
+	0,							/* U+011CB5 */
+	0,							/* U+011CB6 */
+	0,							/* U+011CB7 */
+	0,							/* U+011CB8 */
+	0,							/* U+011CB9 */
+	0,							/* U+011CBA */
+	0,							/* U+011CBB */
+	0,							/* U+011CBC */
+	0,							/* U+011CBD */
+	0,							/* U+011CBE */
+	0,							/* U+011CBF */
+	0,							/* U+011CC0 */
+	0,							/* U+011CC1 */
+	0,							/* U+011CC2 */
+	0,							/* U+011CC3 */
+	0,							/* U+011CC4 */
+	0,							/* U+011CC5 */
+	0,							/* U+011CC6 */
+	0,							/* U+011CC7 */
+	0,							/* U+011CC8 */
+	0,							/* U+011CC9 */
+	0,							/* U+011CCA */
+	0,							/* U+011CCB */
+	0,							/* U+011CCC */
+	0,							/* U+011CCD */
+	0,							/* U+011CCE */
+	0,							/* U+011CCF */
+	0,							/* U+011CD0 */
+	0,							/* U+011CD1 */
+	0,							/* U+011CD2 */
+	0,							/* U+011CD3 */
+	0,							/* U+011CD4 */
+	0,							/* U+011CD5 */
+	0,							/* U+011CD6 */
+	0,							/* U+011CD7 */
+	0,							/* U+011CD8 */
+	0,							/* U+011CD9 */
+	0,							/* U+011CDA */
+	0,							/* U+011CDB */
+	0,							/* U+011CDC */
+	0,							/* U+011CDD */
+	0,							/* U+011CDE */
+	0,							/* U+011CDF */
+	0,							/* U+011CE0 */
+	0,							/* U+011CE1 */
+	0,							/* U+011CE2 */
+	0,							/* U+011CE3 */
+	0,							/* U+011CE4 */
+	0,							/* U+011CE5 */
+	0,							/* U+011CE6 */
+	0,							/* U+011CE7 */
+	0,							/* U+011CE8 */
+	0,							/* U+011CE9 */
+	0,							/* U+011CEA */
+	0,							/* U+011CEB */
+	0,							/* U+011CEC */
+	0,							/* U+011CED */
+	0,							/* U+011CEE */
+	0,							/* U+011CEF */
+	0,							/* U+011CF0 */
+	0,							/* U+011CF1 */
+	0,							/* U+011CF2 */
+	0,							/* U+011CF3 */
+	0,							/* U+011CF4 */
+	0,							/* U+011CF5 */
+	0,							/* U+011CF6 */
+	0,							/* U+011CF7 */
+	0,							/* U+011CF8 */
+	0,							/* U+011CF9 */
+	0,							/* U+011CFA */
+	0,							/* U+011CFB */
+	0,							/* U+011CFC */
+	0,							/* U+011CFD */
+	0,							/* U+011CFE */
+	0,							/* U+011CFF */
+	0,							/* U+011D00 */
+	0,							/* U+011D01 */
+	0,							/* U+011D02 */
+	0,							/* U+011D03 */
+	0,							/* U+011D04 */
+	0,							/* U+011D05 */
+	0,							/* U+011D06 */
+	0,							/* U+011D07 */
+	0,							/* U+011D08 */
+	0,							/* U+011D09 */
+	0,							/* U+011D0A */
+	0,							/* U+011D0B */
+	0,							/* U+011D0C */
+	0,							/* U+011D0D */
+	0,							/* U+011D0E */
+	0,							/* U+011D0F */
+	0,							/* U+011D10 */
+	0,							/* U+011D11 */
+	0,							/* U+011D12 */
+	0,							/* U+011D13 */
+	0,							/* U+011D14 */
+	0,							/* U+011D15 */
+	0,							/* U+011D16 */
+	0,							/* U+011D17 */
+	0,							/* U+011D18 */
+	0,							/* U+011D19 */
+	0,							/* U+011D1A */
+	0,							/* U+011D1B */
+	0,							/* U+011D1C */
+	0,							/* U+011D1D */
+	0,							/* U+011D1E */
+	0,							/* U+011D1F */
+	0,							/* U+011D20 */
+	0,							/* U+011D21 */
+	0,							/* U+011D22 */
+	0,							/* U+011D23 */
+	0,							/* U+011D24 */
+	0,							/* U+011D25 */
+	0,							/* U+011D26 */
+	0,							/* U+011D27 */
+	0,							/* U+011D28 */
+	0,							/* U+011D29 */
+	0,							/* U+011D2A */
+	0,							/* U+011D2B */
+	0,							/* U+011D2C */
+	0,							/* U+011D2D */
+	0,							/* U+011D2E */
+	0,							/* U+011D2F */
+	0,							/* U+011D30 */
+	0,							/* U+011D31 */
+	0,							/* U+011D32 */
+	0,							/* U+011D33 */
+	0,							/* U+011D34 */
+	0,							/* U+011D35 */
+	0,							/* U+011D36 */
+	0,							/* U+011D37 */
+	0,							/* U+011D38 */
+	0,							/* U+011D39 */
+	0,							/* U+011D3A */
+	0,							/* U+011D3B */
+	0,							/* U+011D3C */
+	0,							/* U+011D3D */
+	0,							/* U+011D3E */
+	0,							/* U+011D3F */
+	0,							/* U+011D40 */
+	0,							/* U+011D41 */
+	451,						/* U+011D42 */
+	0,							/* U+011D43 */
+	452,						/* U+011D44 */
+	452,						/* U+011D45 */
+	0,							/* U+011D46 */
+	0,							/* U+011D47 */
+	0,							/* U+011D48 */
+	0,							/* U+011D49 */
+	0,							/* U+011D4A */
+	0,							/* U+011D4B */
+	0,							/* U+011D4C */
+	0,							/* U+011D4D */
+	0,							/* U+011D4E */
+	0,							/* U+011D4F */
+	0,							/* U+011D50 */
+	0,							/* U+011D51 */
+	0,							/* U+011D52 */
+	0,							/* U+011D53 */
+	0,							/* U+011D54 */
+	0,							/* U+011D55 */
+	0,							/* U+011D56 */
+	0,							/* U+011D57 */
+	0,							/* U+011D58 */
+	0,							/* U+011D59 */
+	0,							/* U+011D5A */
+	0,							/* U+011D5B */
+	0,							/* U+011D5C */
+	0,							/* U+011D5D */
+	0,							/* U+011D5E */
+	0,							/* U+011D5F */
+	0,							/* U+011D60 */
+	0,							/* U+011D61 */
+	0,							/* U+011D62 */
+	0,							/* U+011D63 */
+	0,							/* U+011D64 */
+	0,							/* U+011D65 */
+	0,							/* U+011D66 */
+	0,							/* U+011D67 */
+	0,							/* U+011D68 */
+	0,							/* U+011D69 */
+	0,							/* U+011D6A */
+	0,							/* U+011D6B */
+	0,							/* U+011D6C */
+	0,							/* U+011D6D */
+	0,							/* U+011D6E */
+	0,							/* U+011D6F */
+	0,							/* U+011D70 */
+	0,							/* U+011D71 */
+	0,							/* U+011D72 */
+	0,							/* U+011D73 */
+	0,							/* U+011D74 */
+	0,							/* U+011D75 */
+	0,							/* U+011D76 */
+	0,							/* U+011D77 */
+	0,							/* U+011D78 */
+	0,							/* U+011D79 */
+	0,							/* U+011D7A */
+	0,							/* U+011D7B */
+	0,							/* U+011D7C */
+	0,							/* U+011D7D */
+	0,							/* U+011D7E */
+	0,							/* U+011D7F */
+	0,							/* U+011D80 */
+	0,							/* U+011D81 */
+	0,							/* U+011D82 */
+	0,							/* U+011D83 */
+	0,							/* U+011D84 */
+	0,							/* U+011D85 */
+	0,							/* U+011D86 */
+	0,							/* U+011D87 */
+	0,							/* U+011D88 */
+	0,							/* U+011D89 */
+	0,							/* U+011D8A */
+	0,							/* U+011D8B */
+	0,							/* U+011D8C */
+	0,							/* U+011D8D */
+	0,							/* U+011D8E */
+	0,							/* U+011D8F */
+	0,							/* U+011D90 */
+	0,							/* U+011D91 */
+	0,							/* U+011D92 */
+	0,							/* U+011D93 */
+	0,							/* U+011D94 */
+	0,							/* U+011D95 */
+	0,							/* U+011D96 */
+	452,						/* U+011D97 */
+	0,							/* U+011D98 */
+	0,							/* U+011D99 */
+	0,							/* U+011D9A */
+	0,							/* U+011D9B */
+	0,							/* U+011D9C */
+	0,							/* U+011D9D */
+	0,							/* U+011D9E */
+	0,							/* U+011D9F */
+	0,							/* U+011DA0 */
+	0,							/* U+011DA1 */
+	0,							/* U+011DA2 */
+	0,							/* U+011DA3 */
+	0,							/* U+011DA4 */
+	0,							/* U+011DA5 */
+	0,							/* U+011DA6 */
+	0,							/* U+011DA7 */
+	0,							/* U+011DA8 */
+	0,							/* U+011DA9 */
+	0,							/* U+011DAA */
+	0,							/* U+011DAB */
+	0,							/* U+011DAC */
+	0,							/* U+011DAD */
+	0,							/* U+011DAE */
+	0,							/* U+011DAF */
+	0,							/* U+011DB0 */
+	0,							/* U+011DB1 */
+	0,							/* U+011DB2 */
+	0,							/* U+011DB3 */
+	0,							/* U+011DB4 */
+	0,							/* U+011DB5 */
+	0,							/* U+011DB6 */
+	0,							/* U+011DB7 */
+	0,							/* U+011DB8 */
+	0,							/* U+011DB9 */
+	0,							/* U+011DBA */
+	0,							/* U+011DBB */
+	0,							/* U+011DBC */
+	0,							/* U+011DBD */
+	0,							/* U+011DBE */
+	0,							/* U+011DBF */
+	0,							/* U+011DC0 */
+	0,							/* U+011DC1 */
+	0,							/* U+011DC2 */
+	0,							/* U+011DC3 */
+	0,							/* U+011DC4 */
+	0,							/* U+011DC5 */
+	0,							/* U+011DC6 */
+	0,							/* U+011DC7 */
+	0,							/* U+011DC8 */
+	0,							/* U+011DC9 */
+	0,							/* U+011DCA */
+	0,							/* U+011DCB */
+	0,							/* U+011DCC */
+	0,							/* U+011DCD */
+	0,							/* U+011DCE */
+	0,							/* U+011DCF */
+	0,							/* U+011DD0 */
+	0,							/* U+011DD1 */
+	0,							/* U+011DD2 */
+	0,							/* U+011DD3 */
+	0,							/* U+011DD4 */
+	0,							/* U+011DD5 */
+	0,							/* U+011DD6 */
+	0,							/* U+011DD7 */
+	0,							/* U+011DD8 */
+	0,							/* U+011DD9 */
+	0,							/* U+011DDA */
+	0,							/* U+011DDB */
+	0,							/* U+011DDC */
+	0,							/* U+011DDD */
+	0,							/* U+011DDE */
+	0,							/* U+011DDF */
+	0,							/* U+011DE0 */
+	0,							/* U+011DE1 */
+	0,							/* U+011DE2 */
+	0,							/* U+011DE3 */
+	0,							/* U+011DE4 */
+	0,							/* U+011DE5 */
+	0,							/* U+011DE6 */
+	0,							/* U+011DE7 */
+	0,							/* U+011DE8 */
+	0,							/* U+011DE9 */
+	0,							/* U+011DEA */
+	0,							/* U+011DEB */
+	0,							/* U+011DEC */
+	0,							/* U+011DED */
+	0,							/* U+011DEE */
+	0,							/* U+011DEF */
+	0,							/* U+011DF0 */
+	0,							/* U+011DF1 */
+	0,							/* U+011DF2 */
+	0,							/* U+011DF3 */
+	0,							/* U+011DF4 */
+	0,							/* U+011DF5 */
+	0,							/* U+011DF6 */
+	0,							/* U+011DF7 */
+	0,							/* U+011DF8 */
+	0,							/* U+011DF9 */
+	0,							/* U+011DFA */
+	0,							/* U+011DFB */
+	0,							/* U+011DFC */
+	0,							/* U+011DFD */
+	0,							/* U+011DFE */
+	0,							/* U+011DFF */
+	0,							/* U+011E00 */
+	0,							/* U+011E01 */
+	0,							/* U+011E02 */
+	0,							/* U+011E03 */
+	0,							/* U+011E04 */
+	0,							/* U+011E05 */
+	0,							/* U+011E06 */
+	0,							/* U+011E07 */
+	0,							/* U+011E08 */
+	0,							/* U+011E09 */
+	0,							/* U+011E0A */
+	0,							/* U+011E0B */
+	0,							/* U+011E0C */
+	0,							/* U+011E0D */
+	0,							/* U+011E0E */
+	0,							/* U+011E0F */
+	0,							/* U+011E10 */
+	0,							/* U+011E11 */
+	0,							/* U+011E12 */
+	0,							/* U+011E13 */
+	0,							/* U+011E14 */
+	0,							/* U+011E15 */
+	0,							/* U+011E16 */
+	0,							/* U+011E17 */
+	0,							/* U+011E18 */
+	0,							/* U+011E19 */
+	0,							/* U+011E1A */
+	0,							/* U+011E1B */
+	0,							/* U+011E1C */
+	0,							/* U+011E1D */
+	0,							/* U+011E1E */
+	0,							/* U+011E1F */
+	0,							/* U+011E20 */
+	0,							/* U+011E21 */
+	0,							/* U+011E22 */
+	0,							/* U+011E23 */
+	0,							/* U+011E24 */
+	0,							/* U+011E25 */
+	0,							/* U+011E26 */
+	0,							/* U+011E27 */
+	0,							/* U+011E28 */
+	0,							/* U+011E29 */
+	0,							/* U+011E2A */
+	0,							/* U+011E2B */
+	0,							/* U+011E2C */
+	0,							/* U+011E2D */
+	0,							/* U+011E2E */
+	0,							/* U+011E2F */
+	0,							/* U+011E30 */
+	0,							/* U+011E31 */
+	0,							/* U+011E32 */
+	0,							/* U+011E33 */
+	0,							/* U+011E34 */
+	0,							/* U+011E35 */
+	0,							/* U+011E36 */
+	0,							/* U+011E37 */
+	0,							/* U+011E38 */
+	0,							/* U+011E39 */
+	0,							/* U+011E3A */
+	0,							/* U+011E3B */
+	0,							/* U+011E3C */
+	0,							/* U+011E3D */
+	0,							/* U+011E3E */
+	0,							/* U+011E3F */
+	0,							/* U+011E40 */
+	0,							/* U+011E41 */
+	0,							/* U+011E42 */
+	0,							/* U+011E43 */
+	0,							/* U+011E44 */
+	0,							/* U+011E45 */
+	0,							/* U+011E46 */
+	0,							/* U+011E47 */
+	0,							/* U+011E48 */
+	0,							/* U+011E49 */
+	0,							/* U+011E4A */
+	0,							/* U+011E4B */
+	0,							/* U+011E4C */
+	0,							/* U+011E4D */
+	0,							/* U+011E4E */
+	0,							/* U+011E4F */
+	0,							/* U+011E50 */
+	0,							/* U+011E51 */
+	0,							/* U+011E52 */
+	0,							/* U+011E53 */
+	0,							/* U+011E54 */
+	0,							/* U+011E55 */
+	0,							/* U+011E56 */
+	0,							/* U+011E57 */
+	0,							/* U+011E58 */
+	0,							/* U+011E59 */
+	0,							/* U+011E5A */
+	0,							/* U+011E5B */
+	0,							/* U+011E5C */
+	0,							/* U+011E5D */
+	0,							/* U+011E5E */
+	0,							/* U+011E5F */
+	0,							/* U+011E60 */
+	0,							/* U+011E61 */
+	0,							/* U+011E62 */
+	0,							/* U+011E63 */
+	0,							/* U+011E64 */
+	0,							/* U+011E65 */
+	0,							/* U+011E66 */
+	0,							/* U+011E67 */
+	0,							/* U+011E68 */
+	0,							/* U+011E69 */
+	0,							/* U+011E6A */
+	0,							/* U+011E6B */
+	0,							/* U+011E6C */
+	0,							/* U+011E6D */
+	0,							/* U+011E6E */
+	0,							/* U+011E6F */
+	0,							/* U+011E70 */
+	0,							/* U+011E71 */
+	0,							/* U+011E72 */
+	0,							/* U+011E73 */
+	0,							/* U+011E74 */
+	0,							/* U+011E75 */
+	0,							/* U+011E76 */
+	0,							/* U+011E77 */
+	0,							/* U+011E78 */
+	0,							/* U+011E79 */
+	0,							/* U+011E7A */
+	0,							/* U+011E7B */
+	0,							/* U+011E7C */
+	0,							/* U+011E7D */
+	0,							/* U+011E7E */
+	0,							/* U+011E7F */
+	0,							/* U+011E80 */
+	0,							/* U+011E81 */
+	0,							/* U+011E82 */
+	0,							/* U+011E83 */
+	0,							/* U+011E84 */
+	0,							/* U+011E85 */
+	0,							/* U+011E86 */
+	0,							/* U+011E87 */
+	0,							/* U+011E88 */
+	0,							/* U+011E89 */
+	0,							/* U+011E8A */
+	0,							/* U+011E8B */
+	0,							/* U+011E8C */
+	0,							/* U+011E8D */
+	0,							/* U+011E8E */
+	0,							/* U+011E8F */
+	0,							/* U+011E90 */
+	0,							/* U+011E91 */
+	0,							/* U+011E92 */
+	0,							/* U+011E93 */
+	0,							/* U+011E94 */
+	0,							/* U+011E95 */
+	0,							/* U+011E96 */
+	0,							/* U+011E97 */
+	0,							/* U+011E98 */
+	0,							/* U+011E99 */
+	0,							/* U+011E9A */
+	0,							/* U+011E9B */
+	0,							/* U+011E9C */
+	0,							/* U+011E9D */
+	0,							/* U+011E9E */
+	0,							/* U+011E9F */
+	0,							/* U+011EA0 */
+	0,							/* U+011EA1 */
+	0,							/* U+011EA2 */
+	0,							/* U+011EA3 */
+	0,							/* U+011EA4 */
+	0,							/* U+011EA5 */
+	0,							/* U+011EA6 */
+	0,							/* U+011EA7 */
+	0,							/* U+011EA8 */
+	0,							/* U+011EA9 */
+	0,							/* U+011EAA */
+	0,							/* U+011EAB */
+	0,							/* U+011EAC */
+	0,							/* U+011EAD */
+	0,							/* U+011EAE */
+	0,							/* U+011EAF */
+	0,							/* U+011EB0 */
+	0,							/* U+011EB1 */
+	0,							/* U+011EB2 */
+	0,							/* U+011EB3 */
+	0,							/* U+011EB4 */
+	0,							/* U+011EB5 */
+	0,							/* U+011EB6 */
+	0,							/* U+011EB7 */
+	0,							/* U+011EB8 */
+	0,							/* U+011EB9 */
+	0,							/* U+011EBA */
+	0,							/* U+011EBB */
+	0,							/* U+011EBC */
+	0,							/* U+011EBD */
+	0,							/* U+011EBE */
+	0,							/* U+011EBF */
+	0,							/* U+011EC0 */
+	0,							/* U+011EC1 */
+	0,							/* U+011EC2 */
+	0,							/* U+011EC3 */
+	0,							/* U+011EC4 */
+	0,							/* U+011EC5 */
+	0,							/* U+011EC6 */
+	0,							/* U+011EC7 */
+	0,							/* U+011EC8 */
+	0,							/* U+011EC9 */
+	0,							/* U+011ECA */
+	0,							/* U+011ECB */
+	0,							/* U+011ECC */
+	0,							/* U+011ECD */
+	0,							/* U+011ECE */
+	0,							/* U+011ECF */
+	0,							/* U+011ED0 */
+	0,							/* U+011ED1 */
+	0,							/* U+011ED2 */
+	0,							/* U+011ED3 */
+	0,							/* U+011ED4 */
+	0,							/* U+011ED5 */
+	0,							/* U+011ED6 */
+	0,							/* U+011ED7 */
+	0,							/* U+011ED8 */
+	0,							/* U+011ED9 */
+	0,							/* U+011EDA */
+	0,							/* U+011EDB */
+	0,							/* U+011EDC */
+	0,							/* U+011EDD */
+	0,							/* U+011EDE */
+	0,							/* U+011EDF */
+	0,							/* U+011EE0 */
+	0,							/* U+011EE1 */
+	0,							/* U+011EE2 */
+	0,							/* U+011EE3 */
+	0,							/* U+011EE4 */
+	0,							/* U+011EE5 */
+	0,							/* U+011EE6 */
+	0,							/* U+011EE7 */
+	0,							/* U+011EE8 */
+	0,							/* U+011EE9 */
+	0,							/* U+011EEA */
+	0,							/* U+011EEB */
+	0,							/* U+011EEC */
+	0,							/* U+011EED */
+	0,							/* U+011EEE */
+	0,							/* U+011EEF */
+	0,							/* U+011EF0 */
+	0,							/* U+011EF1 */
+	0,							/* U+011EF2 */
+	0,							/* U+011EF3 */
+	0,							/* U+011EF4 */
+	0,							/* U+011EF5 */
+	0,							/* U+011EF6 */
+	0,							/* U+011EF7 */
+	0,							/* U+011EF8 */
+	0,							/* U+011EF9 */
+	0,							/* U+011EFA */
+	0,							/* U+011EFB */
+	0,							/* U+011EFC */
+	0,							/* U+011EFD */
+	0,							/* U+011EFE */
+	0,							/* U+011EFF */
+	0,							/* U+011F00 */
+	0,							/* U+011F01 */
+	0,							/* U+011F02 */
+	0,							/* U+011F03 */
+	0,							/* U+011F04 */
+	0,							/* U+011F05 */
+	0,							/* U+011F06 */
+	0,							/* U+011F07 */
+	0,							/* U+011F08 */
+	0,							/* U+011F09 */
+	0,							/* U+011F0A */
+	0,							/* U+011F0B */
+	0,							/* U+011F0C */
+	0,							/* U+011F0D */
+	0,							/* U+011F0E */
+	0,							/* U+011F0F */
+	0,							/* U+011F10 */
+	0,							/* U+011F11 */
+	0,							/* U+011F12 */
+	0,							/* U+011F13 */
+	0,							/* U+011F14 */
+	0,							/* U+011F15 */
+	0,							/* U+011F16 */
+	0,							/* U+011F17 */
+	0,							/* U+011F18 */
+	0,							/* U+011F19 */
+	0,							/* U+011F1A */
+	0,							/* U+011F1B */
+	0,							/* U+011F1C */
+	0,							/* U+011F1D */
+	0,							/* U+011F1E */
+	0,							/* U+011F1F */
+	0,							/* U+011F20 */
+	0,							/* U+011F21 */
+	0,							/* U+011F22 */
+	0,							/* U+011F23 */
+	0,							/* U+011F24 */
+	0,							/* U+011F25 */
+	0,							/* U+011F26 */
+	0,							/* U+011F27 */
+	0,							/* U+011F28 */
+	0,							/* U+011F29 */
+	0,							/* U+011F2A */
+	0,							/* U+011F2B */
+	0,							/* U+011F2C */
+	0,							/* U+011F2D */
+	0,							/* U+011F2E */
+	0,							/* U+011F2F */
+	0,							/* U+011F30 */
+	0,							/* U+011F31 */
+	0,							/* U+011F32 */
+	0,							/* U+011F33 */
+	0,							/* U+011F34 */
+	0,							/* U+011F35 */
+	0,							/* U+011F36 */
+	0,							/* U+011F37 */
+	0,							/* U+011F38 */
+	0,							/* U+011F39 */
+	0,							/* U+011F3A */
+	0,							/* U+011F3B */
+	0,							/* U+011F3C */
+	0,							/* U+011F3D */
+	0,							/* U+011F3E */
+	0,							/* U+011F3F */
+	0,							/* U+011F40 */
+	452,						/* U+011F41 */
+	452,						/* U+011F42 */
+	3259,						/* U+016121 */
+	3260,						/* U+016122 */
+	3261,						/* U+016123 */
+	3262,						/* U+016124 */
+	3263,						/* U+016125 */
+	3264,						/* U+016126 */
+	3265,						/* U+016127 */
+	3266,						/* U+016128 */
+	0,							/* U+016129 */
+	0,							/* U+01612A */
+	0,							/* U+01612B */
+	0,							/* U+01612C */
+	0,							/* U+01612D */
+	0,							/* U+01612E */
+	452,						/* U+01612F */
+	309,						/* U+016AF0 */
+	309,						/* U+016AF1 */
+	309,						/* U+016AF2 */
+	309,						/* U+016AF3 */
+	309,						/* U+016AF4 */
+	0,							/* U+016AF5 */
+	0,							/* U+016AF6 */
+	0,							/* U+016AF7 */
+	0,							/* U+016AF8 */
+	0,							/* U+016AF9 */
+	0,							/* U+016AFA */
+	0,							/* U+016AFB */
+	0,							/* U+016AFC */
+	0,							/* U+016AFD */
+	0,							/* U+016AFE */
+	0,							/* U+016AFF */
+	0,							/* U+016B00 */
+	0,							/* U+016B01 */
+	0,							/* U+016B02 */
+	0,							/* U+016B03 */
+	0,							/* U+016B04 */
+	0,							/* U+016B05 */
+	0,							/* U+016B06 */
+	0,							/* U+016B07 */
+	0,							/* U+016B08 */
+	0,							/* U+016B09 */
+	0,							/* U+016B0A */
+	0,							/* U+016B0B */
+	0,							/* U+016B0C */
+	0,							/* U+016B0D */
+	0,							/* U+016B0E */
+	0,							/* U+016B0F */
+	0,							/* U+016B10 */
+	0,							/* U+016B11 */
+	0,							/* U+016B12 */
+	0,							/* U+016B13 */
+	0,							/* U+016B14 */
+	0,							/* U+016B15 */
+	0,							/* U+016B16 */
+	0,							/* U+016B17 */
+	0,							/* U+016B18 */
+	0,							/* U+016B19 */
+	0,							/* U+016B1A */
+	0,							/* U+016B1B */
+	0,							/* U+016B1C */
+	0,							/* U+016B1D */
+	0,							/* U+016B1E */
+	0,							/* U+016B1F */
+	0,							/* U+016B20 */
+	0,							/* U+016B21 */
+	0,							/* U+016B22 */
+	0,							/* U+016B23 */
+	0,							/* U+016B24 */
+	0,							/* U+016B25 */
+	0,							/* U+016B26 */
+	0,							/* U+016B27 */
+	0,							/* U+016B28 */
+	0,							/* U+016B29 */
+	0,							/* U+016B2A */
+	0,							/* U+016B2B */
+	0,							/* U+016B2C */
+	0,							/* U+016B2D */
+	0,							/* U+016B2E */
+	0,							/* U+016B2F */
+	304,						/* U+016B30 */
+	304,						/* U+016B31 */
+	304,						/* U+016B32 */
+	304,						/* U+016B33 */
+	304,						/* U+016B34 */
+	304,						/* U+016B35 */
+	304,						/* U+016B36 */
+	0,							/* U+016B37 */
+	0,							/* U+016B38 */
+	0,							/* U+016B39 */
+	0,							/* U+016B3A */
+	0,							/* U+016B3B */
+	0,							/* U+016B3C */
+	0,							/* U+016B3D */
+	0,							/* U+016B3E */
+	0,							/* U+016B3F */
+	0,							/* U+016B40 */
+	0,							/* U+016B41 */
+	0,							/* U+016B42 */
+	0,							/* U+016B43 */
+	0,							/* U+016B44 */
+	0,							/* U+016B45 */
+	0,							/* U+016B46 */
+	0,							/* U+016B47 */
+	0,							/* U+016B48 */
+	0,							/* U+016B49 */
+	0,							/* U+016B4A */
+	0,							/* U+016B4B */
+	0,							/* U+016B4C */
+	0,							/* U+016B4D */
+	0,							/* U+016B4E */
+	0,							/* U+016B4F */
+	0,							/* U+016B50 */
+	0,							/* U+016B51 */
+	0,							/* U+016B52 */
+	0,							/* U+016B53 */
+	0,							/* U+016B54 */
+	0,							/* U+016B55 */
+	0,							/* U+016B56 */
+	0,							/* U+016B57 */
+	0,							/* U+016B58 */
+	0,							/* U+016B59 */
+	0,							/* U+016B5A */
+	0,							/* U+016B5B */
+	0,							/* U+016B5C */
+	0,							/* U+016B5D */
+	0,							/* U+016B5E */
+	0,							/* U+016B5F */
+	0,							/* U+016B60 */
+	0,							/* U+016B61 */
+	0,							/* U+016B62 */
+	0,							/* U+016B63 */
+	0,							/* U+016B64 */
+	0,							/* U+016B65 */
+	0,							/* U+016B66 */
+	0,							/* U+016B67 */
+	0,							/* U+016B68 */
+	0,							/* U+016B69 */
+	0,							/* U+016B6A */
+	0,							/* U+016B6B */
+	0,							/* U+016B6C */
+	0,							/* U+016B6D */
+	0,							/* U+016B6E */
+	0,							/* U+016B6F */
+	0,							/* U+016B70 */
+	0,							/* U+016B71 */
+	0,							/* U+016B72 */
+	0,							/* U+016B73 */
+	0,							/* U+016B74 */
+	0,							/* U+016B75 */
+	0,							/* U+016B76 */
+	0,							/* U+016B77 */
+	0,							/* U+016B78 */
+	0,							/* U+016B79 */
+	0,							/* U+016B7A */
+	0,							/* U+016B7B */
+	0,							/* U+016B7C */
+	0,							/* U+016B7D */
+	0,							/* U+016B7E */
+	0,							/* U+016B7F */
+	0,							/* U+016B80 */
+	0,							/* U+016B81 */
+	0,							/* U+016B82 */
+	0,							/* U+016B83 */
+	0,							/* U+016B84 */
+	0,							/* U+016B85 */
+	0,							/* U+016B86 */
+	0,							/* U+016B87 */
+	0,							/* U+016B88 */
+	0,							/* U+016B89 */
+	0,							/* U+016B8A */
+	0,							/* U+016B8B */
+	0,							/* U+016B8C */
+	0,							/* U+016B8D */
+	0,							/* U+016B8E */
+	0,							/* U+016B8F */
+	0,							/* U+016B90 */
+	0,							/* U+016B91 */
+	0,							/* U+016B92 */
+	0,							/* U+016B93 */
+	0,							/* U+016B94 */
+	0,							/* U+016B95 */
+	0,							/* U+016B96 */
+	0,							/* U+016B97 */
+	0,							/* U+016B98 */
+	0,							/* U+016B99 */
+	0,							/* U+016B9A */
+	0,							/* U+016B9B */
+	0,							/* U+016B9C */
+	0,							/* U+016B9D */
+	0,							/* U+016B9E */
+	0,							/* U+016B9F */
+	0,							/* U+016BA0 */
+	0,							/* U+016BA1 */
+	0,							/* U+016BA2 */
+	0,							/* U+016BA3 */
+	0,							/* U+016BA4 */
+	0,							/* U+016BA5 */
+	0,							/* U+016BA6 */
+	0,							/* U+016BA7 */
+	0,							/* U+016BA8 */
+	0,							/* U+016BA9 */
+	0,							/* U+016BAA */
+	0,							/* U+016BAB */
+	0,							/* U+016BAC */
+	0,							/* U+016BAD */
+	0,							/* U+016BAE */
+	0,							/* U+016BAF */
+	0,							/* U+016BB0 */
+	0,							/* U+016BB1 */
+	0,							/* U+016BB2 */
+	0,							/* U+016BB3 */
+	0,							/* U+016BB4 */
+	0,							/* U+016BB5 */
+	0,							/* U+016BB6 */
+	0,							/* U+016BB7 */
+	0,							/* U+016BB8 */
+	0,							/* U+016BB9 */
+	0,							/* U+016BBA */
+	0,							/* U+016BBB */
+	0,							/* U+016BBC */
+	0,							/* U+016BBD */
+	0,							/* U+016BBE */
+	0,							/* U+016BBF */
+	0,							/* U+016BC0 */
+	0,							/* U+016BC1 */
+	0,							/* U+016BC2 */
+	0,							/* U+016BC3 */
+	0,							/* U+016BC4 */
+	0,							/* U+016BC5 */
+	0,							/* U+016BC6 */
+	0,							/* U+016BC7 */
+	0,							/* U+016BC8 */
+	0,							/* U+016BC9 */
+	0,							/* U+016BCA */
+	0,							/* U+016BCB */
+	0,							/* U+016BCC */
+	0,							/* U+016BCD */
+	0,							/* U+016BCE */
+	0,							/* U+016BCF */
+	0,							/* U+016BD0 */
+	0,							/* U+016BD1 */
+	0,							/* U+016BD2 */
+	0,							/* U+016BD3 */
+	0,							/* U+016BD4 */
+	0,							/* U+016BD5 */
+	0,							/* U+016BD6 */
+	0,							/* U+016BD7 */
+	0,							/* U+016BD8 */
+	0,							/* U+016BD9 */
+	0,							/* U+016BDA */
+	0,							/* U+016BDB */
+	0,							/* U+016BDC */
+	0,							/* U+016BDD */
+	0,							/* U+016BDE */
+	0,							/* U+016BDF */
+	0,							/* U+016BE0 */
+	0,							/* U+016BE1 */
+	0,							/* U+016BE2 */
+	0,							/* U+016BE3 */
+	0,							/* U+016BE4 */
+	0,							/* U+016BE5 */
+	0,							/* U+016BE6 */
+	0,							/* U+016BE7 */
+	0,							/* U+016BE8 */
+	0,							/* U+016BE9 */
+	0,							/* U+016BEA */
+	0,							/* U+016BEB */
+	0,							/* U+016BEC */
+	0,							/* U+016BED */
+	0,							/* U+016BEE */
+	0,							/* U+016BEF */
+	0,							/* U+016BF0 */
+	0,							/* U+016BF1 */
+	0,							/* U+016BF2 */
+	0,							/* U+016BF3 */
+	0,							/* U+016BF4 */
+	0,							/* U+016BF5 */
+	0,							/* U+016BF6 */
+	0,							/* U+016BF7 */
+	0,							/* U+016BF8 */
+	0,							/* U+016BF9 */
+	0,							/* U+016BFA */
+	0,							/* U+016BFB */
+	0,							/* U+016BFC */
+	0,							/* U+016BFD */
+	0,							/* U+016BFE */
+	0,							/* U+016BFF */
+	0,							/* U+016C00 */
+	0,							/* U+016C01 */
+	0,							/* U+016C02 */
+	0,							/* U+016C03 */
+	0,							/* U+016C04 */
+	0,							/* U+016C05 */
+	0,							/* U+016C06 */
+	0,							/* U+016C07 */
+	0,							/* U+016C08 */
+	0,							/* U+016C09 */
+	0,							/* U+016C0A */
+	0,							/* U+016C0B */
+	0,							/* U+016C0C */
+	0,							/* U+016C0D */
+	0,							/* U+016C0E */
+	0,							/* U+016C0F */
+	0,							/* U+016C10 */
+	0,							/* U+016C11 */
+	0,							/* U+016C12 */
+	0,							/* U+016C13 */
+	0,							/* U+016C14 */
+	0,							/* U+016C15 */
+	0,							/* U+016C16 */
+	0,							/* U+016C17 */
+	0,							/* U+016C18 */
+	0,							/* U+016C19 */
+	0,							/* U+016C1A */
+	0,							/* U+016C1B */
+	0,							/* U+016C1C */
+	0,							/* U+016C1D */
+	0,							/* U+016C1E */
+	0,							/* U+016C1F */
+	0,							/* U+016C20 */
+	0,							/* U+016C21 */
+	0,							/* U+016C22 */
+	0,							/* U+016C23 */
+	0,							/* U+016C24 */
+	0,							/* U+016C25 */
+	0,							/* U+016C26 */
+	0,							/* U+016C27 */
+	0,							/* U+016C28 */
+	0,							/* U+016C29 */
+	0,							/* U+016C2A */
+	0,							/* U+016C2B */
+	0,							/* U+016C2C */
+	0,							/* U+016C2D */
+	0,							/* U+016C2E */
+	0,							/* U+016C2F */
+	0,							/* U+016C30 */
+	0,							/* U+016C31 */
+	0,							/* U+016C32 */
+	0,							/* U+016C33 */
+	0,							/* U+016C34 */
+	0,							/* U+016C35 */
+	0,							/* U+016C36 */
+	0,							/* U+016C37 */
+	0,							/* U+016C38 */
+	0,							/* U+016C39 */
+	0,							/* U+016C3A */
+	0,							/* U+016C3B */
+	0,							/* U+016C3C */
+	0,							/* U+016C3D */
+	0,							/* U+016C3E */
+	0,							/* U+016C3F */
+	0,							/* U+016C40 */
+	0,							/* U+016C41 */
+	0,							/* U+016C42 */
+	0,							/* U+016C43 */
+	0,							/* U+016C44 */
+	0,							/* U+016C45 */
+	0,							/* U+016C46 */
+	0,							/* U+016C47 */
+	0,							/* U+016C48 */
+	0,							/* U+016C49 */
+	0,							/* U+016C4A */
+	0,							/* U+016C4B */
+	0,							/* U+016C4C */
+	0,							/* U+016C4D */
+	0,							/* U+016C4E */
+	0,							/* U+016C4F */
+	0,							/* U+016C50 */
+	0,							/* U+016C51 */
+	0,							/* U+016C52 */
+	0,							/* U+016C53 */
+	0,							/* U+016C54 */
+	0,							/* U+016C55 */
+	0,							/* U+016C56 */
+	0,							/* U+016C57 */
+	0,							/* U+016C58 */
+	0,							/* U+016C59 */
+	0,							/* U+016C5A */
+	0,							/* U+016C5B */
+	0,							/* U+016C5C */
+	0,							/* U+016C5D */
+	0,							/* U+016C5E */
+	0,							/* U+016C5F */
+	0,							/* U+016C60 */
+	0,							/* U+016C61 */
+	0,							/* U+016C62 */
+	0,							/* U+016C63 */
+	0,							/* U+016C64 */
+	0,							/* U+016C65 */
+	0,							/* U+016C66 */
+	0,							/* U+016C67 */
+	0,							/* U+016C68 */
+	0,							/* U+016C69 */
+	0,							/* U+016C6A */
+	0,							/* U+016C6B */
+	0,							/* U+016C6C */
+	0,							/* U+016C6D */
+	0,							/* U+016C6E */
+	0,							/* U+016C6F */
+	0,							/* U+016C70 */
+	0,							/* U+016C71 */
+	0,							/* U+016C72 */
+	0,							/* U+016C73 */
+	0,							/* U+016C74 */
+	0,							/* U+016C75 */
+	0,							/* U+016C76 */
+	0,							/* U+016C77 */
+	0,							/* U+016C78 */
+	0,							/* U+016C79 */
+	0,							/* U+016C7A */
+	0,							/* U+016C7B */
+	0,							/* U+016C7C */
+	0,							/* U+016C7D */
+	0,							/* U+016C7E */
+	0,							/* U+016C7F */
+	0,							/* U+016C80 */
+	0,							/* U+016C81 */
+	0,							/* U+016C82 */
+	0,							/* U+016C83 */
+	0,							/* U+016C84 */
+	0,							/* U+016C85 */
+	0,							/* U+016C86 */
+	0,							/* U+016C87 */
+	0,							/* U+016C88 */
+	0,							/* U+016C89 */
+	0,							/* U+016C8A */
+	0,							/* U+016C8B */
+	0,							/* U+016C8C */
+	0,							/* U+016C8D */
+	0,							/* U+016C8E */
+	0,							/* U+016C8F */
+	0,							/* U+016C90 */
+	0,							/* U+016C91 */
+	0,							/* U+016C92 */
+	0,							/* U+016C93 */
+	0,							/* U+016C94 */
+	0,							/* U+016C95 */
+	0,							/* U+016C96 */
+	0,							/* U+016C97 */
+	0,							/* U+016C98 */
+	0,							/* U+016C99 */
+	0,							/* U+016C9A */
+	0,							/* U+016C9B */
+	0,							/* U+016C9C */
+	0,							/* U+016C9D */
+	0,							/* U+016C9E */
+	0,							/* U+016C9F */
+	0,							/* U+016CA0 */
+	0,							/* U+016CA1 */
+	0,							/* U+016CA2 */
+	0,							/* U+016CA3 */
+	0,							/* U+016CA4 */
+	0,							/* U+016CA5 */
+	0,							/* U+016CA6 */
+	0,							/* U+016CA7 */
+	0,							/* U+016CA8 */
+	0,							/* U+016CA9 */
+	0,							/* U+016CAA */
+	0,							/* U+016CAB */
+	0,							/* U+016CAC */
+	0,							/* U+016CAD */
+	0,							/* U+016CAE */
+	0,							/* U+016CAF */
+	0,							/* U+016CB0 */
+	0,							/* U+016CB1 */
+	0,							/* U+016CB2 */
+	0,							/* U+016CB3 */
+	0,							/* U+016CB4 */
+	0,							/* U+016CB5 */
+	0,							/* U+016CB6 */
+	0,							/* U+016CB7 */
+	0,							/* U+016CB8 */
+	0,							/* U+016CB9 */
+	0,							/* U+016CBA */
+	0,							/* U+016CBB */
+	0,							/* U+016CBC */
+	0,							/* U+016CBD */
+	0,							/* U+016CBE */
+	0,							/* U+016CBF */
+	0,							/* U+016CC0 */
+	0,							/* U+016CC1 */
+	0,							/* U+016CC2 */
+	0,							/* U+016CC3 */
+	0,							/* U+016CC4 */
+	0,							/* U+016CC5 */
+	0,							/* U+016CC6 */
+	0,							/* U+016CC7 */
+	0,							/* U+016CC8 */
+	0,							/* U+016CC9 */
+	0,							/* U+016CCA */
+	0,							/* U+016CCB */
+	0,							/* U+016CCC */
+	0,							/* U+016CCD */
+	0,							/* U+016CCE */
+	0,							/* U+016CCF */
+	0,							/* U+016CD0 */
+	0,							/* U+016CD1 */
+	0,							/* U+016CD2 */
+	0,							/* U+016CD3 */
+	0,							/* U+016CD4 */
+	0,							/* U+016CD5 */
+	0,							/* U+016CD6 */
+	0,							/* U+016CD7 */
+	0,							/* U+016CD8 */
+	0,							/* U+016CD9 */
+	0,							/* U+016CDA */
+	0,							/* U+016CDB */
+	0,							/* U+016CDC */
+	0,							/* U+016CDD */
+	0,							/* U+016CDE */
+	0,							/* U+016CDF */
+	0,							/* U+016CE0 */
+	0,							/* U+016CE1 */
+	0,							/* U+016CE2 */
+	0,							/* U+016CE3 */
+	0,							/* U+016CE4 */
+	0,							/* U+016CE5 */
+	0,							/* U+016CE6 */
+	0,							/* U+016CE7 */
+	0,							/* U+016CE8 */
+	0,							/* U+016CE9 */
+	0,							/* U+016CEA */
+	0,							/* U+016CEB */
+	0,							/* U+016CEC */
+	0,							/* U+016CED */
+	0,							/* U+016CEE */
+	0,							/* U+016CEF */
+	0,							/* U+016CF0 */
+	0,							/* U+016CF1 */
+	0,							/* U+016CF2 */
+	0,							/* U+016CF3 */
+	0,							/* U+016CF4 */
+	0,							/* U+016CF5 */
+	0,							/* U+016CF6 */
+	0,							/* U+016CF7 */
+	0,							/* U+016CF8 */
+	0,							/* U+016CF9 */
+	0,							/* U+016CFA */
+	0,							/* U+016CFB */
+	0,							/* U+016CFC */
+	0,							/* U+016CFD */
+	0,							/* U+016CFE */
+	0,							/* U+016CFF */
+	0,							/* U+016D00 */
+	0,							/* U+016D01 */
+	0,							/* U+016D02 */
+	0,							/* U+016D03 */
+	0,							/* U+016D04 */
+	0,							/* U+016D05 */
+	0,							/* U+016D06 */
+	0,							/* U+016D07 */
+	0,							/* U+016D08 */
+	0,							/* U+016D09 */
+	0,							/* U+016D0A */
+	0,							/* U+016D0B */
+	0,							/* U+016D0C */
+	0,							/* U+016D0D */
+	0,							/* U+016D0E */
+	0,							/* U+016D0F */
+	0,							/* U+016D10 */
+	0,							/* U+016D11 */
+	0,							/* U+016D12 */
+	0,							/* U+016D13 */
+	0,							/* U+016D14 */
+	0,							/* U+016D15 */
+	0,							/* U+016D16 */
+	0,							/* U+016D17 */
+	0,							/* U+016D18 */
+	0,							/* U+016D19 */
+	0,							/* U+016D1A */
+	0,							/* U+016D1B */
+	0,							/* U+016D1C */
+	0,							/* U+016D1D */
+	0,							/* U+016D1E */
+	0,							/* U+016D1F */
+	0,							/* U+016D20 */
+	0,							/* U+016D21 */
+	0,							/* U+016D22 */
+	0,							/* U+016D23 */
+	0,							/* U+016D24 */
+	0,							/* U+016D25 */
+	0,							/* U+016D26 */
+	0,							/* U+016D27 */
+	0,							/* U+016D28 */
+	0,							/* U+016D29 */
+	0,							/* U+016D2A */
+	0,							/* U+016D2B */
+	0,							/* U+016D2C */
+	0,							/* U+016D2D */
+	0,							/* U+016D2E */
+	0,							/* U+016D2F */
+	0,							/* U+016D30 */
+	0,							/* U+016D31 */
+	0,							/* U+016D32 */
+	0,							/* U+016D33 */
+	0,							/* U+016D34 */
+	0,							/* U+016D35 */
+	0,							/* U+016D36 */
+	0,							/* U+016D37 */
+	0,							/* U+016D38 */
+	0,							/* U+016D39 */
+	0,							/* U+016D3A */
+	0,							/* U+016D3B */
+	0,							/* U+016D3C */
+	0,							/* U+016D3D */
+	0,							/* U+016D3E */
+	0,							/* U+016D3F */
+	0,							/* U+016D40 */
+	0,							/* U+016D41 */
+	0,							/* U+016D42 */
+	0,							/* U+016D43 */
+	0,							/* U+016D44 */
+	0,							/* U+016D45 */
+	0,							/* U+016D46 */
+	0,							/* U+016D47 */
+	0,							/* U+016D48 */
+	0,							/* U+016D49 */
+	0,							/* U+016D4A */
+	0,							/* U+016D4B */
+	0,							/* U+016D4C */
+	0,							/* U+016D4D */
+	0,							/* U+016D4E */
+	0,							/* U+016D4F */
+	0,							/* U+016D50 */
+	0,							/* U+016D51 */
+	0,							/* U+016D52 */
+	0,							/* U+016D53 */
+	0,							/* U+016D54 */
+	0,							/* U+016D55 */
+	0,							/* U+016D56 */
+	0,							/* U+016D57 */
+	0,							/* U+016D58 */
+	0,							/* U+016D59 */
+	0,							/* U+016D5A */
+	0,							/* U+016D5B */
+	0,							/* U+016D5C */
+	0,							/* U+016D5D */
+	0,							/* U+016D5E */
+	0,							/* U+016D5F */
+	0,							/* U+016D60 */
+	0,							/* U+016D61 */
+	0,							/* U+016D62 */
+	0,							/* U+016D63 */
+	0,							/* U+016D64 */
+	0,							/* U+016D65 */
+	0,							/* U+016D66 */
+	0,							/* U+016D67 */
+	3267,						/* U+016D68 */
+	3268,						/* U+016D69 */
+	3269,						/* U+016D6A */
+	0,							/* U+016D6B */
+	0,							/* U+016D6C */
+	0,							/* U+016D6D */
+	0,							/* U+016D6E */
+	0,							/* U+016D6F */
+	0,							/* U+016D70 */
+	0,							/* U+016D71 */
+	0,							/* U+016D72 */
+	0,							/* U+016D73 */
+	0,							/* U+016D74 */
+	0,							/* U+016D75 */
+	0,							/* U+016D76 */
+	0,							/* U+016D77 */
+	0,							/* U+016D78 */
+	0,							/* U+016D79 */
+	0,							/* U+016D7A */
+	0,							/* U+016D7B */
+	0,							/* U+016D7C */
+	0,							/* U+016D7D */
+	0,							/* U+016D7E */
+	0,							/* U+016D7F */
+	0,							/* U+016D80 */
+	0,							/* U+016D81 */
+	0,							/* U+016D82 */
+	0,							/* U+016D83 */
+	0,							/* U+016D84 */
+	0,							/* U+016D85 */
+	0,							/* U+016D86 */
+	0,							/* U+016D87 */
+	0,							/* U+016D88 */
+	0,							/* U+016D89 */
+	0,							/* U+016D8A */
+	0,							/* U+016D8B */
+	0,							/* U+016D8C */
+	0,							/* U+016D8D */
+	0,							/* U+016D8E */
+	0,							/* U+016D8F */
+	0,							/* U+016D90 */
+	0,							/* U+016D91 */
+	0,							/* U+016D92 */
+	0,							/* U+016D93 */
+	0,							/* U+016D94 */
+	0,							/* U+016D95 */
+	0,							/* U+016D96 */
+	0,							/* U+016D97 */
+	0,							/* U+016D98 */
+	0,							/* U+016D99 */
+	0,							/* U+016D9A */
+	0,							/* U+016D9B */
+	0,							/* U+016D9C */
+	0,							/* U+016D9D */
+	0,							/* U+016D9E */
+	0,							/* U+016D9F */
+	0,							/* U+016DA0 */
+	0,							/* U+016DA1 */
+	0,							/* U+016DA2 */
+	0,							/* U+016DA3 */
+	0,							/* U+016DA4 */
+	0,							/* U+016DA5 */
+	0,							/* U+016DA6 */
+	0,							/* U+016DA7 */
+	0,							/* U+016DA8 */
+	0,							/* U+016DA9 */
+	0,							/* U+016DAA */
+	0,							/* U+016DAB */
+	0,							/* U+016DAC */
+	0,							/* U+016DAD */
+	0,							/* U+016DAE */
+	0,							/* U+016DAF */
+	0,							/* U+016DB0 */
+	0,							/* U+016DB1 */
+	0,							/* U+016DB2 */
+	0,							/* U+016DB3 */
+	0,							/* U+016DB4 */
+	0,							/* U+016DB5 */
+	0,							/* U+016DB6 */
+	0,							/* U+016DB7 */
+	0,							/* U+016DB8 */
+	0,							/* U+016DB9 */
+	0,							/* U+016DBA */
+	0,							/* U+016DBB */
+	0,							/* U+016DBC */
+	0,							/* U+016DBD */
+	0,							/* U+016DBE */
+	0,							/* U+016DBF */
+	0,							/* U+016DC0 */
+	0,							/* U+016DC1 */
+	0,							/* U+016DC2 */
+	0,							/* U+016DC3 */
+	0,							/* U+016DC4 */
+	0,							/* U+016DC5 */
+	0,							/* U+016DC6 */
+	0,							/* U+016DC7 */
+	0,							/* U+016DC8 */
+	0,							/* U+016DC9 */
+	0,							/* U+016DCA */
+	0,							/* U+016DCB */
+	0,							/* U+016DCC */
+	0,							/* U+016DCD */
+	0,							/* U+016DCE */
+	0,							/* U+016DCF */
+	0,							/* U+016DD0 */
+	0,							/* U+016DD1 */
+	0,							/* U+016DD2 */
+	0,							/* U+016DD3 */
+	0,							/* U+016DD4 */
+	0,							/* U+016DD5 */
+	0,							/* U+016DD6 */
+	0,							/* U+016DD7 */
+	0,							/* U+016DD8 */
+	0,							/* U+016DD9 */
+	0,							/* U+016DDA */
+	0,							/* U+016DDB */
+	0,							/* U+016DDC */
+	0,							/* U+016DDD */
+	0,							/* U+016DDE */
+	0,							/* U+016DDF */
+	0,							/* U+016DE0 */
+	0,							/* U+016DE1 */
+	0,							/* U+016DE2 */
+	0,							/* U+016DE3 */
+	0,							/* U+016DE4 */
+	0,							/* U+016DE5 */
+	0,							/* U+016DE6 */
+	0,							/* U+016DE7 */
+	0,							/* U+016DE8 */
+	0,							/* U+016DE9 */
+	0,							/* U+016DEA */
+	0,							/* U+016DEB */
+	0,							/* U+016DEC */
+	0,							/* U+016DED */
+	0,							/* U+016DEE */
+	0,							/* U+016DEF */
+	0,							/* U+016DF0 */
+	0,							/* U+016DF1 */
+	0,							/* U+016DF2 */
+	0,							/* U+016DF3 */
+	0,							/* U+016DF4 */
+	0,							/* U+016DF5 */
+	0,							/* U+016DF6 */
+	0,							/* U+016DF7 */
+	0,							/* U+016DF8 */
+	0,							/* U+016DF9 */
+	0,							/* U+016DFA */
+	0,							/* U+016DFB */
+	0,							/* U+016DFC */
+	0,							/* U+016DFD */
+	0,							/* U+016DFE */
+	0,							/* U+016DFF */
+	0,							/* U+016E00 */
+	0,							/* U+016E01 */
+	0,							/* U+016E02 */
+	0,							/* U+016E03 */
+	0,							/* U+016E04 */
+	0,							/* U+016E05 */
+	0,							/* U+016E06 */
+	0,							/* U+016E07 */
+	0,							/* U+016E08 */
+	0,							/* U+016E09 */
+	0,							/* U+016E0A */
+	0,							/* U+016E0B */
+	0,							/* U+016E0C */
+	0,							/* U+016E0D */
+	0,							/* U+016E0E */
+	0,							/* U+016E0F */
+	0,							/* U+016E10 */
+	0,							/* U+016E11 */
+	0,							/* U+016E12 */
+	0,							/* U+016E13 */
+	0,							/* U+016E14 */
+	0,							/* U+016E15 */
+	0,							/* U+016E16 */
+	0,							/* U+016E17 */
+	0,							/* U+016E18 */
+	0,							/* U+016E19 */
+	0,							/* U+016E1A */
+	0,							/* U+016E1B */
+	0,							/* U+016E1C */
+	0,							/* U+016E1D */
+	0,							/* U+016E1E */
+	0,							/* U+016E1F */
+	0,							/* U+016E20 */
+	0,							/* U+016E21 */
+	0,							/* U+016E22 */
+	0,							/* U+016E23 */
+	0,							/* U+016E24 */
+	0,							/* U+016E25 */
+	0,							/* U+016E26 */
+	0,							/* U+016E27 */
+	0,							/* U+016E28 */
+	0,							/* U+016E29 */
+	0,							/* U+016E2A */
+	0,							/* U+016E2B */
+	0,							/* U+016E2C */
+	0,							/* U+016E2D */
+	0,							/* U+016E2E */
+	0,							/* U+016E2F */
+	0,							/* U+016E30 */
+	0,							/* U+016E31 */
+	0,							/* U+016E32 */
+	0,							/* U+016E33 */
+	0,							/* U+016E34 */
+	0,							/* U+016E35 */
+	0,							/* U+016E36 */
+	0,							/* U+016E37 */
+	0,							/* U+016E38 */
+	0,							/* U+016E39 */
+	0,							/* U+016E3A */
+	0,							/* U+016E3B */
+	0,							/* U+016E3C */
+	0,							/* U+016E3D */
+	0,							/* U+016E3E */
+	0,							/* U+016E3F */
+	0,							/* U+016E40 */
+	0,							/* U+016E41 */
+	0,							/* U+016E42 */
+	0,							/* U+016E43 */
+	0,							/* U+016E44 */
+	0,							/* U+016E45 */
+	0,							/* U+016E46 */
+	0,							/* U+016E47 */
+	0,							/* U+016E48 */
+	0,							/* U+016E49 */
+	0,							/* U+016E4A */
+	0,							/* U+016E4B */
+	0,							/* U+016E4C */
+	0,							/* U+016E4D */
+	0,							/* U+016E4E */
+	0,							/* U+016E4F */
+	0,							/* U+016E50 */
+	0,							/* U+016E51 */
+	0,							/* U+016E52 */
+	0,							/* U+016E53 */
+	0,							/* U+016E54 */
+	0,							/* U+016E55 */
+	0,							/* U+016E56 */
+	0,							/* U+016E57 */
+	0,							/* U+016E58 */
+	0,							/* U+016E59 */
+	0,							/* U+016E5A */
+	0,							/* U+016E5B */
+	0,							/* U+016E5C */
+	0,							/* U+016E5D */
+	0,							/* U+016E5E */
+	0,							/* U+016E5F */
+	0,							/* U+016E60 */
+	0,							/* U+016E61 */
+	0,							/* U+016E62 */
+	0,							/* U+016E63 */
+	0,							/* U+016E64 */
+	0,							/* U+016E65 */
+	0,							/* U+016E66 */
+	0,							/* U+016E67 */
+	0,							/* U+016E68 */
+	0,							/* U+016E69 */
+	0,							/* U+016E6A */
+	0,							/* U+016E6B */
+	0,							/* U+016E6C */
+	0,							/* U+016E6D */
+	0,							/* U+016E6E */
+	0,							/* U+016E6F */
+	0,							/* U+016E70 */
+	0,							/* U+016E71 */
+	0,							/* U+016E72 */
+	0,							/* U+016E73 */
+	0,							/* U+016E74 */
+	0,							/* U+016E75 */
+	0,							/* U+016E76 */
+	0,							/* U+016E77 */
+	0,							/* U+016E78 */
+	0,							/* U+016E79 */
+	0,							/* U+016E7A */
+	0,							/* U+016E7B */
+	0,							/* U+016E7C */
+	0,							/* U+016E7D */
+	0,							/* U+016E7E */
+	0,							/* U+016E7F */
+	0,							/* U+016E80 */
+	0,							/* U+016E81 */
+	0,							/* U+016E82 */
+	0,							/* U+016E83 */
+	0,							/* U+016E84 */
+	0,							/* U+016E85 */
+	0,							/* U+016E86 */
+	0,							/* U+016E87 */
+	0,							/* U+016E88 */
+	0,							/* U+016E89 */
+	0,							/* U+016E8A */
+	0,							/* U+016E8B */
+	0,							/* U+016E8C */
+	0,							/* U+016E8D */
+	0,							/* U+016E8E */
+	0,							/* U+016E8F */
+	0,							/* U+016E90 */
+	0,							/* U+016E91 */
+	0,							/* U+016E92 */
+	0,							/* U+016E93 */
+	0,							/* U+016E94 */
+	0,							/* U+016E95 */
+	0,							/* U+016E96 */
+	0,							/* U+016E97 */
+	0,							/* U+016E98 */
+	0,							/* U+016E99 */
+	0,							/* U+016E9A */
+	0,							/* U+016E9B */
+	0,							/* U+016E9C */
+	0,							/* U+016E9D */
+	0,							/* U+016E9E */
+	0,							/* U+016E9F */
+	0,							/* U+016EA0 */
+	0,							/* U+016EA1 */
+	0,							/* U+016EA2 */
+	0,							/* U+016EA3 */
+	0,							/* U+016EA4 */
+	0,							/* U+016EA5 */
+	0,							/* U+016EA6 */
+	0,							/* U+016EA7 */
+	0,							/* U+016EA8 */
+	0,							/* U+016EA9 */
+	0,							/* U+016EAA */
+	0,							/* U+016EAB */
+	0,							/* U+016EAC */
+	0,							/* U+016EAD */
+	0,							/* U+016EAE */
+	0,							/* U+016EAF */
+	0,							/* U+016EB0 */
+	0,							/* U+016EB1 */
+	0,							/* U+016EB2 */
+	0,							/* U+016EB3 */
+	0,							/* U+016EB4 */
+	0,							/* U+016EB5 */
+	0,							/* U+016EB6 */
+	0,							/* U+016EB7 */
+	0,							/* U+016EB8 */
+	0,							/* U+016EB9 */
+	0,							/* U+016EBA */
+	0,							/* U+016EBB */
+	0,							/* U+016EBC */
+	0,							/* U+016EBD */
+	0,							/* U+016EBE */
+	0,							/* U+016EBF */
+	0,							/* U+016EC0 */
+	0,							/* U+016EC1 */
+	0,							/* U+016EC2 */
+	0,							/* U+016EC3 */
+	0,							/* U+016EC4 */
+	0,							/* U+016EC5 */
+	0,							/* U+016EC6 */
+	0,							/* U+016EC7 */
+	0,							/* U+016EC8 */
+	0,							/* U+016EC9 */
+	0,							/* U+016ECA */
+	0,							/* U+016ECB */
+	0,							/* U+016ECC */
+	0,							/* U+016ECD */
+	0,							/* U+016ECE */
+	0,							/* U+016ECF */
+	0,							/* U+016ED0 */
+	0,							/* U+016ED1 */
+	0,							/* U+016ED2 */
+	0,							/* U+016ED3 */
+	0,							/* U+016ED4 */
+	0,							/* U+016ED5 */
+	0,							/* U+016ED6 */
+	0,							/* U+016ED7 */
+	0,							/* U+016ED8 */
+	0,							/* U+016ED9 */
+	0,							/* U+016EDA */
+	0,							/* U+016EDB */
+	0,							/* U+016EDC */
+	0,							/* U+016EDD */
+	0,							/* U+016EDE */
+	0,							/* U+016EDF */
+	0,							/* U+016EE0 */
+	0,							/* U+016EE1 */
+	0,							/* U+016EE2 */
+	0,							/* U+016EE3 */
+	0,							/* U+016EE4 */
+	0,							/* U+016EE5 */
+	0,							/* U+016EE6 */
+	0,							/* U+016EE7 */
+	0,							/* U+016EE8 */
+	0,							/* U+016EE9 */
+	0,							/* U+016EEA */
+	0,							/* U+016EEB */
+	0,							/* U+016EEC */
+	0,							/* U+016EED */
+	0,							/* U+016EEE */
+	0,							/* U+016EEF */
+	0,							/* U+016EF0 */
+	0,							/* U+016EF1 */
+	0,							/* U+016EF2 */
+	0,							/* U+016EF3 */
+	0,							/* U+016EF4 */
+	0,							/* U+016EF5 */
+	0,							/* U+016EF6 */
+	0,							/* U+016EF7 */
+	0,							/* U+016EF8 */
+	0,							/* U+016EF9 */
+	0,							/* U+016EFA */
+	0,							/* U+016EFB */
+	0,							/* U+016EFC */
+	0,							/* U+016EFD */
+	0,							/* U+016EFE */
+	0,							/* U+016EFF */
+	0,							/* U+016F00 */
+	0,							/* U+016F01 */
+	0,							/* U+016F02 */
+	0,							/* U+016F03 */
+	0,							/* U+016F04 */
+	0,							/* U+016F05 */
+	0,							/* U+016F06 */
+	0,							/* U+016F07 */
+	0,							/* U+016F08 */
+	0,							/* U+016F09 */
+	0,							/* U+016F0A */
+	0,							/* U+016F0B */
+	0,							/* U+016F0C */
+	0,							/* U+016F0D */
+	0,							/* U+016F0E */
+	0,							/* U+016F0F */
+	0,							/* U+016F10 */
+	0,							/* U+016F11 */
+	0,							/* U+016F12 */
+	0,							/* U+016F13 */
+	0,							/* U+016F14 */
+	0,							/* U+016F15 */
+	0,							/* U+016F16 */
+	0,							/* U+016F17 */
+	0,							/* U+016F18 */
+	0,							/* U+016F19 */
+	0,							/* U+016F1A */
+	0,							/* U+016F1B */
+	0,							/* U+016F1C */
+	0,							/* U+016F1D */
+	0,							/* U+016F1E */
+	0,							/* U+016F1F */
+	0,							/* U+016F20 */
+	0,							/* U+016F21 */
+	0,							/* U+016F22 */
+	0,							/* U+016F23 */
+	0,							/* U+016F24 */
+	0,							/* U+016F25 */
+	0,							/* U+016F26 */
+	0,							/* U+016F27 */
+	0,							/* U+016F28 */
+	0,							/* U+016F29 */
+	0,							/* U+016F2A */
+	0,							/* U+016F2B */
+	0,							/* U+016F2C */
+	0,							/* U+016F2D */
+	0,							/* U+016F2E */
+	0,							/* U+016F2F */
+	0,							/* U+016F30 */
+	0,							/* U+016F31 */
+	0,							/* U+016F32 */
+	0,							/* U+016F33 */
+	0,							/* U+016F34 */
+	0,							/* U+016F35 */
+	0,							/* U+016F36 */
+	0,							/* U+016F37 */
+	0,							/* U+016F38 */
+	0,							/* U+016F39 */
+	0,							/* U+016F3A */
+	0,							/* U+016F3B */
+	0,							/* U+016F3C */
+	0,							/* U+016F3D */
+	0,							/* U+016F3E */
+	0,							/* U+016F3F */
+	0,							/* U+016F40 */
+	0,							/* U+016F41 */
+	0,							/* U+016F42 */
+	0,							/* U+016F43 */
+	0,							/* U+016F44 */
+	0,							/* U+016F45 */
+	0,							/* U+016F46 */
+	0,							/* U+016F47 */
+	0,							/* U+016F48 */
+	0,							/* U+016F49 */
+	0,							/* U+016F4A */
+	0,							/* U+016F4B */
+	0,							/* U+016F4C */
+	0,							/* U+016F4D */
+	0,							/* U+016F4E */
+	0,							/* U+016F4F */
+	0,							/* U+016F50 */
+	0,							/* U+016F51 */
+	0,							/* U+016F52 */
+	0,							/* U+016F53 */
+	0,							/* U+016F54 */
+	0,							/* U+016F55 */
+	0,							/* U+016F56 */
+	0,							/* U+016F57 */
+	0,							/* U+016F58 */
+	0,							/* U+016F59 */
+	0,							/* U+016F5A */
+	0,							/* U+016F5B */
+	0,							/* U+016F5C */
+	0,							/* U+016F5D */
+	0,							/* U+016F5E */
+	0,							/* U+016F5F */
+	0,							/* U+016F60 */
+	0,							/* U+016F61 */
+	0,							/* U+016F62 */
+	0,							/* U+016F63 */
+	0,							/* U+016F64 */
+	0,							/* U+016F65 */
+	0,							/* U+016F66 */
+	0,							/* U+016F67 */
+	0,							/* U+016F68 */
+	0,							/* U+016F69 */
+	0,							/* U+016F6A */
+	0,							/* U+016F6B */
+	0,							/* U+016F6C */
+	0,							/* U+016F6D */
+	0,							/* U+016F6E */
+	0,							/* U+016F6F */
+	0,							/* U+016F70 */
+	0,							/* U+016F71 */
+	0,							/* U+016F72 */
+	0,							/* U+016F73 */
+	0,							/* U+016F74 */
+	0,							/* U+016F75 */
+	0,							/* U+016F76 */
+	0,							/* U+016F77 */
+	0,							/* U+016F78 */
+	0,							/* U+016F79 */
+	0,							/* U+016F7A */
+	0,							/* U+016F7B */
+	0,							/* U+016F7C */
+	0,							/* U+016F7D */
+	0,							/* U+016F7E */
+	0,							/* U+016F7F */
+	0,							/* U+016F80 */
+	0,							/* U+016F81 */
+	0,							/* U+016F82 */
+	0,							/* U+016F83 */
+	0,							/* U+016F84 */
+	0,							/* U+016F85 */
+	0,							/* U+016F86 */
+	0,							/* U+016F87 */
+	0,							/* U+016F88 */
+	0,							/* U+016F89 */
+	0,							/* U+016F8A */
+	0,							/* U+016F8B */
+	0,							/* U+016F8C */
+	0,							/* U+016F8D */
+	0,							/* U+016F8E */
+	0,							/* U+016F8F */
+	0,							/* U+016F90 */
+	0,							/* U+016F91 */
+	0,							/* U+016F92 */
+	0,							/* U+016F93 */
+	0,							/* U+016F94 */
+	0,							/* U+016F95 */
+	0,							/* U+016F96 */
+	0,							/* U+016F97 */
+	0,							/* U+016F98 */
+	0,							/* U+016F99 */
+	0,							/* U+016F9A */
+	0,							/* U+016F9B */
+	0,							/* U+016F9C */
+	0,							/* U+016F9D */
+	0,							/* U+016F9E */
+	0,							/* U+016F9F */
+	0,							/* U+016FA0 */
+	0,							/* U+016FA1 */
+	0,							/* U+016FA2 */
+	0,							/* U+016FA3 */
+	0,							/* U+016FA4 */
+	0,							/* U+016FA5 */
+	0,							/* U+016FA6 */
+	0,							/* U+016FA7 */
+	0,							/* U+016FA8 */
+	0,							/* U+016FA9 */
+	0,							/* U+016FAA */
+	0,							/* U+016FAB */
+	0,							/* U+016FAC */
+	0,							/* U+016FAD */
+	0,							/* U+016FAE */
+	0,							/* U+016FAF */
+	0,							/* U+016FB0 */
+	0,							/* U+016FB1 */
+	0,							/* U+016FB2 */
+	0,							/* U+016FB3 */
+	0,							/* U+016FB4 */
+	0,							/* U+016FB5 */
+	0,							/* U+016FB6 */
+	0,							/* U+016FB7 */
+	0,							/* U+016FB8 */
+	0,							/* U+016FB9 */
+	0,							/* U+016FBA */
+	0,							/* U+016FBB */
+	0,							/* U+016FBC */
+	0,							/* U+016FBD */
+	0,							/* U+016FBE */
+	0,							/* U+016FBF */
+	0,							/* U+016FC0 */
+	0,							/* U+016FC1 */
+	0,							/* U+016FC2 */
+	0,							/* U+016FC3 */
+	0,							/* U+016FC4 */
+	0,							/* U+016FC5 */
+	0,							/* U+016FC6 */
+	0,							/* U+016FC7 */
+	0,							/* U+016FC8 */
+	0,							/* U+016FC9 */
+	0,							/* U+016FCA */
+	0,							/* U+016FCB */
+	0,							/* U+016FCC */
+	0,							/* U+016FCD */
+	0,							/* U+016FCE */
+	0,							/* U+016FCF */
+	0,							/* U+016FD0 */
+	0,							/* U+016FD1 */
+	0,							/* U+016FD2 */
+	0,							/* U+016FD3 */
+	0,							/* U+016FD4 */
+	0,							/* U+016FD5 */
+	0,							/* U+016FD6 */
+	0,							/* U+016FD7 */
+	0,							/* U+016FD8 */
+	0,							/* U+016FD9 */
+	0,							/* U+016FDA */
+	0,							/* U+016FDB */
+	0,							/* U+016FDC */
+	0,							/* U+016FDD */
+	0,							/* U+016FDE */
+	0,							/* U+016FDF */
+	0,							/* U+016FE0 */
+	0,							/* U+016FE1 */
+	0,							/* U+016FE2 */
+	0,							/* U+016FE3 */
+	0,							/* U+016FE4 */
+	0,							/* U+016FE5 */
+	0,							/* U+016FE6 */
+	0,							/* U+016FE7 */
+	0,							/* U+016FE8 */
+	0,							/* U+016FE9 */
+	0,							/* U+016FEA */
+	0,							/* U+016FEB */
+	0,							/* U+016FEC */
+	0,							/* U+016FED */
+	0,							/* U+016FEE */
+	0,							/* U+016FEF */
+	3270,						/* U+016FF0 */
+	3270,						/* U+016FF1 */
+	309,						/* U+01BC9E */
+	540,						/* U+01CCD6 */
+	542,						/* U+01CCD7 */
+	1137,						/* U+01CCD8 */
+	543,						/* U+01CCD9 */
+	544,						/* U+01CCDA */
+	1153,						/* U+01CCDB */
+	546,						/* U+01CCDC */
+	547,						/* U+01CCDD */
+	548,						/* U+01CCDE */
+	549,						/* U+01CCDF */
+	550,						/* U+01CCE0 */
+	551,						/* U+01CCE1 */
+	552,						/* U+01CCE2 */
+	553,						/* U+01CCE3 */
+	554,						/* U+01CCE4 */
+	556,						/* U+01CCE5 */
+	1145,						/* U+01CCE6 */
+	557,						/* U+01CCE7 */
+	1326,						/* U+01CCE8 */
+	558,						/* U+01CCE9 */
+	559,						/* U+01CCEA */
+	1181,						/* U+01CCEB */
+	560,						/* U+01CCEC */
+	1186,						/* U+01CCED */
+	1327,						/* U+01CCEE */
+	1149,						/* U+01CCEF */
+	1121,						/* U+01CCF0 */
+	10,							/* U+01CCF1 */
+	5,							/* U+01CCF2 */
+	6,							/* U+01CCF3 */
+	1122,						/* U+01CCF4 */
+	1123,						/* U+01CCF5 */
+	1124,						/* U+01CCF6 */
+	1125,						/* U+01CCF7 */
+	1126,						/* U+01CCF8 */
+	1127,						/* U+01CCF9 */
+	0,							/* U+01CCFA */
+	0,							/* U+01CCFB */
+	0,							/* U+01CCFC */
+	0,							/* U+01CCFD */
+	0,							/* U+01CCFE */
+	0,							/* U+01CCFF */
+	0,							/* U+01CD00 */
+	0,							/* U+01CD01 */
+	0,							/* U+01CD02 */
+	0,							/* U+01CD03 */
+	0,							/* U+01CD04 */
+	0,							/* U+01CD05 */
+	0,							/* U+01CD06 */
+	0,							/* U+01CD07 */
+	0,							/* U+01CD08 */
+	0,							/* U+01CD09 */
+	0,							/* U+01CD0A */
+	0,							/* U+01CD0B */
+	0,							/* U+01CD0C */
+	0,							/* U+01CD0D */
+	0,							/* U+01CD0E */
+	0,							/* U+01CD0F */
+	0,							/* U+01CD10 */
+	0,							/* U+01CD11 */
+	0,							/* U+01CD12 */
+	0,							/* U+01CD13 */
+	0,							/* U+01CD14 */
+	0,							/* U+01CD15 */
+	0,							/* U+01CD16 */
+	0,							/* U+01CD17 */
+	0,							/* U+01CD18 */
+	0,							/* U+01CD19 */
+	0,							/* U+01CD1A */
+	0,							/* U+01CD1B */
+	0,							/* U+01CD1C */
+	0,							/* U+01CD1D */
+	0,							/* U+01CD1E */
+	0,							/* U+01CD1F */
+	0,							/* U+01CD20 */
+	0,							/* U+01CD21 */
+	0,							/* U+01CD22 */
+	0,							/* U+01CD23 */
+	0,							/* U+01CD24 */
+	0,							/* U+01CD25 */
+	0,							/* U+01CD26 */
+	0,							/* U+01CD27 */
+	0,							/* U+01CD28 */
+	0,							/* U+01CD29 */
+	0,							/* U+01CD2A */
+	0,							/* U+01CD2B */
+	0,							/* U+01CD2C */
+	0,							/* U+01CD2D */
+	0,							/* U+01CD2E */
+	0,							/* U+01CD2F */
+	0,							/* U+01CD30 */
+	0,							/* U+01CD31 */
+	0,							/* U+01CD32 */
+	0,							/* U+01CD33 */
+	0,							/* U+01CD34 */
+	0,							/* U+01CD35 */
+	0,							/* U+01CD36 */
+	0,							/* U+01CD37 */
+	0,							/* U+01CD38 */
+	0,							/* U+01CD39 */
+	0,							/* U+01CD3A */
+	0,							/* U+01CD3B */
+	0,							/* U+01CD3C */
+	0,							/* U+01CD3D */
+	0,							/* U+01CD3E */
+	0,							/* U+01CD3F */
+	0,							/* U+01CD40 */
+	0,							/* U+01CD41 */
+	0,							/* U+01CD42 */
+	0,							/* U+01CD43 */
+	0,							/* U+01CD44 */
+	0,							/* U+01CD45 */
+	0,							/* U+01CD46 */
+	0,							/* U+01CD47 */
+	0,							/* U+01CD48 */
+	0,							/* U+01CD49 */
+	0,							/* U+01CD4A */
+	0,							/* U+01CD4B */
+	0,							/* U+01CD4C */
+	0,							/* U+01CD4D */
+	0,							/* U+01CD4E */
+	0,							/* U+01CD4F */
+	0,							/* U+01CD50 */
+	0,							/* U+01CD51 */
+	0,							/* U+01CD52 */
+	0,							/* U+01CD53 */
+	0,							/* U+01CD54 */
+	0,							/* U+01CD55 */
+	0,							/* U+01CD56 */
+	0,							/* U+01CD57 */
+	0,							/* U+01CD58 */
+	0,							/* U+01CD59 */
+	0,							/* U+01CD5A */
+	0,							/* U+01CD5B */
+	0,							/* U+01CD5C */
+	0,							/* U+01CD5D */
+	0,							/* U+01CD5E */
+	0,							/* U+01CD5F */
+	0,							/* U+01CD60 */
+	0,							/* U+01CD61 */
+	0,							/* U+01CD62 */
+	0,							/* U+01CD63 */
+	0,							/* U+01CD64 */
+	0,							/* U+01CD65 */
+	0,							/* U+01CD66 */
+	0,							/* U+01CD67 */
+	0,							/* U+01CD68 */
+	0,							/* U+01CD69 */
+	0,							/* U+01CD6A */
+	0,							/* U+01CD6B */
+	0,							/* U+01CD6C */
+	0,							/* U+01CD6D */
+	0,							/* U+01CD6E */
+	0,							/* U+01CD6F */
+	0,							/* U+01CD70 */
+	0,							/* U+01CD71 */
+	0,							/* U+01CD72 */
+	0,							/* U+01CD73 */
+	0,							/* U+01CD74 */
+	0,							/* U+01CD75 */
+	0,							/* U+01CD76 */
+	0,							/* U+01CD77 */
+	0,							/* U+01CD78 */
+	0,							/* U+01CD79 */
+	0,							/* U+01CD7A */
+	0,							/* U+01CD7B */
+	0,							/* U+01CD7C */
+	0,							/* U+01CD7D */
+	0,							/* U+01CD7E */
+	0,							/* U+01CD7F */
+	0,							/* U+01CD80 */
+	0,							/* U+01CD81 */
+	0,							/* U+01CD82 */
+	0,							/* U+01CD83 */
+	0,							/* U+01CD84 */
+	0,							/* U+01CD85 */
+	0,							/* U+01CD86 */
+	0,							/* U+01CD87 */
+	0,							/* U+01CD88 */
+	0,							/* U+01CD89 */
+	0,							/* U+01CD8A */
+	0,							/* U+01CD8B */
+	0,							/* U+01CD8C */
+	0,							/* U+01CD8D */
+	0,							/* U+01CD8E */
+	0,							/* U+01CD8F */
+	0,							/* U+01CD90 */
+	0,							/* U+01CD91 */
+	0,							/* U+01CD92 */
+	0,							/* U+01CD93 */
+	0,							/* U+01CD94 */
+	0,							/* U+01CD95 */
+	0,							/* U+01CD96 */
+	0,							/* U+01CD97 */
+	0,							/* U+01CD98 */
+	0,							/* U+01CD99 */
+	0,							/* U+01CD9A */
+	0,							/* U+01CD9B */
+	0,							/* U+01CD9C */
+	0,							/* U+01CD9D */
+	0,							/* U+01CD9E */
+	0,							/* U+01CD9F */
+	0,							/* U+01CDA0 */
+	0,							/* U+01CDA1 */
+	0,							/* U+01CDA2 */
+	0,							/* U+01CDA3 */
+	0,							/* U+01CDA4 */
+	0,							/* U+01CDA5 */
+	0,							/* U+01CDA6 */
+	0,							/* U+01CDA7 */
+	0,							/* U+01CDA8 */
+	0,							/* U+01CDA9 */
+	0,							/* U+01CDAA */
+	0,							/* U+01CDAB */
+	0,							/* U+01CDAC */
+	0,							/* U+01CDAD */
+	0,							/* U+01CDAE */
+	0,							/* U+01CDAF */
+	0,							/* U+01CDB0 */
+	0,							/* U+01CDB1 */
+	0,							/* U+01CDB2 */
+	0,							/* U+01CDB3 */
+	0,							/* U+01CDB4 */
+	0,							/* U+01CDB5 */
+	0,							/* U+01CDB6 */
+	0,							/* U+01CDB7 */
+	0,							/* U+01CDB8 */
+	0,							/* U+01CDB9 */
+	0,							/* U+01CDBA */
+	0,							/* U+01CDBB */
+	0,							/* U+01CDBC */
+	0,							/* U+01CDBD */
+	0,							/* U+01CDBE */
+	0,							/* U+01CDBF */
+	0,							/* U+01CDC0 */
+	0,							/* U+01CDC1 */
+	0,							/* U+01CDC2 */
+	0,							/* U+01CDC3 */
+	0,							/* U+01CDC4 */
+	0,							/* U+01CDC5 */
+	0,							/* U+01CDC6 */
+	0,							/* U+01CDC7 */
+	0,							/* U+01CDC8 */
+	0,							/* U+01CDC9 */
+	0,							/* U+01CDCA */
+	0,							/* U+01CDCB */
+	0,							/* U+01CDCC */
+	0,							/* U+01CDCD */
+	0,							/* U+01CDCE */
+	0,							/* U+01CDCF */
+	0,							/* U+01CDD0 */
+	0,							/* U+01CDD1 */
+	0,							/* U+01CDD2 */
+	0,							/* U+01CDD3 */
+	0,							/* U+01CDD4 */
+	0,							/* U+01CDD5 */
+	0,							/* U+01CDD6 */
+	0,							/* U+01CDD7 */
+	0,							/* U+01CDD8 */
+	0,							/* U+01CDD9 */
+	0,							/* U+01CDDA */
+	0,							/* U+01CDDB */
+	0,							/* U+01CDDC */
+	0,							/* U+01CDDD */
+	0,							/* U+01CDDE */
+	0,							/* U+01CDDF */
+	0,							/* U+01CDE0 */
+	0,							/* U+01CDE1 */
+	0,							/* U+01CDE2 */
+	0,							/* U+01CDE3 */
+	0,							/* U+01CDE4 */
+	0,							/* U+01CDE5 */
+	0,							/* U+01CDE6 */
+	0,							/* U+01CDE7 */
+	0,							/* U+01CDE8 */
+	0,							/* U+01CDE9 */
+	0,							/* U+01CDEA */
+	0,							/* U+01CDEB */
+	0,							/* U+01CDEC */
+	0,							/* U+01CDED */
+	0,							/* U+01CDEE */
+	0,							/* U+01CDEF */
+	0,							/* U+01CDF0 */
+	0,							/* U+01CDF1 */
+	0,							/* U+01CDF2 */
+	0,							/* U+01CDF3 */
+	0,							/* U+01CDF4 */
+	0,							/* U+01CDF5 */
+	0,							/* U+01CDF6 */
+	0,							/* U+01CDF7 */
+	0,							/* U+01CDF8 */
+	0,							/* U+01CDF9 */
+	0,							/* U+01CDFA */
+	0,							/* U+01CDFB */
+	0,							/* U+01CDFC */
+	0,							/* U+01CDFD */
+	0,							/* U+01CDFE */
+	0,							/* U+01CDFF */
+	0,							/* U+01CE00 */
+	0,							/* U+01CE01 */
+	0,							/* U+01CE02 */
+	0,							/* U+01CE03 */
+	0,							/* U+01CE04 */
+	0,							/* U+01CE05 */
+	0,							/* U+01CE06 */
+	0,							/* U+01CE07 */
+	0,							/* U+01CE08 */
+	0,							/* U+01CE09 */
+	0,							/* U+01CE0A */
+	0,							/* U+01CE0B */
+	0,							/* U+01CE0C */
+	0,							/* U+01CE0D */
+	0,							/* U+01CE0E */
+	0,							/* U+01CE0F */
+	0,							/* U+01CE10 */
+	0,							/* U+01CE11 */
+	0,							/* U+01CE12 */
+	0,							/* U+01CE13 */
+	0,							/* U+01CE14 */
+	0,							/* U+01CE15 */
+	0,							/* U+01CE16 */
+	0,							/* U+01CE17 */
+	0,							/* U+01CE18 */
+	0,							/* U+01CE19 */
+	0,							/* U+01CE1A */
+	0,							/* U+01CE1B */
+	0,							/* U+01CE1C */
+	0,							/* U+01CE1D */
+	0,							/* U+01CE1E */
+	0,							/* U+01CE1F */
+	0,							/* U+01CE20 */
+	0,							/* U+01CE21 */
+	0,							/* U+01CE22 */
+	0,							/* U+01CE23 */
+	0,							/* U+01CE24 */
+	0,							/* U+01CE25 */
+	0,							/* U+01CE26 */
+	0,							/* U+01CE27 */
+	0,							/* U+01CE28 */
+	0,							/* U+01CE29 */
+	0,							/* U+01CE2A */
+	0,							/* U+01CE2B */
+	0,							/* U+01CE2C */
+	0,							/* U+01CE2D */
+	0,							/* U+01CE2E */
+	0,							/* U+01CE2F */
+	0,							/* U+01CE30 */
+	0,							/* U+01CE31 */
+	0,							/* U+01CE32 */
+	0,							/* U+01CE33 */
+	0,							/* U+01CE34 */
+	0,							/* U+01CE35 */
+	0,							/* U+01CE36 */
+	0,							/* U+01CE37 */
+	0,							/* U+01CE38 */
+	0,							/* U+01CE39 */
+	0,							/* U+01CE3A */
+	0,							/* U+01CE3B */
+	0,							/* U+01CE3C */
+	0,							/* U+01CE3D */
+	0,							/* U+01CE3E */
+	0,							/* U+01CE3F */
+	0,							/* U+01CE40 */
+	0,							/* U+01CE41 */
+	0,							/* U+01CE42 */
+	0,							/* U+01CE43 */
+	0,							/* U+01CE44 */
+	0,							/* U+01CE45 */
+	0,							/* U+01CE46 */
+	0,							/* U+01CE47 */
+	0,							/* U+01CE48 */
+	0,							/* U+01CE49 */
+	0,							/* U+01CE4A */
+	0,							/* U+01CE4B */
+	0,							/* U+01CE4C */
+	0,							/* U+01CE4D */
+	0,							/* U+01CE4E */
+	0,							/* U+01CE4F */
+	0,							/* U+01CE50 */
+	0,							/* U+01CE51 */
+	0,							/* U+01CE52 */
+	0,							/* U+01CE53 */
+	0,							/* U+01CE54 */
+	0,							/* U+01CE55 */
+	0,							/* U+01CE56 */
+	0,							/* U+01CE57 */
+	0,							/* U+01CE58 */
+	0,							/* U+01CE59 */
+	0,							/* U+01CE5A */
+	0,							/* U+01CE5B */
+	0,							/* U+01CE5C */
+	0,							/* U+01CE5D */
+	0,							/* U+01CE5E */
+	0,							/* U+01CE5F */
+	0,							/* U+01CE60 */
+	0,							/* U+01CE61 */
+	0,							/* U+01CE62 */
+	0,							/* U+01CE63 */
+	0,							/* U+01CE64 */
+	0,							/* U+01CE65 */
+	0,							/* U+01CE66 */
+	0,							/* U+01CE67 */
+	0,							/* U+01CE68 */
+	0,							/* U+01CE69 */
+	0,							/* U+01CE6A */
+	0,							/* U+01CE6B */
+	0,							/* U+01CE6C */
+	0,							/* U+01CE6D */
+	0,							/* U+01CE6E */
+	0,							/* U+01CE6F */
+	0,							/* U+01CE70 */
+	0,							/* U+01CE71 */
+	0,							/* U+01CE72 */
+	0,							/* U+01CE73 */
+	0,							/* U+01CE74 */
+	0,							/* U+01CE75 */
+	0,							/* U+01CE76 */
+	0,							/* U+01CE77 */
+	0,							/* U+01CE78 */
+	0,							/* U+01CE79 */
+	0,							/* U+01CE7A */
+	0,							/* U+01CE7B */
+	0,							/* U+01CE7C */
+	0,							/* U+01CE7D */
+	0,							/* U+01CE7E */
+	0,							/* U+01CE7F */
+	0,							/* U+01CE80 */
+	0,							/* U+01CE81 */
+	0,							/* U+01CE82 */
+	0,							/* U+01CE83 */
+	0,							/* U+01CE84 */
+	0,							/* U+01CE85 */
+	0,							/* U+01CE86 */
+	0,							/* U+01CE87 */
+	0,							/* U+01CE88 */
+	0,							/* U+01CE89 */
+	0,							/* U+01CE8A */
+	0,							/* U+01CE8B */
+	0,							/* U+01CE8C */
+	0,							/* U+01CE8D */
+	0,							/* U+01CE8E */
+	0,							/* U+01CE8F */
+	0,							/* U+01CE90 */
+	0,							/* U+01CE91 */
+	0,							/* U+01CE92 */
+	0,							/* U+01CE93 */
+	0,							/* U+01CE94 */
+	0,							/* U+01CE95 */
+	0,							/* U+01CE96 */
+	0,							/* U+01CE97 */
+	0,							/* U+01CE98 */
+	0,							/* U+01CE99 */
+	0,							/* U+01CE9A */
+	0,							/* U+01CE9B */
+	0,							/* U+01CE9C */
+	0,							/* U+01CE9D */
+	0,							/* U+01CE9E */
+	0,							/* U+01CE9F */
+	0,							/* U+01CEA0 */
+	0,							/* U+01CEA1 */
+	0,							/* U+01CEA2 */
+	0,							/* U+01CEA3 */
+	0,							/* U+01CEA4 */
+	0,							/* U+01CEA5 */
+	0,							/* U+01CEA6 */
+	0,							/* U+01CEA7 */
+	0,							/* U+01CEA8 */
+	0,							/* U+01CEA9 */
+	0,							/* U+01CEAA */
+	0,							/* U+01CEAB */
+	0,							/* U+01CEAC */
+	0,							/* U+01CEAD */
+	0,							/* U+01CEAE */
+	0,							/* U+01CEAF */
+	0,							/* U+01CEB0 */
+	0,							/* U+01CEB1 */
+	0,							/* U+01CEB2 */
+	0,							/* U+01CEB3 */
+	0,							/* U+01CEB4 */
+	0,							/* U+01CEB5 */
+	0,							/* U+01CEB6 */
+	0,							/* U+01CEB7 */
+	0,							/* U+01CEB8 */
+	0,							/* U+01CEB9 */
+	0,							/* U+01CEBA */
+	0,							/* U+01CEBB */
+	0,							/* U+01CEBC */
+	0,							/* U+01CEBD */
+	0,							/* U+01CEBE */
+	0,							/* U+01CEBF */
+	0,							/* U+01CEC0 */
+	0,							/* U+01CEC1 */
+	0,							/* U+01CEC2 */
+	0,							/* U+01CEC3 */
+	0,							/* U+01CEC4 */
+	0,							/* U+01CEC5 */
+	0,							/* U+01CEC6 */
+	0,							/* U+01CEC7 */
+	0,							/* U+01CEC8 */
+	0,							/* U+01CEC9 */
+	0,							/* U+01CECA */
+	0,							/* U+01CECB */
+	0,							/* U+01CECC */
+	0,							/* U+01CECD */
+	0,							/* U+01CECE */
+	0,							/* U+01CECF */
+	0,							/* U+01CED0 */
+	0,							/* U+01CED1 */
+	0,							/* U+01CED2 */
+	0,							/* U+01CED3 */
+	0,							/* U+01CED4 */
+	0,							/* U+01CED5 */
+	0,							/* U+01CED6 */
+	0,							/* U+01CED7 */
+	0,							/* U+01CED8 */
+	0,							/* U+01CED9 */
+	0,							/* U+01CEDA */
+	0,							/* U+01CEDB */
+	0,							/* U+01CEDC */
+	0,							/* U+01CEDD */
+	0,							/* U+01CEDE */
+	0,							/* U+01CEDF */
+	0,							/* U+01CEE0 */
+	0,							/* U+01CEE1 */
+	0,							/* U+01CEE2 */
+	0,							/* U+01CEE3 */
+	0,							/* U+01CEE4 */
+	0,							/* U+01CEE5 */
+	0,							/* U+01CEE6 */
+	0,							/* U+01CEE7 */
+	0,							/* U+01CEE8 */
+	0,							/* U+01CEE9 */
+	0,							/* U+01CEEA */
+	0,							/* U+01CEEB */
+	0,							/* U+01CEEC */
+	0,							/* U+01CEED */
+	0,							/* U+01CEEE */
+	0,							/* U+01CEEF */
+	0,							/* U+01CEF0 */
+	0,							/* U+01CEF1 */
+	0,							/* U+01CEF2 */
+	0,							/* U+01CEF3 */
+	0,							/* U+01CEF4 */
+	0,							/* U+01CEF5 */
+	0,							/* U+01CEF6 */
+	0,							/* U+01CEF7 */
+	0,							/* U+01CEF8 */
+	0,							/* U+01CEF9 */
+	0,							/* U+01CEFA */
+	0,							/* U+01CEFB */
+	0,							/* U+01CEFC */
+	0,							/* U+01CEFD */
+	0,							/* U+01CEFE */
+	0,							/* U+01CEFF */
+	0,							/* U+01CF00 */
+	0,							/* U+01CF01 */
+	0,							/* U+01CF02 */
+	0,							/* U+01CF03 */
+	0,							/* U+01CF04 */
+	0,							/* U+01CF05 */
+	0,							/* U+01CF06 */
+	0,							/* U+01CF07 */
+	0,							/* U+01CF08 */
+	0,							/* U+01CF09 */
+	0,							/* U+01CF0A */
+	0,							/* U+01CF0B */
+	0,							/* U+01CF0C */
+	0,							/* U+01CF0D */
+	0,							/* U+01CF0E */
+	0,							/* U+01CF0F */
+	0,							/* U+01CF10 */
+	0,							/* U+01CF11 */
+	0,							/* U+01CF12 */
+	0,							/* U+01CF13 */
+	0,							/* U+01CF14 */
+	0,							/* U+01CF15 */
+	0,							/* U+01CF16 */
+	0,							/* U+01CF17 */
+	0,							/* U+01CF18 */
+	0,							/* U+01CF19 */
+	0,							/* U+01CF1A */
+	0,							/* U+01CF1B */
+	0,							/* U+01CF1C */
+	0,							/* U+01CF1D */
+	0,							/* U+01CF1E */
+	0,							/* U+01CF1F */
+	0,							/* U+01CF20 */
+	0,							/* U+01CF21 */
+	0,							/* U+01CF22 */
+	0,							/* U+01CF23 */
+	0,							/* U+01CF24 */
+	0,							/* U+01CF25 */
+	0,							/* U+01CF26 */
+	0,							/* U+01CF27 */
+	0,							/* U+01CF28 */
+	0,							/* U+01CF29 */
+	0,							/* U+01CF2A */
+	0,							/* U+01CF2B */
+	0,							/* U+01CF2C */
+	0,							/* U+01CF2D */
+	0,							/* U+01CF2E */
+	0,							/* U+01CF2F */
+	0,							/* U+01CF30 */
+	0,							/* U+01CF31 */
+	0,							/* U+01CF32 */
+	0,							/* U+01CF33 */
+	0,							/* U+01CF34 */
+	0,							/* U+01CF35 */
+	0,							/* U+01CF36 */
+	0,							/* U+01CF37 */
+	0,							/* U+01CF38 */
+	0,							/* U+01CF39 */
+	0,							/* U+01CF3A */
+	0,							/* U+01CF3B */
+	0,							/* U+01CF3C */
+	0,							/* U+01CF3D */
+	0,							/* U+01CF3E */
+	0,							/* U+01CF3F */
+	0,							/* U+01CF40 */
+	0,							/* U+01CF41 */
+	0,							/* U+01CF42 */
+	0,							/* U+01CF43 */
+	0,							/* U+01CF44 */
+	0,							/* U+01CF45 */
+	0,							/* U+01CF46 */
+	0,							/* U+01CF47 */
+	0,							/* U+01CF48 */
+	0,							/* U+01CF49 */
+	0,							/* U+01CF4A */
+	0,							/* U+01CF4B */
+	0,							/* U+01CF4C */
+	0,							/* U+01CF4D */
+	0,							/* U+01CF4E */
+	0,							/* U+01CF4F */
+	0,							/* U+01CF50 */
+	0,							/* U+01CF51 */
+	0,							/* U+01CF52 */
+	0,							/* U+01CF53 */
+	0,							/* U+01CF54 */
+	0,							/* U+01CF55 */
+	0,							/* U+01CF56 */
+	0,							/* U+01CF57 */
+	0,							/* U+01CF58 */
+	0,							/* U+01CF59 */
+	0,							/* U+01CF5A */
+	0,							/* U+01CF5B */
+	0,							/* U+01CF5C */
+	0,							/* U+01CF5D */
+	0,							/* U+01CF5E */
+	0,							/* U+01CF5F */
+	0,							/* U+01CF60 */
+	0,							/* U+01CF61 */
+	0,							/* U+01CF62 */
+	0,							/* U+01CF63 */
+	0,							/* U+01CF64 */
+	0,							/* U+01CF65 */
+	0,							/* U+01CF66 */
+	0,							/* U+01CF67 */
+	0,							/* U+01CF68 */
+	0,							/* U+01CF69 */
+	0,							/* U+01CF6A */
+	0,							/* U+01CF6B */
+	0,							/* U+01CF6C */
+	0,							/* U+01CF6D */
+	0,							/* U+01CF6E */
+	0,							/* U+01CF6F */
+	0,							/* U+01CF70 */
+	0,							/* U+01CF71 */
+	0,							/* U+01CF72 */
+	0,							/* U+01CF73 */
+	0,							/* U+01CF74 */
+	0,							/* U+01CF75 */
+	0,							/* U+01CF76 */
+	0,							/* U+01CF77 */
+	0,							/* U+01CF78 */
+	0,							/* U+01CF79 */
+	0,							/* U+01CF7A */
+	0,							/* U+01CF7B */
+	0,							/* U+01CF7C */
+	0,							/* U+01CF7D */
+	0,							/* U+01CF7E */
+	0,							/* U+01CF7F */
+	0,							/* U+01CF80 */
+	0,							/* U+01CF81 */
+	0,							/* U+01CF82 */
+	0,							/* U+01CF83 */
+	0,							/* U+01CF84 */
+	0,							/* U+01CF85 */
+	0,							/* U+01CF86 */
+	0,							/* U+01CF87 */
+	0,							/* U+01CF88 */
+	0,							/* U+01CF89 */
+	0,							/* U+01CF8A */
+	0,							/* U+01CF8B */
+	0,							/* U+01CF8C */
+	0,							/* U+01CF8D */
+	0,							/* U+01CF8E */
+	0,							/* U+01CF8F */
+	0,							/* U+01CF90 */
+	0,							/* U+01CF91 */
+	0,							/* U+01CF92 */
+	0,							/* U+01CF93 */
+	0,							/* U+01CF94 */
+	0,							/* U+01CF95 */
+	0,							/* U+01CF96 */
+	0,							/* U+01CF97 */
+	0,							/* U+01CF98 */
+	0,							/* U+01CF99 */
+	0,							/* U+01CF9A */
+	0,							/* U+01CF9B */
+	0,							/* U+01CF9C */
+	0,							/* U+01CF9D */
+	0,							/* U+01CF9E */
+	0,							/* U+01CF9F */
+	0,							/* U+01CFA0 */
+	0,							/* U+01CFA1 */
+	0,							/* U+01CFA2 */
+	0,							/* U+01CFA3 */
+	0,							/* U+01CFA4 */
+	0,							/* U+01CFA5 */
+	0,							/* U+01CFA6 */
+	0,							/* U+01CFA7 */
+	0,							/* U+01CFA8 */
+	0,							/* U+01CFA9 */
+	0,							/* U+01CFAA */
+	0,							/* U+01CFAB */
+	0,							/* U+01CFAC */
+	0,							/* U+01CFAD */
+	0,							/* U+01CFAE */
+	0,							/* U+01CFAF */
+	0,							/* U+01CFB0 */
+	0,							/* U+01CFB1 */
+	0,							/* U+01CFB2 */
+	0,							/* U+01CFB3 */
+	0,							/* U+01CFB4 */
+	0,							/* U+01CFB5 */
+	0,							/* U+01CFB6 */
+	0,							/* U+01CFB7 */
+	0,							/* U+01CFB8 */
+	0,							/* U+01CFB9 */
+	0,							/* U+01CFBA */
+	0,							/* U+01CFBB */
+	0,							/* U+01CFBC */
+	0,							/* U+01CFBD */
+	0,							/* U+01CFBE */
+	0,							/* U+01CFBF */
+	0,							/* U+01CFC0 */
+	0,							/* U+01CFC1 */
+	0,							/* U+01CFC2 */
+	0,							/* U+01CFC3 */
+	0,							/* U+01CFC4 */
+	0,							/* U+01CFC5 */
+	0,							/* U+01CFC6 */
+	0,							/* U+01CFC7 */
+	0,							/* U+01CFC8 */
+	0,							/* U+01CFC9 */
+	0,							/* U+01CFCA */
+	0,							/* U+01CFCB */
+	0,							/* U+01CFCC */
+	0,							/* U+01CFCD */
+	0,							/* U+01CFCE */
+	0,							/* U+01CFCF */
+	0,							/* U+01CFD0 */
+	0,							/* U+01CFD1 */
+	0,							/* U+01CFD2 */
+	0,							/* U+01CFD3 */
+	0,							/* U+01CFD4 */
+	0,							/* U+01CFD5 */
+	0,							/* U+01CFD6 */
+	0,							/* U+01CFD7 */
+	0,							/* U+01CFD8 */
+	0,							/* U+01CFD9 */
+	0,							/* U+01CFDA */
+	0,							/* U+01CFDB */
+	0,							/* U+01CFDC */
+	0,							/* U+01CFDD */
+	0,							/* U+01CFDE */
+	0,							/* U+01CFDF */
+	0,							/* U+01CFE0 */
+	0,							/* U+01CFE1 */
+	0,							/* U+01CFE2 */
+	0,							/* U+01CFE3 */
+	0,							/* U+01CFE4 */
+	0,							/* U+01CFE5 */
+	0,							/* U+01CFE6 */
+	0,							/* U+01CFE7 */
+	0,							/* U+01CFE8 */
+	0,							/* U+01CFE9 */
+	0,							/* U+01CFEA */
+	0,							/* U+01CFEB */
+	0,							/* U+01CFEC */
+	0,							/* U+01CFED */
+	0,							/* U+01CFEE */
+	0,							/* U+01CFEF */
+	0,							/* U+01CFF0 */
+	0,							/* U+01CFF1 */
+	0,							/* U+01CFF2 */
+	0,							/* U+01CFF3 */
+	0,							/* U+01CFF4 */
+	0,							/* U+01CFF5 */
+	0,							/* U+01CFF6 */
+	0,							/* U+01CFF7 */
+	0,							/* U+01CFF8 */
+	0,							/* U+01CFF9 */
+	0,							/* U+01CFFA */
+	0,							/* U+01CFFB */
+	0,							/* U+01CFFC */
+	0,							/* U+01CFFD */
+	0,							/* U+01CFFE */
+	0,							/* U+01CFFF */
+	0,							/* U+01D000 */
+	0,							/* U+01D001 */
+	0,							/* U+01D002 */
+	0,							/* U+01D003 */
+	0,							/* U+01D004 */
+	0,							/* U+01D005 */
+	0,							/* U+01D006 */
+	0,							/* U+01D007 */
+	0,							/* U+01D008 */
+	0,							/* U+01D009 */
+	0,							/* U+01D00A */
+	0,							/* U+01D00B */
+	0,							/* U+01D00C */
+	0,							/* U+01D00D */
+	0,							/* U+01D00E */
+	0,							/* U+01D00F */
+	0,							/* U+01D010 */
+	0,							/* U+01D011 */
+	0,							/* U+01D012 */
+	0,							/* U+01D013 */
+	0,							/* U+01D014 */
+	0,							/* U+01D015 */
+	0,							/* U+01D016 */
+	0,							/* U+01D017 */
+	0,							/* U+01D018 */
+	0,							/* U+01D019 */
+	0,							/* U+01D01A */
+	0,							/* U+01D01B */
+	0,							/* U+01D01C */
+	0,							/* U+01D01D */
+	0,							/* U+01D01E */
+	0,							/* U+01D01F */
+	0,							/* U+01D020 */
+	0,							/* U+01D021 */
+	0,							/* U+01D022 */
+	0,							/* U+01D023 */
+	0,							/* U+01D024 */
+	0,							/* U+01D025 */
+	0,							/* U+01D026 */
+	0,							/* U+01D027 */
+	0,							/* U+01D028 */
+	0,							/* U+01D029 */
+	0,							/* U+01D02A */
+	0,							/* U+01D02B */
+	0,							/* U+01D02C */
+	0,							/* U+01D02D */
+	0,							/* U+01D02E */
+	0,							/* U+01D02F */
+	0,							/* U+01D030 */
+	0,							/* U+01D031 */
+	0,							/* U+01D032 */
+	0,							/* U+01D033 */
+	0,							/* U+01D034 */
+	0,							/* U+01D035 */
+	0,							/* U+01D036 */
+	0,							/* U+01D037 */
+	0,							/* U+01D038 */
+	0,							/* U+01D039 */
+	0,							/* U+01D03A */
+	0,							/* U+01D03B */
+	0,							/* U+01D03C */
+	0,							/* U+01D03D */
+	0,							/* U+01D03E */
+	0,							/* U+01D03F */
+	0,							/* U+01D040 */
+	0,							/* U+01D041 */
+	0,							/* U+01D042 */
+	0,							/* U+01D043 */
+	0,							/* U+01D044 */
+	0,							/* U+01D045 */
+	0,							/* U+01D046 */
+	0,							/* U+01D047 */
+	0,							/* U+01D048 */
+	0,							/* U+01D049 */
+	0,							/* U+01D04A */
+	0,							/* U+01D04B */
+	0,							/* U+01D04C */
+	0,							/* U+01D04D */
+	0,							/* U+01D04E */
+	0,							/* U+01D04F */
+	0,							/* U+01D050 */
+	0,							/* U+01D051 */
+	0,							/* U+01D052 */
+	0,							/* U+01D053 */
+	0,							/* U+01D054 */
+	0,							/* U+01D055 */
+	0,							/* U+01D056 */
+	0,							/* U+01D057 */
+	0,							/* U+01D058 */
+	0,							/* U+01D059 */
+	0,							/* U+01D05A */
+	0,							/* U+01D05B */
+	0,							/* U+01D05C */
+	0,							/* U+01D05D */
+	0,							/* U+01D05E */
+	0,							/* U+01D05F */
+	0,							/* U+01D060 */
+	0,							/* U+01D061 */
+	0,							/* U+01D062 */
+	0,							/* U+01D063 */
+	0,							/* U+01D064 */
+	0,							/* U+01D065 */
+	0,							/* U+01D066 */
+	0,							/* U+01D067 */
+	0,							/* U+01D068 */
+	0,							/* U+01D069 */
+	0,							/* U+01D06A */
+	0,							/* U+01D06B */
+	0,							/* U+01D06C */
+	0,							/* U+01D06D */
+	0,							/* U+01D06E */
+	0,							/* U+01D06F */
+	0,							/* U+01D070 */
+	0,							/* U+01D071 */
+	0,							/* U+01D072 */
+	0,							/* U+01D073 */
+	0,							/* U+01D074 */
+	0,							/* U+01D075 */
+	0,							/* U+01D076 */
+	0,							/* U+01D077 */
+	0,							/* U+01D078 */
+	0,							/* U+01D079 */
+	0,							/* U+01D07A */
+	0,							/* U+01D07B */
+	0,							/* U+01D07C */
+	0,							/* U+01D07D */
+	0,							/* U+01D07E */
+	0,							/* U+01D07F */
+	0,							/* U+01D080 */
+	0,							/* U+01D081 */
+	0,							/* U+01D082 */
+	0,							/* U+01D083 */
+	0,							/* U+01D084 */
+	0,							/* U+01D085 */
+	0,							/* U+01D086 */
+	0,							/* U+01D087 */
+	0,							/* U+01D088 */
+	0,							/* U+01D089 */
+	0,							/* U+01D08A */
+	0,							/* U+01D08B */
+	0,							/* U+01D08C */
+	0,							/* U+01D08D */
+	0,							/* U+01D08E */
+	0,							/* U+01D08F */
+	0,							/* U+01D090 */
+	0,							/* U+01D091 */
+	0,							/* U+01D092 */
+	0,							/* U+01D093 */
+	0,							/* U+01D094 */
+	0,							/* U+01D095 */
+	0,							/* U+01D096 */
+	0,							/* U+01D097 */
+	0,							/* U+01D098 */
+	0,							/* U+01D099 */
+	0,							/* U+01D09A */
+	0,							/* U+01D09B */
+	0,							/* U+01D09C */
+	0,							/* U+01D09D */
+	0,							/* U+01D09E */
+	0,							/* U+01D09F */
+	0,							/* U+01D0A0 */
+	0,							/* U+01D0A1 */
+	0,							/* U+01D0A2 */
+	0,							/* U+01D0A3 */
+	0,							/* U+01D0A4 */
+	0,							/* U+01D0A5 */
+	0,							/* U+01D0A6 */
+	0,							/* U+01D0A7 */
+	0,							/* U+01D0A8 */
+	0,							/* U+01D0A9 */
+	0,							/* U+01D0AA */
+	0,							/* U+01D0AB */
+	0,							/* U+01D0AC */
+	0,							/* U+01D0AD */
+	0,							/* U+01D0AE */
+	0,							/* U+01D0AF */
+	0,							/* U+01D0B0 */
+	0,							/* U+01D0B1 */
+	0,							/* U+01D0B2 */
+	0,							/* U+01D0B3 */
+	0,							/* U+01D0B4 */
+	0,							/* U+01D0B5 */
+	0,							/* U+01D0B6 */
+	0,							/* U+01D0B7 */
+	0,							/* U+01D0B8 */
+	0,							/* U+01D0B9 */
+	0,							/* U+01D0BA */
+	0,							/* U+01D0BB */
+	0,							/* U+01D0BC */
+	0,							/* U+01D0BD */
+	0,							/* U+01D0BE */
+	0,							/* U+01D0BF */
+	0,							/* U+01D0C0 */
+	0,							/* U+01D0C1 */
+	0,							/* U+01D0C2 */
+	0,							/* U+01D0C3 */
+	0,							/* U+01D0C4 */
+	0,							/* U+01D0C5 */
+	0,							/* U+01D0C6 */
+	0,							/* U+01D0C7 */
+	0,							/* U+01D0C8 */
+	0,							/* U+01D0C9 */
+	0,							/* U+01D0CA */
+	0,							/* U+01D0CB */
+	0,							/* U+01D0CC */
+	0,							/* U+01D0CD */
+	0,							/* U+01D0CE */
+	0,							/* U+01D0CF */
+	0,							/* U+01D0D0 */
+	0,							/* U+01D0D1 */
+	0,							/* U+01D0D2 */
+	0,							/* U+01D0D3 */
+	0,							/* U+01D0D4 */
+	0,							/* U+01D0D5 */
+	0,							/* U+01D0D6 */
+	0,							/* U+01D0D7 */
+	0,							/* U+01D0D8 */
+	0,							/* U+01D0D9 */
+	0,							/* U+01D0DA */
+	0,							/* U+01D0DB */
+	0,							/* U+01D0DC */
+	0,							/* U+01D0DD */
+	0,							/* U+01D0DE */
+	0,							/* U+01D0DF */
+	0,							/* U+01D0E0 */
+	0,							/* U+01D0E1 */
+	0,							/* U+01D0E2 */
+	0,							/* U+01D0E3 */
+	0,							/* U+01D0E4 */
+	0,							/* U+01D0E5 */
+	0,							/* U+01D0E6 */
+	0,							/* U+01D0E7 */
+	0,							/* U+01D0E8 */
+	0,							/* U+01D0E9 */
+	0,							/* U+01D0EA */
+	0,							/* U+01D0EB */
+	0,							/* U+01D0EC */
+	0,							/* U+01D0ED */
+	0,							/* U+01D0EE */
+	0,							/* U+01D0EF */
+	0,							/* U+01D0F0 */
+	0,							/* U+01D0F1 */
+	0,							/* U+01D0F2 */
+	0,							/* U+01D0F3 */
+	0,							/* U+01D0F4 */
+	0,							/* U+01D0F5 */
+	0,							/* U+01D0F6 */
+	0,							/* U+01D0F7 */
+	0,							/* U+01D0F8 */
+	0,							/* U+01D0F9 */
+	0,							/* U+01D0FA */
+	0,							/* U+01D0FB */
+	0,							/* U+01D0FC */
+	0,							/* U+01D0FD */
+	0,							/* U+01D0FE */
+	0,							/* U+01D0FF */
+	0,							/* U+01D100 */
+	0,							/* U+01D101 */
+	0,							/* U+01D102 */
+	0,							/* U+01D103 */
+	0,							/* U+01D104 */
+	0,							/* U+01D105 */
+	0,							/* U+01D106 */
+	0,							/* U+01D107 */
+	0,							/* U+01D108 */
+	0,							/* U+01D109 */
+	0,							/* U+01D10A */
+	0,							/* U+01D10B */
+	0,							/* U+01D10C */
+	0,							/* U+01D10D */
+	0,							/* U+01D10E */
+	0,							/* U+01D10F */
+	0,							/* U+01D110 */
+	0,							/* U+01D111 */
+	0,							/* U+01D112 */
+	0,							/* U+01D113 */
+	0,							/* U+01D114 */
+	0,							/* U+01D115 */
+	0,							/* U+01D116 */
+	0,							/* U+01D117 */
+	0,							/* U+01D118 */
+	0,							/* U+01D119 */
+	0,							/* U+01D11A */
+	0,							/* U+01D11B */
+	0,							/* U+01D11C */
+	0,							/* U+01D11D */
+	0,							/* U+01D11E */
+	0,							/* U+01D11F */
+	0,							/* U+01D120 */
+	0,							/* U+01D121 */
+	0,							/* U+01D122 */
+	0,							/* U+01D123 */
+	0,							/* U+01D124 */
+	0,							/* U+01D125 */
+	0,							/* U+01D126 */
+	0,							/* U+01D127 */
+	0,							/* U+01D128 */
+	0,							/* U+01D129 */
+	0,							/* U+01D12A */
+	0,							/* U+01D12B */
+	0,							/* U+01D12C */
+	0,							/* U+01D12D */
+	0,							/* U+01D12E */
+	0,							/* U+01D12F */
+	0,							/* U+01D130 */
+	0,							/* U+01D131 */
+	0,							/* U+01D132 */
+	0,							/* U+01D133 */
+	0,							/* U+01D134 */
+	0,							/* U+01D135 */
+	0,							/* U+01D136 */
+	0,							/* U+01D137 */
+	0,							/* U+01D138 */
+	0,							/* U+01D139 */
+	0,							/* U+01D13A */
+	0,							/* U+01D13B */
+	0,							/* U+01D13C */
+	0,							/* U+01D13D */
+	0,							/* U+01D13E */
+	0,							/* U+01D13F */
+	0,							/* U+01D140 */
+	0,							/* U+01D141 */
+	0,							/* U+01D142 */
+	0,							/* U+01D143 */
+	0,							/* U+01D144 */
+	0,							/* U+01D145 */
+	0,							/* U+01D146 */
+	0,							/* U+01D147 */
+	0,							/* U+01D148 */
+	0,							/* U+01D149 */
+	0,							/* U+01D14A */
+	0,							/* U+01D14B */
+	0,							/* U+01D14C */
+	0,							/* U+01D14D */
+	0,							/* U+01D14E */
+	0,							/* U+01D14F */
+	0,							/* U+01D150 */
+	0,							/* U+01D151 */
+	0,							/* U+01D152 */
+	0,							/* U+01D153 */
+	0,							/* U+01D154 */
+	0,							/* U+01D155 */
+	0,							/* U+01D156 */
+	0,							/* U+01D157 */
+	0,							/* U+01D158 */
+	0,							/* U+01D159 */
+	0,							/* U+01D15A */
+	0,							/* U+01D15B */
+	0,							/* U+01D15C */
+	0,							/* U+01D15D */
+	3271,						/* U+01D15E */
+	3272,						/* U+01D15F */
+	3273,						/* U+01D160 */
+	3274,						/* U+01D161 */
+	3275,						/* U+01D162 */
+	3276,						/* U+01D163 */
+	3277,						/* U+01D164 */
+	307,						/* U+01D165 */
+	307,						/* U+01D166 */
+	309,						/* U+01D167 */
+	309,						/* U+01D168 */
+	309,						/* U+01D169 */
+	0,							/* U+01D16A */
+	0,							/* U+01D16B */
+	0,							/* U+01D16C */
+	3278,						/* U+01D16D */
+	307,						/* U+01D16E */
+	307,						/* U+01D16F */
+	307,						/* U+01D170 */
+	307,						/* U+01D171 */
+	307,						/* U+01D172 */
+	0,							/* U+01D173 */
+	0,							/* U+01D174 */
+	0,							/* U+01D175 */
+	0,							/* U+01D176 */
+	0,							/* U+01D177 */
+	0,							/* U+01D178 */
+	0,							/* U+01D179 */
+	0,							/* U+01D17A */
+	306,						/* U+01D17B */
+	306,						/* U+01D17C */
+	306,						/* U+01D17D */
+	306,						/* U+01D17E */
+	306,						/* U+01D17F */
+	306,						/* U+01D180 */
+	306,						/* U+01D181 */
+	306,						/* U+01D182 */
+	0,							/* U+01D183 */
+	0,							/* U+01D184 */
+	304,						/* U+01D185 */
+	304,						/* U+01D186 */
+	304,						/* U+01D187 */
+	304,						/* U+01D188 */
+	304,						/* U+01D189 */
+	306,						/* U+01D18A */
+	306,						/* U+01D18B */
+	0,							/* U+01D18C */
+	0,							/* U+01D18D */
+	0,							/* U+01D18E */
+	0,							/* U+01D18F */
+	0,							/* U+01D190 */
+	0,							/* U+01D191 */
+	0,							/* U+01D192 */
+	0,							/* U+01D193 */
+	0,							/* U+01D194 */
+	0,							/* U+01D195 */
+	0,							/* U+01D196 */
+	0,							/* U+01D197 */
+	0,							/* U+01D198 */
+	0,							/* U+01D199 */
+	0,							/* U+01D19A */
+	0,							/* U+01D19B */
+	0,							/* U+01D19C */
+	0,							/* U+01D19D */
+	0,							/* U+01D19E */
+	0,							/* U+01D19F */
+	0,							/* U+01D1A0 */
+	0,							/* U+01D1A1 */
+	0,							/* U+01D1A2 */
+	0,							/* U+01D1A3 */
+	0,							/* U+01D1A4 */
+	0,							/* U+01D1A5 */
+	0,							/* U+01D1A6 */
+	0,							/* U+01D1A7 */
+	0,							/* U+01D1A8 */
+	0,							/* U+01D1A9 */
+	304,						/* U+01D1AA */
+	304,						/* U+01D1AB */
+	304,						/* U+01D1AC */
+	304,						/* U+01D1AD */
+	0,							/* U+01D1AE */
+	0,							/* U+01D1AF */
+	0,							/* U+01D1B0 */
+	0,							/* U+01D1B1 */
+	0,							/* U+01D1B2 */
+	0,							/* U+01D1B3 */
+	0,							/* U+01D1B4 */
+	0,							/* U+01D1B5 */
+	0,							/* U+01D1B6 */
+	0,							/* U+01D1B7 */
+	0,							/* U+01D1B8 */
+	0,							/* U+01D1B9 */
+	0,							/* U+01D1BA */
+	3279,						/* U+01D1BB */
+	3280,						/* U+01D1BC */
+	3281,						/* U+01D1BD */
+	3282,						/* U+01D1BE */
+	3283,						/* U+01D1BF */
+	3284,						/* U+01D1C0 */
+	0,							/* U+01D1C1 */
+	0,							/* U+01D1C2 */
+	0,							/* U+01D1C3 */
+	0,							/* U+01D1C4 */
+	0,							/* U+01D1C5 */
+	0,							/* U+01D1C6 */
+	0,							/* U+01D1C7 */
+	0,							/* U+01D1C8 */
+	0,							/* U+01D1C9 */
+	0,							/* U+01D1CA */
+	0,							/* U+01D1CB */
+	0,							/* U+01D1CC */
+	0,							/* U+01D1CD */
+	0,							/* U+01D1CE */
+	0,							/* U+01D1CF */
+	0,							/* U+01D1D0 */
+	0,							/* U+01D1D1 */
+	0,							/* U+01D1D2 */
+	0,							/* U+01D1D3 */
+	0,							/* U+01D1D4 */
+	0,							/* U+01D1D5 */
+	0,							/* U+01D1D6 */
+	0,							/* U+01D1D7 */
+	0,							/* U+01D1D8 */
+	0,							/* U+01D1D9 */
+	0,							/* U+01D1DA */
+	0,							/* U+01D1DB */
+	0,							/* U+01D1DC */
+	0,							/* U+01D1DD */
+	0,							/* U+01D1DE */
+	0,							/* U+01D1DF */
+	0,							/* U+01D1E0 */
+	0,							/* U+01D1E1 */
+	0,							/* U+01D1E2 */
+	0,							/* U+01D1E3 */
+	0,							/* U+01D1E4 */
+	0,							/* U+01D1E5 */
+	0,							/* U+01D1E6 */
+	0,							/* U+01D1E7 */
+	0,							/* U+01D1E8 */
+	0,							/* U+01D1E9 */
+	0,							/* U+01D1EA */
+	0,							/* U+01D1EB */
+	0,							/* U+01D1EC */
+	0,							/* U+01D1ED */
+	0,							/* U+01D1EE */
+	0,							/* U+01D1EF */
+	0,							/* U+01D1F0 */
+	0,							/* U+01D1F1 */
+	0,							/* U+01D1F2 */
+	0,							/* U+01D1F3 */
+	0,							/* U+01D1F4 */
+	0,							/* U+01D1F5 */
+	0,							/* U+01D1F6 */
+	0,							/* U+01D1F7 */
+	0,							/* U+01D1F8 */
+	0,							/* U+01D1F9 */
+	0,							/* U+01D1FA */
+	0,							/* U+01D1FB */
+	0,							/* U+01D1FC */
+	0,							/* U+01D1FD */
+	0,							/* U+01D1FE */
+	0,							/* U+01D1FF */
+	0,							/* U+01D200 */
+	0,							/* U+01D201 */
+	0,							/* U+01D202 */
+	0,							/* U+01D203 */
+	0,							/* U+01D204 */
+	0,							/* U+01D205 */
+	0,							/* U+01D206 */
+	0,							/* U+01D207 */
+	0,							/* U+01D208 */
+	0,							/* U+01D209 */
+	0,							/* U+01D20A */
+	0,							/* U+01D20B */
+	0,							/* U+01D20C */
+	0,							/* U+01D20D */
+	0,							/* U+01D20E */
+	0,							/* U+01D20F */
+	0,							/* U+01D210 */
+	0,							/* U+01D211 */
+	0,							/* U+01D212 */
+	0,							/* U+01D213 */
+	0,							/* U+01D214 */
+	0,							/* U+01D215 */
+	0,							/* U+01D216 */
+	0,							/* U+01D217 */
+	0,							/* U+01D218 */
+	0,							/* U+01D219 */
+	0,							/* U+01D21A */
+	0,							/* U+01D21B */
+	0,							/* U+01D21C */
+	0,							/* U+01D21D */
+	0,							/* U+01D21E */
+	0,							/* U+01D21F */
+	0,							/* U+01D220 */
+	0,							/* U+01D221 */
+	0,							/* U+01D222 */
+	0,							/* U+01D223 */
+	0,							/* U+01D224 */
+	0,							/* U+01D225 */
+	0,							/* U+01D226 */
+	0,							/* U+01D227 */
+	0,							/* U+01D228 */
+	0,							/* U+01D229 */
+	0,							/* U+01D22A */
+	0,							/* U+01D22B */
+	0,							/* U+01D22C */
+	0,							/* U+01D22D */
+	0,							/* U+01D22E */
+	0,							/* U+01D22F */
+	0,							/* U+01D230 */
+	0,							/* U+01D231 */
+	0,							/* U+01D232 */
+	0,							/* U+01D233 */
+	0,							/* U+01D234 */
+	0,							/* U+01D235 */
+	0,							/* U+01D236 */
+	0,							/* U+01D237 */
+	0,							/* U+01D238 */
+	0,							/* U+01D239 */
+	0,							/* U+01D23A */
+	0,							/* U+01D23B */
+	0,							/* U+01D23C */
+	0,							/* U+01D23D */
+	0,							/* U+01D23E */
+	0,							/* U+01D23F */
+	0,							/* U+01D240 */
+	0,							/* U+01D241 */
+	304,						/* U+01D242 */
+	304,						/* U+01D243 */
+	304,						/* U+01D244 */
+	0,							/* U+01D245 */
+	0,							/* U+01D246 */
+	0,							/* U+01D247 */
+	0,							/* U+01D248 */
+	0,							/* U+01D249 */
+	0,							/* U+01D24A */
+	0,							/* U+01D24B */
+	0,							/* U+01D24C */
+	0,							/* U+01D24D */
+	0,							/* U+01D24E */
+	0,							/* U+01D24F */
+	0,							/* U+01D250 */
+	0,							/* U+01D251 */
+	0,							/* U+01D252 */
+	0,							/* U+01D253 */
+	0,							/* U+01D254 */
+	0,							/* U+01D255 */
+	0,							/* U+01D256 */
+	0,							/* U+01D257 */
+	0,							/* U+01D258 */
+	0,							/* U+01D259 */
+	0,							/* U+01D25A */
+	0,							/* U+01D25B */
+	0,							/* U+01D25C */
+	0,							/* U+01D25D */
+	0,							/* U+01D25E */
+	0,							/* U+01D25F */
+	0,							/* U+01D260 */
+	0,							/* U+01D261 */
+	0,							/* U+01D262 */
+	0,							/* U+01D263 */
+	0,							/* U+01D264 */
+	0,							/* U+01D265 */
+	0,							/* U+01D266 */
+	0,							/* U+01D267 */
+	0,							/* U+01D268 */
+	0,							/* U+01D269 */
+	0,							/* U+01D26A */
+	0,							/* U+01D26B */
+	0,							/* U+01D26C */
+	0,							/* U+01D26D */
+	0,							/* U+01D26E */
+	0,							/* U+01D26F */
+	0,							/* U+01D270 */
+	0,							/* U+01D271 */
+	0,							/* U+01D272 */
+	0,							/* U+01D273 */
+	0,							/* U+01D274 */
+	0,							/* U+01D275 */
+	0,							/* U+01D276 */
+	0,							/* U+01D277 */
+	0,							/* U+01D278 */
+	0,							/* U+01D279 */
+	0,							/* U+01D27A */
+	0,							/* U+01D27B */
+	0,							/* U+01D27C */
+	0,							/* U+01D27D */
+	0,							/* U+01D27E */
+	0,							/* U+01D27F */
+	0,							/* U+01D280 */
+	0,							/* U+01D281 */
+	0,							/* U+01D282 */
+	0,							/* U+01D283 */
+	0,							/* U+01D284 */
+	0,							/* U+01D285 */
+	0,							/* U+01D286 */
+	0,							/* U+01D287 */
+	0,							/* U+01D288 */
+	0,							/* U+01D289 */
+	0,							/* U+01D28A */
+	0,							/* U+01D28B */
+	0,							/* U+01D28C */
+	0,							/* U+01D28D */
+	0,							/* U+01D28E */
+	0,							/* U+01D28F */
+	0,							/* U+01D290 */
+	0,							/* U+01D291 */
+	0,							/* U+01D292 */
+	0,							/* U+01D293 */
+	0,							/* U+01D294 */
+	0,							/* U+01D295 */
+	0,							/* U+01D296 */
+	0,							/* U+01D297 */
+	0,							/* U+01D298 */
+	0,							/* U+01D299 */
+	0,							/* U+01D29A */
+	0,							/* U+01D29B */
+	0,							/* U+01D29C */
+	0,							/* U+01D29D */
+	0,							/* U+01D29E */
+	0,							/* U+01D29F */
+	0,							/* U+01D2A0 */
+	0,							/* U+01D2A1 */
+	0,							/* U+01D2A2 */
+	0,							/* U+01D2A3 */
+	0,							/* U+01D2A4 */
+	0,							/* U+01D2A5 */
+	0,							/* U+01D2A6 */
+	0,							/* U+01D2A7 */
+	0,							/* U+01D2A8 */
+	0,							/* U+01D2A9 */
+	0,							/* U+01D2AA */
+	0,							/* U+01D2AB */
+	0,							/* U+01D2AC */
+	0,							/* U+01D2AD */
+	0,							/* U+01D2AE */
+	0,							/* U+01D2AF */
+	0,							/* U+01D2B0 */
+	0,							/* U+01D2B1 */
+	0,							/* U+01D2B2 */
+	0,							/* U+01D2B3 */
+	0,							/* U+01D2B4 */
+	0,							/* U+01D2B5 */
+	0,							/* U+01D2B6 */
+	0,							/* U+01D2B7 */
+	0,							/* U+01D2B8 */
+	0,							/* U+01D2B9 */
+	0,							/* U+01D2BA */
+	0,							/* U+01D2BB */
+	0,							/* U+01D2BC */
+	0,							/* U+01D2BD */
+	0,							/* U+01D2BE */
+	0,							/* U+01D2BF */
+	0,							/* U+01D2C0 */
+	0,							/* U+01D2C1 */
+	0,							/* U+01D2C2 */
+	0,							/* U+01D2C3 */
+	0,							/* U+01D2C4 */
+	0,							/* U+01D2C5 */
+	0,							/* U+01D2C6 */
+	0,							/* U+01D2C7 */
+	0,							/* U+01D2C8 */
+	0,							/* U+01D2C9 */
+	0,							/* U+01D2CA */
+	0,							/* U+01D2CB */
+	0,							/* U+01D2CC */
+	0,							/* U+01D2CD */
+	0,							/* U+01D2CE */
+	0,							/* U+01D2CF */
+	0,							/* U+01D2D0 */
+	0,							/* U+01D2D1 */
+	0,							/* U+01D2D2 */
+	0,							/* U+01D2D3 */
+	0,							/* U+01D2D4 */
+	0,							/* U+01D2D5 */
+	0,							/* U+01D2D6 */
+	0,							/* U+01D2D7 */
+	0,							/* U+01D2D8 */
+	0,							/* U+01D2D9 */
+	0,							/* U+01D2DA */
+	0,							/* U+01D2DB */
+	0,							/* U+01D2DC */
+	0,							/* U+01D2DD */
+	0,							/* U+01D2DE */
+	0,							/* U+01D2DF */
+	0,							/* U+01D2E0 */
+	0,							/* U+01D2E1 */
+	0,							/* U+01D2E2 */
+	0,							/* U+01D2E3 */
+	0,							/* U+01D2E4 */
+	0,							/* U+01D2E5 */
+	0,							/* U+01D2E6 */
+	0,							/* U+01D2E7 */
+	0,							/* U+01D2E8 */
+	0,							/* U+01D2E9 */
+	0,							/* U+01D2EA */
+	0,							/* U+01D2EB */
+	0,							/* U+01D2EC */
+	0,							/* U+01D2ED */
+	0,							/* U+01D2EE */
+	0,							/* U+01D2EF */
+	0,							/* U+01D2F0 */
+	0,							/* U+01D2F1 */
+	0,							/* U+01D2F2 */
+	0,							/* U+01D2F3 */
+	0,							/* U+01D2F4 */
+	0,							/* U+01D2F5 */
+	0,							/* U+01D2F6 */
+	0,							/* U+01D2F7 */
+	0,							/* U+01D2F8 */
+	0,							/* U+01D2F9 */
+	0,							/* U+01D2FA */
+	0,							/* U+01D2FB */
+	0,							/* U+01D2FC */
+	0,							/* U+01D2FD */
+	0,							/* U+01D2FE */
+	0,							/* U+01D2FF */
+	0,							/* U+01D300 */
+	0,							/* U+01D301 */
+	0,							/* U+01D302 */
+	0,							/* U+01D303 */
+	0,							/* U+01D304 */
+	0,							/* U+01D305 */
+	0,							/* U+01D306 */
+	0,							/* U+01D307 */
+	0,							/* U+01D308 */
+	0,							/* U+01D309 */
+	0,							/* U+01D30A */
+	0,							/* U+01D30B */
+	0,							/* U+01D30C */
+	0,							/* U+01D30D */
+	0,							/* U+01D30E */
+	0,							/* U+01D30F */
+	0,							/* U+01D310 */
+	0,							/* U+01D311 */
+	0,							/* U+01D312 */
+	0,							/* U+01D313 */
+	0,							/* U+01D314 */
+	0,							/* U+01D315 */
+	0,							/* U+01D316 */
+	0,							/* U+01D317 */
+	0,							/* U+01D318 */
+	0,							/* U+01D319 */
+	0,							/* U+01D31A */
+	0,							/* U+01D31B */
+	0,							/* U+01D31C */
+	0,							/* U+01D31D */
+	0,							/* U+01D31E */
+	0,							/* U+01D31F */
+	0,							/* U+01D320 */
+	0,							/* U+01D321 */
+	0,							/* U+01D322 */
+	0,							/* U+01D323 */
+	0,							/* U+01D324 */
+	0,							/* U+01D325 */
+	0,							/* U+01D326 */
+	0,							/* U+01D327 */
+	0,							/* U+01D328 */
+	0,							/* U+01D329 */
+	0,							/* U+01D32A */
+	0,							/* U+01D32B */
+	0,							/* U+01D32C */
+	0,							/* U+01D32D */
+	0,							/* U+01D32E */
+	0,							/* U+01D32F */
+	0,							/* U+01D330 */
+	0,							/* U+01D331 */
+	0,							/* U+01D332 */
+	0,							/* U+01D333 */
+	0,							/* U+01D334 */
+	0,							/* U+01D335 */
+	0,							/* U+01D336 */
+	0,							/* U+01D337 */
+	0,							/* U+01D338 */
+	0,							/* U+01D339 */
+	0,							/* U+01D33A */
+	0,							/* U+01D33B */
+	0,							/* U+01D33C */
+	0,							/* U+01D33D */
+	0,							/* U+01D33E */
+	0,							/* U+01D33F */
+	0,							/* U+01D340 */
+	0,							/* U+01D341 */
+	0,							/* U+01D342 */
+	0,							/* U+01D343 */
+	0,							/* U+01D344 */
+	0,							/* U+01D345 */
+	0,							/* U+01D346 */
+	0,							/* U+01D347 */
+	0,							/* U+01D348 */
+	0,							/* U+01D349 */
+	0,							/* U+01D34A */
+	0,							/* U+01D34B */
+	0,							/* U+01D34C */
+	0,							/* U+01D34D */
+	0,							/* U+01D34E */
+	0,							/* U+01D34F */
+	0,							/* U+01D350 */
+	0,							/* U+01D351 */
+	0,							/* U+01D352 */
+	0,							/* U+01D353 */
+	0,							/* U+01D354 */
+	0,							/* U+01D355 */
+	0,							/* U+01D356 */
+	0,							/* U+01D357 */
+	0,							/* U+01D358 */
+	0,							/* U+01D359 */
+	0,							/* U+01D35A */
+	0,							/* U+01D35B */
+	0,							/* U+01D35C */
+	0,							/* U+01D35D */
+	0,							/* U+01D35E */
+	0,							/* U+01D35F */
+	0,							/* U+01D360 */
+	0,							/* U+01D361 */
+	0,							/* U+01D362 */
+	0,							/* U+01D363 */
+	0,							/* U+01D364 */
+	0,							/* U+01D365 */
+	0,							/* U+01D366 */
+	0,							/* U+01D367 */
+	0,							/* U+01D368 */
+	0,							/* U+01D369 */
+	0,							/* U+01D36A */
+	0,							/* U+01D36B */
+	0,							/* U+01D36C */
+	0,							/* U+01D36D */
+	0,							/* U+01D36E */
+	0,							/* U+01D36F */
+	0,							/* U+01D370 */
+	0,							/* U+01D371 */
+	0,							/* U+01D372 */
+	0,							/* U+01D373 */
+	0,							/* U+01D374 */
+	0,							/* U+01D375 */
+	0,							/* U+01D376 */
+	0,							/* U+01D377 */
+	0,							/* U+01D378 */
+	0,							/* U+01D379 */
+	0,							/* U+01D37A */
+	0,							/* U+01D37B */
+	0,							/* U+01D37C */
+	0,							/* U+01D37D */
+	0,							/* U+01D37E */
+	0,							/* U+01D37F */
+	0,							/* U+01D380 */
+	0,							/* U+01D381 */
+	0,							/* U+01D382 */
+	0,							/* U+01D383 */
+	0,							/* U+01D384 */
+	0,							/* U+01D385 */
+	0,							/* U+01D386 */
+	0,							/* U+01D387 */
+	0,							/* U+01D388 */
+	0,							/* U+01D389 */
+	0,							/* U+01D38A */
+	0,							/* U+01D38B */
+	0,							/* U+01D38C */
+	0,							/* U+01D38D */
+	0,							/* U+01D38E */
+	0,							/* U+01D38F */
+	0,							/* U+01D390 */
+	0,							/* U+01D391 */
+	0,							/* U+01D392 */
+	0,							/* U+01D393 */
+	0,							/* U+01D394 */
+	0,							/* U+01D395 */
+	0,							/* U+01D396 */
+	0,							/* U+01D397 */
+	0,							/* U+01D398 */
+	0,							/* U+01D399 */
+	0,							/* U+01D39A */
+	0,							/* U+01D39B */
+	0,							/* U+01D39C */
+	0,							/* U+01D39D */
+	0,							/* U+01D39E */
+	0,							/* U+01D39F */
+	0,							/* U+01D3A0 */
+	0,							/* U+01D3A1 */
+	0,							/* U+01D3A2 */
+	0,							/* U+01D3A3 */
+	0,							/* U+01D3A4 */
+	0,							/* U+01D3A5 */
+	0,							/* U+01D3A6 */
+	0,							/* U+01D3A7 */
+	0,							/* U+01D3A8 */
+	0,							/* U+01D3A9 */
+	0,							/* U+01D3AA */
+	0,							/* U+01D3AB */
+	0,							/* U+01D3AC */
+	0,							/* U+01D3AD */
+	0,							/* U+01D3AE */
+	0,							/* U+01D3AF */
+	0,							/* U+01D3B0 */
+	0,							/* U+01D3B1 */
+	0,							/* U+01D3B2 */
+	0,							/* U+01D3B3 */
+	0,							/* U+01D3B4 */
+	0,							/* U+01D3B5 */
+	0,							/* U+01D3B6 */
+	0,							/* U+01D3B7 */
+	0,							/* U+01D3B8 */
+	0,							/* U+01D3B9 */
+	0,							/* U+01D3BA */
+	0,							/* U+01D3BB */
+	0,							/* U+01D3BC */
+	0,							/* U+01D3BD */
+	0,							/* U+01D3BE */
+	0,							/* U+01D3BF */
+	0,							/* U+01D3C0 */
+	0,							/* U+01D3C1 */
+	0,							/* U+01D3C2 */
+	0,							/* U+01D3C3 */
+	0,							/* U+01D3C4 */
+	0,							/* U+01D3C5 */
+	0,							/* U+01D3C6 */
+	0,							/* U+01D3C7 */
+	0,							/* U+01D3C8 */
+	0,							/* U+01D3C9 */
+	0,							/* U+01D3CA */
+	0,							/* U+01D3CB */
+	0,							/* U+01D3CC */
+	0,							/* U+01D3CD */
+	0,							/* U+01D3CE */
+	0,							/* U+01D3CF */
+	0,							/* U+01D3D0 */
+	0,							/* U+01D3D1 */
+	0,							/* U+01D3D2 */
+	0,							/* U+01D3D3 */
+	0,							/* U+01D3D4 */
+	0,							/* U+01D3D5 */
+	0,							/* U+01D3D6 */
+	0,							/* U+01D3D7 */
+	0,							/* U+01D3D8 */
+	0,							/* U+01D3D9 */
+	0,							/* U+01D3DA */
+	0,							/* U+01D3DB */
+	0,							/* U+01D3DC */
+	0,							/* U+01D3DD */
+	0,							/* U+01D3DE */
+	0,							/* U+01D3DF */
+	0,							/* U+01D3E0 */
+	0,							/* U+01D3E1 */
+	0,							/* U+01D3E2 */
+	0,							/* U+01D3E3 */
+	0,							/* U+01D3E4 */
+	0,							/* U+01D3E5 */
+	0,							/* U+01D3E6 */
+	0,							/* U+01D3E7 */
+	0,							/* U+01D3E8 */
+	0,							/* U+01D3E9 */
+	0,							/* U+01D3EA */
+	0,							/* U+01D3EB */
+	0,							/* U+01D3EC */
+	0,							/* U+01D3ED */
+	0,							/* U+01D3EE */
+	0,							/* U+01D3EF */
+	0,							/* U+01D3F0 */
+	0,							/* U+01D3F1 */
+	0,							/* U+01D3F2 */
+	0,							/* U+01D3F3 */
+	0,							/* U+01D3F4 */
+	0,							/* U+01D3F5 */
+	0,							/* U+01D3F6 */
+	0,							/* U+01D3F7 */
+	0,							/* U+01D3F8 */
+	0,							/* U+01D3F9 */
+	0,							/* U+01D3FA */
+	0,							/* U+01D3FB */
+	0,							/* U+01D3FC */
+	0,							/* U+01D3FD */
+	0,							/* U+01D3FE */
+	0,							/* U+01D3FF */
+	540,						/* U+01D400 */
+	542,						/* U+01D401 */
+	1137,						/* U+01D402 */
+	543,						/* U+01D403 */
+	544,						/* U+01D404 */
+	1153,						/* U+01D405 */
+	546,						/* U+01D406 */
+	547,						/* U+01D407 */
+	548,						/* U+01D408 */
+	549,						/* U+01D409 */
+	550,						/* U+01D40A */
+	551,						/* U+01D40B */
+	552,						/* U+01D40C */
+	553,						/* U+01D40D */
+	554,						/* U+01D40E */
+	556,						/* U+01D40F */
+	1145,						/* U+01D410 */
+	557,						/* U+01D411 */
+	1326,						/* U+01D412 */
+	558,						/* U+01D413 */
+	559,						/* U+01D414 */
+	1181,						/* U+01D415 */
+	560,						/* U+01D416 */
+	1186,						/* U+01D417 */
+	1327,						/* U+01D418 */
+	1149,						/* U+01D419 */
+	3,							/* U+01D41A */
+	564,						/* U+01D41B */
+	590,						/* U+01D41C */
+	565,						/* U+01D41D */
+	566,						/* U+01D41E */
+	593,						/* U+01D41F */
+	570,						/* U+01D420 */
+	285,						/* U+01D421 */
+	587,						/* U+01D422 */
+	287,						/* U+01D423 */
+	571,						/* U+01D424 */
+	301,						/* U+01D425 */
+	572,						/* U+01D426 */
+	1133,						/* U+01D427 */
+	11,							/* U+01D428 */
+	577,						/* U+01D429 */
+	1328,						/* U+01D42A */
+	288,						/* U+01D42B */
+	181,						/* U+01D42C */
+	578,						/* U+01D42D */
+	579,						/* U+01D42E */
+	582,						/* U+01D42F */
+	292,						/* U+01D430 */
+	302,						/* U+01D431 */
+	293,						/* U+01D432 */
+	620,						/* U+01D433 */
+	540,						/* U+01D434 */
+	542,						/* U+01D435 */
+	1137,						/* U+01D436 */
+	543,						/* U+01D437 */
+	544,						/* U+01D438 */
+	1153,						/* U+01D439 */
+	546,						/* U+01D43A */
+	547,						/* U+01D43B */
+	548,						/* U+01D43C */
+	549,						/* U+01D43D */
+	550,						/* U+01D43E */
+	551,						/* U+01D43F */
+	552,						/* U+01D440 */
+	553,						/* U+01D441 */
+	554,						/* U+01D442 */
+	556,						/* U+01D443 */
+	1145,						/* U+01D444 */
+	557,						/* U+01D445 */
+	1326,						/* U+01D446 */
+	558,						/* U+01D447 */
+	559,						/* U+01D448 */
+	1181,						/* U+01D449 */
+	560,						/* U+01D44A */
+	1186,						/* U+01D44B */
+	1327,						/* U+01D44C */
+	1149,						/* U+01D44D */
+	3,							/* U+01D44E */
+	564,						/* U+01D44F */
+	590,						/* U+01D450 */
+	565,						/* U+01D451 */
+	566,						/* U+01D452 */
+	593,						/* U+01D453 */
+	570,						/* U+01D454 */
+	0,							/* U+01D455 */
+	587,						/* U+01D456 */
+	287,						/* U+01D457 */
+	571,						/* U+01D458 */
+	301,						/* U+01D459 */
+	572,						/* U+01D45A */
+	1133,						/* U+01D45B */
+	11,							/* U+01D45C */
+	577,						/* U+01D45D */
+	1328,						/* U+01D45E */
+	288,						/* U+01D45F */
+	181,						/* U+01D460 */
+	578,						/* U+01D461 */
+	579,						/* U+01D462 */
+	582,						/* U+01D463 */
+	292,						/* U+01D464 */
+	302,						/* U+01D465 */
+	293,						/* U+01D466 */
+	620,						/* U+01D467 */
+	540,						/* U+01D468 */
+	542,						/* U+01D469 */
+	1137,						/* U+01D46A */
+	543,						/* U+01D46B */
+	544,						/* U+01D46C */
+	1153,						/* U+01D46D */
+	546,						/* U+01D46E */
+	547,						/* U+01D46F */
+	548,						/* U+01D470 */
+	549,						/* U+01D471 */
+	550,						/* U+01D472 */
+	551,						/* U+01D473 */
+	552,						/* U+01D474 */
+	553,						/* U+01D475 */
+	554,						/* U+01D476 */
+	556,						/* U+01D477 */
+	1145,						/* U+01D478 */
+	557,						/* U+01D479 */
+	1326,						/* U+01D47A */
+	558,						/* U+01D47B */
+	559,						/* U+01D47C */
+	1181,						/* U+01D47D */
+	560,						/* U+01D47E */
+	1186,						/* U+01D47F */
+	1327,						/* U+01D480 */
+	1149,						/* U+01D481 */
+	3,							/* U+01D482 */
+	564,						/* U+01D483 */
+	590,						/* U+01D484 */
+	565,						/* U+01D485 */
+	566,						/* U+01D486 */
+	593,						/* U+01D487 */
+	570,						/* U+01D488 */
+	285,						/* U+01D489 */
+	587,						/* U+01D48A */
+	287,						/* U+01D48B */
+	571,						/* U+01D48C */
+	301,						/* U+01D48D */
+	572,						/* U+01D48E */
+	1133,						/* U+01D48F */
+	11,							/* U+01D490 */
+	577,						/* U+01D491 */
+	1328,						/* U+01D492 */
+	288,						/* U+01D493 */
+	181,						/* U+01D494 */
+	578,						/* U+01D495 */
+	579,						/* U+01D496 */
+	582,						/* U+01D497 */
+	292,						/* U+01D498 */
+	302,						/* U+01D499 */
+	293,						/* U+01D49A */
+	620,						/* U+01D49B */
+	540,						/* U+01D49C */
+	0,							/* U+01D49D */
+	1137,						/* U+01D49E */
+	543,						/* U+01D49F */
+	0,							/* U+01D4A0 */
+	0,							/* U+01D4A1 */
+	546,						/* U+01D4A2 */
+	0,							/* U+01D4A3 */
+	0,							/* U+01D4A4 */
+	549,						/* U+01D4A5 */
+	550,						/* U+01D4A6 */
+	0,							/* U+01D4A7 */
+	0,							/* U+01D4A8 */
+	553,						/* U+01D4A9 */
+	554,						/* U+01D4AA */
+	556,						/* U+01D4AB */
+	1145,						/* U+01D4AC */
+	0,							/* U+01D4AD */
+	1326,						/* U+01D4AE */
+	558,						/* U+01D4AF */
+	559,						/* U+01D4B0 */
+	1181,						/* U+01D4B1 */
+	560,						/* U+01D4B2 */
+	1186,						/* U+01D4B3 */
+	1327,						/* U+01D4B4 */
+	1149,						/* U+01D4B5 */
+	3,							/* U+01D4B6 */
+	564,						/* U+01D4B7 */
+	590,						/* U+01D4B8 */
+	565,						/* U+01D4B9 */
+	0,							/* U+01D4BA */
+	593,						/* U+01D4BB */
+	0,							/* U+01D4BC */
+	285,						/* U+01D4BD */
+	587,						/* U+01D4BE */
+	287,						/* U+01D4BF */
+	571,						/* U+01D4C0 */
+	301,						/* U+01D4C1 */
+	572,						/* U+01D4C2 */
+	1133,						/* U+01D4C3 */
+	0,							/* U+01D4C4 */
+	577,						/* U+01D4C5 */
+	1328,						/* U+01D4C6 */
+	288,						/* U+01D4C7 */
+	181,						/* U+01D4C8 */
+	578,						/* U+01D4C9 */
+	579,						/* U+01D4CA */
+	582,						/* U+01D4CB */
+	292,						/* U+01D4CC */
+	302,						/* U+01D4CD */
+	293,						/* U+01D4CE */
+	620,						/* U+01D4CF */
+	540,						/* U+01D4D0 */
+	542,						/* U+01D4D1 */
+	1137,						/* U+01D4D2 */
+	543,						/* U+01D4D3 */
+	544,						/* U+01D4D4 */
+	1153,						/* U+01D4D5 */
+	546,						/* U+01D4D6 */
+	547,						/* U+01D4D7 */
+	548,						/* U+01D4D8 */
+	549,						/* U+01D4D9 */
+	550,						/* U+01D4DA */
+	551,						/* U+01D4DB */
+	552,						/* U+01D4DC */
+	553,						/* U+01D4DD */
+	554,						/* U+01D4DE */
+	556,						/* U+01D4DF */
+	1145,						/* U+01D4E0 */
+	557,						/* U+01D4E1 */
+	1326,						/* U+01D4E2 */
+	558,						/* U+01D4E3 */
+	559,						/* U+01D4E4 */
+	1181,						/* U+01D4E5 */
+	560,						/* U+01D4E6 */
+	1186,						/* U+01D4E7 */
+	1327,						/* U+01D4E8 */
+	1149,						/* U+01D4E9 */
+	3,							/* U+01D4EA */
+	564,						/* U+01D4EB */
+	590,						/* U+01D4EC */
+	565,						/* U+01D4ED */
+	566,						/* U+01D4EE */
+	593,						/* U+01D4EF */
+	570,						/* U+01D4F0 */
+	285,						/* U+01D4F1 */
+	587,						/* U+01D4F2 */
+	287,						/* U+01D4F3 */
+	571,						/* U+01D4F4 */
+	301,						/* U+01D4F5 */
+	572,						/* U+01D4F6 */
+	1133,						/* U+01D4F7 */
+	11,							/* U+01D4F8 */
+	577,						/* U+01D4F9 */
+	1328,						/* U+01D4FA */
+	288,						/* U+01D4FB */
+	181,						/* U+01D4FC */
+	578,						/* U+01D4FD */
+	579,						/* U+01D4FE */
+	582,						/* U+01D4FF */
+	292,						/* U+01D500 */
+	302,						/* U+01D501 */
+	293,						/* U+01D502 */
+	620,						/* U+01D503 */
+	540,						/* U+01D504 */
+	542,						/* U+01D505 */
+	0,							/* U+01D506 */
+	543,						/* U+01D507 */
+	544,						/* U+01D508 */
+	1153,						/* U+01D509 */
+	546,						/* U+01D50A */
+	0,							/* U+01D50B */
+	0,							/* U+01D50C */
+	549,						/* U+01D50D */
+	550,						/* U+01D50E */
+	551,						/* U+01D50F */
+	552,						/* U+01D510 */
+	553,						/* U+01D511 */
+	554,						/* U+01D512 */
+	556,						/* U+01D513 */
+	1145,						/* U+01D514 */
+	0,							/* U+01D515 */
+	1326,						/* U+01D516 */
+	558,						/* U+01D517 */
+	559,						/* U+01D518 */
+	1181,						/* U+01D519 */
+	560,						/* U+01D51A */
+	1186,						/* U+01D51B */
+	1327,						/* U+01D51C */
+	0,							/* U+01D51D */
+	3,							/* U+01D51E */
+	564,						/* U+01D51F */
+	590,						/* U+01D520 */
+	565,						/* U+01D521 */
+	566,						/* U+01D522 */
+	593,						/* U+01D523 */
+	570,						/* U+01D524 */
+	285,						/* U+01D525 */
+	587,						/* U+01D526 */
+	287,						/* U+01D527 */
+	571,						/* U+01D528 */
+	301,						/* U+01D529 */
+	572,						/* U+01D52A */
+	1133,						/* U+01D52B */
+	11,							/* U+01D52C */
+	577,						/* U+01D52D */
+	1328,						/* U+01D52E */
+	288,						/* U+01D52F */
+	181,						/* U+01D530 */
+	578,						/* U+01D531 */
+	579,						/* U+01D532 */
+	582,						/* U+01D533 */
+	292,						/* U+01D534 */
+	302,						/* U+01D535 */
+	293,						/* U+01D536 */
+	620,						/* U+01D537 */
+	540,						/* U+01D538 */
+	542,						/* U+01D539 */
+	0,							/* U+01D53A */
+	543,						/* U+01D53B */
+	544,						/* U+01D53C */
+	1153,						/* U+01D53D */
+	546,						/* U+01D53E */
+	0,							/* U+01D53F */
+	548,						/* U+01D540 */
+	549,						/* U+01D541 */
+	550,						/* U+01D542 */
+	551,						/* U+01D543 */
+	552,						/* U+01D544 */
+	0,							/* U+01D545 */
+	554,						/* U+01D546 */
+	0,							/* U+01D547 */
+	0,							/* U+01D548 */
+	0,							/* U+01D549 */
+	1326,						/* U+01D54A */
+	558,						/* U+01D54B */
+	559,						/* U+01D54C */
+	1181,						/* U+01D54D */
+	560,						/* U+01D54E */
+	1186,						/* U+01D54F */
+	1327,						/* U+01D550 */
+	0,							/* U+01D551 */
+	3,							/* U+01D552 */
+	564,						/* U+01D553 */
+	590,						/* U+01D554 */
+	565,						/* U+01D555 */
+	566,						/* U+01D556 */
+	593,						/* U+01D557 */
+	570,						/* U+01D558 */
+	285,						/* U+01D559 */
+	587,						/* U+01D55A */
+	287,						/* U+01D55B */
+	571,						/* U+01D55C */
+	301,						/* U+01D55D */
+	572,						/* U+01D55E */
+	1133,						/* U+01D55F */
+	11,							/* U+01D560 */
+	577,						/* U+01D561 */
+	1328,						/* U+01D562 */
+	288,						/* U+01D563 */
+	181,						/* U+01D564 */
+	578,						/* U+01D565 */
+	579,						/* U+01D566 */
+	582,						/* U+01D567 */
+	292,						/* U+01D568 */
+	302,						/* U+01D569 */
+	293,						/* U+01D56A */
+	620,						/* U+01D56B */
+	540,						/* U+01D56C */
+	542,						/* U+01D56D */
+	1137,						/* U+01D56E */
+	543,						/* U+01D56F */
+	544,						/* U+01D570 */
+	1153,						/* U+01D571 */
+	546,						/* U+01D572 */
+	547,						/* U+01D573 */
+	548,						/* U+01D574 */
+	549,						/* U+01D575 */
+	550,						/* U+01D576 */
+	551,						/* U+01D577 */
+	552,						/* U+01D578 */
+	553,						/* U+01D579 */
+	554,						/* U+01D57A */
+	556,						/* U+01D57B */
+	1145,						/* U+01D57C */
+	557,						/* U+01D57D */
+	1326,						/* U+01D57E */
+	558,						/* U+01D57F */
+	559,						/* U+01D580 */
+	1181,						/* U+01D581 */
+	560,						/* U+01D582 */
+	1186,						/* U+01D583 */
+	1327,						/* U+01D584 */
+	1149,						/* U+01D585 */
+	3,							/* U+01D586 */
+	564,						/* U+01D587 */
+	590,						/* U+01D588 */
+	565,						/* U+01D589 */
+	566,						/* U+01D58A */
+	593,						/* U+01D58B */
+	570,						/* U+01D58C */
+	285,						/* U+01D58D */
+	587,						/* U+01D58E */
+	287,						/* U+01D58F */
+	571,						/* U+01D590 */
+	301,						/* U+01D591 */
+	572,						/* U+01D592 */
+	1133,						/* U+01D593 */
+	11,							/* U+01D594 */
+	577,						/* U+01D595 */
+	1328,						/* U+01D596 */
+	288,						/* U+01D597 */
+	181,						/* U+01D598 */
+	578,						/* U+01D599 */
+	579,						/* U+01D59A */
+	582,						/* U+01D59B */
+	292,						/* U+01D59C */
+	302,						/* U+01D59D */
+	293,						/* U+01D59E */
+	620,						/* U+01D59F */
+	540,						/* U+01D5A0 */
+	542,						/* U+01D5A1 */
+	1137,						/* U+01D5A2 */
+	543,						/* U+01D5A3 */
+	544,						/* U+01D5A4 */
+	1153,						/* U+01D5A5 */
+	546,						/* U+01D5A6 */
+	547,						/* U+01D5A7 */
+	548,						/* U+01D5A8 */
+	549,						/* U+01D5A9 */
+	550,						/* U+01D5AA */
+	551,						/* U+01D5AB */
+	552,						/* U+01D5AC */
+	553,						/* U+01D5AD */
+	554,						/* U+01D5AE */
+	556,						/* U+01D5AF */
+	1145,						/* U+01D5B0 */
+	557,						/* U+01D5B1 */
+	1326,						/* U+01D5B2 */
+	558,						/* U+01D5B3 */
+	559,						/* U+01D5B4 */
+	1181,						/* U+01D5B5 */
+	560,						/* U+01D5B6 */
+	1186,						/* U+01D5B7 */
+	1327,						/* U+01D5B8 */
+	1149,						/* U+01D5B9 */
+	3,							/* U+01D5BA */
+	564,						/* U+01D5BB */
+	590,						/* U+01D5BC */
+	565,						/* U+01D5BD */
+	566,						/* U+01D5BE */
+	593,						/* U+01D5BF */
+	570,						/* U+01D5C0 */
+	285,						/* U+01D5C1 */
+	587,						/* U+01D5C2 */
+	287,						/* U+01D5C3 */
+	571,						/* U+01D5C4 */
+	301,						/* U+01D5C5 */
+	572,						/* U+01D5C6 */
+	1133,						/* U+01D5C7 */
+	11,							/* U+01D5C8 */
+	577,						/* U+01D5C9 */
+	1328,						/* U+01D5CA */
+	288,						/* U+01D5CB */
+	181,						/* U+01D5CC */
+	578,						/* U+01D5CD */
+	579,						/* U+01D5CE */
+	582,						/* U+01D5CF */
+	292,						/* U+01D5D0 */
+	302,						/* U+01D5D1 */
+	293,						/* U+01D5D2 */
+	620,						/* U+01D5D3 */
+	540,						/* U+01D5D4 */
+	542,						/* U+01D5D5 */
+	1137,						/* U+01D5D6 */
+	543,						/* U+01D5D7 */
+	544,						/* U+01D5D8 */
+	1153,						/* U+01D5D9 */
+	546,						/* U+01D5DA */
+	547,						/* U+01D5DB */
+	548,						/* U+01D5DC */
+	549,						/* U+01D5DD */
+	550,						/* U+01D5DE */
+	551,						/* U+01D5DF */
+	552,						/* U+01D5E0 */
+	553,						/* U+01D5E1 */
+	554,						/* U+01D5E2 */
+	556,						/* U+01D5E3 */
+	1145,						/* U+01D5E4 */
+	557,						/* U+01D5E5 */
+	1326,						/* U+01D5E6 */
+	558,						/* U+01D5E7 */
+	559,						/* U+01D5E8 */
+	1181,						/* U+01D5E9 */
+	560,						/* U+01D5EA */
+	1186,						/* U+01D5EB */
+	1327,						/* U+01D5EC */
+	1149,						/* U+01D5ED */
+	3,							/* U+01D5EE */
+	564,						/* U+01D5EF */
+	590,						/* U+01D5F0 */
+	565,						/* U+01D5F1 */
+	566,						/* U+01D5F2 */
+	593,						/* U+01D5F3 */
+	570,						/* U+01D5F4 */
+	285,						/* U+01D5F5 */
+	587,						/* U+01D5F6 */
+	287,						/* U+01D5F7 */
+	571,						/* U+01D5F8 */
+	301,						/* U+01D5F9 */
+	572,						/* U+01D5FA */
+	1133,						/* U+01D5FB */
+	11,							/* U+01D5FC */
+	577,						/* U+01D5FD */
+	1328,						/* U+01D5FE */
+	288,						/* U+01D5FF */
+	181,						/* U+01D600 */
+	578,						/* U+01D601 */
+	579,						/* U+01D602 */
+	582,						/* U+01D603 */
+	292,						/* U+01D604 */
+	302,						/* U+01D605 */
+	293,						/* U+01D606 */
+	620,						/* U+01D607 */
+	540,						/* U+01D608 */
+	542,						/* U+01D609 */
+	1137,						/* U+01D60A */
+	543,						/* U+01D60B */
+	544,						/* U+01D60C */
+	1153,						/* U+01D60D */
+	546,						/* U+01D60E */
+	547,						/* U+01D60F */
+	548,						/* U+01D610 */
+	549,						/* U+01D611 */
+	550,						/* U+01D612 */
+	551,						/* U+01D613 */
+	552,						/* U+01D614 */
+	553,						/* U+01D615 */
+	554,						/* U+01D616 */
+	556,						/* U+01D617 */
+	1145,						/* U+01D618 */
+	557,						/* U+01D619 */
+	1326,						/* U+01D61A */
+	558,						/* U+01D61B */
+	559,						/* U+01D61C */
+	1181,						/* U+01D61D */
+	560,						/* U+01D61E */
+	1186,						/* U+01D61F */
+	1327,						/* U+01D620 */
+	1149,						/* U+01D621 */
+	3,							/* U+01D622 */
+	564,						/* U+01D623 */
+	590,						/* U+01D624 */
+	565,						/* U+01D625 */
+	566,						/* U+01D626 */
+	593,						/* U+01D627 */
+	570,						/* U+01D628 */
+	285,						/* U+01D629 */
+	587,						/* U+01D62A */
+	287,						/* U+01D62B */
+	571,						/* U+01D62C */
+	301,						/* U+01D62D */
+	572,						/* U+01D62E */
+	1133,						/* U+01D62F */
+	11,							/* U+01D630 */
+	577,						/* U+01D631 */
+	1328,						/* U+01D632 */
+	288,						/* U+01D633 */
+	181,						/* U+01D634 */
+	578,						/* U+01D635 */
+	579,						/* U+01D636 */
+	582,						/* U+01D637 */
+	292,						/* U+01D638 */
+	302,						/* U+01D639 */
+	293,						/* U+01D63A */
+	620,						/* U+01D63B */
+	540,						/* U+01D63C */
+	542,						/* U+01D63D */
+	1137,						/* U+01D63E */
+	543,						/* U+01D63F */
+	544,						/* U+01D640 */
+	1153,						/* U+01D641 */
+	546,						/* U+01D642 */
+	547,						/* U+01D643 */
+	548,						/* U+01D644 */
+	549,						/* U+01D645 */
+	550,						/* U+01D646 */
+	551,						/* U+01D647 */
+	552,						/* U+01D648 */
+	553,						/* U+01D649 */
+	554,						/* U+01D64A */
+	556,						/* U+01D64B */
+	1145,						/* U+01D64C */
+	557,						/* U+01D64D */
+	1326,						/* U+01D64E */
+	558,						/* U+01D64F */
+	559,						/* U+01D650 */
+	1181,						/* U+01D651 */
+	560,						/* U+01D652 */
+	1186,						/* U+01D653 */
+	1327,						/* U+01D654 */
+	1149,						/* U+01D655 */
+	3,							/* U+01D656 */
+	564,						/* U+01D657 */
+	590,						/* U+01D658 */
+	565,						/* U+01D659 */
+	566,						/* U+01D65A */
+	593,						/* U+01D65B */
+	570,						/* U+01D65C */
+	285,						/* U+01D65D */
+	587,						/* U+01D65E */
+	287,						/* U+01D65F */
+	571,						/* U+01D660 */
+	301,						/* U+01D661 */
+	572,						/* U+01D662 */
+	1133,						/* U+01D663 */
+	11,							/* U+01D664 */
+	577,						/* U+01D665 */
+	1328,						/* U+01D666 */
+	288,						/* U+01D667 */
+	181,						/* U+01D668 */
+	578,						/* U+01D669 */
+	579,						/* U+01D66A */
+	582,						/* U+01D66B */
+	292,						/* U+01D66C */
+	302,						/* U+01D66D */
+	293,						/* U+01D66E */
+	620,						/* U+01D66F */
+	540,						/* U+01D670 */
+	542,						/* U+01D671 */
+	1137,						/* U+01D672 */
+	543,						/* U+01D673 */
+	544,						/* U+01D674 */
+	1153,						/* U+01D675 */
+	546,						/* U+01D676 */
+	547,						/* U+01D677 */
+	548,						/* U+01D678 */
+	549,						/* U+01D679 */
+	550,						/* U+01D67A */
+	551,						/* U+01D67B */
+	552,						/* U+01D67C */
+	553,						/* U+01D67D */
+	554,						/* U+01D67E */
+	556,						/* U+01D67F */
+	1145,						/* U+01D680 */
+	557,						/* U+01D681 */
+	1326,						/* U+01D682 */
+	558,						/* U+01D683 */
+	559,						/* U+01D684 */
+	1181,						/* U+01D685 */
+	560,						/* U+01D686 */
+	1186,						/* U+01D687 */
+	1327,						/* U+01D688 */
+	1149,						/* U+01D689 */
+	3,							/* U+01D68A */
+	564,						/* U+01D68B */
+	590,						/* U+01D68C */
+	565,						/* U+01D68D */
+	566,						/* U+01D68E */
+	593,						/* U+01D68F */
+	570,						/* U+01D690 */
+	285,						/* U+01D691 */
+	587,						/* U+01D692 */
+	287,						/* U+01D693 */
+	571,						/* U+01D694 */
+	301,						/* U+01D695 */
+	572,						/* U+01D696 */
+	1133,						/* U+01D697 */
+	11,							/* U+01D698 */
+	577,						/* U+01D699 */
+	1328,						/* U+01D69A */
+	288,						/* U+01D69B */
+	181,						/* U+01D69C */
+	578,						/* U+01D69D */
+	579,						/* U+01D69E */
+	582,						/* U+01D69F */
+	292,						/* U+01D6A0 */
+	302,						/* U+01D6A1 */
+	293,						/* U+01D6A2 */
+	620,						/* U+01D6A3 */
+	3285,						/* U+01D6A4 */
+	3286,						/* U+01D6A5 */
+	0,							/* U+01D6A6 */
+	0,							/* U+01D6A7 */
+	3287,						/* U+01D6A8 */
+	3288,						/* U+01D6A9 */
+	1159,						/* U+01D6AA */
+	3289,						/* U+01D6AB */
+	3290,						/* U+01D6AC */
+	3291,						/* U+01D6AD */
+	3292,						/* U+01D6AE */
+	352,						/* U+01D6AF */
+	3293,						/* U+01D6B0 */
+	3294,						/* U+01D6B1 */
+	3295,						/* U+01D6B2 */
+	3296,						/* U+01D6B3 */
+	3297,						/* U+01D6B4 */
+	3298,						/* U+01D6B5 */
+	3299,						/* U+01D6B6 */
+	1160,						/* U+01D6B7 */
+	3300,						/* U+01D6B8 */
+	3301,						/* U+01D6B9 */
+	354,						/* U+01D6BA */
+	3302,						/* U+01D6BB */
+	344,						/* U+01D6BC */
+	3303,						/* U+01D6BD */
+	3304,						/* U+01D6BE */
+	3305,						/* U+01D6BF */
+	3306,						/* U+01D6C0 */
+	3307,						/* U+01D6C1 */
+	3308,						/* U+01D6C2 */
+	342,						/* U+01D6C3 */
+	584,						/* U+01D6C4 */
+	585,						/* U+01D6C5 */
+	353,						/* U+01D6C6 */
+	3309,						/* U+01D6C7 */
+	3310,						/* U+01D6C8 */
+	343,						/* U+01D6C9 */
+	3311,						/* U+01D6CA */
+	349,						/* U+01D6CB */
+	3312,						/* U+01D6CC */
+	8,							/* U+01D6CD */
+	3313,						/* U+01D6CE */
+	3314,						/* U+01D6CF */
+	3315,						/* U+01D6D0 */
+	348,						/* U+01D6D1 */
+	350,						/* U+01D6D2 */
+	351,						/* U+01D6D3 */
+	3316,						/* U+01D6D4 */
+	3317,						/* U+01D6D5 */
+	3318,						/* U+01D6D6 */
+	347,						/* U+01D6D7 */
+	586,						/* U+01D6D8 */
+	3319,						/* U+01D6D9 */
+	3320,						/* U+01D6DA */
+	3321,						/* U+01D6DB */
+	3322,						/* U+01D6DC */
+	3323,						/* U+01D6DD */
+	3324,						/* U+01D6DE */
+	3325,						/* U+01D6DF */
+	3326,						/* U+01D6E0 */
+	3327,						/* U+01D6E1 */
+	3287,						/* U+01D6E2 */
+	3288,						/* U+01D6E3 */
+	1159,						/* U+01D6E4 */
+	3289,						/* U+01D6E5 */
+	3290,						/* U+01D6E6 */
+	3291,						/* U+01D6E7 */
+	3292,						/* U+01D6E8 */
+	352,						/* U+01D6E9 */
+	3293,						/* U+01D6EA */
+	3294,						/* U+01D6EB */
+	3295,						/* U+01D6EC */
+	3296,						/* U+01D6ED */
+	3297,						/* U+01D6EE */
+	3298,						/* U+01D6EF */
+	3299,						/* U+01D6F0 */
+	1160,						/* U+01D6F1 */
+	3300,						/* U+01D6F2 */
+	3301,						/* U+01D6F3 */
+	354,						/* U+01D6F4 */
+	3302,						/* U+01D6F5 */
+	344,						/* U+01D6F6 */
+	3303,						/* U+01D6F7 */
+	3304,						/* U+01D6F8 */
+	3305,						/* U+01D6F9 */
+	3306,						/* U+01D6FA */
+	3307,						/* U+01D6FB */
+	3308,						/* U+01D6FC */
+	342,						/* U+01D6FD */
+	584,						/* U+01D6FE */
+	585,						/* U+01D6FF */
+	353,						/* U+01D700 */
+	3309,						/* U+01D701 */
+	3310,						/* U+01D702 */
+	343,						/* U+01D703 */
+	3311,						/* U+01D704 */
+	349,						/* U+01D705 */
+	3312,						/* U+01D706 */
+	8,							/* U+01D707 */
+	3313,						/* U+01D708 */
+	3314,						/* U+01D709 */
+	3315,						/* U+01D70A */
+	348,						/* U+01D70B */
+	350,						/* U+01D70C */
+	351,						/* U+01D70D */
+	3316,						/* U+01D70E */
+	3317,						/* U+01D70F */
+	3318,						/* U+01D710 */
+	347,						/* U+01D711 */
+	586,						/* U+01D712 */
+	3319,						/* U+01D713 */
+	3320,						/* U+01D714 */
+	3321,						/* U+01D715 */
+	3322,						/* U+01D716 */
+	3323,						/* U+01D717 */
+	3324,						/* U+01D718 */
+	3325,						/* U+01D719 */
+	3326,						/* U+01D71A */
+	3327,						/* U+01D71B */
+	3287,						/* U+01D71C */
+	3288,						/* U+01D71D */
+	1159,						/* U+01D71E */
+	3289,						/* U+01D71F */
+	3290,						/* U+01D720 */
+	3291,						/* U+01D721 */
+	3292,						/* U+01D722 */
+	352,						/* U+01D723 */
+	3293,						/* U+01D724 */
+	3294,						/* U+01D725 */
+	3295,						/* U+01D726 */
+	3296,						/* U+01D727 */
+	3297,						/* U+01D728 */
+	3298,						/* U+01D729 */
+	3299,						/* U+01D72A */
+	1160,						/* U+01D72B */
+	3300,						/* U+01D72C */
+	3301,						/* U+01D72D */
+	354,						/* U+01D72E */
+	3302,						/* U+01D72F */
+	344,						/* U+01D730 */
+	3303,						/* U+01D731 */
+	3304,						/* U+01D732 */
+	3305,						/* U+01D733 */
+	3306,						/* U+01D734 */
+	3307,						/* U+01D735 */
+	3308,						/* U+01D736 */
+	342,						/* U+01D737 */
+	584,						/* U+01D738 */
+	585,						/* U+01D739 */
+	353,						/* U+01D73A */
+	3309,						/* U+01D73B */
+	3310,						/* U+01D73C */
+	343,						/* U+01D73D */
+	3311,						/* U+01D73E */
+	349,						/* U+01D73F */
+	3312,						/* U+01D740 */
+	8,							/* U+01D741 */
+	3313,						/* U+01D742 */
+	3314,						/* U+01D743 */
+	3315,						/* U+01D744 */
+	348,						/* U+01D745 */
+	350,						/* U+01D746 */
+	351,						/* U+01D747 */
+	3316,						/* U+01D748 */
+	3317,						/* U+01D749 */
+	3318,						/* U+01D74A */
+	347,						/* U+01D74B */
+	586,						/* U+01D74C */
+	3319,						/* U+01D74D */
+	3320,						/* U+01D74E */
+	3321,						/* U+01D74F */
+	3322,						/* U+01D750 */
+	3323,						/* U+01D751 */
+	3324,						/* U+01D752 */
+	3325,						/* U+01D753 */
+	3326,						/* U+01D754 */
+	3327,						/* U+01D755 */
+	3287,						/* U+01D756 */
+	3288,						/* U+01D757 */
+	1159,						/* U+01D758 */
+	3289,						/* U+01D759 */
+	3290,						/* U+01D75A */
+	3291,						/* U+01D75B */
+	3292,						/* U+01D75C */
+	352,						/* U+01D75D */
+	3293,						/* U+01D75E */
+	3294,						/* U+01D75F */
+	3295,						/* U+01D760 */
+	3296,						/* U+01D761 */
+	3297,						/* U+01D762 */
+	3298,						/* U+01D763 */
+	3299,						/* U+01D764 */
+	1160,						/* U+01D765 */
+	3300,						/* U+01D766 */
+	3301,						/* U+01D767 */
+	354,						/* U+01D768 */
+	3302,						/* U+01D769 */
+	344,						/* U+01D76A */
+	3303,						/* U+01D76B */
+	3304,						/* U+01D76C */
+	3305,						/* U+01D76D */
+	3306,						/* U+01D76E */
+	3307,						/* U+01D76F */
+	3308,						/* U+01D770 */
+	342,						/* U+01D771 */
+	584,						/* U+01D772 */
+	585,						/* U+01D773 */
+	353,						/* U+01D774 */
+	3309,						/* U+01D775 */
+	3310,						/* U+01D776 */
+	343,						/* U+01D777 */
+	3311,						/* U+01D778 */
+	349,						/* U+01D779 */
+	3312,						/* U+01D77A */
+	8,							/* U+01D77B */
+	3313,						/* U+01D77C */
+	3314,						/* U+01D77D */
+	3315,						/* U+01D77E */
+	348,						/* U+01D77F */
+	350,						/* U+01D780 */
+	351,						/* U+01D781 */
+	3316,						/* U+01D782 */
+	3317,						/* U+01D783 */
+	3318,						/* U+01D784 */
+	347,						/* U+01D785 */
+	586,						/* U+01D786 */
+	3319,						/* U+01D787 */
+	3320,						/* U+01D788 */
+	3321,						/* U+01D789 */
+	3322,						/* U+01D78A */
+	3323,						/* U+01D78B */
+	3324,						/* U+01D78C */
+	3325,						/* U+01D78D */
+	3326,						/* U+01D78E */
+	3327,						/* U+01D78F */
+	3287,						/* U+01D790 */
+	3288,						/* U+01D791 */
+	1159,						/* U+01D792 */
+	3289,						/* U+01D793 */
+	3290,						/* U+01D794 */
+	3291,						/* U+01D795 */
+	3292,						/* U+01D796 */
+	352,						/* U+01D797 */
+	3293,						/* U+01D798 */
+	3294,						/* U+01D799 */
+	3295,						/* U+01D79A */
+	3296,						/* U+01D79B */
+	3297,						/* U+01D79C */
+	3298,						/* U+01D79D */
+	3299,						/* U+01D79E */
+	1160,						/* U+01D79F */
+	3300,						/* U+01D7A0 */
+	3301,						/* U+01D7A1 */
+	354,						/* U+01D7A2 */
+	3302,						/* U+01D7A3 */
+	344,						/* U+01D7A4 */
+	3303,						/* U+01D7A5 */
+	3304,						/* U+01D7A6 */
+	3305,						/* U+01D7A7 */
+	3306,						/* U+01D7A8 */
+	3307,						/* U+01D7A9 */
+	3308,						/* U+01D7AA */
+	342,						/* U+01D7AB */
+	584,						/* U+01D7AC */
+	585,						/* U+01D7AD */
+	353,						/* U+01D7AE */
+	3309,						/* U+01D7AF */
+	3310,						/* U+01D7B0 */
+	343,						/* U+01D7B1 */
+	3311,						/* U+01D7B2 */
+	349,						/* U+01D7B3 */
+	3312,						/* U+01D7B4 */
+	8,							/* U+01D7B5 */
+	3313,						/* U+01D7B6 */
+	3314,						/* U+01D7B7 */
+	3315,						/* U+01D7B8 */
+	348,						/* U+01D7B9 */
+	350,						/* U+01D7BA */
+	351,						/* U+01D7BB */
+	3316,						/* U+01D7BC */
+	3317,						/* U+01D7BD */
+	3318,						/* U+01D7BE */
+	347,						/* U+01D7BF */
+	586,						/* U+01D7C0 */
+	3319,						/* U+01D7C1 */
+	3320,						/* U+01D7C2 */
+	3321,						/* U+01D7C3 */
+	3322,						/* U+01D7C4 */
+	3323,						/* U+01D7C5 */
+	3324,						/* U+01D7C6 */
+	3325,						/* U+01D7C7 */
+	3326,						/* U+01D7C8 */
+	3327,						/* U+01D7C9 */
+	3328,						/* U+01D7CA */
+	3329,						/* U+01D7CB */
+	0,							/* U+01D7CC */
+	0,							/* U+01D7CD */
+	1121,						/* U+01D7CE */
+	10,							/* U+01D7CF */
+	5,							/* U+01D7D0 */
+	6,							/* U+01D7D1 */
+	1122,						/* U+01D7D2 */
+	1123,						/* U+01D7D3 */
+	1124,						/* U+01D7D4 */
+	1125,						/* U+01D7D5 */
+	1126,						/* U+01D7D6 */
+	1127,						/* U+01D7D7 */
+	1121,						/* U+01D7D8 */
+	10,							/* U+01D7D9 */
+	5,							/* U+01D7DA */
+	6,							/* U+01D7DB */
+	1122,						/* U+01D7DC */
+	1123,						/* U+01D7DD */
+	1124,						/* U+01D7DE */
+	1125,						/* U+01D7DF */
+	1126,						/* U+01D7E0 */
+	1127,						/* U+01D7E1 */
+	1121,						/* U+01D7E2 */
+	10,							/* U+01D7E3 */
+	5,							/* U+01D7E4 */
+	6,							/* U+01D7E5 */
+	1122,						/* U+01D7E6 */
+	1123,						/* U+01D7E7 */
+	1124,						/* U+01D7E8 */
+	1125,						/* U+01D7E9 */
+	1126,						/* U+01D7EA */
+	1127,						/* U+01D7EB */
+	1121,						/* U+01D7EC */
+	10,							/* U+01D7ED */
+	5,							/* U+01D7EE */
+	6,							/* U+01D7EF */
+	1122,						/* U+01D7F0 */
+	1123,						/* U+01D7F1 */
+	1124,						/* U+01D7F2 */
+	1125,						/* U+01D7F3 */
+	1126,						/* U+01D7F4 */
+	1127,						/* U+01D7F5 */
+	1121,						/* U+01D7F6 */
+	10,							/* U+01D7F7 */
+	5,							/* U+01D7F8 */
+	6,							/* U+01D7F9 */
+	1122,						/* U+01D7FA */
+	1123,						/* U+01D7FB */
+	1124,						/* U+01D7FC */
+	1125,						/* U+01D7FD */
+	1126,						/* U+01D7FE */
+	1127,						/* U+01D7FF */
+	304,						/* U+01E000 */
+	304,						/* U+01E001 */
+	304,						/* U+01E002 */
+	304,						/* U+01E003 */
+	304,						/* U+01E004 */
+	304,						/* U+01E005 */
+	304,						/* U+01E006 */
+	0,							/* U+01E007 */
+	304,						/* U+01E008 */
+	304,						/* U+01E009 */
+	304,						/* U+01E00A */
+	304,						/* U+01E00B */
+	304,						/* U+01E00C */
+	304,						/* U+01E00D */
+	304,						/* U+01E00E */
+	304,						/* U+01E00F */
+	304,						/* U+01E010 */
+	304,						/* U+01E011 */
+	304,						/* U+01E012 */
+	304,						/* U+01E013 */
+	304,						/* U+01E014 */
+	304,						/* U+01E015 */
+	304,						/* U+01E016 */
+	304,						/* U+01E017 */
+	304,						/* U+01E018 */
+	0,							/* U+01E019 */
+	0,							/* U+01E01A */
+	304,						/* U+01E01B */
+	304,						/* U+01E01C */
+	304,						/* U+01E01D */
+	304,						/* U+01E01E */
+	304,						/* U+01E01F */
+	304,						/* U+01E020 */
+	304,						/* U+01E021 */
+	0,							/* U+01E022 */
+	304,						/* U+01E023 */
+	304,						/* U+01E024 */
+	0,							/* U+01E025 */
+	304,						/* U+01E026 */
+	304,						/* U+01E027 */
+	304,						/* U+01E028 */
+	304,						/* U+01E029 */
+	304,						/* U+01E02A */
+	0,							/* U+01E02B */
+	0,							/* U+01E02C */
+	0,							/* U+01E02D */
+	0,							/* U+01E02E */
+	0,							/* U+01E02F */
+	3330,						/* U+01E030 */
+	3331,						/* U+01E031 */
+	3332,						/* U+01E032 */
+	3333,						/* U+01E033 */
+	3334,						/* U+01E034 */
+	3335,						/* U+01E035 */
+	3336,						/* U+01E036 */
+	3337,						/* U+01E037 */
+	3338,						/* U+01E038 */
+	3339,						/* U+01E039 */
+	3340,						/* U+01E03A */
+	3341,						/* U+01E03B */
+	3342,						/* U+01E03C */
+	3343,						/* U+01E03D */
+	3344,						/* U+01E03E */
+	3345,						/* U+01E03F */
+	3346,						/* U+01E040 */
+	3347,						/* U+01E041 */
+	3348,						/* U+01E042 */
+	3349,						/* U+01E043 */
+	3350,						/* U+01E044 */
+	3351,						/* U+01E045 */
+	3352,						/* U+01E046 */
+	3353,						/* U+01E047 */
+	3354,						/* U+01E048 */
+	3355,						/* U+01E049 */
+	3356,						/* U+01E04A */
+	3357,						/* U+01E04B */
+	3358,						/* U+01E04C */
+	3359,						/* U+01E04D */
+	3360,						/* U+01E04E */
+	3361,						/* U+01E04F */
+	3362,						/* U+01E050 */
+	3330,						/* U+01E051 */
+	3331,						/* U+01E052 */
+	3332,						/* U+01E053 */
+	3333,						/* U+01E054 */
+	3334,						/* U+01E055 */
+	3335,						/* U+01E056 */
+	3336,						/* U+01E057 */
+	3337,						/* U+01E058 */
+	3338,						/* U+01E059 */
+	3339,						/* U+01E05A */
+	3340,						/* U+01E05B */
+	3342,						/* U+01E05C */
+	3343,						/* U+01E05D */
+	3345,						/* U+01E05E */
+	3347,						/* U+01E05F */
+	3348,						/* U+01E060 */
+	3349,						/* U+01E061 */
+	3350,						/* U+01E062 */
+	3351,						/* U+01E063 */
+	3352,						/* U+01E064 */
+	2192,						/* U+01E065 */
+	3353,						/* U+01E066 */
+	3363,						/* U+01E067 */
+	3358,						/* U+01E068 */
+	3364,						/* U+01E069 */
+	3365,						/* U+01E06A */
+	3366,						/* U+01E06B */
+	3367,						/* U+01E06C */
+	3368,						/* U+01E06D */
+	0,							/* U+01E06E */
+	0,							/* U+01E06F */
+	0,							/* U+01E070 */
+	0,							/* U+01E071 */
+	0,							/* U+01E072 */
+	0,							/* U+01E073 */
+	0,							/* U+01E074 */
+	0,							/* U+01E075 */
+	0,							/* U+01E076 */
+	0,							/* U+01E077 */
+	0,							/* U+01E078 */
+	0,							/* U+01E079 */
+	0,							/* U+01E07A */
+	0,							/* U+01E07B */
+	0,							/* U+01E07C */
+	0,							/* U+01E07D */
+	0,							/* U+01E07E */
+	0,							/* U+01E07F */
+	0,							/* U+01E080 */
+	0,							/* U+01E081 */
+	0,							/* U+01E082 */
+	0,							/* U+01E083 */
+	0,							/* U+01E084 */
+	0,							/* U+01E085 */
+	0,							/* U+01E086 */
+	0,							/* U+01E087 */
+	0,							/* U+01E088 */
+	0,							/* U+01E089 */
+	0,							/* U+01E08A */
+	0,							/* U+01E08B */
+	0,							/* U+01E08C */
+	0,							/* U+01E08D */
+	0,							/* U+01E08E */
+	304,						/* U+01E08F */
+	0,							/* U+01E090 */
+	0,							/* U+01E091 */
+	0,							/* U+01E092 */
+	0,							/* U+01E093 */
+	0,							/* U+01E094 */
+	0,							/* U+01E095 */
+	0,							/* U+01E096 */
+	0,							/* U+01E097 */
+	0,							/* U+01E098 */
+	0,							/* U+01E099 */
+	0,							/* U+01E09A */
+	0,							/* U+01E09B */
+	0,							/* U+01E09C */
+	0,							/* U+01E09D */
+	0,							/* U+01E09E */
+	0,							/* U+01E09F */
+	0,							/* U+01E0A0 */
+	0,							/* U+01E0A1 */
+	0,							/* U+01E0A2 */
+	0,							/* U+01E0A3 */
+	0,							/* U+01E0A4 */
+	0,							/* U+01E0A5 */
+	0,							/* U+01E0A6 */
+	0,							/* U+01E0A7 */
+	0,							/* U+01E0A8 */
+	0,							/* U+01E0A9 */
+	0,							/* U+01E0AA */
+	0,							/* U+01E0AB */
+	0,							/* U+01E0AC */
+	0,							/* U+01E0AD */
+	0,							/* U+01E0AE */
+	0,							/* U+01E0AF */
+	0,							/* U+01E0B0 */
+	0,							/* U+01E0B1 */
+	0,							/* U+01E0B2 */
+	0,							/* U+01E0B3 */
+	0,							/* U+01E0B4 */
+	0,							/* U+01E0B5 */
+	0,							/* U+01E0B6 */
+	0,							/* U+01E0B7 */
+	0,							/* U+01E0B8 */
+	0,							/* U+01E0B9 */
+	0,							/* U+01E0BA */
+	0,							/* U+01E0BB */
+	0,							/* U+01E0BC */
+	0,							/* U+01E0BD */
+	0,							/* U+01E0BE */
+	0,							/* U+01E0BF */
+	0,							/* U+01E0C0 */
+	0,							/* U+01E0C1 */
+	0,							/* U+01E0C2 */
+	0,							/* U+01E0C3 */
+	0,							/* U+01E0C4 */
+	0,							/* U+01E0C5 */
+	0,							/* U+01E0C6 */
+	0,							/* U+01E0C7 */
+	0,							/* U+01E0C8 */
+	0,							/* U+01E0C9 */
+	0,							/* U+01E0CA */
+	0,							/* U+01E0CB */
+	0,							/* U+01E0CC */
+	0,							/* U+01E0CD */
+	0,							/* U+01E0CE */
+	0,							/* U+01E0CF */
+	0,							/* U+01E0D0 */
+	0,							/* U+01E0D1 */
+	0,							/* U+01E0D2 */
+	0,							/* U+01E0D3 */
+	0,							/* U+01E0D4 */
+	0,							/* U+01E0D5 */
+	0,							/* U+01E0D6 */
+	0,							/* U+01E0D7 */
+	0,							/* U+01E0D8 */
+	0,							/* U+01E0D9 */
+	0,							/* U+01E0DA */
+	0,							/* U+01E0DB */
+	0,							/* U+01E0DC */
+	0,							/* U+01E0DD */
+	0,							/* U+01E0DE */
+	0,							/* U+01E0DF */
+	0,							/* U+01E0E0 */
+	0,							/* U+01E0E1 */
+	0,							/* U+01E0E2 */
+	0,							/* U+01E0E3 */
+	0,							/* U+01E0E4 */
+	0,							/* U+01E0E5 */
+	0,							/* U+01E0E6 */
+	0,							/* U+01E0E7 */
+	0,							/* U+01E0E8 */
+	0,							/* U+01E0E9 */
+	0,							/* U+01E0EA */
+	0,							/* U+01E0EB */
+	0,							/* U+01E0EC */
+	0,							/* U+01E0ED */
+	0,							/* U+01E0EE */
+	0,							/* U+01E0EF */
+	0,							/* U+01E0F0 */
+	0,							/* U+01E0F1 */
+	0,							/* U+01E0F2 */
+	0,							/* U+01E0F3 */
+	0,							/* U+01E0F4 */
+	0,							/* U+01E0F5 */
+	0,							/* U+01E0F6 */
+	0,							/* U+01E0F7 */
+	0,							/* U+01E0F8 */
+	0,							/* U+01E0F9 */
+	0,							/* U+01E0FA */
+	0,							/* U+01E0FB */
+	0,							/* U+01E0FC */
+	0,							/* U+01E0FD */
+	0,							/* U+01E0FE */
+	0,							/* U+01E0FF */
+	0,							/* U+01E100 */
+	0,							/* U+01E101 */
+	0,							/* U+01E102 */
+	0,							/* U+01E103 */
+	0,							/* U+01E104 */
+	0,							/* U+01E105 */
+	0,							/* U+01E106 */
+	0,							/* U+01E107 */
+	0,							/* U+01E108 */
+	0,							/* U+01E109 */
+	0,							/* U+01E10A */
+	0,							/* U+01E10B */
+	0,							/* U+01E10C */
+	0,							/* U+01E10D */
+	0,							/* U+01E10E */
+	0,							/* U+01E10F */
+	0,							/* U+01E110 */
+	0,							/* U+01E111 */
+	0,							/* U+01E112 */
+	0,							/* U+01E113 */
+	0,							/* U+01E114 */
+	0,							/* U+01E115 */
+	0,							/* U+01E116 */
+	0,							/* U+01E117 */
+	0,							/* U+01E118 */
+	0,							/* U+01E119 */
+	0,							/* U+01E11A */
+	0,							/* U+01E11B */
+	0,							/* U+01E11C */
+	0,							/* U+01E11D */
+	0,							/* U+01E11E */
+	0,							/* U+01E11F */
+	0,							/* U+01E120 */
+	0,							/* U+01E121 */
+	0,							/* U+01E122 */
+	0,							/* U+01E123 */
+	0,							/* U+01E124 */
+	0,							/* U+01E125 */
+	0,							/* U+01E126 */
+	0,							/* U+01E127 */
+	0,							/* U+01E128 */
+	0,							/* U+01E129 */
+	0,							/* U+01E12A */
+	0,							/* U+01E12B */
+	0,							/* U+01E12C */
+	0,							/* U+01E12D */
+	0,							/* U+01E12E */
+	0,							/* U+01E12F */
+	304,						/* U+01E130 */
+	304,						/* U+01E131 */
+	304,						/* U+01E132 */
+	304,						/* U+01E133 */
+	304,						/* U+01E134 */
+	304,						/* U+01E135 */
+	304,						/* U+01E136 */
+	0,							/* U+01E137 */
+	0,							/* U+01E138 */
+	0,							/* U+01E139 */
+	0,							/* U+01E13A */
+	0,							/* U+01E13B */
+	0,							/* U+01E13C */
+	0,							/* U+01E13D */
+	0,							/* U+01E13E */
+	0,							/* U+01E13F */
+	0,							/* U+01E140 */
+	0,							/* U+01E141 */
+	0,							/* U+01E142 */
+	0,							/* U+01E143 */
+	0,							/* U+01E144 */
+	0,							/* U+01E145 */
+	0,							/* U+01E146 */
+	0,							/* U+01E147 */
+	0,							/* U+01E148 */
+	0,							/* U+01E149 */
+	0,							/* U+01E14A */
+	0,							/* U+01E14B */
+	0,							/* U+01E14C */
+	0,							/* U+01E14D */
+	0,							/* U+01E14E */
+	0,							/* U+01E14F */
+	0,							/* U+01E150 */
+	0,							/* U+01E151 */
+	0,							/* U+01E152 */
+	0,							/* U+01E153 */
+	0,							/* U+01E154 */
+	0,							/* U+01E155 */
+	0,							/* U+01E156 */
+	0,							/* U+01E157 */
+	0,							/* U+01E158 */
+	0,							/* U+01E159 */
+	0,							/* U+01E15A */
+	0,							/* U+01E15B */
+	0,							/* U+01E15C */
+	0,							/* U+01E15D */
+	0,							/* U+01E15E */
+	0,							/* U+01E15F */
+	0,							/* U+01E160 */
+	0,							/* U+01E161 */
+	0,							/* U+01E162 */
+	0,							/* U+01E163 */
+	0,							/* U+01E164 */
+	0,							/* U+01E165 */
+	0,							/* U+01E166 */
+	0,							/* U+01E167 */
+	0,							/* U+01E168 */
+	0,							/* U+01E169 */
+	0,							/* U+01E16A */
+	0,							/* U+01E16B */
+	0,							/* U+01E16C */
+	0,							/* U+01E16D */
+	0,							/* U+01E16E */
+	0,							/* U+01E16F */
+	0,							/* U+01E170 */
+	0,							/* U+01E171 */
+	0,							/* U+01E172 */
+	0,							/* U+01E173 */
+	0,							/* U+01E174 */
+	0,							/* U+01E175 */
+	0,							/* U+01E176 */
+	0,							/* U+01E177 */
+	0,							/* U+01E178 */
+	0,							/* U+01E179 */
+	0,							/* U+01E17A */
+	0,							/* U+01E17B */
+	0,							/* U+01E17C */
+	0,							/* U+01E17D */
+	0,							/* U+01E17E */
+	0,							/* U+01E17F */
+	0,							/* U+01E180 */
+	0,							/* U+01E181 */
+	0,							/* U+01E182 */
+	0,							/* U+01E183 */
+	0,							/* U+01E184 */
+	0,							/* U+01E185 */
+	0,							/* U+01E186 */
+	0,							/* U+01E187 */
+	0,							/* U+01E188 */
+	0,							/* U+01E189 */
+	0,							/* U+01E18A */
+	0,							/* U+01E18B */
+	0,							/* U+01E18C */
+	0,							/* U+01E18D */
+	0,							/* U+01E18E */
+	0,							/* U+01E18F */
+	0,							/* U+01E190 */
+	0,							/* U+01E191 */
+	0,							/* U+01E192 */
+	0,							/* U+01E193 */
+	0,							/* U+01E194 */
+	0,							/* U+01E195 */
+	0,							/* U+01E196 */
+	0,							/* U+01E197 */
+	0,							/* U+01E198 */
+	0,							/* U+01E199 */
+	0,							/* U+01E19A */
+	0,							/* U+01E19B */
+	0,							/* U+01E19C */
+	0,							/* U+01E19D */
+	0,							/* U+01E19E */
+	0,							/* U+01E19F */
+	0,							/* U+01E1A0 */
+	0,							/* U+01E1A1 */
+	0,							/* U+01E1A2 */
+	0,							/* U+01E1A3 */
+	0,							/* U+01E1A4 */
+	0,							/* U+01E1A5 */
+	0,							/* U+01E1A6 */
+	0,							/* U+01E1A7 */
+	0,							/* U+01E1A8 */
+	0,							/* U+01E1A9 */
+	0,							/* U+01E1AA */
+	0,							/* U+01E1AB */
+	0,							/* U+01E1AC */
+	0,							/* U+01E1AD */
+	0,							/* U+01E1AE */
+	0,							/* U+01E1AF */
+	0,							/* U+01E1B0 */
+	0,							/* U+01E1B1 */
+	0,							/* U+01E1B2 */
+	0,							/* U+01E1B3 */
+	0,							/* U+01E1B4 */
+	0,							/* U+01E1B5 */
+	0,							/* U+01E1B6 */
+	0,							/* U+01E1B7 */
+	0,							/* U+01E1B8 */
+	0,							/* U+01E1B9 */
+	0,							/* U+01E1BA */
+	0,							/* U+01E1BB */
+	0,							/* U+01E1BC */
+	0,							/* U+01E1BD */
+	0,							/* U+01E1BE */
+	0,							/* U+01E1BF */
+	0,							/* U+01E1C0 */
+	0,							/* U+01E1C1 */
+	0,							/* U+01E1C2 */
+	0,							/* U+01E1C3 */
+	0,							/* U+01E1C4 */
+	0,							/* U+01E1C5 */
+	0,							/* U+01E1C6 */
+	0,							/* U+01E1C7 */
+	0,							/* U+01E1C8 */
+	0,							/* U+01E1C9 */
+	0,							/* U+01E1CA */
+	0,							/* U+01E1CB */
+	0,							/* U+01E1CC */
+	0,							/* U+01E1CD */
+	0,							/* U+01E1CE */
+	0,							/* U+01E1CF */
+	0,							/* U+01E1D0 */
+	0,							/* U+01E1D1 */
+	0,							/* U+01E1D2 */
+	0,							/* U+01E1D3 */
+	0,							/* U+01E1D4 */
+	0,							/* U+01E1D5 */
+	0,							/* U+01E1D6 */
+	0,							/* U+01E1D7 */
+	0,							/* U+01E1D8 */
+	0,							/* U+01E1D9 */
+	0,							/* U+01E1DA */
+	0,							/* U+01E1DB */
+	0,							/* U+01E1DC */
+	0,							/* U+01E1DD */
+	0,							/* U+01E1DE */
+	0,							/* U+01E1DF */
+	0,							/* U+01E1E0 */
+	0,							/* U+01E1E1 */
+	0,							/* U+01E1E2 */
+	0,							/* U+01E1E3 */
+	0,							/* U+01E1E4 */
+	0,							/* U+01E1E5 */
+	0,							/* U+01E1E6 */
+	0,							/* U+01E1E7 */
+	0,							/* U+01E1E8 */
+	0,							/* U+01E1E9 */
+	0,							/* U+01E1EA */
+	0,							/* U+01E1EB */
+	0,							/* U+01E1EC */
+	0,							/* U+01E1ED */
+	0,							/* U+01E1EE */
+	0,							/* U+01E1EF */
+	0,							/* U+01E1F0 */
+	0,							/* U+01E1F1 */
+	0,							/* U+01E1F2 */
+	0,							/* U+01E1F3 */
+	0,							/* U+01E1F4 */
+	0,							/* U+01E1F5 */
+	0,							/* U+01E1F6 */
+	0,							/* U+01E1F7 */
+	0,							/* U+01E1F8 */
+	0,							/* U+01E1F9 */
+	0,							/* U+01E1FA */
+	0,							/* U+01E1FB */
+	0,							/* U+01E1FC */
+	0,							/* U+01E1FD */
+	0,							/* U+01E1FE */
+	0,							/* U+01E1FF */
+	0,							/* U+01E200 */
+	0,							/* U+01E201 */
+	0,							/* U+01E202 */
+	0,							/* U+01E203 */
+	0,							/* U+01E204 */
+	0,							/* U+01E205 */
+	0,							/* U+01E206 */
+	0,							/* U+01E207 */
+	0,							/* U+01E208 */
+	0,							/* U+01E209 */
+	0,							/* U+01E20A */
+	0,							/* U+01E20B */
+	0,							/* U+01E20C */
+	0,							/* U+01E20D */
+	0,							/* U+01E20E */
+	0,							/* U+01E20F */
+	0,							/* U+01E210 */
+	0,							/* U+01E211 */
+	0,							/* U+01E212 */
+	0,							/* U+01E213 */
+	0,							/* U+01E214 */
+	0,							/* U+01E215 */
+	0,							/* U+01E216 */
+	0,							/* U+01E217 */
+	0,							/* U+01E218 */
+	0,							/* U+01E219 */
+	0,							/* U+01E21A */
+	0,							/* U+01E21B */
+	0,							/* U+01E21C */
+	0,							/* U+01E21D */
+	0,							/* U+01E21E */
+	0,							/* U+01E21F */
+	0,							/* U+01E220 */
+	0,							/* U+01E221 */
+	0,							/* U+01E222 */
+	0,							/* U+01E223 */
+	0,							/* U+01E224 */
+	0,							/* U+01E225 */
+	0,							/* U+01E226 */
+	0,							/* U+01E227 */
+	0,							/* U+01E228 */
+	0,							/* U+01E229 */
+	0,							/* U+01E22A */
+	0,							/* U+01E22B */
+	0,							/* U+01E22C */
+	0,							/* U+01E22D */
+	0,							/* U+01E22E */
+	0,							/* U+01E22F */
+	0,							/* U+01E230 */
+	0,							/* U+01E231 */
+	0,							/* U+01E232 */
+	0,							/* U+01E233 */
+	0,							/* U+01E234 */
+	0,							/* U+01E235 */
+	0,							/* U+01E236 */
+	0,							/* U+01E237 */
+	0,							/* U+01E238 */
+	0,							/* U+01E239 */
+	0,							/* U+01E23A */
+	0,							/* U+01E23B */
+	0,							/* U+01E23C */
+	0,							/* U+01E23D */
+	0,							/* U+01E23E */
+	0,							/* U+01E23F */
+	0,							/* U+01E240 */
+	0,							/* U+01E241 */
+	0,							/* U+01E242 */
+	0,							/* U+01E243 */
+	0,							/* U+01E244 */
+	0,							/* U+01E245 */
+	0,							/* U+01E246 */
+	0,							/* U+01E247 */
+	0,							/* U+01E248 */
+	0,							/* U+01E249 */
+	0,							/* U+01E24A */
+	0,							/* U+01E24B */
+	0,							/* U+01E24C */
+	0,							/* U+01E24D */
+	0,							/* U+01E24E */
+	0,							/* U+01E24F */
+	0,							/* U+01E250 */
+	0,							/* U+01E251 */
+	0,							/* U+01E252 */
+	0,							/* U+01E253 */
+	0,							/* U+01E254 */
+	0,							/* U+01E255 */
+	0,							/* U+01E256 */
+	0,							/* U+01E257 */
+	0,							/* U+01E258 */
+	0,							/* U+01E259 */
+	0,							/* U+01E25A */
+	0,							/* U+01E25B */
+	0,							/* U+01E25C */
+	0,							/* U+01E25D */
+	0,							/* U+01E25E */
+	0,							/* U+01E25F */
+	0,							/* U+01E260 */
+	0,							/* U+01E261 */
+	0,							/* U+01E262 */
+	0,							/* U+01E263 */
+	0,							/* U+01E264 */
+	0,							/* U+01E265 */
+	0,							/* U+01E266 */
+	0,							/* U+01E267 */
+	0,							/* U+01E268 */
+	0,							/* U+01E269 */
+	0,							/* U+01E26A */
+	0,							/* U+01E26B */
+	0,							/* U+01E26C */
+	0,							/* U+01E26D */
+	0,							/* U+01E26E */
+	0,							/* U+01E26F */
+	0,							/* U+01E270 */
+	0,							/* U+01E271 */
+	0,							/* U+01E272 */
+	0,							/* U+01E273 */
+	0,							/* U+01E274 */
+	0,							/* U+01E275 */
+	0,							/* U+01E276 */
+	0,							/* U+01E277 */
+	0,							/* U+01E278 */
+	0,							/* U+01E279 */
+	0,							/* U+01E27A */
+	0,							/* U+01E27B */
+	0,							/* U+01E27C */
+	0,							/* U+01E27D */
+	0,							/* U+01E27E */
+	0,							/* U+01E27F */
+	0,							/* U+01E280 */
+	0,							/* U+01E281 */
+	0,							/* U+01E282 */
+	0,							/* U+01E283 */
+	0,							/* U+01E284 */
+	0,							/* U+01E285 */
+	0,							/* U+01E286 */
+	0,							/* U+01E287 */
+	0,							/* U+01E288 */
+	0,							/* U+01E289 */
+	0,							/* U+01E28A */
+	0,							/* U+01E28B */
+	0,							/* U+01E28C */
+	0,							/* U+01E28D */
+	0,							/* U+01E28E */
+	0,							/* U+01E28F */
+	0,							/* U+01E290 */
+	0,							/* U+01E291 */
+	0,							/* U+01E292 */
+	0,							/* U+01E293 */
+	0,							/* U+01E294 */
+	0,							/* U+01E295 */
+	0,							/* U+01E296 */
+	0,							/* U+01E297 */
+	0,							/* U+01E298 */
+	0,							/* U+01E299 */
+	0,							/* U+01E29A */
+	0,							/* U+01E29B */
+	0,							/* U+01E29C */
+	0,							/* U+01E29D */
+	0,							/* U+01E29E */
+	0,							/* U+01E29F */
+	0,							/* U+01E2A0 */
+	0,							/* U+01E2A1 */
+	0,							/* U+01E2A2 */
+	0,							/* U+01E2A3 */
+	0,							/* U+01E2A4 */
+	0,							/* U+01E2A5 */
+	0,							/* U+01E2A6 */
+	0,							/* U+01E2A7 */
+	0,							/* U+01E2A8 */
+	0,							/* U+01E2A9 */
+	0,							/* U+01E2AA */
+	0,							/* U+01E2AB */
+	0,							/* U+01E2AC */
+	0,							/* U+01E2AD */
+	304,						/* U+01E2AE */
+	0,							/* U+01E2AF */
+	0,							/* U+01E2B0 */
+	0,							/* U+01E2B1 */
+	0,							/* U+01E2B2 */
+	0,							/* U+01E2B3 */
+	0,							/* U+01E2B4 */
+	0,							/* U+01E2B5 */
+	0,							/* U+01E2B6 */
+	0,							/* U+01E2B7 */
+	0,							/* U+01E2B8 */
+	0,							/* U+01E2B9 */
+	0,							/* U+01E2BA */
+	0,							/* U+01E2BB */
+	0,							/* U+01E2BC */
+	0,							/* U+01E2BD */
+	0,							/* U+01E2BE */
+	0,							/* U+01E2BF */
+	0,							/* U+01E2C0 */
+	0,							/* U+01E2C1 */
+	0,							/* U+01E2C2 */
+	0,							/* U+01E2C3 */
+	0,							/* U+01E2C4 */
+	0,							/* U+01E2C5 */
+	0,							/* U+01E2C6 */
+	0,							/* U+01E2C7 */
+	0,							/* U+01E2C8 */
+	0,							/* U+01E2C9 */
+	0,							/* U+01E2CA */
+	0,							/* U+01E2CB */
+	0,							/* U+01E2CC */
+	0,							/* U+01E2CD */
+	0,							/* U+01E2CE */
+	0,							/* U+01E2CF */
+	0,							/* U+01E2D0 */
+	0,							/* U+01E2D1 */
+	0,							/* U+01E2D2 */
+	0,							/* U+01E2D3 */
+	0,							/* U+01E2D4 */
+	0,							/* U+01E2D5 */
+	0,							/* U+01E2D6 */
+	0,							/* U+01E2D7 */
+	0,							/* U+01E2D8 */
+	0,							/* U+01E2D9 */
+	0,							/* U+01E2DA */
+	0,							/* U+01E2DB */
+	0,							/* U+01E2DC */
+	0,							/* U+01E2DD */
+	0,							/* U+01E2DE */
+	0,							/* U+01E2DF */
+	0,							/* U+01E2E0 */
+	0,							/* U+01E2E1 */
+	0,							/* U+01E2E2 */
+	0,							/* U+01E2E3 */
+	0,							/* U+01E2E4 */
+	0,							/* U+01E2E5 */
+	0,							/* U+01E2E6 */
+	0,							/* U+01E2E7 */
+	0,							/* U+01E2E8 */
+	0,							/* U+01E2E9 */
+	0,							/* U+01E2EA */
+	0,							/* U+01E2EB */
+	304,						/* U+01E2EC */
+	304,						/* U+01E2ED */
+	304,						/* U+01E2EE */
+	304,						/* U+01E2EF */
+	0,							/* U+01E2F0 */
+	0,							/* U+01E2F1 */
+	0,							/* U+01E2F2 */
+	0,							/* U+01E2F3 */
+	0,							/* U+01E2F4 */
+	0,							/* U+01E2F5 */
+	0,							/* U+01E2F6 */
+	0,							/* U+01E2F7 */
+	0,							/* U+01E2F8 */
+	0,							/* U+01E2F9 */
+	0,							/* U+01E2FA */
+	0,							/* U+01E2FB */
+	0,							/* U+01E2FC */
+	0,							/* U+01E2FD */
+	0,							/* U+01E2FE */
+	0,							/* U+01E2FF */
+	0,							/* U+01E300 */
+	0,							/* U+01E301 */
+	0,							/* U+01E302 */
+	0,							/* U+01E303 */
+	0,							/* U+01E304 */
+	0,							/* U+01E305 */
+	0,							/* U+01E306 */
+	0,							/* U+01E307 */
+	0,							/* U+01E308 */
+	0,							/* U+01E309 */
+	0,							/* U+01E30A */
+	0,							/* U+01E30B */
+	0,							/* U+01E30C */
+	0,							/* U+01E30D */
+	0,							/* U+01E30E */
+	0,							/* U+01E30F */
+	0,							/* U+01E310 */
+	0,							/* U+01E311 */
+	0,							/* U+01E312 */
+	0,							/* U+01E313 */
+	0,							/* U+01E314 */
+	0,							/* U+01E315 */
+	0,							/* U+01E316 */
+	0,							/* U+01E317 */
+	0,							/* U+01E318 */
+	0,							/* U+01E319 */
+	0,							/* U+01E31A */
+	0,							/* U+01E31B */
+	0,							/* U+01E31C */
+	0,							/* U+01E31D */
+	0,							/* U+01E31E */
+	0,							/* U+01E31F */
+	0,							/* U+01E320 */
+	0,							/* U+01E321 */
+	0,							/* U+01E322 */
+	0,							/* U+01E323 */
+	0,							/* U+01E324 */
+	0,							/* U+01E325 */
+	0,							/* U+01E326 */
+	0,							/* U+01E327 */
+	0,							/* U+01E328 */
+	0,							/* U+01E329 */
+	0,							/* U+01E32A */
+	0,							/* U+01E32B */
+	0,							/* U+01E32C */
+	0,							/* U+01E32D */
+	0,							/* U+01E32E */
+	0,							/* U+01E32F */
+	0,							/* U+01E330 */
+	0,							/* U+01E331 */
+	0,							/* U+01E332 */
+	0,							/* U+01E333 */
+	0,							/* U+01E334 */
+	0,							/* U+01E335 */
+	0,							/* U+01E336 */
+	0,							/* U+01E337 */
+	0,							/* U+01E338 */
+	0,							/* U+01E339 */
+	0,							/* U+01E33A */
+	0,							/* U+01E33B */
+	0,							/* U+01E33C */
+	0,							/* U+01E33D */
+	0,							/* U+01E33E */
+	0,							/* U+01E33F */
+	0,							/* U+01E340 */
+	0,							/* U+01E341 */
+	0,							/* U+01E342 */
+	0,							/* U+01E343 */
+	0,							/* U+01E344 */
+	0,							/* U+01E345 */
+	0,							/* U+01E346 */
+	0,							/* U+01E347 */
+	0,							/* U+01E348 */
+	0,							/* U+01E349 */
+	0,							/* U+01E34A */
+	0,							/* U+01E34B */
+	0,							/* U+01E34C */
+	0,							/* U+01E34D */
+	0,							/* U+01E34E */
+	0,							/* U+01E34F */
+	0,							/* U+01E350 */
+	0,							/* U+01E351 */
+	0,							/* U+01E352 */
+	0,							/* U+01E353 */
+	0,							/* U+01E354 */
+	0,							/* U+01E355 */
+	0,							/* U+01E356 */
+	0,							/* U+01E357 */
+	0,							/* U+01E358 */
+	0,							/* U+01E359 */
+	0,							/* U+01E35A */
+	0,							/* U+01E35B */
+	0,							/* U+01E35C */
+	0,							/* U+01E35D */
+	0,							/* U+01E35E */
+	0,							/* U+01E35F */
+	0,							/* U+01E360 */
+	0,							/* U+01E361 */
+	0,							/* U+01E362 */
+	0,							/* U+01E363 */
+	0,							/* U+01E364 */
+	0,							/* U+01E365 */
+	0,							/* U+01E366 */
+	0,							/* U+01E367 */
+	0,							/* U+01E368 */
+	0,							/* U+01E369 */
+	0,							/* U+01E36A */
+	0,							/* U+01E36B */
+	0,							/* U+01E36C */
+	0,							/* U+01E36D */
+	0,							/* U+01E36E */
+	0,							/* U+01E36F */
+	0,							/* U+01E370 */
+	0,							/* U+01E371 */
+	0,							/* U+01E372 */
+	0,							/* U+01E373 */
+	0,							/* U+01E374 */
+	0,							/* U+01E375 */
+	0,							/* U+01E376 */
+	0,							/* U+01E377 */
+	0,							/* U+01E378 */
+	0,							/* U+01E379 */
+	0,							/* U+01E37A */
+	0,							/* U+01E37B */
+	0,							/* U+01E37C */
+	0,							/* U+01E37D */
+	0,							/* U+01E37E */
+	0,							/* U+01E37F */
+	0,							/* U+01E380 */
+	0,							/* U+01E381 */
+	0,							/* U+01E382 */
+	0,							/* U+01E383 */
+	0,							/* U+01E384 */
+	0,							/* U+01E385 */
+	0,							/* U+01E386 */
+	0,							/* U+01E387 */
+	0,							/* U+01E388 */
+	0,							/* U+01E389 */
+	0,							/* U+01E38A */
+	0,							/* U+01E38B */
+	0,							/* U+01E38C */
+	0,							/* U+01E38D */
+	0,							/* U+01E38E */
+	0,							/* U+01E38F */
+	0,							/* U+01E390 */
+	0,							/* U+01E391 */
+	0,							/* U+01E392 */
+	0,							/* U+01E393 */
+	0,							/* U+01E394 */
+	0,							/* U+01E395 */
+	0,							/* U+01E396 */
+	0,							/* U+01E397 */
+	0,							/* U+01E398 */
+	0,							/* U+01E399 */
+	0,							/* U+01E39A */
+	0,							/* U+01E39B */
+	0,							/* U+01E39C */
+	0,							/* U+01E39D */
+	0,							/* U+01E39E */
+	0,							/* U+01E39F */
+	0,							/* U+01E3A0 */
+	0,							/* U+01E3A1 */
+	0,							/* U+01E3A2 */
+	0,							/* U+01E3A3 */
+	0,							/* U+01E3A4 */
+	0,							/* U+01E3A5 */
+	0,							/* U+01E3A6 */
+	0,							/* U+01E3A7 */
+	0,							/* U+01E3A8 */
+	0,							/* U+01E3A9 */
+	0,							/* U+01E3AA */
+	0,							/* U+01E3AB */
+	0,							/* U+01E3AC */
+	0,							/* U+01E3AD */
+	0,							/* U+01E3AE */
+	0,							/* U+01E3AF */
+	0,							/* U+01E3B0 */
+	0,							/* U+01E3B1 */
+	0,							/* U+01E3B2 */
+	0,							/* U+01E3B3 */
+	0,							/* U+01E3B4 */
+	0,							/* U+01E3B5 */
+	0,							/* U+01E3B6 */
+	0,							/* U+01E3B7 */
+	0,							/* U+01E3B8 */
+	0,							/* U+01E3B9 */
+	0,							/* U+01E3BA */
+	0,							/* U+01E3BB */
+	0,							/* U+01E3BC */
+	0,							/* U+01E3BD */
+	0,							/* U+01E3BE */
+	0,							/* U+01E3BF */
+	0,							/* U+01E3C0 */
+	0,							/* U+01E3C1 */
+	0,							/* U+01E3C2 */
+	0,							/* U+01E3C3 */
+	0,							/* U+01E3C4 */
+	0,							/* U+01E3C5 */
+	0,							/* U+01E3C6 */
+	0,							/* U+01E3C7 */
+	0,							/* U+01E3C8 */
+	0,							/* U+01E3C9 */
+	0,							/* U+01E3CA */
+	0,							/* U+01E3CB */
+	0,							/* U+01E3CC */
+	0,							/* U+01E3CD */
+	0,							/* U+01E3CE */
+	0,							/* U+01E3CF */
+	0,							/* U+01E3D0 */
+	0,							/* U+01E3D1 */
+	0,							/* U+01E3D2 */
+	0,							/* U+01E3D3 */
+	0,							/* U+01E3D4 */
+	0,							/* U+01E3D5 */
+	0,							/* U+01E3D6 */
+	0,							/* U+01E3D7 */
+	0,							/* U+01E3D8 */
+	0,							/* U+01E3D9 */
+	0,							/* U+01E3DA */
+	0,							/* U+01E3DB */
+	0,							/* U+01E3DC */
+	0,							/* U+01E3DD */
+	0,							/* U+01E3DE */
+	0,							/* U+01E3DF */
+	0,							/* U+01E3E0 */
+	0,							/* U+01E3E1 */
+	0,							/* U+01E3E2 */
+	0,							/* U+01E3E3 */
+	0,							/* U+01E3E4 */
+	0,							/* U+01E3E5 */
+	0,							/* U+01E3E6 */
+	0,							/* U+01E3E7 */
+	0,							/* U+01E3E8 */
+	0,							/* U+01E3E9 */
+	0,							/* U+01E3EA */
+	0,							/* U+01E3EB */
+	0,							/* U+01E3EC */
+	0,							/* U+01E3ED */
+	0,							/* U+01E3EE */
+	0,							/* U+01E3EF */
+	0,							/* U+01E3F0 */
+	0,							/* U+01E3F1 */
+	0,							/* U+01E3F2 */
+	0,							/* U+01E3F3 */
+	0,							/* U+01E3F4 */
+	0,							/* U+01E3F5 */
+	0,							/* U+01E3F6 */
+	0,							/* U+01E3F7 */
+	0,							/* U+01E3F8 */
+	0,							/* U+01E3F9 */
+	0,							/* U+01E3FA */
+	0,							/* U+01E3FB */
+	0,							/* U+01E3FC */
+	0,							/* U+01E3FD */
+	0,							/* U+01E3FE */
+	0,							/* U+01E3FF */
+	0,							/* U+01E400 */
+	0,							/* U+01E401 */
+	0,							/* U+01E402 */
+	0,							/* U+01E403 */
+	0,							/* U+01E404 */
+	0,							/* U+01E405 */
+	0,							/* U+01E406 */
+	0,							/* U+01E407 */
+	0,							/* U+01E408 */
+	0,							/* U+01E409 */
+	0,							/* U+01E40A */
+	0,							/* U+01E40B */
+	0,							/* U+01E40C */
+	0,							/* U+01E40D */
+	0,							/* U+01E40E */
+	0,							/* U+01E40F */
+	0,							/* U+01E410 */
+	0,							/* U+01E411 */
+	0,							/* U+01E412 */
+	0,							/* U+01E413 */
+	0,							/* U+01E414 */
+	0,							/* U+01E415 */
+	0,							/* U+01E416 */
+	0,							/* U+01E417 */
+	0,							/* U+01E418 */
+	0,							/* U+01E419 */
+	0,							/* U+01E41A */
+	0,							/* U+01E41B */
+	0,							/* U+01E41C */
+	0,							/* U+01E41D */
+	0,							/* U+01E41E */
+	0,							/* U+01E41F */
+	0,							/* U+01E420 */
+	0,							/* U+01E421 */
+	0,							/* U+01E422 */
+	0,							/* U+01E423 */
+	0,							/* U+01E424 */
+	0,							/* U+01E425 */
+	0,							/* U+01E426 */
+	0,							/* U+01E427 */
+	0,							/* U+01E428 */
+	0,							/* U+01E429 */
+	0,							/* U+01E42A */
+	0,							/* U+01E42B */
+	0,							/* U+01E42C */
+	0,							/* U+01E42D */
+	0,							/* U+01E42E */
+	0,							/* U+01E42F */
+	0,							/* U+01E430 */
+	0,							/* U+01E431 */
+	0,							/* U+01E432 */
+	0,							/* U+01E433 */
+	0,							/* U+01E434 */
+	0,							/* U+01E435 */
+	0,							/* U+01E436 */
+	0,							/* U+01E437 */
+	0,							/* U+01E438 */
+	0,							/* U+01E439 */
+	0,							/* U+01E43A */
+	0,							/* U+01E43B */
+	0,							/* U+01E43C */
+	0,							/* U+01E43D */
+	0,							/* U+01E43E */
+	0,							/* U+01E43F */
+	0,							/* U+01E440 */
+	0,							/* U+01E441 */
+	0,							/* U+01E442 */
+	0,							/* U+01E443 */
+	0,							/* U+01E444 */
+	0,							/* U+01E445 */
+	0,							/* U+01E446 */
+	0,							/* U+01E447 */
+	0,							/* U+01E448 */
+	0,							/* U+01E449 */
+	0,							/* U+01E44A */
+	0,							/* U+01E44B */
+	0,							/* U+01E44C */
+	0,							/* U+01E44D */
+	0,							/* U+01E44E */
+	0,							/* U+01E44F */
+	0,							/* U+01E450 */
+	0,							/* U+01E451 */
+	0,							/* U+01E452 */
+	0,							/* U+01E453 */
+	0,							/* U+01E454 */
+	0,							/* U+01E455 */
+	0,							/* U+01E456 */
+	0,							/* U+01E457 */
+	0,							/* U+01E458 */
+	0,							/* U+01E459 */
+	0,							/* U+01E45A */
+	0,							/* U+01E45B */
+	0,							/* U+01E45C */
+	0,							/* U+01E45D */
+	0,							/* U+01E45E */
+	0,							/* U+01E45F */
+	0,							/* U+01E460 */
+	0,							/* U+01E461 */
+	0,							/* U+01E462 */
+	0,							/* U+01E463 */
+	0,							/* U+01E464 */
+	0,							/* U+01E465 */
+	0,							/* U+01E466 */
+	0,							/* U+01E467 */
+	0,							/* U+01E468 */
+	0,							/* U+01E469 */
+	0,							/* U+01E46A */
+	0,							/* U+01E46B */
+	0,							/* U+01E46C */
+	0,							/* U+01E46D */
+	0,							/* U+01E46E */
+	0,							/* U+01E46F */
+	0,							/* U+01E470 */
+	0,							/* U+01E471 */
+	0,							/* U+01E472 */
+	0,							/* U+01E473 */
+	0,							/* U+01E474 */
+	0,							/* U+01E475 */
+	0,							/* U+01E476 */
+	0,							/* U+01E477 */
+	0,							/* U+01E478 */
+	0,							/* U+01E479 */
+	0,							/* U+01E47A */
+	0,							/* U+01E47B */
+	0,							/* U+01E47C */
+	0,							/* U+01E47D */
+	0,							/* U+01E47E */
+	0,							/* U+01E47F */
+	0,							/* U+01E480 */
+	0,							/* U+01E481 */
+	0,							/* U+01E482 */
+	0,							/* U+01E483 */
+	0,							/* U+01E484 */
+	0,							/* U+01E485 */
+	0,							/* U+01E486 */
+	0,							/* U+01E487 */
+	0,							/* U+01E488 */
+	0,							/* U+01E489 */
+	0,							/* U+01E48A */
+	0,							/* U+01E48B */
+	0,							/* U+01E48C */
+	0,							/* U+01E48D */
+	0,							/* U+01E48E */
+	0,							/* U+01E48F */
+	0,							/* U+01E490 */
+	0,							/* U+01E491 */
+	0,							/* U+01E492 */
+	0,							/* U+01E493 */
+	0,							/* U+01E494 */
+	0,							/* U+01E495 */
+	0,							/* U+01E496 */
+	0,							/* U+01E497 */
+	0,							/* U+01E498 */
+	0,							/* U+01E499 */
+	0,							/* U+01E49A */
+	0,							/* U+01E49B */
+	0,							/* U+01E49C */
+	0,							/* U+01E49D */
+	0,							/* U+01E49E */
+	0,							/* U+01E49F */
+	0,							/* U+01E4A0 */
+	0,							/* U+01E4A1 */
+	0,							/* U+01E4A2 */
+	0,							/* U+01E4A3 */
+	0,							/* U+01E4A4 */
+	0,							/* U+01E4A5 */
+	0,							/* U+01E4A6 */
+	0,							/* U+01E4A7 */
+	0,							/* U+01E4A8 */
+	0,							/* U+01E4A9 */
+	0,							/* U+01E4AA */
+	0,							/* U+01E4AB */
+	0,							/* U+01E4AC */
+	0,							/* U+01E4AD */
+	0,							/* U+01E4AE */
+	0,							/* U+01E4AF */
+	0,							/* U+01E4B0 */
+	0,							/* U+01E4B1 */
+	0,							/* U+01E4B2 */
+	0,							/* U+01E4B3 */
+	0,							/* U+01E4B4 */
+	0,							/* U+01E4B5 */
+	0,							/* U+01E4B6 */
+	0,							/* U+01E4B7 */
+	0,							/* U+01E4B8 */
+	0,							/* U+01E4B9 */
+	0,							/* U+01E4BA */
+	0,							/* U+01E4BB */
+	0,							/* U+01E4BC */
+	0,							/* U+01E4BD */
+	0,							/* U+01E4BE */
+	0,							/* U+01E4BF */
+	0,							/* U+01E4C0 */
+	0,							/* U+01E4C1 */
+	0,							/* U+01E4C2 */
+	0,							/* U+01E4C3 */
+	0,							/* U+01E4C4 */
+	0,							/* U+01E4C5 */
+	0,							/* U+01E4C6 */
+	0,							/* U+01E4C7 */
+	0,							/* U+01E4C8 */
+	0,							/* U+01E4C9 */
+	0,							/* U+01E4CA */
+	0,							/* U+01E4CB */
+	0,							/* U+01E4CC */
+	0,							/* U+01E4CD */
+	0,							/* U+01E4CE */
+	0,							/* U+01E4CF */
+	0,							/* U+01E4D0 */
+	0,							/* U+01E4D1 */
+	0,							/* U+01E4D2 */
+	0,							/* U+01E4D3 */
+	0,							/* U+01E4D4 */
+	0,							/* U+01E4D5 */
+	0,							/* U+01E4D6 */
+	0,							/* U+01E4D7 */
+	0,							/* U+01E4D8 */
+	0,							/* U+01E4D9 */
+	0,							/* U+01E4DA */
+	0,							/* U+01E4DB */
+	0,							/* U+01E4DC */
+	0,							/* U+01E4DD */
+	0,							/* U+01E4DE */
+	0,							/* U+01E4DF */
+	0,							/* U+01E4E0 */
+	0,							/* U+01E4E1 */
+	0,							/* U+01E4E2 */
+	0,							/* U+01E4E3 */
+	0,							/* U+01E4E4 */
+	0,							/* U+01E4E5 */
+	0,							/* U+01E4E6 */
+	0,							/* U+01E4E7 */
+	0,							/* U+01E4E8 */
+	0,							/* U+01E4E9 */
+	0,							/* U+01E4EA */
+	0,							/* U+01E4EB */
+	305,						/* U+01E4EC */
+	305,						/* U+01E4ED */
+	306,						/* U+01E4EE */
+	304,						/* U+01E4EF */
+	0,							/* U+01E4F0 */
+	0,							/* U+01E4F1 */
+	0,							/* U+01E4F2 */
+	0,							/* U+01E4F3 */
+	0,							/* U+01E4F4 */
+	0,							/* U+01E4F5 */
+	0,							/* U+01E4F6 */
+	0,							/* U+01E4F7 */
+	0,							/* U+01E4F8 */
+	0,							/* U+01E4F9 */
+	0,							/* U+01E4FA */
+	0,							/* U+01E4FB */
+	0,							/* U+01E4FC */
+	0,							/* U+01E4FD */
+	0,							/* U+01E4FE */
+	0,							/* U+01E4FF */
+	0,							/* U+01E500 */
+	0,							/* U+01E501 */
+	0,							/* U+01E502 */
+	0,							/* U+01E503 */
+	0,							/* U+01E504 */
+	0,							/* U+01E505 */
+	0,							/* U+01E506 */
+	0,							/* U+01E507 */
+	0,							/* U+01E508 */
+	0,							/* U+01E509 */
+	0,							/* U+01E50A */
+	0,							/* U+01E50B */
+	0,							/* U+01E50C */
+	0,							/* U+01E50D */
+	0,							/* U+01E50E */
+	0,							/* U+01E50F */
+	0,							/* U+01E510 */
+	0,							/* U+01E511 */
+	0,							/* U+01E512 */
+	0,							/* U+01E513 */
+	0,							/* U+01E514 */
+	0,							/* U+01E515 */
+	0,							/* U+01E516 */
+	0,							/* U+01E517 */
+	0,							/* U+01E518 */
+	0,							/* U+01E519 */
+	0,							/* U+01E51A */
+	0,							/* U+01E51B */
+	0,							/* U+01E51C */
+	0,							/* U+01E51D */
+	0,							/* U+01E51E */
+	0,							/* U+01E51F */
+	0,							/* U+01E520 */
+	0,							/* U+01E521 */
+	0,							/* U+01E522 */
+	0,							/* U+01E523 */
+	0,							/* U+01E524 */
+	0,							/* U+01E525 */
+	0,							/* U+01E526 */
+	0,							/* U+01E527 */
+	0,							/* U+01E528 */
+	0,							/* U+01E529 */
+	0,							/* U+01E52A */
+	0,							/* U+01E52B */
+	0,							/* U+01E52C */
+	0,							/* U+01E52D */
+	0,							/* U+01E52E */
+	0,							/* U+01E52F */
+	0,							/* U+01E530 */
+	0,							/* U+01E531 */
+	0,							/* U+01E532 */
+	0,							/* U+01E533 */
+	0,							/* U+01E534 */
+	0,							/* U+01E535 */
+	0,							/* U+01E536 */
+	0,							/* U+01E537 */
+	0,							/* U+01E538 */
+	0,							/* U+01E539 */
+	0,							/* U+01E53A */
+	0,							/* U+01E53B */
+	0,							/* U+01E53C */
+	0,							/* U+01E53D */
+	0,							/* U+01E53E */
+	0,							/* U+01E53F */
+	0,							/* U+01E540 */
+	0,							/* U+01E541 */
+	0,							/* U+01E542 */
+	0,							/* U+01E543 */
+	0,							/* U+01E544 */
+	0,							/* U+01E545 */
+	0,							/* U+01E546 */
+	0,							/* U+01E547 */
+	0,							/* U+01E548 */
+	0,							/* U+01E549 */
+	0,							/* U+01E54A */
+	0,							/* U+01E54B */
+	0,							/* U+01E54C */
+	0,							/* U+01E54D */
+	0,							/* U+01E54E */
+	0,							/* U+01E54F */
+	0,							/* U+01E550 */
+	0,							/* U+01E551 */
+	0,							/* U+01E552 */
+	0,							/* U+01E553 */
+	0,							/* U+01E554 */
+	0,							/* U+01E555 */
+	0,							/* U+01E556 */
+	0,							/* U+01E557 */
+	0,							/* U+01E558 */
+	0,							/* U+01E559 */
+	0,							/* U+01E55A */
+	0,							/* U+01E55B */
+	0,							/* U+01E55C */
+	0,							/* U+01E55D */
+	0,							/* U+01E55E */
+	0,							/* U+01E55F */
+	0,							/* U+01E560 */
+	0,							/* U+01E561 */
+	0,							/* U+01E562 */
+	0,							/* U+01E563 */
+	0,							/* U+01E564 */
+	0,							/* U+01E565 */
+	0,							/* U+01E566 */
+	0,							/* U+01E567 */
+	0,							/* U+01E568 */
+	0,							/* U+01E569 */
+	0,							/* U+01E56A */
+	0,							/* U+01E56B */
+	0,							/* U+01E56C */
+	0,							/* U+01E56D */
+	0,							/* U+01E56E */
+	0,							/* U+01E56F */
+	0,							/* U+01E570 */
+	0,							/* U+01E571 */
+	0,							/* U+01E572 */
+	0,							/* U+01E573 */
+	0,							/* U+01E574 */
+	0,							/* U+01E575 */
+	0,							/* U+01E576 */
+	0,							/* U+01E577 */
+	0,							/* U+01E578 */
+	0,							/* U+01E579 */
+	0,							/* U+01E57A */
+	0,							/* U+01E57B */
+	0,							/* U+01E57C */
+	0,							/* U+01E57D */
+	0,							/* U+01E57E */
+	0,							/* U+01E57F */
+	0,							/* U+01E580 */
+	0,							/* U+01E581 */
+	0,							/* U+01E582 */
+	0,							/* U+01E583 */
+	0,							/* U+01E584 */
+	0,							/* U+01E585 */
+	0,							/* U+01E586 */
+	0,							/* U+01E587 */
+	0,							/* U+01E588 */
+	0,							/* U+01E589 */
+	0,							/* U+01E58A */
+	0,							/* U+01E58B */
+	0,							/* U+01E58C */
+	0,							/* U+01E58D */
+	0,							/* U+01E58E */
+	0,							/* U+01E58F */
+	0,							/* U+01E590 */
+	0,							/* U+01E591 */
+	0,							/* U+01E592 */
+	0,							/* U+01E593 */
+	0,							/* U+01E594 */
+	0,							/* U+01E595 */
+	0,							/* U+01E596 */
+	0,							/* U+01E597 */
+	0,							/* U+01E598 */
+	0,							/* U+01E599 */
+	0,							/* U+01E59A */
+	0,							/* U+01E59B */
+	0,							/* U+01E59C */
+	0,							/* U+01E59D */
+	0,							/* U+01E59E */
+	0,							/* U+01E59F */
+	0,							/* U+01E5A0 */
+	0,							/* U+01E5A1 */
+	0,							/* U+01E5A2 */
+	0,							/* U+01E5A3 */
+	0,							/* U+01E5A4 */
+	0,							/* U+01E5A5 */
+	0,							/* U+01E5A6 */
+	0,							/* U+01E5A7 */
+	0,							/* U+01E5A8 */
+	0,							/* U+01E5A9 */
+	0,							/* U+01E5AA */
+	0,							/* U+01E5AB */
+	0,							/* U+01E5AC */
+	0,							/* U+01E5AD */
+	0,							/* U+01E5AE */
+	0,							/* U+01E5AF */
+	0,							/* U+01E5B0 */
+	0,							/* U+01E5B1 */
+	0,							/* U+01E5B2 */
+	0,							/* U+01E5B3 */
+	0,							/* U+01E5B4 */
+	0,							/* U+01E5B5 */
+	0,							/* U+01E5B6 */
+	0,							/* U+01E5B7 */
+	0,							/* U+01E5B8 */
+	0,							/* U+01E5B9 */
+	0,							/* U+01E5BA */
+	0,							/* U+01E5BB */
+	0,							/* U+01E5BC */
+	0,							/* U+01E5BD */
+	0,							/* U+01E5BE */
+	0,							/* U+01E5BF */
+	0,							/* U+01E5C0 */
+	0,							/* U+01E5C1 */
+	0,							/* U+01E5C2 */
+	0,							/* U+01E5C3 */
+	0,							/* U+01E5C4 */
+	0,							/* U+01E5C5 */
+	0,							/* U+01E5C6 */
+	0,							/* U+01E5C7 */
+	0,							/* U+01E5C8 */
+	0,							/* U+01E5C9 */
+	0,							/* U+01E5CA */
+	0,							/* U+01E5CB */
+	0,							/* U+01E5CC */
+	0,							/* U+01E5CD */
+	0,							/* U+01E5CE */
+	0,							/* U+01E5CF */
+	0,							/* U+01E5D0 */
+	0,							/* U+01E5D1 */
+	0,							/* U+01E5D2 */
+	0,							/* U+01E5D3 */
+	0,							/* U+01E5D4 */
+	0,							/* U+01E5D5 */
+	0,							/* U+01E5D6 */
+	0,							/* U+01E5D7 */
+	0,							/* U+01E5D8 */
+	0,							/* U+01E5D9 */
+	0,							/* U+01E5DA */
+	0,							/* U+01E5DB */
+	0,							/* U+01E5DC */
+	0,							/* U+01E5DD */
+	0,							/* U+01E5DE */
+	0,							/* U+01E5DF */
+	0,							/* U+01E5E0 */
+	0,							/* U+01E5E1 */
+	0,							/* U+01E5E2 */
+	0,							/* U+01E5E3 */
+	0,							/* U+01E5E4 */
+	0,							/* U+01E5E5 */
+	0,							/* U+01E5E6 */
+	0,							/* U+01E5E7 */
+	0,							/* U+01E5E8 */
+	0,							/* U+01E5E9 */
+	0,							/* U+01E5EA */
+	0,							/* U+01E5EB */
+	0,							/* U+01E5EC */
+	0,							/* U+01E5ED */
+	304,						/* U+01E5EE */
+	306,						/* U+01E5EF */
+	0,							/* U+01E5F0 */
+	0,							/* U+01E5F1 */
+	0,							/* U+01E5F2 */
+	0,							/* U+01E5F3 */
+	0,							/* U+01E5F4 */
+	0,							/* U+01E5F5 */
+	0,							/* U+01E5F6 */
+	0,							/* U+01E5F7 */
+	0,							/* U+01E5F8 */
+	0,							/* U+01E5F9 */
+	0,							/* U+01E5FA */
+	0,							/* U+01E5FB */
+	0,							/* U+01E5FC */
+	0,							/* U+01E5FD */
+	0,							/* U+01E5FE */
+	0,							/* U+01E5FF */
+	0,							/* U+01E600 */
+	0,							/* U+01E601 */
+	0,							/* U+01E602 */
+	0,							/* U+01E603 */
+	0,							/* U+01E604 */
+	0,							/* U+01E605 */
+	0,							/* U+01E606 */
+	0,							/* U+01E607 */
+	0,							/* U+01E608 */
+	0,							/* U+01E609 */
+	0,							/* U+01E60A */
+	0,							/* U+01E60B */
+	0,							/* U+01E60C */
+	0,							/* U+01E60D */
+	0,							/* U+01E60E */
+	0,							/* U+01E60F */
+	0,							/* U+01E610 */
+	0,							/* U+01E611 */
+	0,							/* U+01E612 */
+	0,							/* U+01E613 */
+	0,							/* U+01E614 */
+	0,							/* U+01E615 */
+	0,							/* U+01E616 */
+	0,							/* U+01E617 */
+	0,							/* U+01E618 */
+	0,							/* U+01E619 */
+	0,							/* U+01E61A */
+	0,							/* U+01E61B */
+	0,							/* U+01E61C */
+	0,							/* U+01E61D */
+	0,							/* U+01E61E */
+	0,							/* U+01E61F */
+	0,							/* U+01E620 */
+	0,							/* U+01E621 */
+	0,							/* U+01E622 */
+	0,							/* U+01E623 */
+	0,							/* U+01E624 */
+	0,							/* U+01E625 */
+	0,							/* U+01E626 */
+	0,							/* U+01E627 */
+	0,							/* U+01E628 */
+	0,							/* U+01E629 */
+	0,							/* U+01E62A */
+	0,							/* U+01E62B */
+	0,							/* U+01E62C */
+	0,							/* U+01E62D */
+	0,							/* U+01E62E */
+	0,							/* U+01E62F */
+	0,							/* U+01E630 */
+	0,							/* U+01E631 */
+	0,							/* U+01E632 */
+	0,							/* U+01E633 */
+	0,							/* U+01E634 */
+	0,							/* U+01E635 */
+	0,							/* U+01E636 */
+	0,							/* U+01E637 */
+	0,							/* U+01E638 */
+	0,							/* U+01E639 */
+	0,							/* U+01E63A */
+	0,							/* U+01E63B */
+	0,							/* U+01E63C */
+	0,							/* U+01E63D */
+	0,							/* U+01E63E */
+	0,							/* U+01E63F */
+	0,							/* U+01E640 */
+	0,							/* U+01E641 */
+	0,							/* U+01E642 */
+	0,							/* U+01E643 */
+	0,							/* U+01E644 */
+	0,							/* U+01E645 */
+	0,							/* U+01E646 */
+	0,							/* U+01E647 */
+	0,							/* U+01E648 */
+	0,							/* U+01E649 */
+	0,							/* U+01E64A */
+	0,							/* U+01E64B */
+	0,							/* U+01E64C */
+	0,							/* U+01E64D */
+	0,							/* U+01E64E */
+	0,							/* U+01E64F */
+	0,							/* U+01E650 */
+	0,							/* U+01E651 */
+	0,							/* U+01E652 */
+	0,							/* U+01E653 */
+	0,							/* U+01E654 */
+	0,							/* U+01E655 */
+	0,							/* U+01E656 */
+	0,							/* U+01E657 */
+	0,							/* U+01E658 */
+	0,							/* U+01E659 */
+	0,							/* U+01E65A */
+	0,							/* U+01E65B */
+	0,							/* U+01E65C */
+	0,							/* U+01E65D */
+	0,							/* U+01E65E */
+	0,							/* U+01E65F */
+	0,							/* U+01E660 */
+	0,							/* U+01E661 */
+	0,							/* U+01E662 */
+	0,							/* U+01E663 */
+	0,							/* U+01E664 */
+	0,							/* U+01E665 */
+	0,							/* U+01E666 */
+	0,							/* U+01E667 */
+	0,							/* U+01E668 */
+	0,							/* U+01E669 */
+	0,							/* U+01E66A */
+	0,							/* U+01E66B */
+	0,							/* U+01E66C */
+	0,							/* U+01E66D */
+	0,							/* U+01E66E */
+	0,							/* U+01E66F */
+	0,							/* U+01E670 */
+	0,							/* U+01E671 */
+	0,							/* U+01E672 */
+	0,							/* U+01E673 */
+	0,							/* U+01E674 */
+	0,							/* U+01E675 */
+	0,							/* U+01E676 */
+	0,							/* U+01E677 */
+	0,							/* U+01E678 */
+	0,							/* U+01E679 */
+	0,							/* U+01E67A */
+	0,							/* U+01E67B */
+	0,							/* U+01E67C */
+	0,							/* U+01E67D */
+	0,							/* U+01E67E */
+	0,							/* U+01E67F */
+	0,							/* U+01E680 */
+	0,							/* U+01E681 */
+	0,							/* U+01E682 */
+	0,							/* U+01E683 */
+	0,							/* U+01E684 */
+	0,							/* U+01E685 */
+	0,							/* U+01E686 */
+	0,							/* U+01E687 */
+	0,							/* U+01E688 */
+	0,							/* U+01E689 */
+	0,							/* U+01E68A */
+	0,							/* U+01E68B */
+	0,							/* U+01E68C */
+	0,							/* U+01E68D */
+	0,							/* U+01E68E */
+	0,							/* U+01E68F */
+	0,							/* U+01E690 */
+	0,							/* U+01E691 */
+	0,							/* U+01E692 */
+	0,							/* U+01E693 */
+	0,							/* U+01E694 */
+	0,							/* U+01E695 */
+	0,							/* U+01E696 */
+	0,							/* U+01E697 */
+	0,							/* U+01E698 */
+	0,							/* U+01E699 */
+	0,							/* U+01E69A */
+	0,							/* U+01E69B */
+	0,							/* U+01E69C */
+	0,							/* U+01E69D */
+	0,							/* U+01E69E */
+	0,							/* U+01E69F */
+	0,							/* U+01E6A0 */
+	0,							/* U+01E6A1 */
+	0,							/* U+01E6A2 */
+	0,							/* U+01E6A3 */
+	0,							/* U+01E6A4 */
+	0,							/* U+01E6A5 */
+	0,							/* U+01E6A6 */
+	0,							/* U+01E6A7 */
+	0,							/* U+01E6A8 */
+	0,							/* U+01E6A9 */
+	0,							/* U+01E6AA */
+	0,							/* U+01E6AB */
+	0,							/* U+01E6AC */
+	0,							/* U+01E6AD */
+	0,							/* U+01E6AE */
+	0,							/* U+01E6AF */
+	0,							/* U+01E6B0 */
+	0,							/* U+01E6B1 */
+	0,							/* U+01E6B2 */
+	0,							/* U+01E6B3 */
+	0,							/* U+01E6B4 */
+	0,							/* U+01E6B5 */
+	0,							/* U+01E6B6 */
+	0,							/* U+01E6B7 */
+	0,							/* U+01E6B8 */
+	0,							/* U+01E6B9 */
+	0,							/* U+01E6BA */
+	0,							/* U+01E6BB */
+	0,							/* U+01E6BC */
+	0,							/* U+01E6BD */
+	0,							/* U+01E6BE */
+	0,							/* U+01E6BF */
+	0,							/* U+01E6C0 */
+	0,							/* U+01E6C1 */
+	0,							/* U+01E6C2 */
+	0,							/* U+01E6C3 */
+	0,							/* U+01E6C4 */
+	0,							/* U+01E6C5 */
+	0,							/* U+01E6C6 */
+	0,							/* U+01E6C7 */
+	0,							/* U+01E6C8 */
+	0,							/* U+01E6C9 */
+	0,							/* U+01E6CA */
+	0,							/* U+01E6CB */
+	0,							/* U+01E6CC */
+	0,							/* U+01E6CD */
+	0,							/* U+01E6CE */
+	0,							/* U+01E6CF */
+	0,							/* U+01E6D0 */
+	0,							/* U+01E6D1 */
+	0,							/* U+01E6D2 */
+	0,							/* U+01E6D3 */
+	0,							/* U+01E6D4 */
+	0,							/* U+01E6D5 */
+	0,							/* U+01E6D6 */
+	0,							/* U+01E6D7 */
+	0,							/* U+01E6D8 */
+	0,							/* U+01E6D9 */
+	0,							/* U+01E6DA */
+	0,							/* U+01E6DB */
+	0,							/* U+01E6DC */
+	0,							/* U+01E6DD */
+	0,							/* U+01E6DE */
+	0,							/* U+01E6DF */
+	0,							/* U+01E6E0 */
+	0,							/* U+01E6E1 */
+	0,							/* U+01E6E2 */
+	0,							/* U+01E6E3 */
+	0,							/* U+01E6E4 */
+	0,							/* U+01E6E5 */
+	0,							/* U+01E6E6 */
+	0,							/* U+01E6E7 */
+	0,							/* U+01E6E8 */
+	0,							/* U+01E6E9 */
+	0,							/* U+01E6EA */
+	0,							/* U+01E6EB */
+	0,							/* U+01E6EC */
+	0,							/* U+01E6ED */
+	0,							/* U+01E6EE */
+	0,							/* U+01E6EF */
+	0,							/* U+01E6F0 */
+	0,							/* U+01E6F1 */
+	0,							/* U+01E6F2 */
+	0,							/* U+01E6F3 */
+	0,							/* U+01E6F4 */
+	0,							/* U+01E6F5 */
+	0,							/* U+01E6F6 */
+	0,							/* U+01E6F7 */
+	0,							/* U+01E6F8 */
+	0,							/* U+01E6F9 */
+	0,							/* U+01E6FA */
+	0,							/* U+01E6FB */
+	0,							/* U+01E6FC */
+	0,							/* U+01E6FD */
+	0,							/* U+01E6FE */
+	0,							/* U+01E6FF */
+	0,							/* U+01E700 */
+	0,							/* U+01E701 */
+	0,							/* U+01E702 */
+	0,							/* U+01E703 */
+	0,							/* U+01E704 */
+	0,							/* U+01E705 */
+	0,							/* U+01E706 */
+	0,							/* U+01E707 */
+	0,							/* U+01E708 */
+	0,							/* U+01E709 */
+	0,							/* U+01E70A */
+	0,							/* U+01E70B */
+	0,							/* U+01E70C */
+	0,							/* U+01E70D */
+	0,							/* U+01E70E */
+	0,							/* U+01E70F */
+	0,							/* U+01E710 */
+	0,							/* U+01E711 */
+	0,							/* U+01E712 */
+	0,							/* U+01E713 */
+	0,							/* U+01E714 */
+	0,							/* U+01E715 */
+	0,							/* U+01E716 */
+	0,							/* U+01E717 */
+	0,							/* U+01E718 */
+	0,							/* U+01E719 */
+	0,							/* U+01E71A */
+	0,							/* U+01E71B */
+	0,							/* U+01E71C */
+	0,							/* U+01E71D */
+	0,							/* U+01E71E */
+	0,							/* U+01E71F */
+	0,							/* U+01E720 */
+	0,							/* U+01E721 */
+	0,							/* U+01E722 */
+	0,							/* U+01E723 */
+	0,							/* U+01E724 */
+	0,							/* U+01E725 */
+	0,							/* U+01E726 */
+	0,							/* U+01E727 */
+	0,							/* U+01E728 */
+	0,							/* U+01E729 */
+	0,							/* U+01E72A */
+	0,							/* U+01E72B */
+	0,							/* U+01E72C */
+	0,							/* U+01E72D */
+	0,							/* U+01E72E */
+	0,							/* U+01E72F */
+	0,							/* U+01E730 */
+	0,							/* U+01E731 */
+	0,							/* U+01E732 */
+	0,							/* U+01E733 */
+	0,							/* U+01E734 */
+	0,							/* U+01E735 */
+	0,							/* U+01E736 */
+	0,							/* U+01E737 */
+	0,							/* U+01E738 */
+	0,							/* U+01E739 */
+	0,							/* U+01E73A */
+	0,							/* U+01E73B */
+	0,							/* U+01E73C */
+	0,							/* U+01E73D */
+	0,							/* U+01E73E */
+	0,							/* U+01E73F */
+	0,							/* U+01E740 */
+	0,							/* U+01E741 */
+	0,							/* U+01E742 */
+	0,							/* U+01E743 */
+	0,							/* U+01E744 */
+	0,							/* U+01E745 */
+	0,							/* U+01E746 */
+	0,							/* U+01E747 */
+	0,							/* U+01E748 */
+	0,							/* U+01E749 */
+	0,							/* U+01E74A */
+	0,							/* U+01E74B */
+	0,							/* U+01E74C */
+	0,							/* U+01E74D */
+	0,							/* U+01E74E */
+	0,							/* U+01E74F */
+	0,							/* U+01E750 */
+	0,							/* U+01E751 */
+	0,							/* U+01E752 */
+	0,							/* U+01E753 */
+	0,							/* U+01E754 */
+	0,							/* U+01E755 */
+	0,							/* U+01E756 */
+	0,							/* U+01E757 */
+	0,							/* U+01E758 */
+	0,							/* U+01E759 */
+	0,							/* U+01E75A */
+	0,							/* U+01E75B */
+	0,							/* U+01E75C */
+	0,							/* U+01E75D */
+	0,							/* U+01E75E */
+	0,							/* U+01E75F */
+	0,							/* U+01E760 */
+	0,							/* U+01E761 */
+	0,							/* U+01E762 */
+	0,							/* U+01E763 */
+	0,							/* U+01E764 */
+	0,							/* U+01E765 */
+	0,							/* U+01E766 */
+	0,							/* U+01E767 */
+	0,							/* U+01E768 */
+	0,							/* U+01E769 */
+	0,							/* U+01E76A */
+	0,							/* U+01E76B */
+	0,							/* U+01E76C */
+	0,							/* U+01E76D */
+	0,							/* U+01E76E */
+	0,							/* U+01E76F */
+	0,							/* U+01E770 */
+	0,							/* U+01E771 */
+	0,							/* U+01E772 */
+	0,							/* U+01E773 */
+	0,							/* U+01E774 */
+	0,							/* U+01E775 */
+	0,							/* U+01E776 */
+	0,							/* U+01E777 */
+	0,							/* U+01E778 */
+	0,							/* U+01E779 */
+	0,							/* U+01E77A */
+	0,							/* U+01E77B */
+	0,							/* U+01E77C */
+	0,							/* U+01E77D */
+	0,							/* U+01E77E */
+	0,							/* U+01E77F */
+	0,							/* U+01E780 */
+	0,							/* U+01E781 */
+	0,							/* U+01E782 */
+	0,							/* U+01E783 */
+	0,							/* U+01E784 */
+	0,							/* U+01E785 */
+	0,							/* U+01E786 */
+	0,							/* U+01E787 */
+	0,							/* U+01E788 */
+	0,							/* U+01E789 */
+	0,							/* U+01E78A */
+	0,							/* U+01E78B */
+	0,							/* U+01E78C */
+	0,							/* U+01E78D */
+	0,							/* U+01E78E */
+	0,							/* U+01E78F */
+	0,							/* U+01E790 */
+	0,							/* U+01E791 */
+	0,							/* U+01E792 */
+	0,							/* U+01E793 */
+	0,							/* U+01E794 */
+	0,							/* U+01E795 */
+	0,							/* U+01E796 */
+	0,							/* U+01E797 */
+	0,							/* U+01E798 */
+	0,							/* U+01E799 */
+	0,							/* U+01E79A */
+	0,							/* U+01E79B */
+	0,							/* U+01E79C */
+	0,							/* U+01E79D */
+	0,							/* U+01E79E */
+	0,							/* U+01E79F */
+	0,							/* U+01E7A0 */
+	0,							/* U+01E7A1 */
+	0,							/* U+01E7A2 */
+	0,							/* U+01E7A3 */
+	0,							/* U+01E7A4 */
+	0,							/* U+01E7A5 */
+	0,							/* U+01E7A6 */
+	0,							/* U+01E7A7 */
+	0,							/* U+01E7A8 */
+	0,							/* U+01E7A9 */
+	0,							/* U+01E7AA */
+	0,							/* U+01E7AB */
+	0,							/* U+01E7AC */
+	0,							/* U+01E7AD */
+	0,							/* U+01E7AE */
+	0,							/* U+01E7AF */
+	0,							/* U+01E7B0 */
+	0,							/* U+01E7B1 */
+	0,							/* U+01E7B2 */
+	0,							/* U+01E7B3 */
+	0,							/* U+01E7B4 */
+	0,							/* U+01E7B5 */
+	0,							/* U+01E7B6 */
+	0,							/* U+01E7B7 */
+	0,							/* U+01E7B8 */
+	0,							/* U+01E7B9 */
+	0,							/* U+01E7BA */
+	0,							/* U+01E7BB */
+	0,							/* U+01E7BC */
+	0,							/* U+01E7BD */
+	0,							/* U+01E7BE */
+	0,							/* U+01E7BF */
+	0,							/* U+01E7C0 */
+	0,							/* U+01E7C1 */
+	0,							/* U+01E7C2 */
+	0,							/* U+01E7C3 */
+	0,							/* U+01E7C4 */
+	0,							/* U+01E7C5 */
+	0,							/* U+01E7C6 */
+	0,							/* U+01E7C7 */
+	0,							/* U+01E7C8 */
+	0,							/* U+01E7C9 */
+	0,							/* U+01E7CA */
+	0,							/* U+01E7CB */
+	0,							/* U+01E7CC */
+	0,							/* U+01E7CD */
+	0,							/* U+01E7CE */
+	0,							/* U+01E7CF */
+	0,							/* U+01E7D0 */
+	0,							/* U+01E7D1 */
+	0,							/* U+01E7D2 */
+	0,							/* U+01E7D3 */
+	0,							/* U+01E7D4 */
+	0,							/* U+01E7D5 */
+	0,							/* U+01E7D6 */
+	0,							/* U+01E7D7 */
+	0,							/* U+01E7D8 */
+	0,							/* U+01E7D9 */
+	0,							/* U+01E7DA */
+	0,							/* U+01E7DB */
+	0,							/* U+01E7DC */
+	0,							/* U+01E7DD */
+	0,							/* U+01E7DE */
+	0,							/* U+01E7DF */
+	0,							/* U+01E7E0 */
+	0,							/* U+01E7E1 */
+	0,							/* U+01E7E2 */
+	0,							/* U+01E7E3 */
+	0,							/* U+01E7E4 */
+	0,							/* U+01E7E5 */
+	0,							/* U+01E7E6 */
+	0,							/* U+01E7E7 */
+	0,							/* U+01E7E8 */
+	0,							/* U+01E7E9 */
+	0,							/* U+01E7EA */
+	0,							/* U+01E7EB */
+	0,							/* U+01E7EC */
+	0,							/* U+01E7ED */
+	0,							/* U+01E7EE */
+	0,							/* U+01E7EF */
+	0,							/* U+01E7F0 */
+	0,							/* U+01E7F1 */
+	0,							/* U+01E7F2 */
+	0,							/* U+01E7F3 */
+	0,							/* U+01E7F4 */
+	0,							/* U+01E7F5 */
+	0,							/* U+01E7F6 */
+	0,							/* U+01E7F7 */
+	0,							/* U+01E7F8 */
+	0,							/* U+01E7F9 */
+	0,							/* U+01E7FA */
+	0,							/* U+01E7FB */
+	0,							/* U+01E7FC */
+	0,							/* U+01E7FD */
+	0,							/* U+01E7FE */
+	0,							/* U+01E7FF */
+	0,							/* U+01E800 */
+	0,							/* U+01E801 */
+	0,							/* U+01E802 */
+	0,							/* U+01E803 */
+	0,							/* U+01E804 */
+	0,							/* U+01E805 */
+	0,							/* U+01E806 */
+	0,							/* U+01E807 */
+	0,							/* U+01E808 */
+	0,							/* U+01E809 */
+	0,							/* U+01E80A */
+	0,							/* U+01E80B */
+	0,							/* U+01E80C */
+	0,							/* U+01E80D */
+	0,							/* U+01E80E */
+	0,							/* U+01E80F */
+	0,							/* U+01E810 */
+	0,							/* U+01E811 */
+	0,							/* U+01E812 */
+	0,							/* U+01E813 */
+	0,							/* U+01E814 */
+	0,							/* U+01E815 */
+	0,							/* U+01E816 */
+	0,							/* U+01E817 */
+	0,							/* U+01E818 */
+	0,							/* U+01E819 */
+	0,							/* U+01E81A */
+	0,							/* U+01E81B */
+	0,							/* U+01E81C */
+	0,							/* U+01E81D */
+	0,							/* U+01E81E */
+	0,							/* U+01E81F */
+	0,							/* U+01E820 */
+	0,							/* U+01E821 */
+	0,							/* U+01E822 */
+	0,							/* U+01E823 */
+	0,							/* U+01E824 */
+	0,							/* U+01E825 */
+	0,							/* U+01E826 */
+	0,							/* U+01E827 */
+	0,							/* U+01E828 */
+	0,							/* U+01E829 */
+	0,							/* U+01E82A */
+	0,							/* U+01E82B */
+	0,							/* U+01E82C */
+	0,							/* U+01E82D */
+	0,							/* U+01E82E */
+	0,							/* U+01E82F */
+	0,							/* U+01E830 */
+	0,							/* U+01E831 */
+	0,							/* U+01E832 */
+	0,							/* U+01E833 */
+	0,							/* U+01E834 */
+	0,							/* U+01E835 */
+	0,							/* U+01E836 */
+	0,							/* U+01E837 */
+	0,							/* U+01E838 */
+	0,							/* U+01E839 */
+	0,							/* U+01E83A */
+	0,							/* U+01E83B */
+	0,							/* U+01E83C */
+	0,							/* U+01E83D */
+	0,							/* U+01E83E */
+	0,							/* U+01E83F */
+	0,							/* U+01E840 */
+	0,							/* U+01E841 */
+	0,							/* U+01E842 */
+	0,							/* U+01E843 */
+	0,							/* U+01E844 */
+	0,							/* U+01E845 */
+	0,							/* U+01E846 */
+	0,							/* U+01E847 */
+	0,							/* U+01E848 */
+	0,							/* U+01E849 */
+	0,							/* U+01E84A */
+	0,							/* U+01E84B */
+	0,							/* U+01E84C */
+	0,							/* U+01E84D */
+	0,							/* U+01E84E */
+	0,							/* U+01E84F */
+	0,							/* U+01E850 */
+	0,							/* U+01E851 */
+	0,							/* U+01E852 */
+	0,							/* U+01E853 */
+	0,							/* U+01E854 */
+	0,							/* U+01E855 */
+	0,							/* U+01E856 */
+	0,							/* U+01E857 */
+	0,							/* U+01E858 */
+	0,							/* U+01E859 */
+	0,							/* U+01E85A */
+	0,							/* U+01E85B */
+	0,							/* U+01E85C */
+	0,							/* U+01E85D */
+	0,							/* U+01E85E */
+	0,							/* U+01E85F */
+	0,							/* U+01E860 */
+	0,							/* U+01E861 */
+	0,							/* U+01E862 */
+	0,							/* U+01E863 */
+	0,							/* U+01E864 */
+	0,							/* U+01E865 */
+	0,							/* U+01E866 */
+	0,							/* U+01E867 */
+	0,							/* U+01E868 */
+	0,							/* U+01E869 */
+	0,							/* U+01E86A */
+	0,							/* U+01E86B */
+	0,							/* U+01E86C */
+	0,							/* U+01E86D */
+	0,							/* U+01E86E */
+	0,							/* U+01E86F */
+	0,							/* U+01E870 */
+	0,							/* U+01E871 */
+	0,							/* U+01E872 */
+	0,							/* U+01E873 */
+	0,							/* U+01E874 */
+	0,							/* U+01E875 */
+	0,							/* U+01E876 */
+	0,							/* U+01E877 */
+	0,							/* U+01E878 */
+	0,							/* U+01E879 */
+	0,							/* U+01E87A */
+	0,							/* U+01E87B */
+	0,							/* U+01E87C */
+	0,							/* U+01E87D */
+	0,							/* U+01E87E */
+	0,							/* U+01E87F */
+	0,							/* U+01E880 */
+	0,							/* U+01E881 */
+	0,							/* U+01E882 */
+	0,							/* U+01E883 */
+	0,							/* U+01E884 */
+	0,							/* U+01E885 */
+	0,							/* U+01E886 */
+	0,							/* U+01E887 */
+	0,							/* U+01E888 */
+	0,							/* U+01E889 */
+	0,							/* U+01E88A */
+	0,							/* U+01E88B */
+	0,							/* U+01E88C */
+	0,							/* U+01E88D */
+	0,							/* U+01E88E */
+	0,							/* U+01E88F */
+	0,							/* U+01E890 */
+	0,							/* U+01E891 */
+	0,							/* U+01E892 */
+	0,							/* U+01E893 */
+	0,							/* U+01E894 */
+	0,							/* U+01E895 */
+	0,							/* U+01E896 */
+	0,							/* U+01E897 */
+	0,							/* U+01E898 */
+	0,							/* U+01E899 */
+	0,							/* U+01E89A */
+	0,							/* U+01E89B */
+	0,							/* U+01E89C */
+	0,							/* U+01E89D */
+	0,							/* U+01E89E */
+	0,							/* U+01E89F */
+	0,							/* U+01E8A0 */
+	0,							/* U+01E8A1 */
+	0,							/* U+01E8A2 */
+	0,							/* U+01E8A3 */
+	0,							/* U+01E8A4 */
+	0,							/* U+01E8A5 */
+	0,							/* U+01E8A6 */
+	0,							/* U+01E8A7 */
+	0,							/* U+01E8A8 */
+	0,							/* U+01E8A9 */
+	0,							/* U+01E8AA */
+	0,							/* U+01E8AB */
+	0,							/* U+01E8AC */
+	0,							/* U+01E8AD */
+	0,							/* U+01E8AE */
+	0,							/* U+01E8AF */
+	0,							/* U+01E8B0 */
+	0,							/* U+01E8B1 */
+	0,							/* U+01E8B2 */
+	0,							/* U+01E8B3 */
+	0,							/* U+01E8B4 */
+	0,							/* U+01E8B5 */
+	0,							/* U+01E8B6 */
+	0,							/* U+01E8B7 */
+	0,							/* U+01E8B8 */
+	0,							/* U+01E8B9 */
+	0,							/* U+01E8BA */
+	0,							/* U+01E8BB */
+	0,							/* U+01E8BC */
+	0,							/* U+01E8BD */
+	0,							/* U+01E8BE */
+	0,							/* U+01E8BF */
+	0,							/* U+01E8C0 */
+	0,							/* U+01E8C1 */
+	0,							/* U+01E8C2 */
+	0,							/* U+01E8C3 */
+	0,							/* U+01E8C4 */
+	0,							/* U+01E8C5 */
+	0,							/* U+01E8C6 */
+	0,							/* U+01E8C7 */
+	0,							/* U+01E8C8 */
+	0,							/* U+01E8C9 */
+	0,							/* U+01E8CA */
+	0,							/* U+01E8CB */
+	0,							/* U+01E8CC */
+	0,							/* U+01E8CD */
+	0,							/* U+01E8CE */
+	0,							/* U+01E8CF */
+	306,						/* U+01E8D0 */
+	306,						/* U+01E8D1 */
+	306,						/* U+01E8D2 */
+	306,						/* U+01E8D3 */
+	306,						/* U+01E8D4 */
+	306,						/* U+01E8D5 */
+	306,						/* U+01E8D6 */
+	0,							/* U+01E8D7 */
+	0,							/* U+01E8D8 */
+	0,							/* U+01E8D9 */
+	0,							/* U+01E8DA */
+	0,							/* U+01E8DB */
+	0,							/* U+01E8DC */
+	0,							/* U+01E8DD */
+	0,							/* U+01E8DE */
+	0,							/* U+01E8DF */
+	0,							/* U+01E8E0 */
+	0,							/* U+01E8E1 */
+	0,							/* U+01E8E2 */
+	0,							/* U+01E8E3 */
+	0,							/* U+01E8E4 */
+	0,							/* U+01E8E5 */
+	0,							/* U+01E8E6 */
+	0,							/* U+01E8E7 */
+	0,							/* U+01E8E8 */
+	0,							/* U+01E8E9 */
+	0,							/* U+01E8EA */
+	0,							/* U+01E8EB */
+	0,							/* U+01E8EC */
+	0,							/* U+01E8ED */
+	0,							/* U+01E8EE */
+	0,							/* U+01E8EF */
+	0,							/* U+01E8F0 */
+	0,							/* U+01E8F1 */
+	0,							/* U+01E8F2 */
+	0,							/* U+01E8F3 */
+	0,							/* U+01E8F4 */
+	0,							/* U+01E8F5 */
+	0,							/* U+01E8F6 */
+	0,							/* U+01E8F7 */
+	0,							/* U+01E8F8 */
+	0,							/* U+01E8F9 */
+	0,							/* U+01E8FA */
+	0,							/* U+01E8FB */
+	0,							/* U+01E8FC */
+	0,							/* U+01E8FD */
+	0,							/* U+01E8FE */
+	0,							/* U+01E8FF */
+	0,							/* U+01E900 */
+	0,							/* U+01E901 */
+	0,							/* U+01E902 */
+	0,							/* U+01E903 */
+	0,							/* U+01E904 */
+	0,							/* U+01E905 */
+	0,							/* U+01E906 */
+	0,							/* U+01E907 */
+	0,							/* U+01E908 */
+	0,							/* U+01E909 */
+	0,							/* U+01E90A */
+	0,							/* U+01E90B */
+	0,							/* U+01E90C */
+	0,							/* U+01E90D */
+	0,							/* U+01E90E */
+	0,							/* U+01E90F */
+	0,							/* U+01E910 */
+	0,							/* U+01E911 */
+	0,							/* U+01E912 */
+	0,							/* U+01E913 */
+	0,							/* U+01E914 */
+	0,							/* U+01E915 */
+	0,							/* U+01E916 */
+	0,							/* U+01E917 */
+	0,							/* U+01E918 */
+	0,							/* U+01E919 */
+	0,							/* U+01E91A */
+	0,							/* U+01E91B */
+	0,							/* U+01E91C */
+	0,							/* U+01E91D */
+	0,							/* U+01E91E */
+	0,							/* U+01E91F */
+	0,							/* U+01E920 */
+	0,							/* U+01E921 */
+	0,							/* U+01E922 */
+	0,							/* U+01E923 */
+	0,							/* U+01E924 */
+	0,							/* U+01E925 */
+	0,							/* U+01E926 */
+	0,							/* U+01E927 */
+	0,							/* U+01E928 */
+	0,							/* U+01E929 */
+	0,							/* U+01E92A */
+	0,							/* U+01E92B */
+	0,							/* U+01E92C */
+	0,							/* U+01E92D */
+	0,							/* U+01E92E */
+	0,							/* U+01E92F */
+	0,							/* U+01E930 */
+	0,							/* U+01E931 */
+	0,							/* U+01E932 */
+	0,							/* U+01E933 */
+	0,							/* U+01E934 */
+	0,							/* U+01E935 */
+	0,							/* U+01E936 */
+	0,							/* U+01E937 */
+	0,							/* U+01E938 */
+	0,							/* U+01E939 */
+	0,							/* U+01E93A */
+	0,							/* U+01E93B */
+	0,							/* U+01E93C */
+	0,							/* U+01E93D */
+	0,							/* U+01E93E */
+	0,							/* U+01E93F */
+	0,							/* U+01E940 */
+	0,							/* U+01E941 */
+	0,							/* U+01E942 */
+	0,							/* U+01E943 */
+	304,						/* U+01E944 */
+	304,						/* U+01E945 */
+	304,						/* U+01E946 */
+	304,						/* U+01E947 */
+	304,						/* U+01E948 */
+	304,						/* U+01E949 */
+	451,						/* U+01E94A */
+	0,							/* U+01E94B */
+	0,							/* U+01E94C */
+	0,							/* U+01E94D */
+	0,							/* U+01E94E */
+	0,							/* U+01E94F */
+	0,							/* U+01E950 */
+	0,							/* U+01E951 */
+	0,							/* U+01E952 */
+	0,							/* U+01E953 */
+	0,							/* U+01E954 */
+	0,							/* U+01E955 */
+	0,							/* U+01E956 */
+	0,							/* U+01E957 */
+	0,							/* U+01E958 */
+	0,							/* U+01E959 */
+	0,							/* U+01E95A */
+	0,							/* U+01E95B */
+	0,							/* U+01E95C */
+	0,							/* U+01E95D */
+	0,							/* U+01E95E */
+	0,							/* U+01E95F */
+	0,							/* U+01E960 */
+	0,							/* U+01E961 */
+	0,							/* U+01E962 */
+	0,							/* U+01E963 */
+	0,							/* U+01E964 */
+	0,							/* U+01E965 */
+	0,							/* U+01E966 */
+	0,							/* U+01E967 */
+	0,							/* U+01E968 */
+	0,							/* U+01E969 */
+	0,							/* U+01E96A */
+	0,							/* U+01E96B */
+	0,							/* U+01E96C */
+	0,							/* U+01E96D */
+	0,							/* U+01E96E */
+	0,							/* U+01E96F */
+	0,							/* U+01E970 */
+	0,							/* U+01E971 */
+	0,							/* U+01E972 */
+	0,							/* U+01E973 */
+	0,							/* U+01E974 */
+	0,							/* U+01E975 */
+	0,							/* U+01E976 */
+	0,							/* U+01E977 */
+	0,							/* U+01E978 */
+	0,							/* U+01E979 */
+	0,							/* U+01E97A */
+	0,							/* U+01E97B */
+	0,							/* U+01E97C */
+	0,							/* U+01E97D */
+	0,							/* U+01E97E */
+	0,							/* U+01E97F */
+	0,							/* U+01E980 */
+	0,							/* U+01E981 */
+	0,							/* U+01E982 */
+	0,							/* U+01E983 */
+	0,							/* U+01E984 */
+	0,							/* U+01E985 */
+	0,							/* U+01E986 */
+	0,							/* U+01E987 */
+	0,							/* U+01E988 */
+	0,							/* U+01E989 */
+	0,							/* U+01E98A */
+	0,							/* U+01E98B */
+	0,							/* U+01E98C */
+	0,							/* U+01E98D */
+	0,							/* U+01E98E */
+	0,							/* U+01E98F */
+	0,							/* U+01E990 */
+	0,							/* U+01E991 */
+	0,							/* U+01E992 */
+	0,							/* U+01E993 */
+	0,							/* U+01E994 */
+	0,							/* U+01E995 */
+	0,							/* U+01E996 */
+	0,							/* U+01E997 */
+	0,							/* U+01E998 */
+	0,							/* U+01E999 */
+	0,							/* U+01E99A */
+	0,							/* U+01E99B */
+	0,							/* U+01E99C */
+	0,							/* U+01E99D */
+	0,							/* U+01E99E */
+	0,							/* U+01E99F */
+	0,							/* U+01E9A0 */
+	0,							/* U+01E9A1 */
+	0,							/* U+01E9A2 */
+	0,							/* U+01E9A3 */
+	0,							/* U+01E9A4 */
+	0,							/* U+01E9A5 */
+	0,							/* U+01E9A6 */
+	0,							/* U+01E9A7 */
+	0,							/* U+01E9A8 */
+	0,							/* U+01E9A9 */
+	0,							/* U+01E9AA */
+	0,							/* U+01E9AB */
+	0,							/* U+01E9AC */
+	0,							/* U+01E9AD */
+	0,							/* U+01E9AE */
+	0,							/* U+01E9AF */
+	0,							/* U+01E9B0 */
+	0,							/* U+01E9B1 */
+	0,							/* U+01E9B2 */
+	0,							/* U+01E9B3 */
+	0,							/* U+01E9B4 */
+	0,							/* U+01E9B5 */
+	0,							/* U+01E9B6 */
+	0,							/* U+01E9B7 */
+	0,							/* U+01E9B8 */
+	0,							/* U+01E9B9 */
+	0,							/* U+01E9BA */
+	0,							/* U+01E9BB */
+	0,							/* U+01E9BC */
+	0,							/* U+01E9BD */
+	0,							/* U+01E9BE */
+	0,							/* U+01E9BF */
+	0,							/* U+01E9C0 */
+	0,							/* U+01E9C1 */
+	0,							/* U+01E9C2 */
+	0,							/* U+01E9C3 */
+	0,							/* U+01E9C4 */
+	0,							/* U+01E9C5 */
+	0,							/* U+01E9C6 */
+	0,							/* U+01E9C7 */
+	0,							/* U+01E9C8 */
+	0,							/* U+01E9C9 */
+	0,							/* U+01E9CA */
+	0,							/* U+01E9CB */
+	0,							/* U+01E9CC */
+	0,							/* U+01E9CD */
+	0,							/* U+01E9CE */
+	0,							/* U+01E9CF */
+	0,							/* U+01E9D0 */
+	0,							/* U+01E9D1 */
+	0,							/* U+01E9D2 */
+	0,							/* U+01E9D3 */
+	0,							/* U+01E9D4 */
+	0,							/* U+01E9D5 */
+	0,							/* U+01E9D6 */
+	0,							/* U+01E9D7 */
+	0,							/* U+01E9D8 */
+	0,							/* U+01E9D9 */
+	0,							/* U+01E9DA */
+	0,							/* U+01E9DB */
+	0,							/* U+01E9DC */
+	0,							/* U+01E9DD */
+	0,							/* U+01E9DE */
+	0,							/* U+01E9DF */
+	0,							/* U+01E9E0 */
+	0,							/* U+01E9E1 */
+	0,							/* U+01E9E2 */
+	0,							/* U+01E9E3 */
+	0,							/* U+01E9E4 */
+	0,							/* U+01E9E5 */
+	0,							/* U+01E9E6 */
+	0,							/* U+01E9E7 */
+	0,							/* U+01E9E8 */
+	0,							/* U+01E9E9 */
+	0,							/* U+01E9EA */
+	0,							/* U+01E9EB */
+	0,							/* U+01E9EC */
+	0,							/* U+01E9ED */
+	0,							/* U+01E9EE */
+	0,							/* U+01E9EF */
+	0,							/* U+01E9F0 */
+	0,							/* U+01E9F1 */
+	0,							/* U+01E9F2 */
+	0,							/* U+01E9F3 */
+	0,							/* U+01E9F4 */
+	0,							/* U+01E9F5 */
+	0,							/* U+01E9F6 */
+	0,							/* U+01E9F7 */
+	0,							/* U+01E9F8 */
+	0,							/* U+01E9F9 */
+	0,							/* U+01E9FA */
+	0,							/* U+01E9FB */
+	0,							/* U+01E9FC */
+	0,							/* U+01E9FD */
+	0,							/* U+01E9FE */
+	0,							/* U+01E9FF */
+	0,							/* U+01EA00 */
+	0,							/* U+01EA01 */
+	0,							/* U+01EA02 */
+	0,							/* U+01EA03 */
+	0,							/* U+01EA04 */
+	0,							/* U+01EA05 */
+	0,							/* U+01EA06 */
+	0,							/* U+01EA07 */
+	0,							/* U+01EA08 */
+	0,							/* U+01EA09 */
+	0,							/* U+01EA0A */
+	0,							/* U+01EA0B */
+	0,							/* U+01EA0C */
+	0,							/* U+01EA0D */
+	0,							/* U+01EA0E */
+	0,							/* U+01EA0F */
+	0,							/* U+01EA10 */
+	0,							/* U+01EA11 */
+	0,							/* U+01EA12 */
+	0,							/* U+01EA13 */
+	0,							/* U+01EA14 */
+	0,							/* U+01EA15 */
+	0,							/* U+01EA16 */
+	0,							/* U+01EA17 */
+	0,							/* U+01EA18 */
+	0,							/* U+01EA19 */
+	0,							/* U+01EA1A */
+	0,							/* U+01EA1B */
+	0,							/* U+01EA1C */
+	0,							/* U+01EA1D */
+	0,							/* U+01EA1E */
+	0,							/* U+01EA1F */
+	0,							/* U+01EA20 */
+	0,							/* U+01EA21 */
+	0,							/* U+01EA22 */
+	0,							/* U+01EA23 */
+	0,							/* U+01EA24 */
+	0,							/* U+01EA25 */
+	0,							/* U+01EA26 */
+	0,							/* U+01EA27 */
+	0,							/* U+01EA28 */
+	0,							/* U+01EA29 */
+	0,							/* U+01EA2A */
+	0,							/* U+01EA2B */
+	0,							/* U+01EA2C */
+	0,							/* U+01EA2D */
+	0,							/* U+01EA2E */
+	0,							/* U+01EA2F */
+	0,							/* U+01EA30 */
+	0,							/* U+01EA31 */
+	0,							/* U+01EA32 */
+	0,							/* U+01EA33 */
+	0,							/* U+01EA34 */
+	0,							/* U+01EA35 */
+	0,							/* U+01EA36 */
+	0,							/* U+01EA37 */
+	0,							/* U+01EA38 */
+	0,							/* U+01EA39 */
+	0,							/* U+01EA3A */
+	0,							/* U+01EA3B */
+	0,							/* U+01EA3C */
+	0,							/* U+01EA3D */
+	0,							/* U+01EA3E */
+	0,							/* U+01EA3F */
+	0,							/* U+01EA40 */
+	0,							/* U+01EA41 */
+	0,							/* U+01EA42 */
+	0,							/* U+01EA43 */
+	0,							/* U+01EA44 */
+	0,							/* U+01EA45 */
+	0,							/* U+01EA46 */
+	0,							/* U+01EA47 */
+	0,							/* U+01EA48 */
+	0,							/* U+01EA49 */
+	0,							/* U+01EA4A */
+	0,							/* U+01EA4B */
+	0,							/* U+01EA4C */
+	0,							/* U+01EA4D */
+	0,							/* U+01EA4E */
+	0,							/* U+01EA4F */
+	0,							/* U+01EA50 */
+	0,							/* U+01EA51 */
+	0,							/* U+01EA52 */
+	0,							/* U+01EA53 */
+	0,							/* U+01EA54 */
+	0,							/* U+01EA55 */
+	0,							/* U+01EA56 */
+	0,							/* U+01EA57 */
+	0,							/* U+01EA58 */
+	0,							/* U+01EA59 */
+	0,							/* U+01EA5A */
+	0,							/* U+01EA5B */
+	0,							/* U+01EA5C */
+	0,							/* U+01EA5D */
+	0,							/* U+01EA5E */
+	0,							/* U+01EA5F */
+	0,							/* U+01EA60 */
+	0,							/* U+01EA61 */
+	0,							/* U+01EA62 */
+	0,							/* U+01EA63 */
+	0,							/* U+01EA64 */
+	0,							/* U+01EA65 */
+	0,							/* U+01EA66 */
+	0,							/* U+01EA67 */
+	0,							/* U+01EA68 */
+	0,							/* U+01EA69 */
+	0,							/* U+01EA6A */
+	0,							/* U+01EA6B */
+	0,							/* U+01EA6C */
+	0,							/* U+01EA6D */
+	0,							/* U+01EA6E */
+	0,							/* U+01EA6F */
+	0,							/* U+01EA70 */
+	0,							/* U+01EA71 */
+	0,							/* U+01EA72 */
+	0,							/* U+01EA73 */
+	0,							/* U+01EA74 */
+	0,							/* U+01EA75 */
+	0,							/* U+01EA76 */
+	0,							/* U+01EA77 */
+	0,							/* U+01EA78 */
+	0,							/* U+01EA79 */
+	0,							/* U+01EA7A */
+	0,							/* U+01EA7B */
+	0,							/* U+01EA7C */
+	0,							/* U+01EA7D */
+	0,							/* U+01EA7E */
+	0,							/* U+01EA7F */
+	0,							/* U+01EA80 */
+	0,							/* U+01EA81 */
+	0,							/* U+01EA82 */
+	0,							/* U+01EA83 */
+	0,							/* U+01EA84 */
+	0,							/* U+01EA85 */
+	0,							/* U+01EA86 */
+	0,							/* U+01EA87 */
+	0,							/* U+01EA88 */
+	0,							/* U+01EA89 */
+	0,							/* U+01EA8A */
+	0,							/* U+01EA8B */
+	0,							/* U+01EA8C */
+	0,							/* U+01EA8D */
+	0,							/* U+01EA8E */
+	0,							/* U+01EA8F */
+	0,							/* U+01EA90 */
+	0,							/* U+01EA91 */
+	0,							/* U+01EA92 */
+	0,							/* U+01EA93 */
+	0,							/* U+01EA94 */
+	0,							/* U+01EA95 */
+	0,							/* U+01EA96 */
+	0,							/* U+01EA97 */
+	0,							/* U+01EA98 */
+	0,							/* U+01EA99 */
+	0,							/* U+01EA9A */
+	0,							/* U+01EA9B */
+	0,							/* U+01EA9C */
+	0,							/* U+01EA9D */
+	0,							/* U+01EA9E */
+	0,							/* U+01EA9F */
+	0,							/* U+01EAA0 */
+	0,							/* U+01EAA1 */
+	0,							/* U+01EAA2 */
+	0,							/* U+01EAA3 */
+	0,							/* U+01EAA4 */
+	0,							/* U+01EAA5 */
+	0,							/* U+01EAA6 */
+	0,							/* U+01EAA7 */
+	0,							/* U+01EAA8 */
+	0,							/* U+01EAA9 */
+	0,							/* U+01EAAA */
+	0,							/* U+01EAAB */
+	0,							/* U+01EAAC */
+	0,							/* U+01EAAD */
+	0,							/* U+01EAAE */
+	0,							/* U+01EAAF */
+	0,							/* U+01EAB0 */
+	0,							/* U+01EAB1 */
+	0,							/* U+01EAB2 */
+	0,							/* U+01EAB3 */
+	0,							/* U+01EAB4 */
+	0,							/* U+01EAB5 */
+	0,							/* U+01EAB6 */
+	0,							/* U+01EAB7 */
+	0,							/* U+01EAB8 */
+	0,							/* U+01EAB9 */
+	0,							/* U+01EABA */
+	0,							/* U+01EABB */
+	0,							/* U+01EABC */
+	0,							/* U+01EABD */
+	0,							/* U+01EABE */
+	0,							/* U+01EABF */
+	0,							/* U+01EAC0 */
+	0,							/* U+01EAC1 */
+	0,							/* U+01EAC2 */
+	0,							/* U+01EAC3 */
+	0,							/* U+01EAC4 */
+	0,							/* U+01EAC5 */
+	0,							/* U+01EAC6 */
+	0,							/* U+01EAC7 */
+	0,							/* U+01EAC8 */
+	0,							/* U+01EAC9 */
+	0,							/* U+01EACA */
+	0,							/* U+01EACB */
+	0,							/* U+01EACC */
+	0,							/* U+01EACD */
+	0,							/* U+01EACE */
+	0,							/* U+01EACF */
+	0,							/* U+01EAD0 */
+	0,							/* U+01EAD1 */
+	0,							/* U+01EAD2 */
+	0,							/* U+01EAD3 */
+	0,							/* U+01EAD4 */
+	0,							/* U+01EAD5 */
+	0,							/* U+01EAD6 */
+	0,							/* U+01EAD7 */
+	0,							/* U+01EAD8 */
+	0,							/* U+01EAD9 */
+	0,							/* U+01EADA */
+	0,							/* U+01EADB */
+	0,							/* U+01EADC */
+	0,							/* U+01EADD */
+	0,							/* U+01EADE */
+	0,							/* U+01EADF */
+	0,							/* U+01EAE0 */
+	0,							/* U+01EAE1 */
+	0,							/* U+01EAE2 */
+	0,							/* U+01EAE3 */
+	0,							/* U+01EAE4 */
+	0,							/* U+01EAE5 */
+	0,							/* U+01EAE6 */
+	0,							/* U+01EAE7 */
+	0,							/* U+01EAE8 */
+	0,							/* U+01EAE9 */
+	0,							/* U+01EAEA */
+	0,							/* U+01EAEB */
+	0,							/* U+01EAEC */
+	0,							/* U+01EAED */
+	0,							/* U+01EAEE */
+	0,							/* U+01EAEF */
+	0,							/* U+01EAF0 */
+	0,							/* U+01EAF1 */
+	0,							/* U+01EAF2 */
+	0,							/* U+01EAF3 */
+	0,							/* U+01EAF4 */
+	0,							/* U+01EAF5 */
+	0,							/* U+01EAF6 */
+	0,							/* U+01EAF7 */
+	0,							/* U+01EAF8 */
+	0,							/* U+01EAF9 */
+	0,							/* U+01EAFA */
+	0,							/* U+01EAFB */
+	0,							/* U+01EAFC */
+	0,							/* U+01EAFD */
+	0,							/* U+01EAFE */
+	0,							/* U+01EAFF */
+	0,							/* U+01EB00 */
+	0,							/* U+01EB01 */
+	0,							/* U+01EB02 */
+	0,							/* U+01EB03 */
+	0,							/* U+01EB04 */
+	0,							/* U+01EB05 */
+	0,							/* U+01EB06 */
+	0,							/* U+01EB07 */
+	0,							/* U+01EB08 */
+	0,							/* U+01EB09 */
+	0,							/* U+01EB0A */
+	0,							/* U+01EB0B */
+	0,							/* U+01EB0C */
+	0,							/* U+01EB0D */
+	0,							/* U+01EB0E */
+	0,							/* U+01EB0F */
+	0,							/* U+01EB10 */
+	0,							/* U+01EB11 */
+	0,							/* U+01EB12 */
+	0,							/* U+01EB13 */
+	0,							/* U+01EB14 */
+	0,							/* U+01EB15 */
+	0,							/* U+01EB16 */
+	0,							/* U+01EB17 */
+	0,							/* U+01EB18 */
+	0,							/* U+01EB19 */
+	0,							/* U+01EB1A */
+	0,							/* U+01EB1B */
+	0,							/* U+01EB1C */
+	0,							/* U+01EB1D */
+	0,							/* U+01EB1E */
+	0,							/* U+01EB1F */
+	0,							/* U+01EB20 */
+	0,							/* U+01EB21 */
+	0,							/* U+01EB22 */
+	0,							/* U+01EB23 */
+	0,							/* U+01EB24 */
+	0,							/* U+01EB25 */
+	0,							/* U+01EB26 */
+	0,							/* U+01EB27 */
+	0,							/* U+01EB28 */
+	0,							/* U+01EB29 */
+	0,							/* U+01EB2A */
+	0,							/* U+01EB2B */
+	0,							/* U+01EB2C */
+	0,							/* U+01EB2D */
+	0,							/* U+01EB2E */
+	0,							/* U+01EB2F */
+	0,							/* U+01EB30 */
+	0,							/* U+01EB31 */
+	0,							/* U+01EB32 */
+	0,							/* U+01EB33 */
+	0,							/* U+01EB34 */
+	0,							/* U+01EB35 */
+	0,							/* U+01EB36 */
+	0,							/* U+01EB37 */
+	0,							/* U+01EB38 */
+	0,							/* U+01EB39 */
+	0,							/* U+01EB3A */
+	0,							/* U+01EB3B */
+	0,							/* U+01EB3C */
+	0,							/* U+01EB3D */
+	0,							/* U+01EB3E */
+	0,							/* U+01EB3F */
+	0,							/* U+01EB40 */
+	0,							/* U+01EB41 */
+	0,							/* U+01EB42 */
+	0,							/* U+01EB43 */
+	0,							/* U+01EB44 */
+	0,							/* U+01EB45 */
+	0,							/* U+01EB46 */
+	0,							/* U+01EB47 */
+	0,							/* U+01EB48 */
+	0,							/* U+01EB49 */
+	0,							/* U+01EB4A */
+	0,							/* U+01EB4B */
+	0,							/* U+01EB4C */
+	0,							/* U+01EB4D */
+	0,							/* U+01EB4E */
+	0,							/* U+01EB4F */
+	0,							/* U+01EB50 */
+	0,							/* U+01EB51 */
+	0,							/* U+01EB52 */
+	0,							/* U+01EB53 */
+	0,							/* U+01EB54 */
+	0,							/* U+01EB55 */
+	0,							/* U+01EB56 */
+	0,							/* U+01EB57 */
+	0,							/* U+01EB58 */
+	0,							/* U+01EB59 */
+	0,							/* U+01EB5A */
+	0,							/* U+01EB5B */
+	0,							/* U+01EB5C */
+	0,							/* U+01EB5D */
+	0,							/* U+01EB5E */
+	0,							/* U+01EB5F */
+	0,							/* U+01EB60 */
+	0,							/* U+01EB61 */
+	0,							/* U+01EB62 */
+	0,							/* U+01EB63 */
+	0,							/* U+01EB64 */
+	0,							/* U+01EB65 */
+	0,							/* U+01EB66 */
+	0,							/* U+01EB67 */
+	0,							/* U+01EB68 */
+	0,							/* U+01EB69 */
+	0,							/* U+01EB6A */
+	0,							/* U+01EB6B */
+	0,							/* U+01EB6C */
+	0,							/* U+01EB6D */
+	0,							/* U+01EB6E */
+	0,							/* U+01EB6F */
+	0,							/* U+01EB70 */
+	0,							/* U+01EB71 */
+	0,							/* U+01EB72 */
+	0,							/* U+01EB73 */
+	0,							/* U+01EB74 */
+	0,							/* U+01EB75 */
+	0,							/* U+01EB76 */
+	0,							/* U+01EB77 */
+	0,							/* U+01EB78 */
+	0,							/* U+01EB79 */
+	0,							/* U+01EB7A */
+	0,							/* U+01EB7B */
+	0,							/* U+01EB7C */
+	0,							/* U+01EB7D */
+	0,							/* U+01EB7E */
+	0,							/* U+01EB7F */
+	0,							/* U+01EB80 */
+	0,							/* U+01EB81 */
+	0,							/* U+01EB82 */
+	0,							/* U+01EB83 */
+	0,							/* U+01EB84 */
+	0,							/* U+01EB85 */
+	0,							/* U+01EB86 */
+	0,							/* U+01EB87 */
+	0,							/* U+01EB88 */
+	0,							/* U+01EB89 */
+	0,							/* U+01EB8A */
+	0,							/* U+01EB8B */
+	0,							/* U+01EB8C */
+	0,							/* U+01EB8D */
+	0,							/* U+01EB8E */
+	0,							/* U+01EB8F */
+	0,							/* U+01EB90 */
+	0,							/* U+01EB91 */
+	0,							/* U+01EB92 */
+	0,							/* U+01EB93 */
+	0,							/* U+01EB94 */
+	0,							/* U+01EB95 */
+	0,							/* U+01EB96 */
+	0,							/* U+01EB97 */
+	0,							/* U+01EB98 */
+	0,							/* U+01EB99 */
+	0,							/* U+01EB9A */
+	0,							/* U+01EB9B */
+	0,							/* U+01EB9C */
+	0,							/* U+01EB9D */
+	0,							/* U+01EB9E */
+	0,							/* U+01EB9F */
+	0,							/* U+01EBA0 */
+	0,							/* U+01EBA1 */
+	0,							/* U+01EBA2 */
+	0,							/* U+01EBA3 */
+	0,							/* U+01EBA4 */
+	0,							/* U+01EBA5 */
+	0,							/* U+01EBA6 */
+	0,							/* U+01EBA7 */
+	0,							/* U+01EBA8 */
+	0,							/* U+01EBA9 */
+	0,							/* U+01EBAA */
+	0,							/* U+01EBAB */
+	0,							/* U+01EBAC */
+	0,							/* U+01EBAD */
+	0,							/* U+01EBAE */
+	0,							/* U+01EBAF */
+	0,							/* U+01EBB0 */
+	0,							/* U+01EBB1 */
+	0,							/* U+01EBB2 */
+	0,							/* U+01EBB3 */
+	0,							/* U+01EBB4 */
+	0,							/* U+01EBB5 */
+	0,							/* U+01EBB6 */
+	0,							/* U+01EBB7 */
+	0,							/* U+01EBB8 */
+	0,							/* U+01EBB9 */
+	0,							/* U+01EBBA */
+	0,							/* U+01EBBB */
+	0,							/* U+01EBBC */
+	0,							/* U+01EBBD */
+	0,							/* U+01EBBE */
+	0,							/* U+01EBBF */
+	0,							/* U+01EBC0 */
+	0,							/* U+01EBC1 */
+	0,							/* U+01EBC2 */
+	0,							/* U+01EBC3 */
+	0,							/* U+01EBC4 */
+	0,							/* U+01EBC5 */
+	0,							/* U+01EBC6 */
+	0,							/* U+01EBC7 */
+	0,							/* U+01EBC8 */
+	0,							/* U+01EBC9 */
+	0,							/* U+01EBCA */
+	0,							/* U+01EBCB */
+	0,							/* U+01EBCC */
+	0,							/* U+01EBCD */
+	0,							/* U+01EBCE */
+	0,							/* U+01EBCF */
+	0,							/* U+01EBD0 */
+	0,							/* U+01EBD1 */
+	0,							/* U+01EBD2 */
+	0,							/* U+01EBD3 */
+	0,							/* U+01EBD4 */
+	0,							/* U+01EBD5 */
+	0,							/* U+01EBD6 */
+	0,							/* U+01EBD7 */
+	0,							/* U+01EBD8 */
+	0,							/* U+01EBD9 */
+	0,							/* U+01EBDA */
+	0,							/* U+01EBDB */
+	0,							/* U+01EBDC */
+	0,							/* U+01EBDD */
+	0,							/* U+01EBDE */
+	0,							/* U+01EBDF */
+	0,							/* U+01EBE0 */
+	0,							/* U+01EBE1 */
+	0,							/* U+01EBE2 */
+	0,							/* U+01EBE3 */
+	0,							/* U+01EBE4 */
+	0,							/* U+01EBE5 */
+	0,							/* U+01EBE6 */
+	0,							/* U+01EBE7 */
+	0,							/* U+01EBE8 */
+	0,							/* U+01EBE9 */
+	0,							/* U+01EBEA */
+	0,							/* U+01EBEB */
+	0,							/* U+01EBEC */
+	0,							/* U+01EBED */
+	0,							/* U+01EBEE */
+	0,							/* U+01EBEF */
+	0,							/* U+01EBF0 */
+	0,							/* U+01EBF1 */
+	0,							/* U+01EBF2 */
+	0,							/* U+01EBF3 */
+	0,							/* U+01EBF4 */
+	0,							/* U+01EBF5 */
+	0,							/* U+01EBF6 */
+	0,							/* U+01EBF7 */
+	0,							/* U+01EBF8 */
+	0,							/* U+01EBF9 */
+	0,							/* U+01EBFA */
+	0,							/* U+01EBFB */
+	0,							/* U+01EBFC */
+	0,							/* U+01EBFD */
+	0,							/* U+01EBFE */
+	0,							/* U+01EBFF */
+	0,							/* U+01EC00 */
+	0,							/* U+01EC01 */
+	0,							/* U+01EC02 */
+	0,							/* U+01EC03 */
+	0,							/* U+01EC04 */
+	0,							/* U+01EC05 */
+	0,							/* U+01EC06 */
+	0,							/* U+01EC07 */
+	0,							/* U+01EC08 */
+	0,							/* U+01EC09 */
+	0,							/* U+01EC0A */
+	0,							/* U+01EC0B */
+	0,							/* U+01EC0C */
+	0,							/* U+01EC0D */
+	0,							/* U+01EC0E */
+	0,							/* U+01EC0F */
+	0,							/* U+01EC10 */
+	0,							/* U+01EC11 */
+	0,							/* U+01EC12 */
+	0,							/* U+01EC13 */
+	0,							/* U+01EC14 */
+	0,							/* U+01EC15 */
+	0,							/* U+01EC16 */
+	0,							/* U+01EC17 */
+	0,							/* U+01EC18 */
+	0,							/* U+01EC19 */
+	0,							/* U+01EC1A */
+	0,							/* U+01EC1B */
+	0,							/* U+01EC1C */
+	0,							/* U+01EC1D */
+	0,							/* U+01EC1E */
+	0,							/* U+01EC1F */
+	0,							/* U+01EC20 */
+	0,							/* U+01EC21 */
+	0,							/* U+01EC22 */
+	0,							/* U+01EC23 */
+	0,							/* U+01EC24 */
+	0,							/* U+01EC25 */
+	0,							/* U+01EC26 */
+	0,							/* U+01EC27 */
+	0,							/* U+01EC28 */
+	0,							/* U+01EC29 */
+	0,							/* U+01EC2A */
+	0,							/* U+01EC2B */
+	0,							/* U+01EC2C */
+	0,							/* U+01EC2D */
+	0,							/* U+01EC2E */
+	0,							/* U+01EC2F */
+	0,							/* U+01EC30 */
+	0,							/* U+01EC31 */
+	0,							/* U+01EC32 */
+	0,							/* U+01EC33 */
+	0,							/* U+01EC34 */
+	0,							/* U+01EC35 */
+	0,							/* U+01EC36 */
+	0,							/* U+01EC37 */
+	0,							/* U+01EC38 */
+	0,							/* U+01EC39 */
+	0,							/* U+01EC3A */
+	0,							/* U+01EC3B */
+	0,							/* U+01EC3C */
+	0,							/* U+01EC3D */
+	0,							/* U+01EC3E */
+	0,							/* U+01EC3F */
+	0,							/* U+01EC40 */
+	0,							/* U+01EC41 */
+	0,							/* U+01EC42 */
+	0,							/* U+01EC43 */
+	0,							/* U+01EC44 */
+	0,							/* U+01EC45 */
+	0,							/* U+01EC46 */
+	0,							/* U+01EC47 */
+	0,							/* U+01EC48 */
+	0,							/* U+01EC49 */
+	0,							/* U+01EC4A */
+	0,							/* U+01EC4B */
+	0,							/* U+01EC4C */
+	0,							/* U+01EC4D */
+	0,							/* U+01EC4E */
+	0,							/* U+01EC4F */
+	0,							/* U+01EC50 */
+	0,							/* U+01EC51 */
+	0,							/* U+01EC52 */
+	0,							/* U+01EC53 */
+	0,							/* U+01EC54 */
+	0,							/* U+01EC55 */
+	0,							/* U+01EC56 */
+	0,							/* U+01EC57 */
+	0,							/* U+01EC58 */
+	0,							/* U+01EC59 */
+	0,							/* U+01EC5A */
+	0,							/* U+01EC5B */
+	0,							/* U+01EC5C */
+	0,							/* U+01EC5D */
+	0,							/* U+01EC5E */
+	0,							/* U+01EC5F */
+	0,							/* U+01EC60 */
+	0,							/* U+01EC61 */
+	0,							/* U+01EC62 */
+	0,							/* U+01EC63 */
+	0,							/* U+01EC64 */
+	0,							/* U+01EC65 */
+	0,							/* U+01EC66 */
+	0,							/* U+01EC67 */
+	0,							/* U+01EC68 */
+	0,							/* U+01EC69 */
+	0,							/* U+01EC6A */
+	0,							/* U+01EC6B */
+	0,							/* U+01EC6C */
+	0,							/* U+01EC6D */
+	0,							/* U+01EC6E */
+	0,							/* U+01EC6F */
+	0,							/* U+01EC70 */
+	0,							/* U+01EC71 */
+	0,							/* U+01EC72 */
+	0,							/* U+01EC73 */
+	0,							/* U+01EC74 */
+	0,							/* U+01EC75 */
+	0,							/* U+01EC76 */
+	0,							/* U+01EC77 */
+	0,							/* U+01EC78 */
+	0,							/* U+01EC79 */
+	0,							/* U+01EC7A */
+	0,							/* U+01EC7B */
+	0,							/* U+01EC7C */
+	0,							/* U+01EC7D */
+	0,							/* U+01EC7E */
+	0,							/* U+01EC7F */
+	0,							/* U+01EC80 */
+	0,							/* U+01EC81 */
+	0,							/* U+01EC82 */
+	0,							/* U+01EC83 */
+	0,							/* U+01EC84 */
+	0,							/* U+01EC85 */
+	0,							/* U+01EC86 */
+	0,							/* U+01EC87 */
+	0,							/* U+01EC88 */
+	0,							/* U+01EC89 */
+	0,							/* U+01EC8A */
+	0,							/* U+01EC8B */
+	0,							/* U+01EC8C */
+	0,							/* U+01EC8D */
+	0,							/* U+01EC8E */
+	0,							/* U+01EC8F */
+	0,							/* U+01EC90 */
+	0,							/* U+01EC91 */
+	0,							/* U+01EC92 */
+	0,							/* U+01EC93 */
+	0,							/* U+01EC94 */
+	0,							/* U+01EC95 */
+	0,							/* U+01EC96 */
+	0,							/* U+01EC97 */
+	0,							/* U+01EC98 */
+	0,							/* U+01EC99 */
+	0,							/* U+01EC9A */
+	0,							/* U+01EC9B */
+	0,							/* U+01EC9C */
+	0,							/* U+01EC9D */
+	0,							/* U+01EC9E */
+	0,							/* U+01EC9F */
+	0,							/* U+01ECA0 */
+	0,							/* U+01ECA1 */
+	0,							/* U+01ECA2 */
+	0,							/* U+01ECA3 */
+	0,							/* U+01ECA4 */
+	0,							/* U+01ECA5 */
+	0,							/* U+01ECA6 */
+	0,							/* U+01ECA7 */
+	0,							/* U+01ECA8 */
+	0,							/* U+01ECA9 */
+	0,							/* U+01ECAA */
+	0,							/* U+01ECAB */
+	0,							/* U+01ECAC */
+	0,							/* U+01ECAD */
+	0,							/* U+01ECAE */
+	0,							/* U+01ECAF */
+	0,							/* U+01ECB0 */
+	0,							/* U+01ECB1 */
+	0,							/* U+01ECB2 */
+	0,							/* U+01ECB3 */
+	0,							/* U+01ECB4 */
+	0,							/* U+01ECB5 */
+	0,							/* U+01ECB6 */
+	0,							/* U+01ECB7 */
+	0,							/* U+01ECB8 */
+	0,							/* U+01ECB9 */
+	0,							/* U+01ECBA */
+	0,							/* U+01ECBB */
+	0,							/* U+01ECBC */
+	0,							/* U+01ECBD */
+	0,							/* U+01ECBE */
+	0,							/* U+01ECBF */
+	0,							/* U+01ECC0 */
+	0,							/* U+01ECC1 */
+	0,							/* U+01ECC2 */
+	0,							/* U+01ECC3 */
+	0,							/* U+01ECC4 */
+	0,							/* U+01ECC5 */
+	0,							/* U+01ECC6 */
+	0,							/* U+01ECC7 */
+	0,							/* U+01ECC8 */
+	0,							/* U+01ECC9 */
+	0,							/* U+01ECCA */
+	0,							/* U+01ECCB */
+	0,							/* U+01ECCC */
+	0,							/* U+01ECCD */
+	0,							/* U+01ECCE */
+	0,							/* U+01ECCF */
+	0,							/* U+01ECD0 */
+	0,							/* U+01ECD1 */
+	0,							/* U+01ECD2 */
+	0,							/* U+01ECD3 */
+	0,							/* U+01ECD4 */
+	0,							/* U+01ECD5 */
+	0,							/* U+01ECD6 */
+	0,							/* U+01ECD7 */
+	0,							/* U+01ECD8 */
+	0,							/* U+01ECD9 */
+	0,							/* U+01ECDA */
+	0,							/* U+01ECDB */
+	0,							/* U+01ECDC */
+	0,							/* U+01ECDD */
+	0,							/* U+01ECDE */
+	0,							/* U+01ECDF */
+	0,							/* U+01ECE0 */
+	0,							/* U+01ECE1 */
+	0,							/* U+01ECE2 */
+	0,							/* U+01ECE3 */
+	0,							/* U+01ECE4 */
+	0,							/* U+01ECE5 */
+	0,							/* U+01ECE6 */
+	0,							/* U+01ECE7 */
+	0,							/* U+01ECE8 */
+	0,							/* U+01ECE9 */
+	0,							/* U+01ECEA */
+	0,							/* U+01ECEB */
+	0,							/* U+01ECEC */
+	0,							/* U+01ECED */
+	0,							/* U+01ECEE */
+	0,							/* U+01ECEF */
+	0,							/* U+01ECF0 */
+	0,							/* U+01ECF1 */
+	0,							/* U+01ECF2 */
+	0,							/* U+01ECF3 */
+	0,							/* U+01ECF4 */
+	0,							/* U+01ECF5 */
+	0,							/* U+01ECF6 */
+	0,							/* U+01ECF7 */
+	0,							/* U+01ECF8 */
+	0,							/* U+01ECF9 */
+	0,							/* U+01ECFA */
+	0,							/* U+01ECFB */
+	0,							/* U+01ECFC */
+	0,							/* U+01ECFD */
+	0,							/* U+01ECFE */
+	0,							/* U+01ECFF */
+	0,							/* U+01ED00 */
+	0,							/* U+01ED01 */
+	0,							/* U+01ED02 */
+	0,							/* U+01ED03 */
+	0,							/* U+01ED04 */
+	0,							/* U+01ED05 */
+	0,							/* U+01ED06 */
+	0,							/* U+01ED07 */
+	0,							/* U+01ED08 */
+	0,							/* U+01ED09 */
+	0,							/* U+01ED0A */
+	0,							/* U+01ED0B */
+	0,							/* U+01ED0C */
+	0,							/* U+01ED0D */
+	0,							/* U+01ED0E */
+	0,							/* U+01ED0F */
+	0,							/* U+01ED10 */
+	0,							/* U+01ED11 */
+	0,							/* U+01ED12 */
+	0,							/* U+01ED13 */
+	0,							/* U+01ED14 */
+	0,							/* U+01ED15 */
+	0,							/* U+01ED16 */
+	0,							/* U+01ED17 */
+	0,							/* U+01ED18 */
+	0,							/* U+01ED19 */
+	0,							/* U+01ED1A */
+	0,							/* U+01ED1B */
+	0,							/* U+01ED1C */
+	0,							/* U+01ED1D */
+	0,							/* U+01ED1E */
+	0,							/* U+01ED1F */
+	0,							/* U+01ED20 */
+	0,							/* U+01ED21 */
+	0,							/* U+01ED22 */
+	0,							/* U+01ED23 */
+	0,							/* U+01ED24 */
+	0,							/* U+01ED25 */
+	0,							/* U+01ED26 */
+	0,							/* U+01ED27 */
+	0,							/* U+01ED28 */
+	0,							/* U+01ED29 */
+	0,							/* U+01ED2A */
+	0,							/* U+01ED2B */
+	0,							/* U+01ED2C */
+	0,							/* U+01ED2D */
+	0,							/* U+01ED2E */
+	0,							/* U+01ED2F */
+	0,							/* U+01ED30 */
+	0,							/* U+01ED31 */
+	0,							/* U+01ED32 */
+	0,							/* U+01ED33 */
+	0,							/* U+01ED34 */
+	0,							/* U+01ED35 */
+	0,							/* U+01ED36 */
+	0,							/* U+01ED37 */
+	0,							/* U+01ED38 */
+	0,							/* U+01ED39 */
+	0,							/* U+01ED3A */
+	0,							/* U+01ED3B */
+	0,							/* U+01ED3C */
+	0,							/* U+01ED3D */
+	0,							/* U+01ED3E */
+	0,							/* U+01ED3F */
+	0,							/* U+01ED40 */
+	0,							/* U+01ED41 */
+	0,							/* U+01ED42 */
+	0,							/* U+01ED43 */
+	0,							/* U+01ED44 */
+	0,							/* U+01ED45 */
+	0,							/* U+01ED46 */
+	0,							/* U+01ED47 */
+	0,							/* U+01ED48 */
+	0,							/* U+01ED49 */
+	0,							/* U+01ED4A */
+	0,							/* U+01ED4B */
+	0,							/* U+01ED4C */
+	0,							/* U+01ED4D */
+	0,							/* U+01ED4E */
+	0,							/* U+01ED4F */
+	0,							/* U+01ED50 */
+	0,							/* U+01ED51 */
+	0,							/* U+01ED52 */
+	0,							/* U+01ED53 */
+	0,							/* U+01ED54 */
+	0,							/* U+01ED55 */
+	0,							/* U+01ED56 */
+	0,							/* U+01ED57 */
+	0,							/* U+01ED58 */
+	0,							/* U+01ED59 */
+	0,							/* U+01ED5A */
+	0,							/* U+01ED5B */
+	0,							/* U+01ED5C */
+	0,							/* U+01ED5D */
+	0,							/* U+01ED5E */
+	0,							/* U+01ED5F */
+	0,							/* U+01ED60 */
+	0,							/* U+01ED61 */
+	0,							/* U+01ED62 */
+	0,							/* U+01ED63 */
+	0,							/* U+01ED64 */
+	0,							/* U+01ED65 */
+	0,							/* U+01ED66 */
+	0,							/* U+01ED67 */
+	0,							/* U+01ED68 */
+	0,							/* U+01ED69 */
+	0,							/* U+01ED6A */
+	0,							/* U+01ED6B */
+	0,							/* U+01ED6C */
+	0,							/* U+01ED6D */
+	0,							/* U+01ED6E */
+	0,							/* U+01ED6F */
+	0,							/* U+01ED70 */
+	0,							/* U+01ED71 */
+	0,							/* U+01ED72 */
+	0,							/* U+01ED73 */
+	0,							/* U+01ED74 */
+	0,							/* U+01ED75 */
+	0,							/* U+01ED76 */
+	0,							/* U+01ED77 */
+	0,							/* U+01ED78 */
+	0,							/* U+01ED79 */
+	0,							/* U+01ED7A */
+	0,							/* U+01ED7B */
+	0,							/* U+01ED7C */
+	0,							/* U+01ED7D */
+	0,							/* U+01ED7E */
+	0,							/* U+01ED7F */
+	0,							/* U+01ED80 */
+	0,							/* U+01ED81 */
+	0,							/* U+01ED82 */
+	0,							/* U+01ED83 */
+	0,							/* U+01ED84 */
+	0,							/* U+01ED85 */
+	0,							/* U+01ED86 */
+	0,							/* U+01ED87 */
+	0,							/* U+01ED88 */
+	0,							/* U+01ED89 */
+	0,							/* U+01ED8A */
+	0,							/* U+01ED8B */
+	0,							/* U+01ED8C */
+	0,							/* U+01ED8D */
+	0,							/* U+01ED8E */
+	0,							/* U+01ED8F */
+	0,							/* U+01ED90 */
+	0,							/* U+01ED91 */
+	0,							/* U+01ED92 */
+	0,							/* U+01ED93 */
+	0,							/* U+01ED94 */
+	0,							/* U+01ED95 */
+	0,							/* U+01ED96 */
+	0,							/* U+01ED97 */
+	0,							/* U+01ED98 */
+	0,							/* U+01ED99 */
+	0,							/* U+01ED9A */
+	0,							/* U+01ED9B */
+	0,							/* U+01ED9C */
+	0,							/* U+01ED9D */
+	0,							/* U+01ED9E */
+	0,							/* U+01ED9F */
+	0,							/* U+01EDA0 */
+	0,							/* U+01EDA1 */
+	0,							/* U+01EDA2 */
+	0,							/* U+01EDA3 */
+	0,							/* U+01EDA4 */
+	0,							/* U+01EDA5 */
+	0,							/* U+01EDA6 */
+	0,							/* U+01EDA7 */
+	0,							/* U+01EDA8 */
+	0,							/* U+01EDA9 */
+	0,							/* U+01EDAA */
+	0,							/* U+01EDAB */
+	0,							/* U+01EDAC */
+	0,							/* U+01EDAD */
+	0,							/* U+01EDAE */
+	0,							/* U+01EDAF */
+	0,							/* U+01EDB0 */
+	0,							/* U+01EDB1 */
+	0,							/* U+01EDB2 */
+	0,							/* U+01EDB3 */
+	0,							/* U+01EDB4 */
+	0,							/* U+01EDB5 */
+	0,							/* U+01EDB6 */
+	0,							/* U+01EDB7 */
+	0,							/* U+01EDB8 */
+	0,							/* U+01EDB9 */
+	0,							/* U+01EDBA */
+	0,							/* U+01EDBB */
+	0,							/* U+01EDBC */
+	0,							/* U+01EDBD */
+	0,							/* U+01EDBE */
+	0,							/* U+01EDBF */
+	0,							/* U+01EDC0 */
+	0,							/* U+01EDC1 */
+	0,							/* U+01EDC2 */
+	0,							/* U+01EDC3 */
+	0,							/* U+01EDC4 */
+	0,							/* U+01EDC5 */
+	0,							/* U+01EDC6 */
+	0,							/* U+01EDC7 */
+	0,							/* U+01EDC8 */
+	0,							/* U+01EDC9 */
+	0,							/* U+01EDCA */
+	0,							/* U+01EDCB */
+	0,							/* U+01EDCC */
+	0,							/* U+01EDCD */
+	0,							/* U+01EDCE */
+	0,							/* U+01EDCF */
+	0,							/* U+01EDD0 */
+	0,							/* U+01EDD1 */
+	0,							/* U+01EDD2 */
+	0,							/* U+01EDD3 */
+	0,							/* U+01EDD4 */
+	0,							/* U+01EDD5 */
+	0,							/* U+01EDD6 */
+	0,							/* U+01EDD7 */
+	0,							/* U+01EDD8 */
+	0,							/* U+01EDD9 */
+	0,							/* U+01EDDA */
+	0,							/* U+01EDDB */
+	0,							/* U+01EDDC */
+	0,							/* U+01EDDD */
+	0,							/* U+01EDDE */
+	0,							/* U+01EDDF */
+	0,							/* U+01EDE0 */
+	0,							/* U+01EDE1 */
+	0,							/* U+01EDE2 */
+	0,							/* U+01EDE3 */
+	0,							/* U+01EDE4 */
+	0,							/* U+01EDE5 */
+	0,							/* U+01EDE6 */
+	0,							/* U+01EDE7 */
+	0,							/* U+01EDE8 */
+	0,							/* U+01EDE9 */
+	0,							/* U+01EDEA */
+	0,							/* U+01EDEB */
+	0,							/* U+01EDEC */
+	0,							/* U+01EDED */
+	0,							/* U+01EDEE */
+	0,							/* U+01EDEF */
+	0,							/* U+01EDF0 */
+	0,							/* U+01EDF1 */
+	0,							/* U+01EDF2 */
+	0,							/* U+01EDF3 */
+	0,							/* U+01EDF4 */
+	0,							/* U+01EDF5 */
+	0,							/* U+01EDF6 */
+	0,							/* U+01EDF7 */
+	0,							/* U+01EDF8 */
+	0,							/* U+01EDF9 */
+	0,							/* U+01EDFA */
+	0,							/* U+01EDFB */
+	0,							/* U+01EDFC */
+	0,							/* U+01EDFD */
+	0,							/* U+01EDFE */
+	0,							/* U+01EDFF */
+	3061,						/* U+01EE00 */
+	3062,						/* U+01EE01 */
+	3066,						/* U+01EE02 */
+	3069,						/* U+01EE03 */
+	0,							/* U+01EE04 */
+	3088,						/* U+01EE05 */
+	3072,						/* U+01EE06 */
+	3067,						/* U+01EE07 */
+	3077,						/* U+01EE08 */
+	3089,						/* U+01EE09 */
+	3083,						/* U+01EE0A */
+	3084,						/* U+01EE0B */
+	3085,						/* U+01EE0C */
+	3086,						/* U+01EE0D */
+	3073,						/* U+01EE0E */
+	3079,						/* U+01EE0F */
+	3081,						/* U+01EE10 */
+	3075,						/* U+01EE11 */
+	3082,						/* U+01EE12 */
+	3071,						/* U+01EE13 */
+	3074,						/* U+01EE14 */
+	3064,						/* U+01EE15 */
+	3065,						/* U+01EE16 */
+	3068,						/* U+01EE17 */
+	3070,						/* U+01EE18 */
+	3076,						/* U+01EE19 */
+	3078,						/* U+01EE1A */
+	3080,						/* U+01EE1B */
+	3369,						/* U+01EE1C */
+	2705,						/* U+01EE1D */
+	3370,						/* U+01EE1E */
+	3371,						/* U+01EE1F */
+	0,							/* U+01EE20 */
+	3062,						/* U+01EE21 */
+	3066,						/* U+01EE22 */
+	0,							/* U+01EE23 */
+	3087,						/* U+01EE24 */
+	0,							/* U+01EE25 */
+	0,							/* U+01EE26 */
+	3067,						/* U+01EE27 */
+	0,							/* U+01EE28 */
+	3089,						/* U+01EE29 */
+	3083,						/* U+01EE2A */
+	3084,						/* U+01EE2B */
+	3085,						/* U+01EE2C */
+	3086,						/* U+01EE2D */
+	3073,						/* U+01EE2E */
+	3079,						/* U+01EE2F */
+	3081,						/* U+01EE30 */
+	3075,						/* U+01EE31 */
+	3082,						/* U+01EE32 */
+	0,							/* U+01EE33 */
+	3074,						/* U+01EE34 */
+	3064,						/* U+01EE35 */
+	3065,						/* U+01EE36 */
+	3068,						/* U+01EE37 */
+	0,							/* U+01EE38 */
+	3076,						/* U+01EE39 */
+	0,							/* U+01EE3A */
+	3080,						/* U+01EE3B */
+	0,							/* U+01EE3C */
+	0,							/* U+01EE3D */
+	0,							/* U+01EE3E */
+	0,							/* U+01EE3F */
+	0,							/* U+01EE40 */
+	0,							/* U+01EE41 */
+	3066,						/* U+01EE42 */
+	0,							/* U+01EE43 */
+	0,							/* U+01EE44 */
+	0,							/* U+01EE45 */
+	0,							/* U+01EE46 */
+	3067,						/* U+01EE47 */
+	0,							/* U+01EE48 */
+	3089,						/* U+01EE49 */
+	0,							/* U+01EE4A */
+	3084,						/* U+01EE4B */
+	0,							/* U+01EE4C */
+	3086,						/* U+01EE4D */
+	3073,						/* U+01EE4E */
+	3079,						/* U+01EE4F */
+	0,							/* U+01EE50 */
+	3075,						/* U+01EE51 */
+	3082,						/* U+01EE52 */
+	0,							/* U+01EE53 */
+	3074,						/* U+01EE54 */
+	0,							/* U+01EE55 */
+	0,							/* U+01EE56 */
+	3068,						/* U+01EE57 */
+	0,							/* U+01EE58 */
+	3076,						/* U+01EE59 */
+	0,							/* U+01EE5A */
+	3080,						/* U+01EE5B */
+	0,							/* U+01EE5C */
+	2705,						/* U+01EE5D */
+	0,							/* U+01EE5E */
+	3371,						/* U+01EE5F */
+	0,							/* U+01EE60 */
+	3062,						/* U+01EE61 */
+	3066,						/* U+01EE62 */
+	0,							/* U+01EE63 */
+	3087,						/* U+01EE64 */
+	0,							/* U+01EE65 */
+	0,							/* U+01EE66 */
+	3067,						/* U+01EE67 */
+	3077,						/* U+01EE68 */
+	3089,						/* U+01EE69 */
+	3083,						/* U+01EE6A */
+	0,							/* U+01EE6B */
+	3085,						/* U+01EE6C */
+	3086,						/* U+01EE6D */
+	3073,						/* U+01EE6E */
+	3079,						/* U+01EE6F */
+	3081,						/* U+01EE70 */
+	3075,						/* U+01EE71 */
+	3082,						/* U+01EE72 */
+	0,							/* U+01EE73 */
+	3074,						/* U+01EE74 */
+	3064,						/* U+01EE75 */
+	3065,						/* U+01EE76 */
+	3068,						/* U+01EE77 */
+	0,							/* U+01EE78 */
+	3076,						/* U+01EE79 */
+	3078,						/* U+01EE7A */
+	3080,						/* U+01EE7B */
+	3369,						/* U+01EE7C */
+	0,							/* U+01EE7D */
+	3370,						/* U+01EE7E */
+	0,							/* U+01EE7F */
+	3061,						/* U+01EE80 */
+	3062,						/* U+01EE81 */
+	3066,						/* U+01EE82 */
+	3069,						/* U+01EE83 */
+	3087,						/* U+01EE84 */
+	3088,						/* U+01EE85 */
+	3072,						/* U+01EE86 */
+	3067,						/* U+01EE87 */
+	3077,						/* U+01EE88 */
+	3089,						/* U+01EE89 */
+	0,							/* U+01EE8A */
+	3084,						/* U+01EE8B */
+	3085,						/* U+01EE8C */
+	3086,						/* U+01EE8D */
+	3073,						/* U+01EE8E */
+	3079,						/* U+01EE8F */
+	3081,						/* U+01EE90 */
+	3075,						/* U+01EE91 */
+	3082,						/* U+01EE92 */
+	3071,						/* U+01EE93 */
+	3074,						/* U+01EE94 */
+	3064,						/* U+01EE95 */
+	3065,						/* U+01EE96 */
+	3068,						/* U+01EE97 */
+	3070,						/* U+01EE98 */
+	3076,						/* U+01EE99 */
+	3078,						/* U+01EE9A */
+	3080,						/* U+01EE9B */
+	0,							/* U+01EE9C */
+	0,							/* U+01EE9D */
+	0,							/* U+01EE9E */
+	0,							/* U+01EE9F */
+	0,							/* U+01EEA0 */
+	3062,						/* U+01EEA1 */
+	3066,						/* U+01EEA2 */
+	3069,						/* U+01EEA3 */
+	0,							/* U+01EEA4 */
+	3088,						/* U+01EEA5 */
+	3072,						/* U+01EEA6 */
+	3067,						/* U+01EEA7 */
+	3077,						/* U+01EEA8 */
+	3089,						/* U+01EEA9 */
+	0,							/* U+01EEAA */
+	3084,						/* U+01EEAB */
+	3085,						/* U+01EEAC */
+	3086,						/* U+01EEAD */
+	3073,						/* U+01EEAE */
+	3079,						/* U+01EEAF */
+	3081,						/* U+01EEB0 */
+	3075,						/* U+01EEB1 */
+	3082,						/* U+01EEB2 */
+	3071,						/* U+01EEB3 */
+	3074,						/* U+01EEB4 */
+	3064,						/* U+01EEB5 */
+	3065,						/* U+01EEB6 */
+	3068,						/* U+01EEB7 */
+	3070,						/* U+01EEB8 */
+	3076,						/* U+01EEB9 */
+	3078,						/* U+01EEBA */
+	3080,						/* U+01EEBB */
+	0,							/* U+01EEBC */
+	0,							/* U+01EEBD */
+	0,							/* U+01EEBE */
+	0,							/* U+01EEBF */
+	0,							/* U+01EEC0 */
+	0,							/* U+01EEC1 */
+	0,							/* U+01EEC2 */
+	0,							/* U+01EEC3 */
+	0,							/* U+01EEC4 */
+	0,							/* U+01EEC5 */
+	0,							/* U+01EEC6 */
+	0,							/* U+01EEC7 */
+	0,							/* U+01EEC8 */
+	0,							/* U+01EEC9 */
+	0,							/* U+01EECA */
+	0,							/* U+01EECB */
+	0,							/* U+01EECC */
+	0,							/* U+01EECD */
+	0,							/* U+01EECE */
+	0,							/* U+01EECF */
+	0,							/* U+01EED0 */
+	0,							/* U+01EED1 */
+	0,							/* U+01EED2 */
+	0,							/* U+01EED3 */
+	0,							/* U+01EED4 */
+	0,							/* U+01EED5 */
+	0,							/* U+01EED6 */
+	0,							/* U+01EED7 */
+	0,							/* U+01EED8 */
+	0,							/* U+01EED9 */
+	0,							/* U+01EEDA */
+	0,							/* U+01EEDB */
+	0,							/* U+01EEDC */
+	0,							/* U+01EEDD */
+	0,							/* U+01EEDE */
+	0,							/* U+01EEDF */
+	0,							/* U+01EEE0 */
+	0,							/* U+01EEE1 */
+	0,							/* U+01EEE2 */
+	0,							/* U+01EEE3 */
+	0,							/* U+01EEE4 */
+	0,							/* U+01EEE5 */
+	0,							/* U+01EEE6 */
+	0,							/* U+01EEE7 */
+	0,							/* U+01EEE8 */
+	0,							/* U+01EEE9 */
+	0,							/* U+01EEEA */
+	0,							/* U+01EEEB */
+	0,							/* U+01EEEC */
+	0,							/* U+01EEED */
+	0,							/* U+01EEEE */
+	0,							/* U+01EEEF */
+	0,							/* U+01EEF0 */
+	0,							/* U+01EEF1 */
+	0,							/* U+01EEF2 */
+	0,							/* U+01EEF3 */
+	0,							/* U+01EEF4 */
+	0,							/* U+01EEF5 */
+	0,							/* U+01EEF6 */
+	0,							/* U+01EEF7 */
+	0,							/* U+01EEF8 */
+	0,							/* U+01EEF9 */
+	0,							/* U+01EEFA */
+	0,							/* U+01EEFB */
+	0,							/* U+01EEFC */
+	0,							/* U+01EEFD */
+	0,							/* U+01EEFE */
+	0,							/* U+01EEFF */
+	0,							/* U+01EF00 */
+	0,							/* U+01EF01 */
+	0,							/* U+01EF02 */
+	0,							/* U+01EF03 */
+	0,							/* U+01EF04 */
+	0,							/* U+01EF05 */
+	0,							/* U+01EF06 */
+	0,							/* U+01EF07 */
+	0,							/* U+01EF08 */
+	0,							/* U+01EF09 */
+	0,							/* U+01EF0A */
+	0,							/* U+01EF0B */
+	0,							/* U+01EF0C */
+	0,							/* U+01EF0D */
+	0,							/* U+01EF0E */
+	0,							/* U+01EF0F */
+	0,							/* U+01EF10 */
+	0,							/* U+01EF11 */
+	0,							/* U+01EF12 */
+	0,							/* U+01EF13 */
+	0,							/* U+01EF14 */
+	0,							/* U+01EF15 */
+	0,							/* U+01EF16 */
+	0,							/* U+01EF17 */
+	0,							/* U+01EF18 */
+	0,							/* U+01EF19 */
+	0,							/* U+01EF1A */
+	0,							/* U+01EF1B */
+	0,							/* U+01EF1C */
+	0,							/* U+01EF1D */
+	0,							/* U+01EF1E */
+	0,							/* U+01EF1F */
+	0,							/* U+01EF20 */
+	0,							/* U+01EF21 */
+	0,							/* U+01EF22 */
+	0,							/* U+01EF23 */
+	0,							/* U+01EF24 */
+	0,							/* U+01EF25 */
+	0,							/* U+01EF26 */
+	0,							/* U+01EF27 */
+	0,							/* U+01EF28 */
+	0,							/* U+01EF29 */
+	0,							/* U+01EF2A */
+	0,							/* U+01EF2B */
+	0,							/* U+01EF2C */
+	0,							/* U+01EF2D */
+	0,							/* U+01EF2E */
+	0,							/* U+01EF2F */
+	0,							/* U+01EF30 */
+	0,							/* U+01EF31 */
+	0,							/* U+01EF32 */
+	0,							/* U+01EF33 */
+	0,							/* U+01EF34 */
+	0,							/* U+01EF35 */
+	0,							/* U+01EF36 */
+	0,							/* U+01EF37 */
+	0,							/* U+01EF38 */
+	0,							/* U+01EF39 */
+	0,							/* U+01EF3A */
+	0,							/* U+01EF3B */
+	0,							/* U+01EF3C */
+	0,							/* U+01EF3D */
+	0,							/* U+01EF3E */
+	0,							/* U+01EF3F */
+	0,							/* U+01EF40 */
+	0,							/* U+01EF41 */
+	0,							/* U+01EF42 */
+	0,							/* U+01EF43 */
+	0,							/* U+01EF44 */
+	0,							/* U+01EF45 */
+	0,							/* U+01EF46 */
+	0,							/* U+01EF47 */
+	0,							/* U+01EF48 */
+	0,							/* U+01EF49 */
+	0,							/* U+01EF4A */
+	0,							/* U+01EF4B */
+	0,							/* U+01EF4C */
+	0,							/* U+01EF4D */
+	0,							/* U+01EF4E */
+	0,							/* U+01EF4F */
+	0,							/* U+01EF50 */
+	0,							/* U+01EF51 */
+	0,							/* U+01EF52 */
+	0,							/* U+01EF53 */
+	0,							/* U+01EF54 */
+	0,							/* U+01EF55 */
+	0,							/* U+01EF56 */
+	0,							/* U+01EF57 */
+	0,							/* U+01EF58 */
+	0,							/* U+01EF59 */
+	0,							/* U+01EF5A */
+	0,							/* U+01EF5B */
+	0,							/* U+01EF5C */
+	0,							/* U+01EF5D */
+	0,							/* U+01EF5E */
+	0,							/* U+01EF5F */
+	0,							/* U+01EF60 */
+	0,							/* U+01EF61 */
+	0,							/* U+01EF62 */
+	0,							/* U+01EF63 */
+	0,							/* U+01EF64 */
+	0,							/* U+01EF65 */
+	0,							/* U+01EF66 */
+	0,							/* U+01EF67 */
+	0,							/* U+01EF68 */
+	0,							/* U+01EF69 */
+	0,							/* U+01EF6A */
+	0,							/* U+01EF6B */
+	0,							/* U+01EF6C */
+	0,							/* U+01EF6D */
+	0,							/* U+01EF6E */
+	0,							/* U+01EF6F */
+	0,							/* U+01EF70 */
+	0,							/* U+01EF71 */
+	0,							/* U+01EF72 */
+	0,							/* U+01EF73 */
+	0,							/* U+01EF74 */
+	0,							/* U+01EF75 */
+	0,							/* U+01EF76 */
+	0,							/* U+01EF77 */
+	0,							/* U+01EF78 */
+	0,							/* U+01EF79 */
+	0,							/* U+01EF7A */
+	0,							/* U+01EF7B */
+	0,							/* U+01EF7C */
+	0,							/* U+01EF7D */
+	0,							/* U+01EF7E */
+	0,							/* U+01EF7F */
+	0,							/* U+01EF80 */
+	0,							/* U+01EF81 */
+	0,							/* U+01EF82 */
+	0,							/* U+01EF83 */
+	0,							/* U+01EF84 */
+	0,							/* U+01EF85 */
+	0,							/* U+01EF86 */
+	0,							/* U+01EF87 */
+	0,							/* U+01EF88 */
+	0,							/* U+01EF89 */
+	0,							/* U+01EF8A */
+	0,							/* U+01EF8B */
+	0,							/* U+01EF8C */
+	0,							/* U+01EF8D */
+	0,							/* U+01EF8E */
+	0,							/* U+01EF8F */
+	0,							/* U+01EF90 */
+	0,							/* U+01EF91 */
+	0,							/* U+01EF92 */
+	0,							/* U+01EF93 */
+	0,							/* U+01EF94 */
+	0,							/* U+01EF95 */
+	0,							/* U+01EF96 */
+	0,							/* U+01EF97 */
+	0,							/* U+01EF98 */
+	0,							/* U+01EF99 */
+	0,							/* U+01EF9A */
+	0,							/* U+01EF9B */
+	0,							/* U+01EF9C */
+	0,							/* U+01EF9D */
+	0,							/* U+01EF9E */
+	0,							/* U+01EF9F */
+	0,							/* U+01EFA0 */
+	0,							/* U+01EFA1 */
+	0,							/* U+01EFA2 */
+	0,							/* U+01EFA3 */
+	0,							/* U+01EFA4 */
+	0,							/* U+01EFA5 */
+	0,							/* U+01EFA6 */
+	0,							/* U+01EFA7 */
+	0,							/* U+01EFA8 */
+	0,							/* U+01EFA9 */
+	0,							/* U+01EFAA */
+	0,							/* U+01EFAB */
+	0,							/* U+01EFAC */
+	0,							/* U+01EFAD */
+	0,							/* U+01EFAE */
+	0,							/* U+01EFAF */
+	0,							/* U+01EFB0 */
+	0,							/* U+01EFB1 */
+	0,							/* U+01EFB2 */
+	0,							/* U+01EFB3 */
+	0,							/* U+01EFB4 */
+	0,							/* U+01EFB5 */
+	0,							/* U+01EFB6 */
+	0,							/* U+01EFB7 */
+	0,							/* U+01EFB8 */
+	0,							/* U+01EFB9 */
+	0,							/* U+01EFBA */
+	0,							/* U+01EFBB */
+	0,							/* U+01EFBC */
+	0,							/* U+01EFBD */
+	0,							/* U+01EFBE */
+	0,							/* U+01EFBF */
+	0,							/* U+01EFC0 */
+	0,							/* U+01EFC1 */
+	0,							/* U+01EFC2 */
+	0,							/* U+01EFC3 */
+	0,							/* U+01EFC4 */
+	0,							/* U+01EFC5 */
+	0,							/* U+01EFC6 */
+	0,							/* U+01EFC7 */
+	0,							/* U+01EFC8 */
+	0,							/* U+01EFC9 */
+	0,							/* U+01EFCA */
+	0,							/* U+01EFCB */
+	0,							/* U+01EFCC */
+	0,							/* U+01EFCD */
+	0,							/* U+01EFCE */
+	0,							/* U+01EFCF */
+	0,							/* U+01EFD0 */
+	0,							/* U+01EFD1 */
+	0,							/* U+01EFD2 */
+	0,							/* U+01EFD3 */
+	0,							/* U+01EFD4 */
+	0,							/* U+01EFD5 */
+	0,							/* U+01EFD6 */
+	0,							/* U+01EFD7 */
+	0,							/* U+01EFD8 */
+	0,							/* U+01EFD9 */
+	0,							/* U+01EFDA */
+	0,							/* U+01EFDB */
+	0,							/* U+01EFDC */
+	0,							/* U+01EFDD */
+	0,							/* U+01EFDE */
+	0,							/* U+01EFDF */
+	0,							/* U+01EFE0 */
+	0,							/* U+01EFE1 */
+	0,							/* U+01EFE2 */
+	0,							/* U+01EFE3 */
+	0,							/* U+01EFE4 */
+	0,							/* U+01EFE5 */
+	0,							/* U+01EFE6 */
+	0,							/* U+01EFE7 */
+	0,							/* U+01EFE8 */
+	0,							/* U+01EFE9 */
+	0,							/* U+01EFEA */
+	0,							/* U+01EFEB */
+	0,							/* U+01EFEC */
+	0,							/* U+01EFED */
+	0,							/* U+01EFEE */
+	0,							/* U+01EFEF */
+	0,							/* U+01EFF0 */
+	0,							/* U+01EFF1 */
+	0,							/* U+01EFF2 */
+	0,							/* U+01EFF3 */
+	0,							/* U+01EFF4 */
+	0,							/* U+01EFF5 */
+	0,							/* U+01EFF6 */
+	0,							/* U+01EFF7 */
+	0,							/* U+01EFF8 */
+	0,							/* U+01EFF9 */
+	0,							/* U+01EFFA */
+	0,							/* U+01EFFB */
+	0,							/* U+01EFFC */
+	0,							/* U+01EFFD */
+	0,							/* U+01EFFE */
+	0,							/* U+01EFFF */
+	0,							/* U+01F000 */
+	0,							/* U+01F001 */
+	0,							/* U+01F002 */
+	0,							/* U+01F003 */
+	0,							/* U+01F004 */
+	0,							/* U+01F005 */
+	0,							/* U+01F006 */
+	0,							/* U+01F007 */
+	0,							/* U+01F008 */
+	0,							/* U+01F009 */
+	0,							/* U+01F00A */
+	0,							/* U+01F00B */
+	0,							/* U+01F00C */
+	0,							/* U+01F00D */
+	0,							/* U+01F00E */
+	0,							/* U+01F00F */
+	0,							/* U+01F010 */
+	0,							/* U+01F011 */
+	0,							/* U+01F012 */
+	0,							/* U+01F013 */
+	0,							/* U+01F014 */
+	0,							/* U+01F015 */
+	0,							/* U+01F016 */
+	0,							/* U+01F017 */
+	0,							/* U+01F018 */
+	0,							/* U+01F019 */
+	0,							/* U+01F01A */
+	0,							/* U+01F01B */
+	0,							/* U+01F01C */
+	0,							/* U+01F01D */
+	0,							/* U+01F01E */
+	0,							/* U+01F01F */
+	0,							/* U+01F020 */
+	0,							/* U+01F021 */
+	0,							/* U+01F022 */
+	0,							/* U+01F023 */
+	0,							/* U+01F024 */
+	0,							/* U+01F025 */
+	0,							/* U+01F026 */
+	0,							/* U+01F027 */
+	0,							/* U+01F028 */
+	0,							/* U+01F029 */
+	0,							/* U+01F02A */
+	0,							/* U+01F02B */
+	0,							/* U+01F02C */
+	0,							/* U+01F02D */
+	0,							/* U+01F02E */
+	0,							/* U+01F02F */
+	0,							/* U+01F030 */
+	0,							/* U+01F031 */
+	0,							/* U+01F032 */
+	0,							/* U+01F033 */
+	0,							/* U+01F034 */
+	0,							/* U+01F035 */
+	0,							/* U+01F036 */
+	0,							/* U+01F037 */
+	0,							/* U+01F038 */
+	0,							/* U+01F039 */
+	0,							/* U+01F03A */
+	0,							/* U+01F03B */
+	0,							/* U+01F03C */
+	0,							/* U+01F03D */
+	0,							/* U+01F03E */
+	0,							/* U+01F03F */
+	0,							/* U+01F040 */
+	0,							/* U+01F041 */
+	0,							/* U+01F042 */
+	0,							/* U+01F043 */
+	0,							/* U+01F044 */
+	0,							/* U+01F045 */
+	0,							/* U+01F046 */
+	0,							/* U+01F047 */
+	0,							/* U+01F048 */
+	0,							/* U+01F049 */
+	0,							/* U+01F04A */
+	0,							/* U+01F04B */
+	0,							/* U+01F04C */
+	0,							/* U+01F04D */
+	0,							/* U+01F04E */
+	0,							/* U+01F04F */
+	0,							/* U+01F050 */
+	0,							/* U+01F051 */
+	0,							/* U+01F052 */
+	0,							/* U+01F053 */
+	0,							/* U+01F054 */
+	0,							/* U+01F055 */
+	0,							/* U+01F056 */
+	0,							/* U+01F057 */
+	0,							/* U+01F058 */
+	0,							/* U+01F059 */
+	0,							/* U+01F05A */
+	0,							/* U+01F05B */
+	0,							/* U+01F05C */
+	0,							/* U+01F05D */
+	0,							/* U+01F05E */
+	0,							/* U+01F05F */
+	0,							/* U+01F060 */
+	0,							/* U+01F061 */
+	0,							/* U+01F062 */
+	0,							/* U+01F063 */
+	0,							/* U+01F064 */
+	0,							/* U+01F065 */
+	0,							/* U+01F066 */
+	0,							/* U+01F067 */
+	0,							/* U+01F068 */
+	0,							/* U+01F069 */
+	0,							/* U+01F06A */
+	0,							/* U+01F06B */
+	0,							/* U+01F06C */
+	0,							/* U+01F06D */
+	0,							/* U+01F06E */
+	0,							/* U+01F06F */
+	0,							/* U+01F070 */
+	0,							/* U+01F071 */
+	0,							/* U+01F072 */
+	0,							/* U+01F073 */
+	0,							/* U+01F074 */
+	0,							/* U+01F075 */
+	0,							/* U+01F076 */
+	0,							/* U+01F077 */
+	0,							/* U+01F078 */
+	0,							/* U+01F079 */
+	0,							/* U+01F07A */
+	0,							/* U+01F07B */
+	0,							/* U+01F07C */
+	0,							/* U+01F07D */
+	0,							/* U+01F07E */
+	0,							/* U+01F07F */
+	0,							/* U+01F080 */
+	0,							/* U+01F081 */
+	0,							/* U+01F082 */
+	0,							/* U+01F083 */
+	0,							/* U+01F084 */
+	0,							/* U+01F085 */
+	0,							/* U+01F086 */
+	0,							/* U+01F087 */
+	0,							/* U+01F088 */
+	0,							/* U+01F089 */
+	0,							/* U+01F08A */
+	0,							/* U+01F08B */
+	0,							/* U+01F08C */
+	0,							/* U+01F08D */
+	0,							/* U+01F08E */
+	0,							/* U+01F08F */
+	0,							/* U+01F090 */
+	0,							/* U+01F091 */
+	0,							/* U+01F092 */
+	0,							/* U+01F093 */
+	0,							/* U+01F094 */
+	0,							/* U+01F095 */
+	0,							/* U+01F096 */
+	0,							/* U+01F097 */
+	0,							/* U+01F098 */
+	0,							/* U+01F099 */
+	0,							/* U+01F09A */
+	0,							/* U+01F09B */
+	0,							/* U+01F09C */
+	0,							/* U+01F09D */
+	0,							/* U+01F09E */
+	0,							/* U+01F09F */
+	0,							/* U+01F0A0 */
+	0,							/* U+01F0A1 */
+	0,							/* U+01F0A2 */
+	0,							/* U+01F0A3 */
+	0,							/* U+01F0A4 */
+	0,							/* U+01F0A5 */
+	0,							/* U+01F0A6 */
+	0,							/* U+01F0A7 */
+	0,							/* U+01F0A8 */
+	0,							/* U+01F0A9 */
+	0,							/* U+01F0AA */
+	0,							/* U+01F0AB */
+	0,							/* U+01F0AC */
+	0,							/* U+01F0AD */
+	0,							/* U+01F0AE */
+	0,							/* U+01F0AF */
+	0,							/* U+01F0B0 */
+	0,							/* U+01F0B1 */
+	0,							/* U+01F0B2 */
+	0,							/* U+01F0B3 */
+	0,							/* U+01F0B4 */
+	0,							/* U+01F0B5 */
+	0,							/* U+01F0B6 */
+	0,							/* U+01F0B7 */
+	0,							/* U+01F0B8 */
+	0,							/* U+01F0B9 */
+	0,							/* U+01F0BA */
+	0,							/* U+01F0BB */
+	0,							/* U+01F0BC */
+	0,							/* U+01F0BD */
+	0,							/* U+01F0BE */
+	0,							/* U+01F0BF */
+	0,							/* U+01F0C0 */
+	0,							/* U+01F0C1 */
+	0,							/* U+01F0C2 */
+	0,							/* U+01F0C3 */
+	0,							/* U+01F0C4 */
+	0,							/* U+01F0C5 */
+	0,							/* U+01F0C6 */
+	0,							/* U+01F0C7 */
+	0,							/* U+01F0C8 */
+	0,							/* U+01F0C9 */
+	0,							/* U+01F0CA */
+	0,							/* U+01F0CB */
+	0,							/* U+01F0CC */
+	0,							/* U+01F0CD */
+	0,							/* U+01F0CE */
+	0,							/* U+01F0CF */
+	0,							/* U+01F0D0 */
+	0,							/* U+01F0D1 */
+	0,							/* U+01F0D2 */
+	0,							/* U+01F0D3 */
+	0,							/* U+01F0D4 */
+	0,							/* U+01F0D5 */
+	0,							/* U+01F0D6 */
+	0,							/* U+01F0D7 */
+	0,							/* U+01F0D8 */
+	0,							/* U+01F0D9 */
+	0,							/* U+01F0DA */
+	0,							/* U+01F0DB */
+	0,							/* U+01F0DC */
+	0,							/* U+01F0DD */
+	0,							/* U+01F0DE */
+	0,							/* U+01F0DF */
+	0,							/* U+01F0E0 */
+	0,							/* U+01F0E1 */
+	0,							/* U+01F0E2 */
+	0,							/* U+01F0E3 */
+	0,							/* U+01F0E4 */
+	0,							/* U+01F0E5 */
+	0,							/* U+01F0E6 */
+	0,							/* U+01F0E7 */
+	0,							/* U+01F0E8 */
+	0,							/* U+01F0E9 */
+	0,							/* U+01F0EA */
+	0,							/* U+01F0EB */
+	0,							/* U+01F0EC */
+	0,							/* U+01F0ED */
+	0,							/* U+01F0EE */
+	0,							/* U+01F0EF */
+	0,							/* U+01F0F0 */
+	0,							/* U+01F0F1 */
+	0,							/* U+01F0F2 */
+	0,							/* U+01F0F3 */
+	0,							/* U+01F0F4 */
+	0,							/* U+01F0F5 */
+	0,							/* U+01F0F6 */
+	0,							/* U+01F0F7 */
+	0,							/* U+01F0F8 */
+	0,							/* U+01F0F9 */
+	0,							/* U+01F0FA */
+	0,							/* U+01F0FB */
+	0,							/* U+01F0FC */
+	0,							/* U+01F0FD */
+	0,							/* U+01F0FE */
+	0,							/* U+01F0FF */
+	3372,						/* U+01F100 */
+	3373,						/* U+01F101 */
+	3374,						/* U+01F102 */
+	3375,						/* U+01F103 */
+	3376,						/* U+01F104 */
+	3377,						/* U+01F105 */
+	3378,						/* U+01F106 */
+	3379,						/* U+01F107 */
+	3380,						/* U+01F108 */
+	3381,						/* U+01F109 */
+	3382,						/* U+01F10A */
+	0,							/* U+01F10B */
+	0,							/* U+01F10C */
+	0,							/* U+01F10D */
+	0,							/* U+01F10E */
+	0,							/* U+01F10F */
+	3383,						/* U+01F110 */
+	3384,						/* U+01F111 */
+	3385,						/* U+01F112 */
+	3386,						/* U+01F113 */
+	3387,						/* U+01F114 */
+	3388,						/* U+01F115 */
+	3389,						/* U+01F116 */
+	3390,						/* U+01F117 */
+	3391,						/* U+01F118 */
+	3392,						/* U+01F119 */
+	3393,						/* U+01F11A */
+	3394,						/* U+01F11B */
+	3395,						/* U+01F11C */
+	3396,						/* U+01F11D */
+	3397,						/* U+01F11E */
+	3398,						/* U+01F11F */
+	3399,						/* U+01F120 */
+	3400,						/* U+01F121 */
+	3401,						/* U+01F122 */
+	3402,						/* U+01F123 */
+	3403,						/* U+01F124 */
+	3404,						/* U+01F125 */
+	3405,						/* U+01F126 */
+	3406,						/* U+01F127 */
+	3407,						/* U+01F128 */
+	3408,						/* U+01F129 */
+	3409,						/* U+01F12A */
+	1137,						/* U+01F12B */
+	557,						/* U+01F12C */
+	3410,						/* U+01F12D */
+	3411,						/* U+01F12E */
+	0,							/* U+01F12F */
+	540,						/* U+01F130 */
+	542,						/* U+01F131 */
+	1137,						/* U+01F132 */
+	543,						/* U+01F133 */
+	544,						/* U+01F134 */
+	1153,						/* U+01F135 */
+	546,						/* U+01F136 */
+	547,						/* U+01F137 */
+	548,						/* U+01F138 */
+	549,						/* U+01F139 */
+	550,						/* U+01F13A */
+	551,						/* U+01F13B */
+	552,						/* U+01F13C */
+	553,						/* U+01F13D */
+	554,						/* U+01F13E */
+	556,						/* U+01F13F */
+	1145,						/* U+01F140 */
+	557,						/* U+01F141 */
+	1326,						/* U+01F142 */
+	558,						/* U+01F143 */
+	559,						/* U+01F144 */
+	1181,						/* U+01F145 */
+	560,						/* U+01F146 */
+	1186,						/* U+01F147 */
+	1327,						/* U+01F148 */
+	1149,						/* U+01F149 */
+	3412,						/* U+01F14A */
+	2121,						/* U+01F14B */
+	3413,						/* U+01F14C */
+	3414,						/* U+01F14D */
+	3415,						/* U+01F14E */
+	3416,						/* U+01F14F */
+	0,							/* U+01F150 */
+	0,							/* U+01F151 */
+	0,							/* U+01F152 */
+	0,							/* U+01F153 */
+	0,							/* U+01F154 */
+	0,							/* U+01F155 */
+	0,							/* U+01F156 */
+	0,							/* U+01F157 */
+	0,							/* U+01F158 */
+	0,							/* U+01F159 */
+	0,							/* U+01F15A */
+	0,							/* U+01F15B */
+	0,							/* U+01F15C */
+	0,							/* U+01F15D */
+	0,							/* U+01F15E */
+	0,							/* U+01F15F */
+	0,							/* U+01F160 */
+	0,							/* U+01F161 */
+	0,							/* U+01F162 */
+	0,							/* U+01F163 */
+	0,							/* U+01F164 */
+	0,							/* U+01F165 */
+	0,							/* U+01F166 */
+	0,							/* U+01F167 */
+	0,							/* U+01F168 */
+	0,							/* U+01F169 */
+	3417,						/* U+01F16A */
+	3418,						/* U+01F16B */
+	3419,						/* U+01F16C */
+	0,							/* U+01F16D */
+	0,							/* U+01F16E */
+	0,							/* U+01F16F */
+	0,							/* U+01F170 */
+	0,							/* U+01F171 */
+	0,							/* U+01F172 */
+	0,							/* U+01F173 */
+	0,							/* U+01F174 */
+	0,							/* U+01F175 */
+	0,							/* U+01F176 */
+	0,							/* U+01F177 */
+	0,							/* U+01F178 */
+	0,							/* U+01F179 */
+	0,							/* U+01F17A */
+	0,							/* U+01F17B */
+	0,							/* U+01F17C */
+	0,							/* U+01F17D */
+	0,							/* U+01F17E */
+	0,							/* U+01F17F */
+	0,							/* U+01F180 */
+	0,							/* U+01F181 */
+	0,							/* U+01F182 */
+	0,							/* U+01F183 */
+	0,							/* U+01F184 */
+	0,							/* U+01F185 */
+	0,							/* U+01F186 */
+	0,							/* U+01F187 */
+	0,							/* U+01F188 */
+	0,							/* U+01F189 */
+	0,							/* U+01F18A */
+	0,							/* U+01F18B */
+	0,							/* U+01F18C */
+	0,							/* U+01F18D */
+	0,							/* U+01F18E */
+	0,							/* U+01F18F */
+	3420,						/* U+01F190 */
+	0,							/* U+01F191 */
+	0,							/* U+01F192 */
+	0,							/* U+01F193 */
+	0,							/* U+01F194 */
+	0,							/* U+01F195 */
+	0,							/* U+01F196 */
+	0,							/* U+01F197 */
+	0,							/* U+01F198 */
+	0,							/* U+01F199 */
+	0,							/* U+01F19A */
+	0,							/* U+01F19B */
+	0,							/* U+01F19C */
+	0,							/* U+01F19D */
+	0,							/* U+01F19E */
+	0,							/* U+01F19F */
+	0,							/* U+01F1A0 */
+	0,							/* U+01F1A1 */
+	0,							/* U+01F1A2 */
+	0,							/* U+01F1A3 */
+	0,							/* U+01F1A4 */
+	0,							/* U+01F1A5 */
+	0,							/* U+01F1A6 */
+	0,							/* U+01F1A7 */
+	0,							/* U+01F1A8 */
+	0,							/* U+01F1A9 */
+	0,							/* U+01F1AA */
+	0,							/* U+01F1AB */
+	0,							/* U+01F1AC */
+	0,							/* U+01F1AD */
+	0,							/* U+01F1AE */
+	0,							/* U+01F1AF */
+	0,							/* U+01F1B0 */
+	0,							/* U+01F1B1 */
+	0,							/* U+01F1B2 */
+	0,							/* U+01F1B3 */
+	0,							/* U+01F1B4 */
+	0,							/* U+01F1B5 */
+	0,							/* U+01F1B6 */
+	0,							/* U+01F1B7 */
+	0,							/* U+01F1B8 */
+	0,							/* U+01F1B9 */
+	0,							/* U+01F1BA */
+	0,							/* U+01F1BB */
+	0,							/* U+01F1BC */
+	0,							/* U+01F1BD */
+	0,							/* U+01F1BE */
+	0,							/* U+01F1BF */
+	0,							/* U+01F1C0 */
+	0,							/* U+01F1C1 */
+	0,							/* U+01F1C2 */
+	0,							/* U+01F1C3 */
+	0,							/* U+01F1C4 */
+	0,							/* U+01F1C5 */
+	0,							/* U+01F1C6 */
+	0,							/* U+01F1C7 */
+	0,							/* U+01F1C8 */
+	0,							/* U+01F1C9 */
+	0,							/* U+01F1CA */
+	0,							/* U+01F1CB */
+	0,							/* U+01F1CC */
+	0,							/* U+01F1CD */
+	0,							/* U+01F1CE */
+	0,							/* U+01F1CF */
+	0,							/* U+01F1D0 */
+	0,							/* U+01F1D1 */
+	0,							/* U+01F1D2 */
+	0,							/* U+01F1D3 */
+	0,							/* U+01F1D4 */
+	0,							/* U+01F1D5 */
+	0,							/* U+01F1D6 */
+	0,							/* U+01F1D7 */
+	0,							/* U+01F1D8 */
+	0,							/* U+01F1D9 */
+	0,							/* U+01F1DA */
+	0,							/* U+01F1DB */
+	0,							/* U+01F1DC */
+	0,							/* U+01F1DD */
+	0,							/* U+01F1DE */
+	0,							/* U+01F1DF */
+	0,							/* U+01F1E0 */
+	0,							/* U+01F1E1 */
+	0,							/* U+01F1E2 */
+	0,							/* U+01F1E3 */
+	0,							/* U+01F1E4 */
+	0,							/* U+01F1E5 */
+	0,							/* U+01F1E6 */
+	0,							/* U+01F1E7 */
+	0,							/* U+01F1E8 */
+	0,							/* U+01F1E9 */
+	0,							/* U+01F1EA */
+	0,							/* U+01F1EB */
+	0,							/* U+01F1EC */
+	0,							/* U+01F1ED */
+	0,							/* U+01F1EE */
+	0,							/* U+01F1EF */
+	0,							/* U+01F1F0 */
+	0,							/* U+01F1F1 */
+	0,							/* U+01F1F2 */
+	0,							/* U+01F1F3 */
+	0,							/* U+01F1F4 */
+	0,							/* U+01F1F5 */
+	0,							/* U+01F1F6 */
+	0,							/* U+01F1F7 */
+	0,							/* U+01F1F8 */
+	0,							/* U+01F1F9 */
+	0,							/* U+01F1FA */
+	0,							/* U+01F1FB */
+	0,							/* U+01F1FC */
+	0,							/* U+01F1FD */
+	0,							/* U+01F1FE */
+	0,							/* U+01F1FF */
+	3421,						/* U+01F200 */
+	3422,						/* U+01F201 */
+	1898,						/* U+01F202 */
+	0,							/* U+01F203 */
+	0,							/* U+01F204 */
+	0,							/* U+01F205 */
+	0,							/* U+01F206 */
+	0,							/* U+01F207 */
+	0,							/* U+01F208 */
+	0,							/* U+01F209 */
+	0,							/* U+01F20A */
+	0,							/* U+01F20B */
+	0,							/* U+01F20C */
+	0,							/* U+01F20D */
+	0,							/* U+01F20E */
+	0,							/* U+01F20F */
+	1400,						/* U+01F210 */
+	3423,						/* U+01F211 */
+	3424,						/* U+01F212 */
+	3425,						/* U+01F213 */
+	1343,						/* U+01F214 */
+	3426,						/* U+01F215 */
+	3427,						/* U+01F216 */
+	1720,						/* U+01F217 */
+	3428,						/* U+01F218 */
+	3429,						/* U+01F219 */
+	3430,						/* U+01F21A */
+	3431,						/* U+01F21B */
+	3432,						/* U+01F21C */
+	3433,						/* U+01F21D */
+	3434,						/* U+01F21E */
+	3435,						/* U+01F21F */
+	3436,						/* U+01F220 */
+	3437,						/* U+01F221 */
+	1436,						/* U+01F222 */
+	3438,						/* U+01F223 */
+	3439,						/* U+01F224 */
+	3440,						/* U+01F225 */
+	3441,						/* U+01F226 */
+	3442,						/* U+01F227 */
+	3443,						/* U+01F228 */
+	1337,						/* U+01F229 */
+	1712,						/* U+01F22A */
+	3444,						/* U+01F22B */
+	1847,						/* U+01F22C */
+	1715,						/* U+01F22D */
+	1848,						/* U+01F22E */
+	3445,						/* U+01F22F */
+	1492,						/* U+01F230 */
+	3446,						/* U+01F231 */
+	3447,						/* U+01F232 */
+	3448,						/* U+01F233 */
+	3449,						/* U+01F234 */
+	3450,						/* U+01F235 */
+	1830,						/* U+01F236 */
+	1410,						/* U+01F237 */
+	3451,						/* U+01F238 */
+	3452,						/* U+01F239 */
+	3453,						/* U+01F23A */
+	3454,						/* U+01F23B */
+	0,							/* U+01F23C */
+	0,							/* U+01F23D */
+	0,							/* U+01F23E */
+	0,							/* U+01F23F */
+	3455,						/* U+01F240 */
+	3456,						/* U+01F241 */
+	3457,						/* U+01F242 */
+	3458,						/* U+01F243 */
+	3459,						/* U+01F244 */
+	3460,						/* U+01F245 */
+	3461,						/* U+01F246 */
+	3462,						/* U+01F247 */
+	3463,						/* U+01F248 */
+	0,							/* U+01F249 */
+	0,							/* U+01F24A */
+	0,							/* U+01F24B */
+	0,							/* U+01F24C */
+	0,							/* U+01F24D */
+	0,							/* U+01F24E */
+	0,							/* U+01F24F */
+	3464,						/* U+01F250 */
+	3465,						/* U+01F251 */
+	1121,						/* U+01FBF0 */
+	10,							/* U+01FBF1 */
+	5,							/* U+01FBF2 */
+	6,							/* U+01FBF3 */
+	1122,						/* U+01FBF4 */
+	1123,						/* U+01FBF5 */
+	1124,						/* U+01FBF6 */
+	1125,						/* U+01FBF7 */
+	1126,						/* U+01FBF8 */
+	1127,						/* U+01FBF9 */
+	3466,						/* U+02F800 */
+	3467,						/* U+02F801 */
+	3468,						/* U+02F802 */
+	3469,						/* U+02F803 */
+	3470,						/* U+02F804 */
+	2488,						/* U+02F805 */
+	3471,						/* U+02F806 */
+	3472,						/* U+02F807 */
+	3473,						/* U+02F808 */
+	3474,						/* U+02F809 */
+	2489,						/* U+02F80A */
+	3475,						/* U+02F80B */
+	3476,						/* U+02F80C */
+	3477,						/* U+02F80D */
+	2490,						/* U+02F80E */
+	3478,						/* U+02F80F */
+	3479,						/* U+02F810 */
+	3480,						/* U+02F811 */
+	3481,						/* U+02F812 */
+	3482,						/* U+02F813 */
+	3483,						/* U+02F814 */
+	3484,						/* U+02F815 */
+	3485,						/* U+02F816 */
+	3486,						/* U+02F817 */
+	3487,						/* U+02F818 */
+	3488,						/* U+02F819 */
+	3489,						/* U+02F81A */
+	2548,						/* U+02F81B */
+	3490,						/* U+02F81C */
+	3491,						/* U+02F81D */
+	3492,						/* U+02F81E */
+	3493,						/* U+02F81F */
+	3494,						/* U+02F820 */
+	3495,						/* U+02F821 */
+	3496,						/* U+02F822 */
+	3497,						/* U+02F823 */
+	3498,						/* U+02F824 */
+	2553,						/* U+02F825 */
+	2491,						/* U+02F826 */
+	2492,						/* U+02F827 */
+	2554,						/* U+02F828 */
+	3499,						/* U+02F829 */
+	3500,						/* U+02F82A */
+	2299,						/* U+02F82B */
+	3501,						/* U+02F82C */
+	2493,						/* U+02F82D */
+	3502,						/* U+02F82E */
+	3503,						/* U+02F82F */
+	3504,						/* U+02F830 */
+	3505,						/* U+02F831 */
+	3505,						/* U+02F832 */
+	3505,						/* U+02F833 */
+	3506,						/* U+02F834 */
+	3507,						/* U+02F835 */
+	3508,						/* U+02F836 */
+	3509,						/* U+02F837 */
+	3510,						/* U+02F838 */
+	3511,						/* U+02F839 */
+	3512,						/* U+02F83A */
+	3513,						/* U+02F83B */
+	3514,						/* U+02F83C */
+	3515,						/* U+02F83D */
+	3516,						/* U+02F83E */
+	3517,						/* U+02F83F */
+	3518,						/* U+02F840 */
+	3519,						/* U+02F841 */
+	3520,						/* U+02F842 */
+	3521,						/* U+02F843 */
+	3522,						/* U+02F844 */
+	3523,						/* U+02F845 */
+	3523,						/* U+02F846 */
+	2556,						/* U+02F847 */
+	3524,						/* U+02F848 */
+	3525,						/* U+02F849 */
+	3526,						/* U+02F84A */
+	3527,						/* U+02F84B */
+	2495,						/* U+02F84C */
+	3528,						/* U+02F84D */
+	3529,						/* U+02F84E */
+	3530,						/* U+02F84F */
+	2452,						/* U+02F850 */
+	3531,						/* U+02F851 */
+	3532,						/* U+02F852 */
+	3533,						/* U+02F853 */
+	3534,						/* U+02F854 */
+	3535,						/* U+02F855 */
+	3536,						/* U+02F856 */
+	3537,						/* U+02F857 */
+	3538,						/* U+02F858 */
+	3539,						/* U+02F859 */
+	3540,						/* U+02F85A */
+	3541,						/* U+02F85B */
+	3542,						/* U+02F85C */
+	3543,						/* U+02F85D */
+	3544,						/* U+02F85E */
+	3545,						/* U+02F85F */
+	3546,						/* U+02F860 */
+	3547,						/* U+02F861 */
+	3548,						/* U+02F862 */
+	3549,						/* U+02F863 */
+	3550,						/* U+02F864 */
+	3551,						/* U+02F865 */
+	3552,						/* U+02F866 */
+	3553,						/* U+02F867 */
+	3554,						/* U+02F868 */
+	3555,						/* U+02F869 */
+	3556,						/* U+02F86A */
+	3556,						/* U+02F86B */
+	3557,						/* U+02F86C */
+	3558,						/* U+02F86D */
+	3559,						/* U+02F86E */
+	2295,						/* U+02F86F */
+	3560,						/* U+02F870 */
+	3561,						/* U+02F871 */
+	3562,						/* U+02F872 */
+	3563,						/* U+02F873 */
+	3564,						/* U+02F874 */
+	3565,						/* U+02F875 */
+	3566,						/* U+02F876 */
+	3567,						/* U+02F877 */
+	2500,						/* U+02F878 */
+	3568,						/* U+02F879 */
+	3569,						/* U+02F87A */
+	3570,						/* U+02F87B */
+	3571,						/* U+02F87C */
+	3572,						/* U+02F87D */
+	3573,						/* U+02F87E */
+	3574,						/* U+02F87F */
+	3575,						/* U+02F880 */
+	3576,						/* U+02F881 */
+	3577,						/* U+02F882 */
+	3578,						/* U+02F883 */
+	3579,						/* U+02F884 */
+	3580,						/* U+02F885 */
+	3581,						/* U+02F886 */
+	3582,						/* U+02F887 */
+	3583,						/* U+02F888 */
+	3584,						/* U+02F889 */
+	3585,						/* U+02F88A */
+	3586,						/* U+02F88B */
+	3587,						/* U+02F88C */
+	3588,						/* U+02F88D */
+	2241,						/* U+02F88E */
+	3589,						/* U+02F88F */
+	3590,						/* U+02F890 */
+	3591,						/* U+02F891 */
+	3591,						/* U+02F892 */
+	3592,						/* U+02F893 */
+	3593,						/* U+02F894 */
+	3593,						/* U+02F895 */
+	3594,						/* U+02F896 */
+	3595,						/* U+02F897 */
+	3596,						/* U+02F898 */
+	3597,						/* U+02F899 */
+	3598,						/* U+02F89A */
+	3599,						/* U+02F89B */
+	3600,						/* U+02F89C */
+	3601,						/* U+02F89D */
+	3602,						/* U+02F89E */
+	3603,						/* U+02F89F */
+	3604,						/* U+02F8A0 */
+	3605,						/* U+02F8A1 */
+	3606,						/* U+02F8A2 */
+	2501,						/* U+02F8A3 */
+	3607,						/* U+02F8A4 */
+	3608,						/* U+02F8A5 */
+	3609,						/* U+02F8A6 */
+	3610,						/* U+02F8A7 */
+	2568,						/* U+02F8A8 */
+	3610,						/* U+02F8A9 */
+	3611,						/* U+02F8AA */
+	2503,						/* U+02F8AB */
+	3612,						/* U+02F8AC */
+	3613,						/* U+02F8AD */
+	3614,						/* U+02F8AE */
+	3615,						/* U+02F8AF */
+	2504,						/* U+02F8B0 */
+	2214,						/* U+02F8B1 */
+	3616,						/* U+02F8B2 */
+	3617,						/* U+02F8B3 */
+	3618,						/* U+02F8B4 */
+	3619,						/* U+02F8B5 */
+	3620,						/* U+02F8B6 */
+	3621,						/* U+02F8B7 */
+	3622,						/* U+02F8B8 */
+	3623,						/* U+02F8B9 */
+	3624,						/* U+02F8BA */
+	3625,						/* U+02F8BB */
+	3626,						/* U+02F8BC */
+	3627,						/* U+02F8BD */
+	3628,						/* U+02F8BE */
+	3629,						/* U+02F8BF */
+	3630,						/* U+02F8C0 */
+	3631,						/* U+02F8C1 */
+	3632,						/* U+02F8C2 */
+	3633,						/* U+02F8C3 */
+	3634,						/* U+02F8C4 */
+	3635,						/* U+02F8C5 */
+	3636,						/* U+02F8C6 */
+	3637,						/* U+02F8C7 */
+	2505,						/* U+02F8C8 */
+	3638,						/* U+02F8C9 */
+	3639,						/* U+02F8CA */
+	3640,						/* U+02F8CB */
+	3641,						/* U+02F8CC */
+	3642,						/* U+02F8CD */
+	3643,						/* U+02F8CE */
+	2507,						/* U+02F8CF */
+	3644,						/* U+02F8D0 */
+	3645,						/* U+02F8D1 */
+	3646,						/* U+02F8D2 */
+	3647,						/* U+02F8D3 */
+	3648,						/* U+02F8D4 */
+	3649,						/* U+02F8D5 */
+	3650,						/* U+02F8D6 */
+	3651,						/* U+02F8D7 */
+	2242,						/* U+02F8D8 */
+	2576,						/* U+02F8D9 */
+	3652,						/* U+02F8DA */
+	3653,						/* U+02F8DB */
+	3654,						/* U+02F8DC */
+	3655,						/* U+02F8DD */
+	3656,						/* U+02F8DE */
+	3657,						/* U+02F8DF */
+	3658,						/* U+02F8E0 */
+	3659,						/* U+02F8E1 */
+	2508,						/* U+02F8E2 */
+	3660,						/* U+02F8E3 */
+	3661,						/* U+02F8E4 */
+	3662,						/* U+02F8E5 */
+	3663,						/* U+02F8E6 */
+	2619,						/* U+02F8E7 */
+	3664,						/* U+02F8E8 */
+	3665,						/* U+02F8E9 */
+	3666,						/* U+02F8EA */
+	3667,						/* U+02F8EB */
+	3668,						/* U+02F8EC */
+	3669,						/* U+02F8ED */
+	3670,						/* U+02F8EE */
+	3671,						/* U+02F8EF */
+	3672,						/* U+02F8F0 */
+	3673,						/* U+02F8F1 */
+	3674,						/* U+02F8F2 */
+	3675,						/* U+02F8F3 */
+	3676,						/* U+02F8F4 */
+	2312,						/* U+02F8F5 */
+	3677,						/* U+02F8F6 */
+	3678,						/* U+02F8F7 */
+	3679,						/* U+02F8F8 */
+	3680,						/* U+02F8F9 */
+	3681,						/* U+02F8FA */
+	3682,						/* U+02F8FB */
+	3683,						/* U+02F8FC */
+	3684,						/* U+02F8FD */
+	3685,						/* U+02F8FE */
+	3686,						/* U+02F8FF */
+	3687,						/* U+02F900 */
+	2509,						/* U+02F901 */
+	2399,						/* U+02F902 */
+	3688,						/* U+02F903 */
+	3689,						/* U+02F904 */
+	3690,						/* U+02F905 */
+	3691,						/* U+02F906 */
+	3692,						/* U+02F907 */
+	3693,						/* U+02F908 */
+	3694,						/* U+02F909 */
+	3695,						/* U+02F90A */
+	2580,						/* U+02F90B */
+	3696,						/* U+02F90C */
+	3697,						/* U+02F90D */
+	3698,						/* U+02F90E */
+	3699,						/* U+02F90F */
+	3700,						/* U+02F910 */
+	3701,						/* U+02F911 */
+	3702,						/* U+02F912 */
+	3703,						/* U+02F913 */
+	2581,						/* U+02F914 */
+	3704,						/* U+02F915 */
+	3705,						/* U+02F916 */
+	3706,						/* U+02F917 */
+	3707,						/* U+02F918 */
+	3708,						/* U+02F919 */
+	3709,						/* U+02F91A */
+	3710,						/* U+02F91B */
+	3711,						/* U+02F91C */
+	3712,						/* U+02F91D */
+	3713,						/* U+02F91E */
+	3714,						/* U+02F91F */
+	3715,						/* U+02F920 */
+	2583,						/* U+02F921 */
+	3716,						/* U+02F922 */
+	3717,						/* U+02F923 */
+	3718,						/* U+02F924 */
+	3719,						/* U+02F925 */
+	3720,						/* U+02F926 */
+	3721,						/* U+02F927 */
+	3722,						/* U+02F928 */
+	3723,						/* U+02F929 */
+	3724,						/* U+02F92A */
+	3725,						/* U+02F92B */
+	3726,						/* U+02F92C */
+	3726,						/* U+02F92D */
+	3727,						/* U+02F92E */
+	3728,						/* U+02F92F */
+	2585,						/* U+02F930 */
+	3729,						/* U+02F931 */
+	3730,						/* U+02F932 */
+	3731,						/* U+02F933 */
+	3732,						/* U+02F934 */
+	3733,						/* U+02F935 */
+	3734,						/* U+02F936 */
+	3735,						/* U+02F937 */
+	2298,						/* U+02F938 */
+	3736,						/* U+02F939 */
+	3737,						/* U+02F93A */
+	3738,						/* U+02F93B */
+	3739,						/* U+02F93C */
+	3740,						/* U+02F93D */
+	3741,						/* U+02F93E */
+	3742,						/* U+02F93F */
+	2591,						/* U+02F940 */
+	3743,						/* U+02F941 */
+	3744,						/* U+02F942 */
+	3745,						/* U+02F943 */
+	3746,						/* U+02F944 */
+	3747,						/* U+02F945 */
+	3748,						/* U+02F946 */
+	3748,						/* U+02F947 */
+	2592,						/* U+02F948 */
+	2621,						/* U+02F949 */
+	3749,						/* U+02F94A */
+	3750,						/* U+02F94B */
+	3751,						/* U+02F94C */
+	3752,						/* U+02F94D */
+	3753,						/* U+02F94E */
+	2260,						/* U+02F94F */
+	2594,						/* U+02F950 */
+	3754,						/* U+02F951 */
+	3755,						/* U+02F952 */
+	2520,						/* U+02F953 */
+	3756,						/* U+02F954 */
+	3757,						/* U+02F955 */
+	2474,						/* U+02F956 */
+	3758,						/* U+02F957 */
+	3759,						/* U+02F958 */
+	2524,						/* U+02F959 */
+	3760,						/* U+02F95A */
+	3761,						/* U+02F95B */
+	3762,						/* U+02F95C */
+	3763,						/* U+02F95D */
+	3763,						/* U+02F95E */
+	3764,						/* U+02F95F */
+	3765,						/* U+02F960 */
+	3766,						/* U+02F961 */
+	3767,						/* U+02F962 */
+	3768,						/* U+02F963 */
+	3769,						/* U+02F964 */
+	3770,						/* U+02F965 */
+	3771,						/* U+02F966 */
+	3772,						/* U+02F967 */
+	3773,						/* U+02F968 */
+	3774,						/* U+02F969 */
+	3775,						/* U+02F96A */
+	3776,						/* U+02F96B */
+	3777,						/* U+02F96C */
+	3778,						/* U+02F96D */
+	3779,						/* U+02F96E */
+	3780,						/* U+02F96F */
+	3781,						/* U+02F970 */
+	3782,						/* U+02F971 */
+	3783,						/* U+02F972 */
+	3784,						/* U+02F973 */
+	3785,						/* U+02F974 */
+	3786,						/* U+02F975 */
+	3787,						/* U+02F976 */
+	3788,						/* U+02F977 */
+	3789,						/* U+02F978 */
+	3790,						/* U+02F979 */
+	2530,						/* U+02F97A */
+	3791,						/* U+02F97B */
+	3792,						/* U+02F97C */
+	3793,						/* U+02F97D */
+	3794,						/* U+02F97E */
+	3795,						/* U+02F97F */
+	3796,						/* U+02F980 */
+	3797,						/* U+02F981 */
+	3798,						/* U+02F982 */
+	3799,						/* U+02F983 */
+	3800,						/* U+02F984 */
+	3801,						/* U+02F985 */
+	3802,						/* U+02F986 */
+	3803,						/* U+02F987 */
+	3804,						/* U+02F988 */
+	3805,						/* U+02F989 */
+	3806,						/* U+02F98A */
+	3592,						/* U+02F98B */
+	3807,						/* U+02F98C */
+	3808,						/* U+02F98D */
+	3809,						/* U+02F98E */
+	3810,						/* U+02F98F */
+	3811,						/* U+02F990 */
+	3812,						/* U+02F991 */
+	3813,						/* U+02F992 */
+	3814,						/* U+02F993 */
+	3815,						/* U+02F994 */
+	3816,						/* U+02F995 */
+	3817,						/* U+02F996 */
+	3818,						/* U+02F997 */
+	2316,						/* U+02F998 */
+	3819,						/* U+02F999 */
+	3820,						/* U+02F99A */
+	3821,						/* U+02F99B */
+	3822,						/* U+02F99C */
+	3823,						/* U+02F99D */
+	3824,						/* U+02F99E */
+	2533,						/* U+02F99F */
+	3825,						/* U+02F9A0 */
+	3826,						/* U+02F9A1 */
+	3827,						/* U+02F9A2 */
+	3828,						/* U+02F9A3 */
+	3829,						/* U+02F9A4 */
+	3830,						/* U+02F9A5 */
+	3831,						/* U+02F9A6 */
+	3832,						/* U+02F9A7 */
+	3833,						/* U+02F9A8 */
+	3834,						/* U+02F9A9 */
+	3835,						/* U+02F9AA */
+	3836,						/* U+02F9AB */
+	3837,						/* U+02F9AC */
+	3838,						/* U+02F9AD */
+	3839,						/* U+02F9AE */
+	3840,						/* U+02F9AF */
+	3841,						/* U+02F9B0 */
+	3842,						/* U+02F9B1 */
+	3843,						/* U+02F9B2 */
+	3844,						/* U+02F9B3 */
+	2255,						/* U+02F9B4 */
+	3845,						/* U+02F9B5 */
+	3846,						/* U+02F9B6 */
+	3847,						/* U+02F9B7 */
+	3848,						/* U+02F9B8 */
+	3849,						/* U+02F9B9 */
+	3850,						/* U+02F9BA */
+	2601,						/* U+02F9BB */
+	3851,						/* U+02F9BC */
+	3852,						/* U+02F9BD */
+	3853,						/* U+02F9BE */
+	3854,						/* U+02F9BF */
+	3855,						/* U+02F9C0 */
+	3856,						/* U+02F9C1 */
+	3857,						/* U+02F9C2 */
+	3858,						/* U+02F9C3 */
+	3859,						/* U+02F9C4 */
+	3860,						/* U+02F9C5 */
+	3861,						/* U+02F9C6 */
+	3862,						/* U+02F9C7 */
+	3863,						/* U+02F9C8 */
+	3864,						/* U+02F9C9 */
+	3865,						/* U+02F9CA */
+	3866,						/* U+02F9CB */
+	3867,						/* U+02F9CC */
+	3868,						/* U+02F9CD */
+	3869,						/* U+02F9CE */
+	3870,						/* U+02F9CF */
+	2606,						/* U+02F9D0 */
+	2607,						/* U+02F9D1 */
+	3871,						/* U+02F9D2 */
+	3872,						/* U+02F9D3 */
+	3873,						/* U+02F9D4 */
+	3874,						/* U+02F9D5 */
+	3875,						/* U+02F9D6 */
+	3876,						/* U+02F9D7 */
+	3877,						/* U+02F9D8 */
+	3878,						/* U+02F9D9 */
+	3879,						/* U+02F9DA */
+	3880,						/* U+02F9DB */
+	3881,						/* U+02F9DC */
+	3882,						/* U+02F9DD */
+	3883,						/* U+02F9DE */
+	2608,						/* U+02F9DF */
+	3884,						/* U+02F9E0 */
+	3885,						/* U+02F9E1 */
+	3886,						/* U+02F9E2 */
+	3887,						/* U+02F9E3 */
+	3888,						/* U+02F9E4 */
+	3889,						/* U+02F9E5 */
+	3890,						/* U+02F9E6 */
+	3891,						/* U+02F9E7 */
+	3892,						/* U+02F9E8 */
+	3893,						/* U+02F9E9 */
+	3894,						/* U+02F9EA */
+	3895,						/* U+02F9EB */
+	3896,						/* U+02F9EC */
+	3897,						/* U+02F9ED */
+	3898,						/* U+02F9EE */
+	3899,						/* U+02F9EF */
+	3900,						/* U+02F9F0 */
+	3901,						/* U+02F9F1 */
+	3902,						/* U+02F9F2 */
+	3903,						/* U+02F9F3 */
+	3904,						/* U+02F9F4 */
+	3905,						/* U+02F9F5 */
+	3906,						/* U+02F9F6 */
+	3907,						/* U+02F9F7 */
+	3908,						/* U+02F9F8 */
+	3909,						/* U+02F9F9 */
+	3910,						/* U+02F9FA */
+	3911,						/* U+02F9FB */
+	3912,						/* U+02F9FC */
+	3913,						/* U+02F9FD */
+	2614,						/* U+02F9FE */
+	2614,						/* U+02F9FF */
+	3914,						/* U+02FA00 */
+	3915,						/* U+02FA01 */
+	3916,						/* U+02FA02 */
+	3917,						/* U+02FA03 */
+	3918,						/* U+02FA04 */
+	3919,						/* U+02FA05 */
+	3920,						/* U+02FA06 */
+	3921,						/* U+02FA07 */
+	3922,						/* U+02FA08 */
+	3923,						/* U+02FA09 */
+	2615,						/* U+02FA0A */
+	3924,						/* U+02FA0B */
+	3925,						/* U+02FA0C */
+	3926,						/* U+02FA0D */
+	3927,						/* U+02FA0E */
+	3928,						/* U+02FA0F */
+	3929,						/* U+02FA10 */
+	3930,						/* U+02FA11 */
+	3931,						/* U+02FA12 */
+	3932,						/* U+02FA13 */
+	3933,						/* U+02FA14 */
+	3934,						/* U+02FA15 */
+	3935,						/* U+02FA16 */
+	3936,						/* U+02FA17 */
+	3937,						/* U+02FA18 */
+	3938,						/* U+02FA19 */
+	3939,						/* U+02FA1A */
+	3940,						/* U+02FA1B */
+	3941,						/* U+02FA1C */
+	3942,						/* U+02FA1D */
+};
+
+/*
+ * Used by inverse_index() to map a codepoint to an index that can be
+ * used in UnicodeDecompInverseSecond table.
+ */
+static const uint16 inverse_map[8460] =
+{
+	3,							/* U+00003C */
+	7,							/* U+00003D */
+	11,							/* U+00003E */
+	0,							/* U+00003F */
+	0,							/* U+000040 */
+	15,							/* U+000041 */
+	59,							/* U+000042 */
+	105,						/* U+000043 */
+	147,						/* U+000044 */
+	193,						/* U+000045 */
+	245,						/* U+000046 */
+	249,						/* U+000047 */
+	291,						/* U+000048 */
+	339,						/* U+000049 */
+	391,						/* U+00004A */
+	395,						/* U+00004B */
+	447,						/* U+00004C */
+	499,						/* U+00004D */
+	537,						/* U+00004E */
+	590,						/* U+00004F */
+	634,						/* U+000050 */
+	0,							/* U+000051 */
+	644,						/* U+000052 */
+	696,						/* U+000053 */
+	738,						/* U+000054 */
+	784,						/* U+000055 */
+	836,						/* U+000056 */
+	872,						/* U+000057 */
+	911,						/* U+000058 */
+	916,						/* U+000059 */
+	955,						/* U+00005A */
+	0,							/* U+00005B */
+	0,							/* U+00005C */
+	0,							/* U+00005D */
+	0,							/* U+00005E */
+	0,							/* U+00005F */
+	0,							/* U+000060 */
+	1007,						/* U+000061 */
+	1051,						/* U+000062 */
+	1097,						/* U+000063 */
+	1139,						/* U+000064 */
+	1185,						/* U+000065 */
+	1237,						/* U+000066 */
+	1241,						/* U+000067 */
+	1283,						/* U+000068 */
+	1334,						/* U+000069 */
+	1386,						/* U+00006A */
+	1400,						/* U+00006B */
+	1452,						/* U+00006C */
+	1504,						/* U+00006D */
+	1542,						/* U+00006E */
+	1595,						/* U+00006F */
+	1639,						/* U+000070 */
+	0,							/* U+000071 */
+	1649,						/* U+000072 */
+	1701,						/* U+000073 */
+	1743,						/* U+000074 */
+	1789,						/* U+000075 */
+	1841,						/* U+000076 */
+	1877,						/* U+000077 */
+	1916,						/* U+000078 */
+	1921,						/* U+000079 */
+	1960,						/* U+00007A */
+	0,							/* U+00007B */
+	0,							/* U+00007C */
+	0,							/* U+00007D */
+	0,							/* U+00007E */
+	0,							/* U+00007F */
+	0,							/* U+000080 */
+	0,							/* U+000081 */
+	0,							/* U+000082 */
+	0,							/* U+000083 */
+	0,							/* U+000084 */
+	0,							/* U+000085 */
+	0,							/* U+000086 */
+	0,							/* U+000087 */
+	0,							/* U+000088 */
+	0,							/* U+000089 */
+	0,							/* U+00008A */
+	0,							/* U+00008B */
+	0,							/* U+00008C */
+	0,							/* U+00008D */
+	0,							/* U+00008E */
+	0,							/* U+00008F */
+	0,							/* U+000090 */
+	0,							/* U+000091 */
+	0,							/* U+000092 */
+	0,							/* U+000093 */
+	0,							/* U+000094 */
+	0,							/* U+000095 */
+	0,							/* U+000096 */
+	0,							/* U+000097 */
+	0,							/* U+000098 */
+	0,							/* U+000099 */
+	0,							/* U+00009A */
+	0,							/* U+00009B */
+	0,							/* U+00009C */
+	0,							/* U+00009D */
+	0,							/* U+00009E */
+	0,							/* U+00009F */
+	0,							/* U+0000A0 */
+	0,							/* U+0000A1 */
+	0,							/* U+0000A2 */
+	0,							/* U+0000A3 */
+	0,							/* U+0000A4 */
+	0,							/* U+0000A5 */
+	0,							/* U+0000A6 */
+	0,							/* U+0000A7 */
+	2012,						/* U+0000A8 */
+	0,							/* U+0000A9 */
+	0,							/* U+0000AA */
+	0,							/* U+0000AB */
+	0,							/* U+0000AC */
+	0,							/* U+0000AD */
+	0,							/* U+0000AE */
+	0,							/* U+0000AF */
+	0,							/* U+0000B0 */
+	0,							/* U+0000B1 */
+	0,							/* U+0000B2 */
+	0,							/* U+0000B3 */
+	0,							/* U+0000B4 */
+	0,							/* U+0000B5 */
+	0,							/* U+0000B6 */
+	0,							/* U+0000B7 */
+	0,							/* U+0000B8 */
+	0,							/* U+0000B9 */
+	0,							/* U+0000BA */
+	0,							/* U+0000BB */
+	0,							/* U+0000BC */
+	0,							/* U+0000BD */
+	0,							/* U+0000BE */
+	0,							/* U+0000BF */
+	0,							/* U+0000C0 */
+	0,							/* U+0000C1 */
+	2082,						/* U+0000C2 */
+	0,							/* U+0000C3 */
+	2095,						/* U+0000C4 */
+	2099,						/* U+0000C5 */
+	2103,						/* U+0000C6 */
+	2110,						/* U+0000C7 */
+	0,							/* U+0000C8 */
+	0,							/* U+0000C9 */
+	2114,						/* U+0000CA */
+	0,							/* U+0000CB */
+	0,							/* U+0000CC */
+	0,							/* U+0000CD */
+	0,							/* U+0000CE */
+	2127,						/* U+0000CF */
+	0,							/* U+0000D0 */
+	0,							/* U+0000D1 */
+	0,							/* U+0000D2 */
+	0,							/* U+0000D3 */
+	2131,						/* U+0000D4 */
+	2144,						/* U+0000D5 */
+	2155,						/* U+0000D6 */
+	0,							/* U+0000D7 */
+	2159,						/* U+0000D8 */
+	0,							/* U+0000D9 */
+	0,							/* U+0000DA */
+	0,							/* U+0000DB */
+	2163,						/* U+0000DC */
+	0,							/* U+0000DD */
+	0,							/* U+0000DE */
+	0,							/* U+0000DF */
+	0,							/* U+0000E0 */
+	0,							/* U+0000E1 */
+	2179,						/* U+0000E2 */
+	0,							/* U+0000E3 */
+	2192,						/* U+0000E4 */
+	2196,						/* U+0000E5 */
+	2200,						/* U+0000E6 */
+	2207,						/* U+0000E7 */
+	0,							/* U+0000E8 */
+	0,							/* U+0000E9 */
+	2211,						/* U+0000EA */
+	0,							/* U+0000EB */
+	0,							/* U+0000EC */
+	0,							/* U+0000ED */
+	0,							/* U+0000EE */
+	2224,						/* U+0000EF */
+	0,							/* U+0000F0 */
+	0,							/* U+0000F1 */
+	0,							/* U+0000F2 */
+	0,							/* U+0000F3 */
+	2228,						/* U+0000F4 */
+	2241,						/* U+0000F5 */
+	2252,						/* U+0000F6 */
+	0,							/* U+0000F7 */
+	2256,						/* U+0000F8 */
+	0,							/* U+0000F9 */
+	0,							/* U+0000FA */
+	0,							/* U+0000FB */
+	2260,						/* U+0000FC */
+	0,							/* U+0000FD */
+	0,							/* U+0000FE */
+	0,							/* U+0000FF */
+	0,							/* U+000100 */
+	0,							/* U+000101 */
+	2276,						/* U+000102 */
+	2289,						/* U+000103 */
+	0,							/* U+000104 */
+	0,							/* U+000105 */
+	0,							/* U+000106 */
+	0,							/* U+000107 */
+	0,							/* U+000108 */
+	0,							/* U+000109 */
+	0,							/* U+00010A */
+	0,							/* U+00010B */
+	0,							/* U+00010C */
+	0,							/* U+00010D */
+	0,							/* U+00010E */
+	0,							/* U+00010F */
+	0,							/* U+000110 */
+	0,							/* U+000111 */
+	2302,						/* U+000112 */
+	2307,						/* U+000113 */
+	0,							/* U+000114 */
+	0,							/* U+000115 */
+	0,							/* U+000116 */
+	0,							/* U+000117 */
+	0,							/* U+000118 */
+	0,							/* U+000119 */
+	0,							/* U+00011A */
+	0,							/* U+00011B */
+	0,							/* U+00011C */
+	0,							/* U+00011D */
+	0,							/* U+00011E */
+	0,							/* U+00011F */
+	0,							/* U+000120 */
+	0,							/* U+000121 */
+	0,							/* U+000122 */
+	0,							/* U+000123 */
+	0,							/* U+000124 */
+	0,							/* U+000125 */
+	0,							/* U+000126 */
+	0,							/* U+000127 */
+	0,							/* U+000128 */
+	0,							/* U+000129 */
+	0,							/* U+00012A */
+	0,							/* U+00012B */
+	0,							/* U+00012C */
+	0,							/* U+00012D */
+	0,							/* U+00012E */
+	0,							/* U+00012F */
+	0,							/* U+000130 */
+	0,							/* U+000131 */
+	0,							/* U+000132 */
+	0,							/* U+000133 */
+	0,							/* U+000134 */
+	0,							/* U+000135 */
+	0,							/* U+000136 */
+	0,							/* U+000137 */
+	0,							/* U+000138 */
+	0,							/* U+000139 */
+	0,							/* U+00013A */
+	0,							/* U+00013B */
+	0,							/* U+00013C */
+	0,							/* U+00013D */
+	0,							/* U+00013E */
+	0,							/* U+00013F */
+	0,							/* U+000140 */
+	0,							/* U+000141 */
+	0,							/* U+000142 */
+	0,							/* U+000143 */
+	0,							/* U+000144 */
+	0,							/* U+000145 */
+	0,							/* U+000146 */
+	0,							/* U+000147 */
+	0,							/* U+000148 */
+	0,							/* U+000149 */
+	0,							/* U+00014A */
+	0,							/* U+00014B */
+	2312,						/* U+00014C */
+	2317,						/* U+00014D */
+	0,							/* U+00014E */
+	0,							/* U+00014F */
+	0,							/* U+000150 */
+	0,							/* U+000151 */
+	0,							/* U+000152 */
+	0,							/* U+000153 */
+	0,							/* U+000154 */
+	0,							/* U+000155 */
+	0,							/* U+000156 */
+	0,							/* U+000157 */
+	0,							/* U+000158 */
+	0,							/* U+000159 */
+	2322,						/* U+00015A */
+	2326,						/* U+00015B */
+	0,							/* U+00015C */
+	0,							/* U+00015D */
+	0,							/* U+00015E */
+	0,							/* U+00015F */
+	2330,						/* U+000160 */
+	2334,						/* U+000161 */
+	0,							/* U+000162 */
+	0,							/* U+000163 */
+	0,							/* U+000164 */
+	0,							/* U+000165 */
+	0,							/* U+000166 */
+	0,							/* U+000167 */
+	2338,						/* U+000168 */
+	2342,						/* U+000169 */
+	2346,						/* U+00016A */
+	2350,						/* U+00016B */
+	0,							/* U+00016C */
+	0,							/* U+00016D */
+	0,							/* U+00016E */
+	0,							/* U+00016F */
+	0,							/* U+000170 */
+	0,							/* U+000171 */
+	0,							/* U+000172 */
+	0,							/* U+000173 */
+	0,							/* U+000174 */
+	0,							/* U+000175 */
+	0,							/* U+000176 */
+	0,							/* U+000177 */
+	0,							/* U+000178 */
+	0,							/* U+000179 */
+	0,							/* U+00017A */
+	0,							/* U+00017B */
+	0,							/* U+00017C */
+	0,							/* U+00017D */
+	0,							/* U+00017E */
+	2354,						/* U+00017F */
+	0,							/* U+000180 */
+	0,							/* U+000181 */
+	0,							/* U+000182 */
+	0,							/* U+000183 */
+	0,							/* U+000184 */
+	0,							/* U+000185 */
+	0,							/* U+000186 */
+	0,							/* U+000187 */
+	0,							/* U+000188 */
+	0,							/* U+000189 */
+	0,							/* U+00018A */
+	0,							/* U+00018B */
+	0,							/* U+00018C */
+	0,							/* U+00018D */
+	0,							/* U+00018E */
+	0,							/* U+00018F */
+	0,							/* U+000190 */
+	0,							/* U+000191 */
+	0,							/* U+000192 */
+	0,							/* U+000193 */
+	0,							/* U+000194 */
+	0,							/* U+000195 */
+	0,							/* U+000196 */
+	0,							/* U+000197 */
+	0,							/* U+000198 */
+	0,							/* U+000199 */
+	0,							/* U+00019A */
+	0,							/* U+00019B */
+	0,							/* U+00019C */
+	0,							/* U+00019D */
+	0,							/* U+00019E */
+	0,							/* U+00019F */
+	2358,						/* U+0001A0 */
+	2397,						/* U+0001A1 */
+	0,							/* U+0001A2 */
+	0,							/* U+0001A3 */
+	0,							/* U+0001A4 */
+	0,							/* U+0001A5 */
+	0,							/* U+0001A6 */
+	0,							/* U+0001A7 */
+	0,							/* U+0001A8 */
+	0,							/* U+0001A9 */
+	0,							/* U+0001AA */
+	0,							/* U+0001AB */
+	0,							/* U+0001AC */
+	0,							/* U+0001AD */
+	0,							/* U+0001AE */
+	2436,						/* U+0001AF */
+	2475,						/* U+0001B0 */
+	0,							/* U+0001B1 */
+	0,							/* U+0001B2 */
+	0,							/* U+0001B3 */
+	0,							/* U+0001B4 */
+	0,							/* U+0001B5 */
+	0,							/* U+0001B6 */
+	2514,						/* U+0001B7 */
+	0,							/* U+0001B8 */
+	0,							/* U+0001B9 */
+	0,							/* U+0001BA */
+	0,							/* U+0001BB */
+	0,							/* U+0001BC */
+	0,							/* U+0001BD */
+	0,							/* U+0001BE */
+	0,							/* U+0001BF */
+	0,							/* U+0001C0 */
+	0,							/* U+0001C1 */
+	0,							/* U+0001C2 */
+	0,							/* U+0001C3 */
+	0,							/* U+0001C4 */
+	0,							/* U+0001C5 */
+	0,							/* U+0001C6 */
+	0,							/* U+0001C7 */
+	0,							/* U+0001C8 */
+	0,							/* U+0001C9 */
+	0,							/* U+0001CA */
+	0,							/* U+0001CB */
+	0,							/* U+0001CC */
+	0,							/* U+0001CD */
+	0,							/* U+0001CE */
+	0,							/* U+0001CF */
+	0,							/* U+0001D0 */
+	0,							/* U+0001D1 */
+	0,							/* U+0001D2 */
+	0,							/* U+0001D3 */
+	0,							/* U+0001D4 */
+	0,							/* U+0001D5 */
+	0,							/* U+0001D6 */
+	0,							/* U+0001D7 */
+	0,							/* U+0001D8 */
+	0,							/* U+0001D9 */
+	0,							/* U+0001DA */
+	0,							/* U+0001DB */
+	0,							/* U+0001DC */
+	0,							/* U+0001DD */
+	0,							/* U+0001DE */
+	0,							/* U+0001DF */
+	0,							/* U+0001E0 */
+	0,							/* U+0001E1 */
+	0,							/* U+0001E2 */
+	0,							/* U+0001E3 */
+	0,							/* U+0001E4 */
+	0,							/* U+0001E5 */
+	0,							/* U+0001E6 */
+	0,							/* U+0001E7 */
+	0,							/* U+0001E8 */
+	0,							/* U+0001E9 */
+	2518,						/* U+0001EA */
+	2522,						/* U+0001EB */
+	0,							/* U+0001EC */
+	0,							/* U+0001ED */
+	0,							/* U+0001EE */
+	0,							/* U+0001EF */
+	0,							/* U+0001F0 */
+	0,							/* U+0001F1 */
+	0,							/* U+0001F2 */
+	0,							/* U+0001F3 */
+	0,							/* U+0001F4 */
+	0,							/* U+0001F5 */
+	0,							/* U+0001F6 */
+	0,							/* U+0001F7 */
+	0,							/* U+0001F8 */
+	0,							/* U+0001F9 */
+	0,							/* U+0001FA */
+	0,							/* U+0001FB */
+	0,							/* U+0001FC */
+	0,							/* U+0001FD */
+	0,							/* U+0001FE */
+	0,							/* U+0001FF */
+	0,							/* U+000200 */
+	0,							/* U+000201 */
+	0,							/* U+000202 */
+	0,							/* U+000203 */
+	0,							/* U+000204 */
+	0,							/* U+000205 */
+	0,							/* U+000206 */
+	0,							/* U+000207 */
+	0,							/* U+000208 */
+	0,							/* U+000209 */
+	0,							/* U+00020A */
+	0,							/* U+00020B */
+	0,							/* U+00020C */
+	0,							/* U+00020D */
+	0,							/* U+00020E */
+	0,							/* U+00020F */
+	0,							/* U+000210 */
+	0,							/* U+000211 */
+	0,							/* U+000212 */
+	0,							/* U+000213 */
+	0,							/* U+000214 */
+	0,							/* U+000215 */
+	0,							/* U+000216 */
+	0,							/* U+000217 */
+	0,							/* U+000218 */
+	0,							/* U+000219 */
+	0,							/* U+00021A */
+	0,							/* U+00021B */
+	0,							/* U+00021C */
+	0,							/* U+00021D */
+	0,							/* U+00021E */
+	0,							/* U+00021F */
+	0,							/* U+000220 */
+	0,							/* U+000221 */
+	0,							/* U+000222 */
+	0,							/* U+000223 */
+	0,							/* U+000224 */
+	0,							/* U+000225 */
+	2526,						/* U+000226 */
+	2530,						/* U+000227 */
+	2534,						/* U+000228 */
+	2538,						/* U+000229 */
+	0,							/* U+00022A */
+	0,							/* U+00022B */
+	0,							/* U+00022C */
+	0,							/* U+00022D */
+	2542,						/* U+00022E */
+	2546,						/* U+00022F */
+	0,							/* U+000230 */
+	0,							/* U+000231 */
+	0,							/* U+000232 */
+	0,							/* U+000233 */
+	0,							/* U+000234 */
+	0,							/* U+000235 */
+	0,							/* U+000236 */
+	0,							/* U+000237 */
+	0,							/* U+000238 */
+	0,							/* U+000239 */
+	0,							/* U+00023A */
+	0,							/* U+00023B */
+	0,							/* U+00023C */
+	0,							/* U+00023D */
+	0,							/* U+00023E */
+	0,							/* U+00023F */
+	0,							/* U+000240 */
+	0,							/* U+000241 */
+	0,							/* U+000242 */
+	0,							/* U+000243 */
+	0,							/* U+000244 */
+	0,							/* U+000245 */
+	0,							/* U+000246 */
+	0,							/* U+000247 */
+	0,							/* U+000248 */
+	0,							/* U+000249 */
+	0,							/* U+00024A */
+	0,							/* U+00024B */
+	0,							/* U+00024C */
+	0,							/* U+00024D */
+	0,							/* U+00024E */
+	0,							/* U+00024F */
+	0,							/* U+000250 */
+	0,							/* U+000251 */
+	0,							/* U+000252 */
+	0,							/* U+000253 */
+	0,							/* U+000254 */
+	0,							/* U+000255 */
+	0,							/* U+000256 */
+	0,							/* U+000257 */
+	0,							/* U+000258 */
+	0,							/* U+000259 */
+	0,							/* U+00025A */
+	0,							/* U+00025B */
+	0,							/* U+00025C */
+	0,							/* U+00025D */
+	0,							/* U+00025E */
+	0,							/* U+00025F */
+	0,							/* U+000260 */
+	0,							/* U+000261 */
+	0,							/* U+000262 */
+	0,							/* U+000263 */
+	0,							/* U+000264 */
+	0,							/* U+000265 */
+	0,							/* U+000266 */
+	0,							/* U+000267 */
+	0,							/* U+000268 */
+	0,							/* U+000269 */
+	0,							/* U+00026A */
+	0,							/* U+00026B */
+	0,							/* U+00026C */
+	0,							/* U+00026D */
+	0,							/* U+00026E */
+	0,							/* U+00026F */
+	0,							/* U+000270 */
+	0,							/* U+000271 */
+	0,							/* U+000272 */
+	0,							/* U+000273 */
+	0,							/* U+000274 */
+	0,							/* U+000275 */
+	0,							/* U+000276 */
+	0,							/* U+000277 */
+	0,							/* U+000278 */
+	0,							/* U+000279 */
+	0,							/* U+00027A */
+	0,							/* U+00027B */
+	0,							/* U+00027C */
+	0,							/* U+00027D */
+	0,							/* U+00027E */
+	0,							/* U+00027F */
+	0,							/* U+000280 */
+	0,							/* U+000281 */
+	0,							/* U+000282 */
+	0,							/* U+000283 */
+	0,							/* U+000284 */
+	0,							/* U+000285 */
+	0,							/* U+000286 */
+	0,							/* U+000287 */
+	0,							/* U+000288 */
+	0,							/* U+000289 */
+	0,							/* U+00028A */
+	0,							/* U+00028B */
+	0,							/* U+00028C */
+	0,							/* U+00028D */
+	0,							/* U+00028E */
+	0,							/* U+00028F */
+	0,							/* U+000290 */
+	0,							/* U+000291 */
+	2550,						/* U+000292 */
+	0,							/* U+000293 */
+	0,							/* U+000294 */
+	0,							/* U+000295 */
+	0,							/* U+000296 */
+	0,							/* U+000297 */
+	0,							/* U+000298 */
+	0,							/* U+000299 */
+	0,							/* U+00029A */
+	0,							/* U+00029B */
+	0,							/* U+00029C */
+	0,							/* U+00029D */
+	0,							/* U+00029E */
+	0,							/* U+00029F */
+	0,							/* U+0002A0 */
+	0,							/* U+0002A1 */
+	0,							/* U+0002A2 */
+	0,							/* U+0002A3 */
+	0,							/* U+0002A4 */
+	0,							/* U+0002A5 */
+	0,							/* U+0002A6 */
+	0,							/* U+0002A7 */
+	0,							/* U+0002A8 */
+	0,							/* U+0002A9 */
+	0,							/* U+0002AA */
+	0,							/* U+0002AB */
+	0,							/* U+0002AC */
+	0,							/* U+0002AD */
+	0,							/* U+0002AE */
+	0,							/* U+0002AF */
+	0,							/* U+0002B0 */
+	0,							/* U+0002B1 */
+	0,							/* U+0002B2 */
+	0,							/* U+0002B3 */
+	0,							/* U+0002B4 */
+	0,							/* U+0002B5 */
+	0,							/* U+0002B6 */
+	0,							/* U+0002B7 */
+	0,							/* U+0002B8 */
+	0,							/* U+0002B9 */
+	0,							/* U+0002BA */
+	0,							/* U+0002BB */
+	0,							/* U+0002BC */
+	0,							/* U+0002BD */
+	0,							/* U+0002BE */
+	0,							/* U+0002BF */
+	0,							/* U+0002C0 */
+	0,							/* U+0002C1 */
+	0,							/* U+0002C2 */
+	0,							/* U+0002C3 */
+	0,							/* U+0002C4 */
+	0,							/* U+0002C5 */
+	0,							/* U+0002C6 */
+	0,							/* U+0002C7 */
+	0,							/* U+0002C8 */
+	0,							/* U+0002C9 */
+	0,							/* U+0002CA */
+	0,							/* U+0002CB */
+	0,							/* U+0002CC */
+	0,							/* U+0002CD */
+	0,							/* U+0002CE */
+	0,							/* U+0002CF */
+	0,							/* U+0002D0 */
+	0,							/* U+0002D1 */
+	0,							/* U+0002D2 */
+	0,							/* U+0002D3 */
+	0,							/* U+0002D4 */
+	0,							/* U+0002D5 */
+	0,							/* U+0002D6 */
+	0,							/* U+0002D7 */
+	0,							/* U+0002D8 */
+	0,							/* U+0002D9 */
+	0,							/* U+0002DA */
+	0,							/* U+0002DB */
+	0,							/* U+0002DC */
+	0,							/* U+0002DD */
+	0,							/* U+0002DE */
+	0,							/* U+0002DF */
+	0,							/* U+0002E0 */
+	0,							/* U+0002E1 */
+	0,							/* U+0002E2 */
+	0,							/* U+0002E3 */
+	0,							/* U+0002E4 */
+	0,							/* U+0002E5 */
+	0,							/* U+0002E6 */
+	0,							/* U+0002E7 */
+	0,							/* U+0002E8 */
+	0,							/* U+0002E9 */
+	0,							/* U+0002EA */
+	0,							/* U+0002EB */
+	0,							/* U+0002EC */
+	0,							/* U+0002ED */
+	0,							/* U+0002EE */
+	0,							/* U+0002EF */
+	0,							/* U+0002F0 */
+	0,							/* U+0002F1 */
+	0,							/* U+0002F2 */
+	0,							/* U+0002F3 */
+	0,							/* U+0002F4 */
+	0,							/* U+0002F5 */
+	0,							/* U+0002F6 */
+	0,							/* U+0002F7 */
+	0,							/* U+0002F8 */
+	0,							/* U+0002F9 */
+	0,							/* U+0002FA */
+	0,							/* U+0002FB */
+	0,							/* U+0002FC */
+	0,							/* U+0002FD */
+	0,							/* U+0002FE */
+	0,							/* U+0002FF */
+	0,							/* U+000300 */
+	0,							/* U+000301 */
+	0,							/* U+000302 */
+	0,							/* U+000303 */
+	0,							/* U+000304 */
+	0,							/* U+000305 */
+	0,							/* U+000306 */
+	0,							/* U+000307 */
+	0,							/* U+000308 */
+	0,							/* U+000309 */
+	0,							/* U+00030A */
+	0,							/* U+00030B */
+	0,							/* U+00030C */
+	0,							/* U+00030D */
+	0,							/* U+00030E */
+	0,							/* U+00030F */
+	0,							/* U+000310 */
+	0,							/* U+000311 */
+	0,							/* U+000312 */
+	0,							/* U+000313 */
+	0,							/* U+000314 */
+	0,							/* U+000315 */
+	0,							/* U+000316 */
+	0,							/* U+000317 */
+	0,							/* U+000318 */
+	0,							/* U+000319 */
+	0,							/* U+00031A */
+	0,							/* U+00031B */
+	0,							/* U+00031C */
+	0,							/* U+00031D */
+	0,							/* U+00031E */
+	0,							/* U+00031F */
+	0,							/* U+000320 */
+	0,							/* U+000321 */
+	0,							/* U+000322 */
+	0,							/* U+000323 */
+	0,							/* U+000324 */
+	0,							/* U+000325 */
+	0,							/* U+000326 */
+	0,							/* U+000327 */
+	0,							/* U+000328 */
+	0,							/* U+000329 */
+	0,							/* U+00032A */
+	0,							/* U+00032B */
+	0,							/* U+00032C */
+	0,							/* U+00032D */
+	0,							/* U+00032E */
+	0,							/* U+00032F */
+	0,							/* U+000330 */
+	0,							/* U+000331 */
+	0,							/* U+000332 */
+	0,							/* U+000333 */
+	0,							/* U+000334 */
+	0,							/* U+000335 */
+	0,							/* U+000336 */
+	0,							/* U+000337 */
+	0,							/* U+000338 */
+	0,							/* U+000339 */
+	0,							/* U+00033A */
+	0,							/* U+00033B */
+	0,							/* U+00033C */
+	0,							/* U+00033D */
+	0,							/* U+00033E */
+	0,							/* U+00033F */
+	0,							/* U+000340 */
+	0,							/* U+000341 */
+	0,							/* U+000342 */
+	0,							/* U+000343 */
+	0,							/* U+000344 */
+	0,							/* U+000345 */
+	0,							/* U+000346 */
+	0,							/* U+000347 */
+	0,							/* U+000348 */
+	0,							/* U+000349 */
+	0,							/* U+00034A */
+	0,							/* U+00034B */
+	0,							/* U+00034C */
+	0,							/* U+00034D */
+	0,							/* U+00034E */
+	0,							/* U+00034F */
+	0,							/* U+000350 */
+	0,							/* U+000351 */
+	0,							/* U+000352 */
+	0,							/* U+000353 */
+	0,							/* U+000354 */
+	0,							/* U+000355 */
+	0,							/* U+000356 */
+	0,							/* U+000357 */
+	0,							/* U+000358 */
+	0,							/* U+000359 */
+	0,							/* U+00035A */
+	0,							/* U+00035B */
+	0,							/* U+00035C */
+	0,							/* U+00035D */
+	0,							/* U+00035E */
+	0,							/* U+00035F */
+	0,							/* U+000360 */
+	0,							/* U+000361 */
+	0,							/* U+000362 */
+	0,							/* U+000363 */
+	0,							/* U+000364 */
+	0,							/* U+000365 */
+	0,							/* U+000366 */
+	0,							/* U+000367 */
+	0,							/* U+000368 */
+	0,							/* U+000369 */
+	0,							/* U+00036A */
+	0,							/* U+00036B */
+	0,							/* U+00036C */
+	0,							/* U+00036D */
+	0,							/* U+00036E */
+	0,							/* U+00036F */
+	0,							/* U+000370 */
+	0,							/* U+000371 */
+	0,							/* U+000372 */
+	0,							/* U+000373 */
+	0,							/* U+000374 */
+	0,							/* U+000375 */
+	0,							/* U+000376 */
+	0,							/* U+000377 */
+	0,							/* U+000378 */
+	0,							/* U+000379 */
+	0,							/* U+00037A */
+	0,							/* U+00037B */
+	0,							/* U+00037C */
+	0,							/* U+00037D */
+	0,							/* U+00037E */
+	0,							/* U+00037F */
+	0,							/* U+000380 */
+	0,							/* U+000381 */
+	0,							/* U+000382 */
+	0,							/* U+000383 */
+	0,							/* U+000384 */
+	0,							/* U+000385 */
+	0,							/* U+000386 */
+	0,							/* U+000387 */
+	0,							/* U+000388 */
+	0,							/* U+000389 */
+	0,							/* U+00038A */
+	0,							/* U+00038B */
+	0,							/* U+00038C */
+	0,							/* U+00038D */
+	0,							/* U+00038E */
+	0,							/* U+00038F */
+	0,							/* U+000390 */
+	2554,						/* U+000391 */
+	0,							/* U+000392 */
+	0,							/* U+000393 */
+	0,							/* U+000394 */
+	2627,						/* U+000395 */
+	0,							/* U+000396 */
+	2651,						/* U+000397 */
+	0,							/* U+000398 */
+	2724,						/* U+000399 */
+	0,							/* U+00039A */
+	0,							/* U+00039B */
+	0,							/* U+00039C */
+	0,							/* U+00039D */
+	0,							/* U+00039E */
+	2748,						/* U+00039F */
+	0,							/* U+0003A0 */
+	2772,						/* U+0003A1 */
+	0,							/* U+0003A2 */
+	0,							/* U+0003A3 */
+	0,							/* U+0003A4 */
+	2776,						/* U+0003A5 */
+	0,							/* U+0003A6 */
+	0,							/* U+0003A7 */
+	0,							/* U+0003A8 */
+	2800,						/* U+0003A9 */
+	0,							/* U+0003AA */
+	0,							/* U+0003AB */
+	2873,						/* U+0003AC */
+	0,							/* U+0003AD */
+	2877,						/* U+0003AE */
+	0,							/* U+0003AF */
+	0,							/* U+0003B0 */
+	2881,						/* U+0003B1 */
+	0,							/* U+0003B2 */
+	0,							/* U+0003B3 */
+	0,							/* U+0003B4 */
+	2954,						/* U+0003B5 */
+	0,							/* U+0003B6 */
+	2978,						/* U+0003B7 */
+	0,							/* U+0003B8 */
+	3051,						/* U+0003B9 */
+	0,							/* U+0003BA */
+	0,							/* U+0003BB */
+	0,							/* U+0003BC */
+	0,							/* U+0003BD */
+	0,							/* U+0003BE */
+	3121,						/* U+0003BF */
+	0,							/* U+0003C0 */
+	3145,						/* U+0003C1 */
+	0,							/* U+0003C2 */
+	0,							/* U+0003C3 */
+	0,							/* U+0003C4 */
+	3150,						/* U+0003C5 */
+	0,							/* U+0003C6 */
+	0,							/* U+0003C7 */
+	0,							/* U+0003C8 */
+	3220,						/* U+0003C9 */
+	3293,						/* U+0003CA */
+	3363,						/* U+0003CB */
+	0,							/* U+0003CC */
+	0,							/* U+0003CD */
+	3433,						/* U+0003CE */
+	0,							/* U+0003CF */
+	0,							/* U+0003D0 */
+	0,							/* U+0003D1 */
+	3437,						/* U+0003D2 */
+	0,							/* U+0003D3 */
+	0,							/* U+0003D4 */
+	0,							/* U+0003D5 */
+	0,							/* U+0003D6 */
+	0,							/* U+0003D7 */
+	0,							/* U+0003D8 */
+	0,							/* U+0003D9 */
+	0,							/* U+0003DA */
+	0,							/* U+0003DB */
+	0,							/* U+0003DC */
+	0,							/* U+0003DD */
+	0,							/* U+0003DE */
+	0,							/* U+0003DF */
+	0,							/* U+0003E0 */
+	0,							/* U+0003E1 */
+	0,							/* U+0003E2 */
+	0,							/* U+0003E3 */
+	0,							/* U+0003E4 */
+	0,							/* U+0003E5 */
+	0,							/* U+0003E6 */
+	0,							/* U+0003E7 */
+	0,							/* U+0003E8 */
+	0,							/* U+0003E9 */
+	0,							/* U+0003EA */
+	0,							/* U+0003EB */
+	0,							/* U+0003EC */
+	0,							/* U+0003ED */
+	0,							/* U+0003EE */
+	0,							/* U+0003EF */
+	0,							/* U+0003F0 */
+	0,							/* U+0003F1 */
+	0,							/* U+0003F2 */
+	0,							/* U+0003F3 */
+	0,							/* U+0003F4 */
+	0,							/* U+0003F5 */
+	0,							/* U+0003F6 */
+	0,							/* U+0003F7 */
+	0,							/* U+0003F8 */
+	0,							/* U+0003F9 */
+	0,							/* U+0003FA */
+	0,							/* U+0003FB */
+	0,							/* U+0003FC */
+	0,							/* U+0003FD */
+	0,							/* U+0003FE */
+	0,							/* U+0003FF */
+	0,							/* U+000400 */
+	0,							/* U+000401 */
+	0,							/* U+000402 */
+	0,							/* U+000403 */
+	0,							/* U+000404 */
+	0,							/* U+000405 */
+	3448,						/* U+000406 */
+	0,							/* U+000407 */
+	0,							/* U+000408 */
+	0,							/* U+000409 */
+	0,							/* U+00040A */
+	0,							/* U+00040B */
+	0,							/* U+00040C */
+	0,							/* U+00040D */
+	0,							/* U+00040E */
+	0,							/* U+00040F */
+	3452,						/* U+000410 */
+	0,							/* U+000411 */
+	0,							/* U+000412 */
+	3458,						/* U+000413 */
+	0,							/* U+000414 */
+	3462,						/* U+000415 */
+	3474,						/* U+000416 */
+	3480,						/* U+000417 */
+	3484,						/* U+000418 */
+	0,							/* U+000419 */
+	3496,						/* U+00041A */
+	0,							/* U+00041B */
+	0,							/* U+00041C */
+	0,							/* U+00041D */
+	3500,						/* U+00041E */
+	0,							/* U+00041F */
+	0,							/* U+000420 */
+	0,							/* U+000421 */
+	0,							/* U+000422 */
+	3504,						/* U+000423 */
+	0,							/* U+000424 */
+	0,							/* U+000425 */
+	0,							/* U+000426 */
+	3515,						/* U+000427 */
+	0,							/* U+000428 */
+	0,							/* U+000429 */
+	0,							/* U+00042A */
+	3519,						/* U+00042B */
+	0,							/* U+00042C */
+	3523,						/* U+00042D */
+	0,							/* U+00042E */
+	0,							/* U+00042F */
+	3527,						/* U+000430 */
+	0,							/* U+000431 */
+	0,							/* U+000432 */
+	3533,						/* U+000433 */
+	0,							/* U+000434 */
+	3537,						/* U+000435 */
+	3549,						/* U+000436 */
+	3555,						/* U+000437 */
+	3559,						/* U+000438 */
+	0,							/* U+000439 */
+	3571,						/* U+00043A */
+	0,							/* U+00043B */
+	0,							/* U+00043C */
+	0,							/* U+00043D */
+	3575,						/* U+00043E */
+	0,							/* U+00043F */
+	0,							/* U+000440 */
+	0,							/* U+000441 */
+	0,							/* U+000442 */
+	3579,						/* U+000443 */
+	0,							/* U+000444 */
+	0,							/* U+000445 */
+	0,							/* U+000446 */
+	3590,						/* U+000447 */
+	0,							/* U+000448 */
+	0,							/* U+000449 */
+	0,							/* U+00044A */
+	3594,						/* U+00044B */
+	0,							/* U+00044C */
+	3598,						/* U+00044D */
+	0,							/* U+00044E */
+	0,							/* U+00044F */
+	0,							/* U+000450 */
+	0,							/* U+000451 */
+	0,							/* U+000452 */
+	0,							/* U+000453 */
+	0,							/* U+000454 */
+	0,							/* U+000455 */
+	3602,						/* U+000456 */
+	0,							/* U+000457 */
+	0,							/* U+000458 */
+	0,							/* U+000459 */
+	0,							/* U+00045A */
+	0,							/* U+00045B */
+	0,							/* U+00045C */
+	0,							/* U+00045D */
+	0,							/* U+00045E */
+	0,							/* U+00045F */
+	0,							/* U+000460 */
+	0,							/* U+000461 */
+	0,							/* U+000462 */
+	0,							/* U+000463 */
+	0,							/* U+000464 */
+	0,							/* U+000465 */
+	0,							/* U+000466 */
+	0,							/* U+000467 */
+	0,							/* U+000468 */
+	0,							/* U+000469 */
+	0,							/* U+00046A */
+	0,							/* U+00046B */
+	0,							/* U+00046C */
+	0,							/* U+00046D */
+	0,							/* U+00046E */
+	0,							/* U+00046F */
+	0,							/* U+000470 */
+	0,							/* U+000471 */
+	0,							/* U+000472 */
+	0,							/* U+000473 */
+	3606,						/* U+000474 */
+	3610,						/* U+000475 */
+	0,							/* U+000476 */
+	0,							/* U+000477 */
+	0,							/* U+000478 */
+	0,							/* U+000479 */
+	0,							/* U+00047A */
+	0,							/* U+00047B */
+	0,							/* U+00047C */
+	0,							/* U+00047D */
+	0,							/* U+00047E */
+	0,							/* U+00047F */
+	0,							/* U+000480 */
+	0,							/* U+000481 */
+	0,							/* U+000482 */
+	0,							/* U+000483 */
+	0,							/* U+000484 */
+	0,							/* U+000485 */
+	0,							/* U+000486 */
+	0,							/* U+000487 */
+	0,							/* U+000488 */
+	0,							/* U+000489 */
+	0,							/* U+00048A */
+	0,							/* U+00048B */
+	0,							/* U+00048C */
+	0,							/* U+00048D */
+	0,							/* U+00048E */
+	0,							/* U+00048F */
+	0,							/* U+000490 */
+	0,							/* U+000491 */
+	0,							/* U+000492 */
+	0,							/* U+000493 */
+	0,							/* U+000494 */
+	0,							/* U+000495 */
+	0,							/* U+000496 */
+	0,							/* U+000497 */
+	0,							/* U+000498 */
+	0,							/* U+000499 */
+	0,							/* U+00049A */
+	0,							/* U+00049B */
+	0,							/* U+00049C */
+	0,							/* U+00049D */
+	0,							/* U+00049E */
+	0,							/* U+00049F */
+	0,							/* U+0004A0 */
+	0,							/* U+0004A1 */
+	0,							/* U+0004A2 */
+	0,							/* U+0004A3 */
+	0,							/* U+0004A4 */
+	0,							/* U+0004A5 */
+	0,							/* U+0004A6 */
+	0,							/* U+0004A7 */
+	0,							/* U+0004A8 */
+	0,							/* U+0004A9 */
+	0,							/* U+0004AA */
+	0,							/* U+0004AB */
+	0,							/* U+0004AC */
+	0,							/* U+0004AD */
+	0,							/* U+0004AE */
+	0,							/* U+0004AF */
+	0,							/* U+0004B0 */
+	0,							/* U+0004B1 */
+	0,							/* U+0004B2 */
+	0,							/* U+0004B3 */
+	0,							/* U+0004B4 */
+	0,							/* U+0004B5 */
+	0,							/* U+0004B6 */
+	0,							/* U+0004B7 */
+	0,							/* U+0004B8 */
+	0,							/* U+0004B9 */
+	0,							/* U+0004BA */
+	0,							/* U+0004BB */
+	0,							/* U+0004BC */
+	0,							/* U+0004BD */
+	0,							/* U+0004BE */
+	0,							/* U+0004BF */
+	0,							/* U+0004C0 */
+	0,							/* U+0004C1 */
+	0,							/* U+0004C2 */
+	0,							/* U+0004C3 */
+	0,							/* U+0004C4 */
+	0,							/* U+0004C5 */
+	0,							/* U+0004C6 */
+	0,							/* U+0004C7 */
+	0,							/* U+0004C8 */
+	0,							/* U+0004C9 */
+	0,							/* U+0004CA */
+	0,							/* U+0004CB */
+	0,							/* U+0004CC */
+	0,							/* U+0004CD */
+	0,							/* U+0004CE */
+	0,							/* U+0004CF */
+	0,							/* U+0004D0 */
+	0,							/* U+0004D1 */
+	0,							/* U+0004D2 */
+	0,							/* U+0004D3 */
+	0,							/* U+0004D4 */
+	0,							/* U+0004D5 */
+	0,							/* U+0004D6 */
+	0,							/* U+0004D7 */
+	3614,						/* U+0004D8 */
+	3618,						/* U+0004D9 */
+	0,							/* U+0004DA */
+	0,							/* U+0004DB */
+	0,							/* U+0004DC */
+	0,							/* U+0004DD */
+	0,							/* U+0004DE */
+	0,							/* U+0004DF */
+	0,							/* U+0004E0 */
+	0,							/* U+0004E1 */
+	0,							/* U+0004E2 */
+	0,							/* U+0004E3 */
+	0,							/* U+0004E4 */
+	0,							/* U+0004E5 */
+	0,							/* U+0004E6 */
+	0,							/* U+0004E7 */
+	3622,						/* U+0004E8 */
+	3626,						/* U+0004E9 */
+	0,							/* U+0004EA */
+	0,							/* U+0004EB */
+	0,							/* U+0004EC */
+	0,							/* U+0004ED */
+	0,							/* U+0004EE */
+	0,							/* U+0004EF */
+	0,							/* U+0004F0 */
+	0,							/* U+0004F1 */
+	0,							/* U+0004F2 */
+	0,							/* U+0004F3 */
+	0,							/* U+0004F4 */
+	0,							/* U+0004F5 */
+	0,							/* U+0004F6 */
+	0,							/* U+0004F7 */
+	0,							/* U+0004F8 */
+	0,							/* U+0004F9 */
+	0,							/* U+0004FA */
+	0,							/* U+0004FB */
+	0,							/* U+0004FC */
+	0,							/* U+0004FD */
+	0,							/* U+0004FE */
+	0,							/* U+0004FF */
+	0,							/* U+000500 */
+	0,							/* U+000501 */
+	0,							/* U+000502 */
+	0,							/* U+000503 */
+	0,							/* U+000504 */
+	0,							/* U+000505 */
+	0,							/* U+000506 */
+	0,							/* U+000507 */
+	0,							/* U+000508 */
+	0,							/* U+000509 */
+	0,							/* U+00050A */
+	0,							/* U+00050B */
+	0,							/* U+00050C */
+	0,							/* U+00050D */
+	0,							/* U+00050E */
+	0,							/* U+00050F */
+	0,							/* U+000510 */
+	0,							/* U+000511 */
+	0,							/* U+000512 */
+	0,							/* U+000513 */
+	0,							/* U+000514 */
+	0,							/* U+000515 */
+	0,							/* U+000516 */
+	0,							/* U+000517 */
+	0,							/* U+000518 */
+	0,							/* U+000519 */
+	0,							/* U+00051A */
+	0,							/* U+00051B */
+	0,							/* U+00051C */
+	0,							/* U+00051D */
+	0,							/* U+00051E */
+	0,							/* U+00051F */
+	0,							/* U+000520 */
+	0,							/* U+000521 */
+	0,							/* U+000522 */
+	0,							/* U+000523 */
+	0,							/* U+000524 */
+	0,							/* U+000525 */
+	0,							/* U+000526 */
+	0,							/* U+000527 */
+	0,							/* U+000528 */
+	0,							/* U+000529 */
+	0,							/* U+00052A */
+	0,							/* U+00052B */
+	0,							/* U+00052C */
+	0,							/* U+00052D */
+	0,							/* U+00052E */
+	0,							/* U+00052F */
+	0,							/* U+000530 */
+	0,							/* U+000531 */
+	0,							/* U+000532 */
+	0,							/* U+000533 */
+	0,							/* U+000534 */
+	0,							/* U+000535 */
+	0,							/* U+000536 */
+	0,							/* U+000537 */
+	0,							/* U+000538 */
+	0,							/* U+000539 */
+	0,							/* U+00053A */
+	0,							/* U+00053B */
+	0,							/* U+00053C */
+	0,							/* U+00053D */
+	0,							/* U+00053E */
+	0,							/* U+00053F */
+	0,							/* U+000540 */
+	0,							/* U+000541 */
+	0,							/* U+000542 */
+	0,							/* U+000543 */
+	0,							/* U+000544 */
+	0,							/* U+000545 */
+	0,							/* U+000546 */
+	0,							/* U+000547 */
+	0,							/* U+000548 */
+	0,							/* U+000549 */
+	0,							/* U+00054A */
+	0,							/* U+00054B */
+	0,							/* U+00054C */
+	0,							/* U+00054D */
+	0,							/* U+00054E */
+	0,							/* U+00054F */
+	0,							/* U+000550 */
+	0,							/* U+000551 */
+	0,							/* U+000552 */
+	0,							/* U+000553 */
+	0,							/* U+000554 */
+	0,							/* U+000555 */
+	0,							/* U+000556 */
+	0,							/* U+000557 */
+	0,							/* U+000558 */
+	0,							/* U+000559 */
+	0,							/* U+00055A */
+	0,							/* U+00055B */
+	0,							/* U+00055C */
+	0,							/* U+00055D */
+	0,							/* U+00055E */
+	0,							/* U+00055F */
+	0,							/* U+000560 */
+	0,							/* U+000561 */
+	0,							/* U+000562 */
+	0,							/* U+000563 */
+	0,							/* U+000564 */
+	0,							/* U+000565 */
+	0,							/* U+000566 */
+	0,							/* U+000567 */
+	0,							/* U+000568 */
+	0,							/* U+000569 */
+	0,							/* U+00056A */
+	0,							/* U+00056B */
+	0,							/* U+00056C */
+	0,							/* U+00056D */
+	0,							/* U+00056E */
+	0,							/* U+00056F */
+	0,							/* U+000570 */
+	0,							/* U+000571 */
+	0,							/* U+000572 */
+	0,							/* U+000573 */
+	0,							/* U+000574 */
+	0,							/* U+000575 */
+	0,							/* U+000576 */
+	0,							/* U+000577 */
+	0,							/* U+000578 */
+	0,							/* U+000579 */
+	0,							/* U+00057A */
+	0,							/* U+00057B */
+	0,							/* U+00057C */
+	0,							/* U+00057D */
+	0,							/* U+00057E */
+	0,							/* U+00057F */
+	0,							/* U+000580 */
+	0,							/* U+000581 */
+	0,							/* U+000582 */
+	0,							/* U+000583 */
+	0,							/* U+000584 */
+	0,							/* U+000585 */
+	0,							/* U+000586 */
+	0,							/* U+000587 */
+	0,							/* U+000588 */
+	0,							/* U+000589 */
+	0,							/* U+00058A */
+	0,							/* U+00058B */
+	0,							/* U+00058C */
+	0,							/* U+00058D */
+	0,							/* U+00058E */
+	0,							/* U+00058F */
+	0,							/* U+000590 */
+	0,							/* U+000591 */
+	0,							/* U+000592 */
+	0,							/* U+000593 */
+	0,							/* U+000594 */
+	0,							/* U+000595 */
+	0,							/* U+000596 */
+	0,							/* U+000597 */
+	0,							/* U+000598 */
+	0,							/* U+000599 */
+	0,							/* U+00059A */
+	0,							/* U+00059B */
+	0,							/* U+00059C */
+	0,							/* U+00059D */
+	0,							/* U+00059E */
+	0,							/* U+00059F */
+	0,							/* U+0005A0 */
+	0,							/* U+0005A1 */
+	0,							/* U+0005A2 */
+	0,							/* U+0005A3 */
+	0,							/* U+0005A4 */
+	0,							/* U+0005A5 */
+	0,							/* U+0005A6 */
+	0,							/* U+0005A7 */
+	0,							/* U+0005A8 */
+	0,							/* U+0005A9 */
+	0,							/* U+0005AA */
+	0,							/* U+0005AB */
+	0,							/* U+0005AC */
+	0,							/* U+0005AD */
+	0,							/* U+0005AE */
+	0,							/* U+0005AF */
+	0,							/* U+0005B0 */
+	0,							/* U+0005B1 */
+	0,							/* U+0005B2 */
+	0,							/* U+0005B3 */
+	0,							/* U+0005B4 */
+	0,							/* U+0005B5 */
+	0,							/* U+0005B6 */
+	0,							/* U+0005B7 */
+	0,							/* U+0005B8 */
+	0,							/* U+0005B9 */
+	0,							/* U+0005BA */
+	0,							/* U+0005BB */
+	0,							/* U+0005BC */
+	0,							/* U+0005BD */
+	0,							/* U+0005BE */
+	0,							/* U+0005BF */
+	0,							/* U+0005C0 */
+	0,							/* U+0005C1 */
+	0,							/* U+0005C2 */
+	0,							/* U+0005C3 */
+	0,							/* U+0005C4 */
+	0,							/* U+0005C5 */
+	0,							/* U+0005C6 */
+	0,							/* U+0005C7 */
+	0,							/* U+0005C8 */
+	0,							/* U+0005C9 */
+	0,							/* U+0005CA */
+	0,							/* U+0005CB */
+	0,							/* U+0005CC */
+	0,							/* U+0005CD */
+	0,							/* U+0005CE */
+	0,							/* U+0005CF */
+	0,							/* U+0005D0 */
+	0,							/* U+0005D1 */
+	0,							/* U+0005D2 */
+	0,							/* U+0005D3 */
+	0,							/* U+0005D4 */
+	0,							/* U+0005D5 */
+	0,							/* U+0005D6 */
+	0,							/* U+0005D7 */
+	0,							/* U+0005D8 */
+	0,							/* U+0005D9 */
+	0,							/* U+0005DA */
+	0,							/* U+0005DB */
+	0,							/* U+0005DC */
+	0,							/* U+0005DD */
+	0,							/* U+0005DE */
+	0,							/* U+0005DF */
+	0,							/* U+0005E0 */
+	0,							/* U+0005E1 */
+	0,							/* U+0005E2 */
+	0,							/* U+0005E3 */
+	0,							/* U+0005E4 */
+	0,							/* U+0005E5 */
+	0,							/* U+0005E6 */
+	0,							/* U+0005E7 */
+	0,							/* U+0005E8 */
+	0,							/* U+0005E9 */
+	0,							/* U+0005EA */
+	0,							/* U+0005EB */
+	0,							/* U+0005EC */
+	0,							/* U+0005ED */
+	0,							/* U+0005EE */
+	0,							/* U+0005EF */
+	0,							/* U+0005F0 */
+	0,							/* U+0005F1 */
+	0,							/* U+0005F2 */
+	0,							/* U+0005F3 */
+	0,							/* U+0005F4 */
+	0,							/* U+0005F5 */
+	0,							/* U+0005F6 */
+	0,							/* U+0005F7 */
+	0,							/* U+0005F8 */
+	0,							/* U+0005F9 */
+	0,							/* U+0005FA */
+	0,							/* U+0005FB */
+	0,							/* U+0005FC */
+	0,							/* U+0005FD */
+	0,							/* U+0005FE */
+	0,							/* U+0005FF */
+	0,							/* U+000600 */
+	0,							/* U+000601 */
+	0,							/* U+000602 */
+	0,							/* U+000603 */
+	0,							/* U+000604 */
+	0,							/* U+000605 */
+	0,							/* U+000606 */
+	0,							/* U+000607 */
+	0,							/* U+000608 */
+	0,							/* U+000609 */
+	0,							/* U+00060A */
+	0,							/* U+00060B */
+	0,							/* U+00060C */
+	0,							/* U+00060D */
+	0,							/* U+00060E */
+	0,							/* U+00060F */
+	0,							/* U+000610 */
+	0,							/* U+000611 */
+	0,							/* U+000612 */
+	0,							/* U+000613 */
+	0,							/* U+000614 */
+	0,							/* U+000615 */
+	0,							/* U+000616 */
+	0,							/* U+000617 */
+	0,							/* U+000618 */
+	0,							/* U+000619 */
+	0,							/* U+00061A */
+	0,							/* U+00061B */
+	0,							/* U+00061C */
+	0,							/* U+00061D */
+	0,							/* U+00061E */
+	0,							/* U+00061F */
+	0,							/* U+000620 */
+	0,							/* U+000621 */
+	0,							/* U+000622 */
+	0,							/* U+000623 */
+	0,							/* U+000624 */
+	0,							/* U+000625 */
+	0,							/* U+000626 */
+	3630,						/* U+000627 */
+	0,							/* U+000628 */
+	0,							/* U+000629 */
+	0,							/* U+00062A */
+	0,							/* U+00062B */
+	0,							/* U+00062C */
+	0,							/* U+00062D */
+	0,							/* U+00062E */
+	0,							/* U+00062F */
+	0,							/* U+000630 */
+	0,							/* U+000631 */
+	0,							/* U+000632 */
+	0,							/* U+000633 */
+	0,							/* U+000634 */
+	0,							/* U+000635 */
+	0,							/* U+000636 */
+	0,							/* U+000637 */
+	0,							/* U+000638 */
+	0,							/* U+000639 */
+	0,							/* U+00063A */
+	0,							/* U+00063B */
+	0,							/* U+00063C */
+	0,							/* U+00063D */
+	0,							/* U+00063E */
+	0,							/* U+00063F */
+	0,							/* U+000640 */
+	0,							/* U+000641 */
+	0,							/* U+000642 */
+	0,							/* U+000643 */
+	0,							/* U+000644 */
+	0,							/* U+000645 */
+	0,							/* U+000646 */
+	0,							/* U+000647 */
+	3636,						/* U+000648 */
+	0,							/* U+000649 */
+	3640,						/* U+00064A */
+	0,							/* U+00064B */
+	0,							/* U+00064C */
+	0,							/* U+00064D */
+	0,							/* U+00064E */
+	0,							/* U+00064F */
+	0,							/* U+000650 */
+	0,							/* U+000651 */
+	0,							/* U+000652 */
+	0,							/* U+000653 */
+	0,							/* U+000654 */
+	0,							/* U+000655 */
+	0,							/* U+000656 */
+	0,							/* U+000657 */
+	0,							/* U+000658 */
+	0,							/* U+000659 */
+	0,							/* U+00065A */
+	0,							/* U+00065B */
+	0,							/* U+00065C */
+	0,							/* U+00065D */
+	0,							/* U+00065E */
+	0,							/* U+00065F */
+	0,							/* U+000660 */
+	0,							/* U+000661 */
+	0,							/* U+000662 */
+	0,							/* U+000663 */
+	0,							/* U+000664 */
+	0,							/* U+000665 */
+	0,							/* U+000666 */
+	0,							/* U+000667 */
+	0,							/* U+000668 */
+	0,							/* U+000669 */
+	0,							/* U+00066A */
+	0,							/* U+00066B */
+	0,							/* U+00066C */
+	0,							/* U+00066D */
+	0,							/* U+00066E */
+	0,							/* U+00066F */
+	0,							/* U+000670 */
+	0,							/* U+000671 */
+	0,							/* U+000672 */
+	0,							/* U+000673 */
+	0,							/* U+000674 */
+	0,							/* U+000675 */
+	0,							/* U+000676 */
+	0,							/* U+000677 */
+	0,							/* U+000678 */
+	0,							/* U+000679 */
+	0,							/* U+00067A */
+	0,							/* U+00067B */
+	0,							/* U+00067C */
+	0,							/* U+00067D */
+	0,							/* U+00067E */
+	0,							/* U+00067F */
+	0,							/* U+000680 */
+	0,							/* U+000681 */
+	0,							/* U+000682 */
+	0,							/* U+000683 */
+	0,							/* U+000684 */
+	0,							/* U+000685 */
+	0,							/* U+000686 */
+	0,							/* U+000687 */
+	0,							/* U+000688 */
+	0,							/* U+000689 */
+	0,							/* U+00068A */
+	0,							/* U+00068B */
+	0,							/* U+00068C */
+	0,							/* U+00068D */
+	0,							/* U+00068E */
+	0,							/* U+00068F */
+	0,							/* U+000690 */
+	0,							/* U+000691 */
+	0,							/* U+000692 */
+	0,							/* U+000693 */
+	0,							/* U+000694 */
+	0,							/* U+000695 */
+	0,							/* U+000696 */
+	0,							/* U+000697 */
+	0,							/* U+000698 */
+	0,							/* U+000699 */
+	0,							/* U+00069A */
+	0,							/* U+00069B */
+	0,							/* U+00069C */
+	0,							/* U+00069D */
+	0,							/* U+00069E */
+	0,							/* U+00069F */
+	0,							/* U+0006A0 */
+	0,							/* U+0006A1 */
+	0,							/* U+0006A2 */
+	0,							/* U+0006A3 */
+	0,							/* U+0006A4 */
+	0,							/* U+0006A5 */
+	0,							/* U+0006A6 */
+	0,							/* U+0006A7 */
+	0,							/* U+0006A8 */
+	0,							/* U+0006A9 */
+	0,							/* U+0006AA */
+	0,							/* U+0006AB */
+	0,							/* U+0006AC */
+	0,							/* U+0006AD */
+	0,							/* U+0006AE */
+	0,							/* U+0006AF */
+	0,							/* U+0006B0 */
+	0,							/* U+0006B1 */
+	0,							/* U+0006B2 */
+	0,							/* U+0006B3 */
+	0,							/* U+0006B4 */
+	0,							/* U+0006B5 */
+	0,							/* U+0006B6 */
+	0,							/* U+0006B7 */
+	0,							/* U+0006B8 */
+	0,							/* U+0006B9 */
+	0,							/* U+0006BA */
+	0,							/* U+0006BB */
+	0,							/* U+0006BC */
+	0,							/* U+0006BD */
+	0,							/* U+0006BE */
+	0,							/* U+0006BF */
+	0,							/* U+0006C0 */
+	3644,						/* U+0006C1 */
+	0,							/* U+0006C2 */
+	0,							/* U+0006C3 */
+	0,							/* U+0006C4 */
+	0,							/* U+0006C5 */
+	0,							/* U+0006C6 */
+	0,							/* U+0006C7 */
+	0,							/* U+0006C8 */
+	0,							/* U+0006C9 */
+	0,							/* U+0006CA */
+	0,							/* U+0006CB */
+	0,							/* U+0006CC */
+	0,							/* U+0006CD */
+	0,							/* U+0006CE */
+	0,							/* U+0006CF */
+	0,							/* U+0006D0 */
+	0,							/* U+0006D1 */
+	3648,						/* U+0006D2 */
+	0,							/* U+0006D3 */
+	0,							/* U+0006D4 */
+	3652,						/* U+0006D5 */
+	0,							/* U+0006D6 */
+	0,							/* U+0006D7 */
+	0,							/* U+0006D8 */
+	0,							/* U+0006D9 */
+	0,							/* U+0006DA */
+	0,							/* U+0006DB */
+	0,							/* U+0006DC */
+	0,							/* U+0006DD */
+	0,							/* U+0006DE */
+	0,							/* U+0006DF */
+	0,							/* U+0006E0 */
+	0,							/* U+0006E1 */
+	0,							/* U+0006E2 */
+	0,							/* U+0006E3 */
+	0,							/* U+0006E4 */
+	0,							/* U+0006E5 */
+	0,							/* U+0006E6 */
+	0,							/* U+0006E7 */
+	0,							/* U+0006E8 */
+	0,							/* U+0006E9 */
+	0,							/* U+0006EA */
+	0,							/* U+0006EB */
+	0,							/* U+0006EC */
+	0,							/* U+0006ED */
+	0,							/* U+0006EE */
+	0,							/* U+0006EF */
+	0,							/* U+0006F0 */
+	0,							/* U+0006F1 */
+	0,							/* U+0006F2 */
+	0,							/* U+0006F3 */
+	0,							/* U+0006F4 */
+	0,							/* U+0006F5 */
+	0,							/* U+0006F6 */
+	0,							/* U+0006F7 */
+	0,							/* U+0006F8 */
+	0,							/* U+0006F9 */
+	0,							/* U+0006FA */
+	0,							/* U+0006FB */
+	0,							/* U+0006FC */
+	0,							/* U+0006FD */
+	0,							/* U+0006FE */
+	0,							/* U+0006FF */
+	0,							/* U+000700 */
+	0,							/* U+000701 */
+	0,							/* U+000702 */
+	0,							/* U+000703 */
+	0,							/* U+000704 */
+	0,							/* U+000705 */
+	0,							/* U+000706 */
+	0,							/* U+000707 */
+	0,							/* U+000708 */
+	0,							/* U+000709 */
+	0,							/* U+00070A */
+	0,							/* U+00070B */
+	0,							/* U+00070C */
+	0,							/* U+00070D */
+	0,							/* U+00070E */
+	0,							/* U+00070F */
+	0,							/* U+000710 */
+	0,							/* U+000711 */
+	0,							/* U+000712 */
+	0,							/* U+000713 */
+	0,							/* U+000714 */
+	0,							/* U+000715 */
+	0,							/* U+000716 */
+	0,							/* U+000717 */
+	0,							/* U+000718 */
+	0,							/* U+000719 */
+	0,							/* U+00071A */
+	0,							/* U+00071B */
+	0,							/* U+00071C */
+	0,							/* U+00071D */
+	0,							/* U+00071E */
+	0,							/* U+00071F */
+	0,							/* U+000720 */
+	0,							/* U+000721 */
+	0,							/* U+000722 */
+	0,							/* U+000723 */
+	0,							/* U+000724 */
+	0,							/* U+000725 */
+	0,							/* U+000726 */
+	0,							/* U+000727 */
+	0,							/* U+000728 */
+	0,							/* U+000729 */
+	0,							/* U+00072A */
+	0,							/* U+00072B */
+	0,							/* U+00072C */
+	0,							/* U+00072D */
+	0,							/* U+00072E */
+	0,							/* U+00072F */
+	0,							/* U+000730 */
+	0,							/* U+000731 */
+	0,							/* U+000732 */
+	0,							/* U+000733 */
+	0,							/* U+000734 */
+	0,							/* U+000735 */
+	0,							/* U+000736 */
+	0,							/* U+000737 */
+	0,							/* U+000738 */
+	0,							/* U+000739 */
+	0,							/* U+00073A */
+	0,							/* U+00073B */
+	0,							/* U+00073C */
+	0,							/* U+00073D */
+	0,							/* U+00073E */
+	0,							/* U+00073F */
+	0,							/* U+000740 */
+	0,							/* U+000741 */
+	0,							/* U+000742 */
+	0,							/* U+000743 */
+	0,							/* U+000744 */
+	0,							/* U+000745 */
+	0,							/* U+000746 */
+	0,							/* U+000747 */
+	0,							/* U+000748 */
+	0,							/* U+000749 */
+	0,							/* U+00074A */
+	0,							/* U+00074B */
+	0,							/* U+00074C */
+	0,							/* U+00074D */
+	0,							/* U+00074E */
+	0,							/* U+00074F */
+	0,							/* U+000750 */
+	0,							/* U+000751 */
+	0,							/* U+000752 */
+	0,							/* U+000753 */
+	0,							/* U+000754 */
+	0,							/* U+000755 */
+	0,							/* U+000756 */
+	0,							/* U+000757 */
+	0,							/* U+000758 */
+	0,							/* U+000759 */
+	0,							/* U+00075A */
+	0,							/* U+00075B */
+	0,							/* U+00075C */
+	0,							/* U+00075D */
+	0,							/* U+00075E */
+	0,							/* U+00075F */
+	0,							/* U+000760 */
+	0,							/* U+000761 */
+	0,							/* U+000762 */
+	0,							/* U+000763 */
+	0,							/* U+000764 */
+	0,							/* U+000765 */
+	0,							/* U+000766 */
+	0,							/* U+000767 */
+	0,							/* U+000768 */
+	0,							/* U+000769 */
+	0,							/* U+00076A */
+	0,							/* U+00076B */
+	0,							/* U+00076C */
+	0,							/* U+00076D */
+	0,							/* U+00076E */
+	0,							/* U+00076F */
+	0,							/* U+000770 */
+	0,							/* U+000771 */
+	0,							/* U+000772 */
+	0,							/* U+000773 */
+	0,							/* U+000774 */
+	0,							/* U+000775 */
+	0,							/* U+000776 */
+	0,							/* U+000777 */
+	0,							/* U+000778 */
+	0,							/* U+000779 */
+	0,							/* U+00077A */
+	0,							/* U+00077B */
+	0,							/* U+00077C */
+	0,							/* U+00077D */
+	0,							/* U+00077E */
+	0,							/* U+00077F */
+	0,							/* U+000780 */
+	0,							/* U+000781 */
+	0,							/* U+000782 */
+	0,							/* U+000783 */
+	0,							/* U+000784 */
+	0,							/* U+000785 */
+	0,							/* U+000786 */
+	0,							/* U+000787 */
+	0,							/* U+000788 */
+	0,							/* U+000789 */
+	0,							/* U+00078A */
+	0,							/* U+00078B */
+	0,							/* U+00078C */
+	0,							/* U+00078D */
+	0,							/* U+00078E */
+	0,							/* U+00078F */
+	0,							/* U+000790 */
+	0,							/* U+000791 */
+	0,							/* U+000792 */
+	0,							/* U+000793 */
+	0,							/* U+000794 */
+	0,							/* U+000795 */
+	0,							/* U+000796 */
+	0,							/* U+000797 */
+	0,							/* U+000798 */
+	0,							/* U+000799 */
+	0,							/* U+00079A */
+	0,							/* U+00079B */
+	0,							/* U+00079C */
+	0,							/* U+00079D */
+	0,							/* U+00079E */
+	0,							/* U+00079F */
+	0,							/* U+0007A0 */
+	0,							/* U+0007A1 */
+	0,							/* U+0007A2 */
+	0,							/* U+0007A3 */
+	0,							/* U+0007A4 */
+	0,							/* U+0007A5 */
+	0,							/* U+0007A6 */
+	0,							/* U+0007A7 */
+	0,							/* U+0007A8 */
+	0,							/* U+0007A9 */
+	0,							/* U+0007AA */
+	0,							/* U+0007AB */
+	0,							/* U+0007AC */
+	0,							/* U+0007AD */
+	0,							/* U+0007AE */
+	0,							/* U+0007AF */
+	0,							/* U+0007B0 */
+	0,							/* U+0007B1 */
+	0,							/* U+0007B2 */
+	0,							/* U+0007B3 */
+	0,							/* U+0007B4 */
+	0,							/* U+0007B5 */
+	0,							/* U+0007B6 */
+	0,							/* U+0007B7 */
+	0,							/* U+0007B8 */
+	0,							/* U+0007B9 */
+	0,							/* U+0007BA */
+	0,							/* U+0007BB */
+	0,							/* U+0007BC */
+	0,							/* U+0007BD */
+	0,							/* U+0007BE */
+	0,							/* U+0007BF */
+	0,							/* U+0007C0 */
+	0,							/* U+0007C1 */
+	0,							/* U+0007C2 */
+	0,							/* U+0007C3 */
+	0,							/* U+0007C4 */
+	0,							/* U+0007C5 */
+	0,							/* U+0007C6 */
+	0,							/* U+0007C7 */
+	0,							/* U+0007C8 */
+	0,							/* U+0007C9 */
+	0,							/* U+0007CA */
+	0,							/* U+0007CB */
+	0,							/* U+0007CC */
+	0,							/* U+0007CD */
+	0,							/* U+0007CE */
+	0,							/* U+0007CF */
+	0,							/* U+0007D0 */
+	0,							/* U+0007D1 */
+	0,							/* U+0007D2 */
+	0,							/* U+0007D3 */
+	0,							/* U+0007D4 */
+	0,							/* U+0007D5 */
+	0,							/* U+0007D6 */
+	0,							/* U+0007D7 */
+	0,							/* U+0007D8 */
+	0,							/* U+0007D9 */
+	0,							/* U+0007DA */
+	0,							/* U+0007DB */
+	0,							/* U+0007DC */
+	0,							/* U+0007DD */
+	0,							/* U+0007DE */
+	0,							/* U+0007DF */
+	0,							/* U+0007E0 */
+	0,							/* U+0007E1 */
+	0,							/* U+0007E2 */
+	0,							/* U+0007E3 */
+	0,							/* U+0007E4 */
+	0,							/* U+0007E5 */
+	0,							/* U+0007E6 */
+	0,							/* U+0007E7 */
+	0,							/* U+0007E8 */
+	0,							/* U+0007E9 */
+	0,							/* U+0007EA */
+	0,							/* U+0007EB */
+	0,							/* U+0007EC */
+	0,							/* U+0007ED */
+	0,							/* U+0007EE */
+	0,							/* U+0007EF */
+	0,							/* U+0007F0 */
+	0,							/* U+0007F1 */
+	0,							/* U+0007F2 */
+	0,							/* U+0007F3 */
+	0,							/* U+0007F4 */
+	0,							/* U+0007F5 */
+	0,							/* U+0007F6 */
+	0,							/* U+0007F7 */
+	0,							/* U+0007F8 */
+	0,							/* U+0007F9 */
+	0,							/* U+0007FA */
+	0,							/* U+0007FB */
+	0,							/* U+0007FC */
+	0,							/* U+0007FD */
+	0,							/* U+0007FE */
+	0,							/* U+0007FF */
+	0,							/* U+000800 */
+	0,							/* U+000801 */
+	0,							/* U+000802 */
+	0,							/* U+000803 */
+	0,							/* U+000804 */
+	0,							/* U+000805 */
+	0,							/* U+000806 */
+	0,							/* U+000807 */
+	0,							/* U+000808 */
+	0,							/* U+000809 */
+	0,							/* U+00080A */
+	0,							/* U+00080B */
+	0,							/* U+00080C */
+	0,							/* U+00080D */
+	0,							/* U+00080E */
+	0,							/* U+00080F */
+	0,							/* U+000810 */
+	0,							/* U+000811 */
+	0,							/* U+000812 */
+	0,							/* U+000813 */
+	0,							/* U+000814 */
+	0,							/* U+000815 */
+	0,							/* U+000816 */
+	0,							/* U+000817 */
+	0,							/* U+000818 */
+	0,							/* U+000819 */
+	0,							/* U+00081A */
+	0,							/* U+00081B */
+	0,							/* U+00081C */
+	0,							/* U+00081D */
+	0,							/* U+00081E */
+	0,							/* U+00081F */
+	0,							/* U+000820 */
+	0,							/* U+000821 */
+	0,							/* U+000822 */
+	0,							/* U+000823 */
+	0,							/* U+000824 */
+	0,							/* U+000825 */
+	0,							/* U+000826 */
+	0,							/* U+000827 */
+	0,							/* U+000828 */
+	0,							/* U+000829 */
+	0,							/* U+00082A */
+	0,							/* U+00082B */
+	0,							/* U+00082C */
+	0,							/* U+00082D */
+	0,							/* U+00082E */
+	0,							/* U+00082F */
+	0,							/* U+000830 */
+	0,							/* U+000831 */
+	0,							/* U+000832 */
+	0,							/* U+000833 */
+	0,							/* U+000834 */
+	0,							/* U+000835 */
+	0,							/* U+000836 */
+	0,							/* U+000837 */
+	0,							/* U+000838 */
+	0,							/* U+000839 */
+	0,							/* U+00083A */
+	0,							/* U+00083B */
+	0,							/* U+00083C */
+	0,							/* U+00083D */
+	0,							/* U+00083E */
+	0,							/* U+00083F */
+	0,							/* U+000840 */
+	0,							/* U+000841 */
+	0,							/* U+000842 */
+	0,							/* U+000843 */
+	0,							/* U+000844 */
+	0,							/* U+000845 */
+	0,							/* U+000846 */
+	0,							/* U+000847 */
+	0,							/* U+000848 */
+	0,							/* U+000849 */
+	0,							/* U+00084A */
+	0,							/* U+00084B */
+	0,							/* U+00084C */
+	0,							/* U+00084D */
+	0,							/* U+00084E */
+	0,							/* U+00084F */
+	0,							/* U+000850 */
+	0,							/* U+000851 */
+	0,							/* U+000852 */
+	0,							/* U+000853 */
+	0,							/* U+000854 */
+	0,							/* U+000855 */
+	0,							/* U+000856 */
+	0,							/* U+000857 */
+	0,							/* U+000858 */
+	0,							/* U+000859 */
+	0,							/* U+00085A */
+	0,							/* U+00085B */
+	0,							/* U+00085C */
+	0,							/* U+00085D */
+	0,							/* U+00085E */
+	0,							/* U+00085F */
+	0,							/* U+000860 */
+	0,							/* U+000861 */
+	0,							/* U+000862 */
+	0,							/* U+000863 */
+	0,							/* U+000864 */
+	0,							/* U+000865 */
+	0,							/* U+000866 */
+	0,							/* U+000867 */
+	0,							/* U+000868 */
+	0,							/* U+000869 */
+	0,							/* U+00086A */
+	0,							/* U+00086B */
+	0,							/* U+00086C */
+	0,							/* U+00086D */
+	0,							/* U+00086E */
+	0,							/* U+00086F */
+	0,							/* U+000870 */
+	0,							/* U+000871 */
+	0,							/* U+000872 */
+	0,							/* U+000873 */
+	0,							/* U+000874 */
+	0,							/* U+000875 */
+	0,							/* U+000876 */
+	0,							/* U+000877 */
+	0,							/* U+000878 */
+	0,							/* U+000879 */
+	0,							/* U+00087A */
+	0,							/* U+00087B */
+	0,							/* U+00087C */
+	0,							/* U+00087D */
+	0,							/* U+00087E */
+	0,							/* U+00087F */
+	0,							/* U+000880 */
+	0,							/* U+000881 */
+	0,							/* U+000882 */
+	0,							/* U+000883 */
+	0,							/* U+000884 */
+	0,							/* U+000885 */
+	0,							/* U+000886 */
+	0,							/* U+000887 */
+	0,							/* U+000888 */
+	0,							/* U+000889 */
+	0,							/* U+00088A */
+	0,							/* U+00088B */
+	0,							/* U+00088C */
+	0,							/* U+00088D */
+	0,							/* U+00088E */
+	0,							/* U+00088F */
+	0,							/* U+000890 */
+	0,							/* U+000891 */
+	0,							/* U+000892 */
+	0,							/* U+000893 */
+	0,							/* U+000894 */
+	0,							/* U+000895 */
+	0,							/* U+000896 */
+	0,							/* U+000897 */
+	0,							/* U+000898 */
+	0,							/* U+000899 */
+	0,							/* U+00089A */
+	0,							/* U+00089B */
+	0,							/* U+00089C */
+	0,							/* U+00089D */
+	0,							/* U+00089E */
+	0,							/* U+00089F */
+	0,							/* U+0008A0 */
+	0,							/* U+0008A1 */
+	0,							/* U+0008A2 */
+	0,							/* U+0008A3 */
+	0,							/* U+0008A4 */
+	0,							/* U+0008A5 */
+	0,							/* U+0008A6 */
+	0,							/* U+0008A7 */
+	0,							/* U+0008A8 */
+	0,							/* U+0008A9 */
+	0,							/* U+0008AA */
+	0,							/* U+0008AB */
+	0,							/* U+0008AC */
+	0,							/* U+0008AD */
+	0,							/* U+0008AE */
+	0,							/* U+0008AF */
+	0,							/* U+0008B0 */
+	0,							/* U+0008B1 */
+	0,							/* U+0008B2 */
+	0,							/* U+0008B3 */
+	0,							/* U+0008B4 */
+	0,							/* U+0008B5 */
+	0,							/* U+0008B6 */
+	0,							/* U+0008B7 */
+	0,							/* U+0008B8 */
+	0,							/* U+0008B9 */
+	0,							/* U+0008BA */
+	0,							/* U+0008BB */
+	0,							/* U+0008BC */
+	0,							/* U+0008BD */
+	0,							/* U+0008BE */
+	0,							/* U+0008BF */
+	0,							/* U+0008C0 */
+	0,							/* U+0008C1 */
+	0,							/* U+0008C2 */
+	0,							/* U+0008C3 */
+	0,							/* U+0008C4 */
+	0,							/* U+0008C5 */
+	0,							/* U+0008C6 */
+	0,							/* U+0008C7 */
+	0,							/* U+0008C8 */
+	0,							/* U+0008C9 */
+	0,							/* U+0008CA */
+	0,							/* U+0008CB */
+	0,							/* U+0008CC */
+	0,							/* U+0008CD */
+	0,							/* U+0008CE */
+	0,							/* U+0008CF */
+	0,							/* U+0008D0 */
+	0,							/* U+0008D1 */
+	0,							/* U+0008D2 */
+	0,							/* U+0008D3 */
+	0,							/* U+0008D4 */
+	0,							/* U+0008D5 */
+	0,							/* U+0008D6 */
+	0,							/* U+0008D7 */
+	0,							/* U+0008D8 */
+	0,							/* U+0008D9 */
+	0,							/* U+0008DA */
+	0,							/* U+0008DB */
+	0,							/* U+0008DC */
+	0,							/* U+0008DD */
+	0,							/* U+0008DE */
+	0,							/* U+0008DF */
+	0,							/* U+0008E0 */
+	0,							/* U+0008E1 */
+	0,							/* U+0008E2 */
+	0,							/* U+0008E3 */
+	0,							/* U+0008E4 */
+	0,							/* U+0008E5 */
+	0,							/* U+0008E6 */
+	0,							/* U+0008E7 */
+	0,							/* U+0008E8 */
+	0,							/* U+0008E9 */
+	0,							/* U+0008EA */
+	0,							/* U+0008EB */
+	0,							/* U+0008EC */
+	0,							/* U+0008ED */
+	0,							/* U+0008EE */
+	0,							/* U+0008EF */
+	0,							/* U+0008F0 */
+	0,							/* U+0008F1 */
+	0,							/* U+0008F2 */
+	0,							/* U+0008F3 */
+	0,							/* U+0008F4 */
+	0,							/* U+0008F5 */
+	0,							/* U+0008F6 */
+	0,							/* U+0008F7 */
+	0,							/* U+0008F8 */
+	0,							/* U+0008F9 */
+	0,							/* U+0008FA */
+	0,							/* U+0008FB */
+	0,							/* U+0008FC */
+	0,							/* U+0008FD */
+	0,							/* U+0008FE */
+	0,							/* U+0008FF */
+	0,							/* U+000900 */
+	0,							/* U+000901 */
+	0,							/* U+000902 */
+	0,							/* U+000903 */
+	0,							/* U+000904 */
+	0,							/* U+000905 */
+	0,							/* U+000906 */
+	0,							/* U+000907 */
+	0,							/* U+000908 */
+	0,							/* U+000909 */
+	0,							/* U+00090A */
+	0,							/* U+00090B */
+	0,							/* U+00090C */
+	0,							/* U+00090D */
+	0,							/* U+00090E */
+	0,							/* U+00090F */
+	0,							/* U+000910 */
+	0,							/* U+000911 */
+	0,							/* U+000912 */
+	0,							/* U+000913 */
+	0,							/* U+000914 */
+	0,							/* U+000915 */
+	0,							/* U+000916 */
+	0,							/* U+000917 */
+	0,							/* U+000918 */
+	0,							/* U+000919 */
+	0,							/* U+00091A */
+	0,							/* U+00091B */
+	0,							/* U+00091C */
+	0,							/* U+00091D */
+	0,							/* U+00091E */
+	0,							/* U+00091F */
+	0,							/* U+000920 */
+	0,							/* U+000921 */
+	0,							/* U+000922 */
+	0,							/* U+000923 */
+	0,							/* U+000924 */
+	0,							/* U+000925 */
+	0,							/* U+000926 */
+	0,							/* U+000927 */
+	3656,						/* U+000928 */
+	0,							/* U+000929 */
+	0,							/* U+00092A */
+	0,							/* U+00092B */
+	0,							/* U+00092C */
+	0,							/* U+00092D */
+	0,							/* U+00092E */
+	0,							/* U+00092F */
+	3660,						/* U+000930 */
+	0,							/* U+000931 */
+	0,							/* U+000932 */
+	3664,						/* U+000933 */
+	0,							/* U+000934 */
+	0,							/* U+000935 */
+	0,							/* U+000936 */
+	0,							/* U+000937 */
+	0,							/* U+000938 */
+	0,							/* U+000939 */
+	0,							/* U+00093A */
+	0,							/* U+00093B */
+	0,							/* U+00093C */
+	0,							/* U+00093D */
+	0,							/* U+00093E */
+	0,							/* U+00093F */
+	0,							/* U+000940 */
+	0,							/* U+000941 */
+	0,							/* U+000942 */
+	0,							/* U+000943 */
+	0,							/* U+000944 */
+	0,							/* U+000945 */
+	0,							/* U+000946 */
+	0,							/* U+000947 */
+	0,							/* U+000948 */
+	0,							/* U+000949 */
+	0,							/* U+00094A */
+	0,							/* U+00094B */
+	0,							/* U+00094C */
+	0,							/* U+00094D */
+	0,							/* U+00094E */
+	0,							/* U+00094F */
+	0,							/* U+000950 */
+	0,							/* U+000951 */
+	0,							/* U+000952 */
+	0,							/* U+000953 */
+	0,							/* U+000954 */
+	0,							/* U+000955 */
+	0,							/* U+000956 */
+	0,							/* U+000957 */
+	0,							/* U+000958 */
+	0,							/* U+000959 */
+	0,							/* U+00095A */
+	0,							/* U+00095B */
+	0,							/* U+00095C */
+	0,							/* U+00095D */
+	0,							/* U+00095E */
+	0,							/* U+00095F */
+	0,							/* U+000960 */
+	0,							/* U+000961 */
+	0,							/* U+000962 */
+	0,							/* U+000963 */
+	0,							/* U+000964 */
+	0,							/* U+000965 */
+	0,							/* U+000966 */
+	0,							/* U+000967 */
+	0,							/* U+000968 */
+	0,							/* U+000969 */
+	0,							/* U+00096A */
+	0,							/* U+00096B */
+	0,							/* U+00096C */
+	0,							/* U+00096D */
+	0,							/* U+00096E */
+	0,							/* U+00096F */
+	0,							/* U+000970 */
+	0,							/* U+000971 */
+	0,							/* U+000972 */
+	0,							/* U+000973 */
+	0,							/* U+000974 */
+	0,							/* U+000975 */
+	0,							/* U+000976 */
+	0,							/* U+000977 */
+	0,							/* U+000978 */
+	0,							/* U+000979 */
+	0,							/* U+00097A */
+	0,							/* U+00097B */
+	0,							/* U+00097C */
+	0,							/* U+00097D */
+	0,							/* U+00097E */
+	0,							/* U+00097F */
+	0,							/* U+000980 */
+	0,							/* U+000981 */
+	0,							/* U+000982 */
+	0,							/* U+000983 */
+	0,							/* U+000984 */
+	0,							/* U+000985 */
+	0,							/* U+000986 */
+	0,							/* U+000987 */
+	0,							/* U+000988 */
+	0,							/* U+000989 */
+	0,							/* U+00098A */
+	0,							/* U+00098B */
+	0,							/* U+00098C */
+	0,							/* U+00098D */
+	0,							/* U+00098E */
+	0,							/* U+00098F */
+	0,							/* U+000990 */
+	0,							/* U+000991 */
+	0,							/* U+000992 */
+	0,							/* U+000993 */
+	0,							/* U+000994 */
+	0,							/* U+000995 */
+	0,							/* U+000996 */
+	0,							/* U+000997 */
+	0,							/* U+000998 */
+	0,							/* U+000999 */
+	0,							/* U+00099A */
+	0,							/* U+00099B */
+	0,							/* U+00099C */
+	0,							/* U+00099D */
+	0,							/* U+00099E */
+	0,							/* U+00099F */
+	0,							/* U+0009A0 */
+	0,							/* U+0009A1 */
+	0,							/* U+0009A2 */
+	0,							/* U+0009A3 */
+	0,							/* U+0009A4 */
+	0,							/* U+0009A5 */
+	0,							/* U+0009A6 */
+	0,							/* U+0009A7 */
+	0,							/* U+0009A8 */
+	0,							/* U+0009A9 */
+	0,							/* U+0009AA */
+	0,							/* U+0009AB */
+	0,							/* U+0009AC */
+	0,							/* U+0009AD */
+	0,							/* U+0009AE */
+	0,							/* U+0009AF */
+	0,							/* U+0009B0 */
+	0,							/* U+0009B1 */
+	0,							/* U+0009B2 */
+	0,							/* U+0009B3 */
+	0,							/* U+0009B4 */
+	0,							/* U+0009B5 */
+	0,							/* U+0009B6 */
+	0,							/* U+0009B7 */
+	0,							/* U+0009B8 */
+	0,							/* U+0009B9 */
+	0,							/* U+0009BA */
+	0,							/* U+0009BB */
+	0,							/* U+0009BC */
+	0,							/* U+0009BD */
+	0,							/* U+0009BE */
+	0,							/* U+0009BF */
+	0,							/* U+0009C0 */
+	0,							/* U+0009C1 */
+	0,							/* U+0009C2 */
+	0,							/* U+0009C3 */
+	0,							/* U+0009C4 */
+	0,							/* U+0009C5 */
+	0,							/* U+0009C6 */
+	3668,						/* U+0009C7 */
+	0,							/* U+0009C8 */
+	0,							/* U+0009C9 */
+	0,							/* U+0009CA */
+	0,							/* U+0009CB */
+	0,							/* U+0009CC */
+	0,							/* U+0009CD */
+	0,							/* U+0009CE */
+	0,							/* U+0009CF */
+	0,							/* U+0009D0 */
+	0,							/* U+0009D1 */
+	0,							/* U+0009D2 */
+	0,							/* U+0009D3 */
+	0,							/* U+0009D4 */
+	0,							/* U+0009D5 */
+	0,							/* U+0009D6 */
+	0,							/* U+0009D7 */
+	0,							/* U+0009D8 */
+	0,							/* U+0009D9 */
+	0,							/* U+0009DA */
+	0,							/* U+0009DB */
+	0,							/* U+0009DC */
+	0,							/* U+0009DD */
+	0,							/* U+0009DE */
+	0,							/* U+0009DF */
+	0,							/* U+0009E0 */
+	0,							/* U+0009E1 */
+	0,							/* U+0009E2 */
+	0,							/* U+0009E3 */
+	0,							/* U+0009E4 */
+	0,							/* U+0009E5 */
+	0,							/* U+0009E6 */
+	0,							/* U+0009E7 */
+	0,							/* U+0009E8 */
+	0,							/* U+0009E9 */
+	0,							/* U+0009EA */
+	0,							/* U+0009EB */
+	0,							/* U+0009EC */
+	0,							/* U+0009ED */
+	0,							/* U+0009EE */
+	0,							/* U+0009EF */
+	0,							/* U+0009F0 */
+	0,							/* U+0009F1 */
+	0,							/* U+0009F2 */
+	0,							/* U+0009F3 */
+	0,							/* U+0009F4 */
+	0,							/* U+0009F5 */
+	0,							/* U+0009F6 */
+	0,							/* U+0009F7 */
+	0,							/* U+0009F8 */
+	0,							/* U+0009F9 */
+	0,							/* U+0009FA */
+	0,							/* U+0009FB */
+	0,							/* U+0009FC */
+	0,							/* U+0009FD */
+	0,							/* U+0009FE */
+	0,							/* U+0009FF */
+	0,							/* U+000A00 */
+	0,							/* U+000A01 */
+	0,							/* U+000A02 */
+	0,							/* U+000A03 */
+	0,							/* U+000A04 */
+	0,							/* U+000A05 */
+	0,							/* U+000A06 */
+	0,							/* U+000A07 */
+	0,							/* U+000A08 */
+	0,							/* U+000A09 */
+	0,							/* U+000A0A */
+	0,							/* U+000A0B */
+	0,							/* U+000A0C */
+	0,							/* U+000A0D */
+	0,							/* U+000A0E */
+	0,							/* U+000A0F */
+	0,							/* U+000A10 */
+	0,							/* U+000A11 */
+	0,							/* U+000A12 */
+	0,							/* U+000A13 */
+	0,							/* U+000A14 */
+	0,							/* U+000A15 */
+	0,							/* U+000A16 */
+	0,							/* U+000A17 */
+	0,							/* U+000A18 */
+	0,							/* U+000A19 */
+	0,							/* U+000A1A */
+	0,							/* U+000A1B */
+	0,							/* U+000A1C */
+	0,							/* U+000A1D */
+	0,							/* U+000A1E */
+	0,							/* U+000A1F */
+	0,							/* U+000A20 */
+	0,							/* U+000A21 */
+	0,							/* U+000A22 */
+	0,							/* U+000A23 */
+	0,							/* U+000A24 */
+	0,							/* U+000A25 */
+	0,							/* U+000A26 */
+	0,							/* U+000A27 */
+	0,							/* U+000A28 */
+	0,							/* U+000A29 */
+	0,							/* U+000A2A */
+	0,							/* U+000A2B */
+	0,							/* U+000A2C */
+	0,							/* U+000A2D */
+	0,							/* U+000A2E */
+	0,							/* U+000A2F */
+	0,							/* U+000A30 */
+	0,							/* U+000A31 */
+	0,							/* U+000A32 */
+	0,							/* U+000A33 */
+	0,							/* U+000A34 */
+	0,							/* U+000A35 */
+	0,							/* U+000A36 */
+	0,							/* U+000A37 */
+	0,							/* U+000A38 */
+	0,							/* U+000A39 */
+	0,							/* U+000A3A */
+	0,							/* U+000A3B */
+	0,							/* U+000A3C */
+	0,							/* U+000A3D */
+	0,							/* U+000A3E */
+	0,							/* U+000A3F */
+	0,							/* U+000A40 */
+	0,							/* U+000A41 */
+	0,							/* U+000A42 */
+	0,							/* U+000A43 */
+	0,							/* U+000A44 */
+	0,							/* U+000A45 */
+	0,							/* U+000A46 */
+	0,							/* U+000A47 */
+	0,							/* U+000A48 */
+	0,							/* U+000A49 */
+	0,							/* U+000A4A */
+	0,							/* U+000A4B */
+	0,							/* U+000A4C */
+	0,							/* U+000A4D */
+	0,							/* U+000A4E */
+	0,							/* U+000A4F */
+	0,							/* U+000A50 */
+	0,							/* U+000A51 */
+	0,							/* U+000A52 */
+	0,							/* U+000A53 */
+	0,							/* U+000A54 */
+	0,							/* U+000A55 */
+	0,							/* U+000A56 */
+	0,							/* U+000A57 */
+	0,							/* U+000A58 */
+	0,							/* U+000A59 */
+	0,							/* U+000A5A */
+	0,							/* U+000A5B */
+	0,							/* U+000A5C */
+	0,							/* U+000A5D */
+	0,							/* U+000A5E */
+	0,							/* U+000A5F */
+	0,							/* U+000A60 */
+	0,							/* U+000A61 */
+	0,							/* U+000A62 */
+	0,							/* U+000A63 */
+	0,							/* U+000A64 */
+	0,							/* U+000A65 */
+	0,							/* U+000A66 */
+	0,							/* U+000A67 */
+	0,							/* U+000A68 */
+	0,							/* U+000A69 */
+	0,							/* U+000A6A */
+	0,							/* U+000A6B */
+	0,							/* U+000A6C */
+	0,							/* U+000A6D */
+	0,							/* U+000A6E */
+	0,							/* U+000A6F */
+	0,							/* U+000A70 */
+	0,							/* U+000A71 */
+	0,							/* U+000A72 */
+	0,							/* U+000A73 */
+	0,							/* U+000A74 */
+	0,							/* U+000A75 */
+	0,							/* U+000A76 */
+	0,							/* U+000A77 */
+	0,							/* U+000A78 */
+	0,							/* U+000A79 */
+	0,							/* U+000A7A */
+	0,							/* U+000A7B */
+	0,							/* U+000A7C */
+	0,							/* U+000A7D */
+	0,							/* U+000A7E */
+	0,							/* U+000A7F */
+	0,							/* U+000A80 */
+	0,							/* U+000A81 */
+	0,							/* U+000A82 */
+	0,							/* U+000A83 */
+	0,							/* U+000A84 */
+	0,							/* U+000A85 */
+	0,							/* U+000A86 */
+	0,							/* U+000A87 */
+	0,							/* U+000A88 */
+	0,							/* U+000A89 */
+	0,							/* U+000A8A */
+	0,							/* U+000A8B */
+	0,							/* U+000A8C */
+	0,							/* U+000A8D */
+	0,							/* U+000A8E */
+	0,							/* U+000A8F */
+	0,							/* U+000A90 */
+	0,							/* U+000A91 */
+	0,							/* U+000A92 */
+	0,							/* U+000A93 */
+	0,							/* U+000A94 */
+	0,							/* U+000A95 */
+	0,							/* U+000A96 */
+	0,							/* U+000A97 */
+	0,							/* U+000A98 */
+	0,							/* U+000A99 */
+	0,							/* U+000A9A */
+	0,							/* U+000A9B */
+	0,							/* U+000A9C */
+	0,							/* U+000A9D */
+	0,							/* U+000A9E */
+	0,							/* U+000A9F */
+	0,							/* U+000AA0 */
+	0,							/* U+000AA1 */
+	0,							/* U+000AA2 */
+	0,							/* U+000AA3 */
+	0,							/* U+000AA4 */
+	0,							/* U+000AA5 */
+	0,							/* U+000AA6 */
+	0,							/* U+000AA7 */
+	0,							/* U+000AA8 */
+	0,							/* U+000AA9 */
+	0,							/* U+000AAA */
+	0,							/* U+000AAB */
+	0,							/* U+000AAC */
+	0,							/* U+000AAD */
+	0,							/* U+000AAE */
+	0,							/* U+000AAF */
+	0,							/* U+000AB0 */
+	0,							/* U+000AB1 */
+	0,							/* U+000AB2 */
+	0,							/* U+000AB3 */
+	0,							/* U+000AB4 */
+	0,							/* U+000AB5 */
+	0,							/* U+000AB6 */
+	0,							/* U+000AB7 */
+	0,							/* U+000AB8 */
+	0,							/* U+000AB9 */
+	0,							/* U+000ABA */
+	0,							/* U+000ABB */
+	0,							/* U+000ABC */
+	0,							/* U+000ABD */
+	0,							/* U+000ABE */
+	0,							/* U+000ABF */
+	0,							/* U+000AC0 */
+	0,							/* U+000AC1 */
+	0,							/* U+000AC2 */
+	0,							/* U+000AC3 */
+	0,							/* U+000AC4 */
+	0,							/* U+000AC5 */
+	0,							/* U+000AC6 */
+	0,							/* U+000AC7 */
+	0,							/* U+000AC8 */
+	0,							/* U+000AC9 */
+	0,							/* U+000ACA */
+	0,							/* U+000ACB */
+	0,							/* U+000ACC */
+	0,							/* U+000ACD */
+	0,							/* U+000ACE */
+	0,							/* U+000ACF */
+	0,							/* U+000AD0 */
+	0,							/* U+000AD1 */
+	0,							/* U+000AD2 */
+	0,							/* U+000AD3 */
+	0,							/* U+000AD4 */
+	0,							/* U+000AD5 */
+	0,							/* U+000AD6 */
+	0,							/* U+000AD7 */
+	0,							/* U+000AD8 */
+	0,							/* U+000AD9 */
+	0,							/* U+000ADA */
+	0,							/* U+000ADB */
+	0,							/* U+000ADC */
+	0,							/* U+000ADD */
+	0,							/* U+000ADE */
+	0,							/* U+000ADF */
+	0,							/* U+000AE0 */
+	0,							/* U+000AE1 */
+	0,							/* U+000AE2 */
+	0,							/* U+000AE3 */
+	0,							/* U+000AE4 */
+	0,							/* U+000AE5 */
+	0,							/* U+000AE6 */
+	0,							/* U+000AE7 */
+	0,							/* U+000AE8 */
+	0,							/* U+000AE9 */
+	0,							/* U+000AEA */
+	0,							/* U+000AEB */
+	0,							/* U+000AEC */
+	0,							/* U+000AED */
+	0,							/* U+000AEE */
+	0,							/* U+000AEF */
+	0,							/* U+000AF0 */
+	0,							/* U+000AF1 */
+	0,							/* U+000AF2 */
+	0,							/* U+000AF3 */
+	0,							/* U+000AF4 */
+	0,							/* U+000AF5 */
+	0,							/* U+000AF6 */
+	0,							/* U+000AF7 */
+	0,							/* U+000AF8 */
+	0,							/* U+000AF9 */
+	0,							/* U+000AFA */
+	0,							/* U+000AFB */
+	0,							/* U+000AFC */
+	0,							/* U+000AFD */
+	0,							/* U+000AFE */
+	0,							/* U+000AFF */
+	0,							/* U+000B00 */
+	0,							/* U+000B01 */
+	0,							/* U+000B02 */
+	0,							/* U+000B03 */
+	0,							/* U+000B04 */
+	0,							/* U+000B05 */
+	0,							/* U+000B06 */
+	0,							/* U+000B07 */
+	0,							/* U+000B08 */
+	0,							/* U+000B09 */
+	0,							/* U+000B0A */
+	0,							/* U+000B0B */
+	0,							/* U+000B0C */
+	0,							/* U+000B0D */
+	0,							/* U+000B0E */
+	0,							/* U+000B0F */
+	0,							/* U+000B10 */
+	0,							/* U+000B11 */
+	0,							/* U+000B12 */
+	0,							/* U+000B13 */
+	0,							/* U+000B14 */
+	0,							/* U+000B15 */
+	0,							/* U+000B16 */
+	0,							/* U+000B17 */
+	0,							/* U+000B18 */
+	0,							/* U+000B19 */
+	0,							/* U+000B1A */
+	0,							/* U+000B1B */
+	0,							/* U+000B1C */
+	0,							/* U+000B1D */
+	0,							/* U+000B1E */
+	0,							/* U+000B1F */
+	0,							/* U+000B20 */
+	0,							/* U+000B21 */
+	0,							/* U+000B22 */
+	0,							/* U+000B23 */
+	0,							/* U+000B24 */
+	0,							/* U+000B25 */
+	0,							/* U+000B26 */
+	0,							/* U+000B27 */
+	0,							/* U+000B28 */
+	0,							/* U+000B29 */
+	0,							/* U+000B2A */
+	0,							/* U+000B2B */
+	0,							/* U+000B2C */
+	0,							/* U+000B2D */
+	0,							/* U+000B2E */
+	0,							/* U+000B2F */
+	0,							/* U+000B30 */
+	0,							/* U+000B31 */
+	0,							/* U+000B32 */
+	0,							/* U+000B33 */
+	0,							/* U+000B34 */
+	0,							/* U+000B35 */
+	0,							/* U+000B36 */
+	0,							/* U+000B37 */
+	0,							/* U+000B38 */
+	0,							/* U+000B39 */
+	0,							/* U+000B3A */
+	0,							/* U+000B3B */
+	0,							/* U+000B3C */
+	0,							/* U+000B3D */
+	0,							/* U+000B3E */
+	0,							/* U+000B3F */
+	0,							/* U+000B40 */
+	0,							/* U+000B41 */
+	0,							/* U+000B42 */
+	0,							/* U+000B43 */
+	0,							/* U+000B44 */
+	0,							/* U+000B45 */
+	0,							/* U+000B46 */
+	3697,						/* U+000B47 */
+	0,							/* U+000B48 */
+	0,							/* U+000B49 */
+	0,							/* U+000B4A */
+	0,							/* U+000B4B */
+	0,							/* U+000B4C */
+	0,							/* U+000B4D */
+	0,							/* U+000B4E */
+	0,							/* U+000B4F */
+	0,							/* U+000B50 */
+	0,							/* U+000B51 */
+	0,							/* U+000B52 */
+	0,							/* U+000B53 */
+	0,							/* U+000B54 */
+	0,							/* U+000B55 */
+	0,							/* U+000B56 */
+	0,							/* U+000B57 */
+	0,							/* U+000B58 */
+	0,							/* U+000B59 */
+	0,							/* U+000B5A */
+	0,							/* U+000B5B */
+	0,							/* U+000B5C */
+	0,							/* U+000B5D */
+	0,							/* U+000B5E */
+	0,							/* U+000B5F */
+	0,							/* U+000B60 */
+	0,							/* U+000B61 */
+	0,							/* U+000B62 */
+	0,							/* U+000B63 */
+	0,							/* U+000B64 */
+	0,							/* U+000B65 */
+	0,							/* U+000B66 */
+	0,							/* U+000B67 */
+	0,							/* U+000B68 */
+	0,							/* U+000B69 */
+	0,							/* U+000B6A */
+	0,							/* U+000B6B */
+	0,							/* U+000B6C */
+	0,							/* U+000B6D */
+	0,							/* U+000B6E */
+	0,							/* U+000B6F */
+	0,							/* U+000B70 */
+	0,							/* U+000B71 */
+	0,							/* U+000B72 */
+	0,							/* U+000B73 */
+	0,							/* U+000B74 */
+	0,							/* U+000B75 */
+	0,							/* U+000B76 */
+	0,							/* U+000B77 */
+	0,							/* U+000B78 */
+	0,							/* U+000B79 */
+	0,							/* U+000B7A */
+	0,							/* U+000B7B */
+	0,							/* U+000B7C */
+	0,							/* U+000B7D */
+	0,							/* U+000B7E */
+	0,							/* U+000B7F */
+	0,							/* U+000B80 */
+	0,							/* U+000B81 */
+	0,							/* U+000B82 */
+	0,							/* U+000B83 */
+	0,							/* U+000B84 */
+	0,							/* U+000B85 */
+	0,							/* U+000B86 */
+	0,							/* U+000B87 */
+	0,							/* U+000B88 */
+	0,							/* U+000B89 */
+	0,							/* U+000B8A */
+	0,							/* U+000B8B */
+	0,							/* U+000B8C */
+	0,							/* U+000B8D */
+	0,							/* U+000B8E */
+	0,							/* U+000B8F */
+	0,							/* U+000B90 */
+	0,							/* U+000B91 */
+	3726,						/* U+000B92 */
+	0,							/* U+000B93 */
+	0,							/* U+000B94 */
+	0,							/* U+000B95 */
+	0,							/* U+000B96 */
+	0,							/* U+000B97 */
+	0,							/* U+000B98 */
+	0,							/* U+000B99 */
+	0,							/* U+000B9A */
+	0,							/* U+000B9B */
+	0,							/* U+000B9C */
+	0,							/* U+000B9D */
+	0,							/* U+000B9E */
+	0,							/* U+000B9F */
+	0,							/* U+000BA0 */
+	0,							/* U+000BA1 */
+	0,							/* U+000BA2 */
+	0,							/* U+000BA3 */
+	0,							/* U+000BA4 */
+	0,							/* U+000BA5 */
+	0,							/* U+000BA6 */
+	0,							/* U+000BA7 */
+	0,							/* U+000BA8 */
+	0,							/* U+000BA9 */
+	0,							/* U+000BAA */
+	0,							/* U+000BAB */
+	0,							/* U+000BAC */
+	0,							/* U+000BAD */
+	0,							/* U+000BAE */
+	0,							/* U+000BAF */
+	0,							/* U+000BB0 */
+	0,							/* U+000BB1 */
+	0,							/* U+000BB2 */
+	0,							/* U+000BB3 */
+	0,							/* U+000BB4 */
+	0,							/* U+000BB5 */
+	0,							/* U+000BB6 */
+	0,							/* U+000BB7 */
+	0,							/* U+000BB8 */
+	0,							/* U+000BB9 */
+	0,							/* U+000BBA */
+	0,							/* U+000BBB */
+	0,							/* U+000BBC */
+	0,							/* U+000BBD */
+	0,							/* U+000BBE */
+	0,							/* U+000BBF */
+	0,							/* U+000BC0 */
+	0,							/* U+000BC1 */
+	0,							/* U+000BC2 */
+	0,							/* U+000BC3 */
+	0,							/* U+000BC4 */
+	0,							/* U+000BC5 */
+	3730,						/* U+000BC6 */
+	3759,						/* U+000BC7 */
+	0,							/* U+000BC8 */
+	0,							/* U+000BC9 */
+	0,							/* U+000BCA */
+	0,							/* U+000BCB */
+	0,							/* U+000BCC */
+	0,							/* U+000BCD */
+	0,							/* U+000BCE */
+	0,							/* U+000BCF */
+	0,							/* U+000BD0 */
+	0,							/* U+000BD1 */
+	0,							/* U+000BD2 */
+	0,							/* U+000BD3 */
+	0,							/* U+000BD4 */
+	0,							/* U+000BD5 */
+	0,							/* U+000BD6 */
+	0,							/* U+000BD7 */
+	0,							/* U+000BD8 */
+	0,							/* U+000BD9 */
+	0,							/* U+000BDA */
+	0,							/* U+000BDB */
+	0,							/* U+000BDC */
+	0,							/* U+000BDD */
+	0,							/* U+000BDE */
+	0,							/* U+000BDF */
+	0,							/* U+000BE0 */
+	0,							/* U+000BE1 */
+	0,							/* U+000BE2 */
+	0,							/* U+000BE3 */
+	0,							/* U+000BE4 */
+	0,							/* U+000BE5 */
+	0,							/* U+000BE6 */
+	0,							/* U+000BE7 */
+	0,							/* U+000BE8 */
+	0,							/* U+000BE9 */
+	0,							/* U+000BEA */
+	0,							/* U+000BEB */
+	0,							/* U+000BEC */
+	0,							/* U+000BED */
+	0,							/* U+000BEE */
+	0,							/* U+000BEF */
+	0,							/* U+000BF0 */
+	0,							/* U+000BF1 */
+	0,							/* U+000BF2 */
+	0,							/* U+000BF3 */
+	0,							/* U+000BF4 */
+	0,							/* U+000BF5 */
+	0,							/* U+000BF6 */
+	0,							/* U+000BF7 */
+	0,							/* U+000BF8 */
+	0,							/* U+000BF9 */
+	0,							/* U+000BFA */
+	0,							/* U+000BFB */
+	0,							/* U+000BFC */
+	0,							/* U+000BFD */
+	0,							/* U+000BFE */
+	0,							/* U+000BFF */
+	0,							/* U+000C00 */
+	0,							/* U+000C01 */
+	0,							/* U+000C02 */
+	0,							/* U+000C03 */
+	0,							/* U+000C04 */
+	0,							/* U+000C05 */
+	0,							/* U+000C06 */
+	0,							/* U+000C07 */
+	0,							/* U+000C08 */
+	0,							/* U+000C09 */
+	0,							/* U+000C0A */
+	0,							/* U+000C0B */
+	0,							/* U+000C0C */
+	0,							/* U+000C0D */
+	0,							/* U+000C0E */
+	0,							/* U+000C0F */
+	0,							/* U+000C10 */
+	0,							/* U+000C11 */
+	0,							/* U+000C12 */
+	0,							/* U+000C13 */
+	0,							/* U+000C14 */
+	0,							/* U+000C15 */
+	0,							/* U+000C16 */
+	0,							/* U+000C17 */
+	0,							/* U+000C18 */
+	0,							/* U+000C19 */
+	0,							/* U+000C1A */
+	0,							/* U+000C1B */
+	0,							/* U+000C1C */
+	0,							/* U+000C1D */
+	0,							/* U+000C1E */
+	0,							/* U+000C1F */
+	0,							/* U+000C20 */
+	0,							/* U+000C21 */
+	0,							/* U+000C22 */
+	0,							/* U+000C23 */
+	0,							/* U+000C24 */
+	0,							/* U+000C25 */
+	0,							/* U+000C26 */
+	0,							/* U+000C27 */
+	0,							/* U+000C28 */
+	0,							/* U+000C29 */
+	0,							/* U+000C2A */
+	0,							/* U+000C2B */
+	0,							/* U+000C2C */
+	0,							/* U+000C2D */
+	0,							/* U+000C2E */
+	0,							/* U+000C2F */
+	0,							/* U+000C30 */
+	0,							/* U+000C31 */
+	0,							/* U+000C32 */
+	0,							/* U+000C33 */
+	0,							/* U+000C34 */
+	0,							/* U+000C35 */
+	0,							/* U+000C36 */
+	0,							/* U+000C37 */
+	0,							/* U+000C38 */
+	0,							/* U+000C39 */
+	0,							/* U+000C3A */
+	0,							/* U+000C3B */
+	0,							/* U+000C3C */
+	0,							/* U+000C3D */
+	0,							/* U+000C3E */
+	0,							/* U+000C3F */
+	0,							/* U+000C40 */
+	0,							/* U+000C41 */
+	0,							/* U+000C42 */
+	0,							/* U+000C43 */
+	0,							/* U+000C44 */
+	0,							/* U+000C45 */
+	3763,						/* U+000C46 */
+	0,							/* U+000C47 */
+	0,							/* U+000C48 */
+	0,							/* U+000C49 */
+	0,							/* U+000C4A */
+	0,							/* U+000C4B */
+	0,							/* U+000C4C */
+	0,							/* U+000C4D */
+	0,							/* U+000C4E */
+	0,							/* U+000C4F */
+	0,							/* U+000C50 */
+	0,							/* U+000C51 */
+	0,							/* U+000C52 */
+	0,							/* U+000C53 */
+	0,							/* U+000C54 */
+	0,							/* U+000C55 */
+	0,							/* U+000C56 */
+	0,							/* U+000C57 */
+	0,							/* U+000C58 */
+	0,							/* U+000C59 */
+	0,							/* U+000C5A */
+	0,							/* U+000C5B */
+	0,							/* U+000C5C */
+	0,							/* U+000C5D */
+	0,							/* U+000C5E */
+	0,							/* U+000C5F */
+	0,							/* U+000C60 */
+	0,							/* U+000C61 */
+	0,							/* U+000C62 */
+	0,							/* U+000C63 */
+	0,							/* U+000C64 */
+	0,							/* U+000C65 */
+	0,							/* U+000C66 */
+	0,							/* U+000C67 */
+	0,							/* U+000C68 */
+	0,							/* U+000C69 */
+	0,							/* U+000C6A */
+	0,							/* U+000C6B */
+	0,							/* U+000C6C */
+	0,							/* U+000C6D */
+	0,							/* U+000C6E */
+	0,							/* U+000C6F */
+	0,							/* U+000C70 */
+	0,							/* U+000C71 */
+	0,							/* U+000C72 */
+	0,							/* U+000C73 */
+	0,							/* U+000C74 */
+	0,							/* U+000C75 */
+	0,							/* U+000C76 */
+	0,							/* U+000C77 */
+	0,							/* U+000C78 */
+	0,							/* U+000C79 */
+	0,							/* U+000C7A */
+	0,							/* U+000C7B */
+	0,							/* U+000C7C */
+	0,							/* U+000C7D */
+	0,							/* U+000C7E */
+	0,							/* U+000C7F */
+	0,							/* U+000C80 */
+	0,							/* U+000C81 */
+	0,							/* U+000C82 */
+	0,							/* U+000C83 */
+	0,							/* U+000C84 */
+	0,							/* U+000C85 */
+	0,							/* U+000C86 */
+	0,							/* U+000C87 */
+	0,							/* U+000C88 */
+	0,							/* U+000C89 */
+	0,							/* U+000C8A */
+	0,							/* U+000C8B */
+	0,							/* U+000C8C */
+	0,							/* U+000C8D */
+	0,							/* U+000C8E */
+	0,							/* U+000C8F */
+	0,							/* U+000C90 */
+	0,							/* U+000C91 */
+	0,							/* U+000C92 */
+	0,							/* U+000C93 */
+	0,							/* U+000C94 */
+	0,							/* U+000C95 */
+	0,							/* U+000C96 */
+	0,							/* U+000C97 */
+	0,							/* U+000C98 */
+	0,							/* U+000C99 */
+	0,							/* U+000C9A */
+	0,							/* U+000C9B */
+	0,							/* U+000C9C */
+	0,							/* U+000C9D */
+	0,							/* U+000C9E */
+	0,							/* U+000C9F */
+	0,							/* U+000CA0 */
+	0,							/* U+000CA1 */
+	0,							/* U+000CA2 */
+	0,							/* U+000CA3 */
+	0,							/* U+000CA4 */
+	0,							/* U+000CA5 */
+	0,							/* U+000CA6 */
+	0,							/* U+000CA7 */
+	0,							/* U+000CA8 */
+	0,							/* U+000CA9 */
+	0,							/* U+000CAA */
+	0,							/* U+000CAB */
+	0,							/* U+000CAC */
+	0,							/* U+000CAD */
+	0,							/* U+000CAE */
+	0,							/* U+000CAF */
+	0,							/* U+000CB0 */
+	0,							/* U+000CB1 */
+	0,							/* U+000CB2 */
+	0,							/* U+000CB3 */
+	0,							/* U+000CB4 */
+	0,							/* U+000CB5 */
+	0,							/* U+000CB6 */
+	0,							/* U+000CB7 */
+	0,							/* U+000CB8 */
+	0,							/* U+000CB9 */
+	0,							/* U+000CBA */
+	0,							/* U+000CBB */
+	0,							/* U+000CBC */
+	0,							/* U+000CBD */
+	0,							/* U+000CBE */
+	3767,						/* U+000CBF */
+	0,							/* U+000CC0 */
+	0,							/* U+000CC1 */
+	0,							/* U+000CC2 */
+	0,							/* U+000CC3 */
+	0,							/* U+000CC4 */
+	0,							/* U+000CC5 */
+	3771,						/* U+000CC6 */
+	0,							/* U+000CC7 */
+	0,							/* U+000CC8 */
+	0,							/* U+000CC9 */
+	3795,						/* U+000CCA */
+	0,							/* U+000CCB */
+	0,							/* U+000CCC */
+	0,							/* U+000CCD */
+	0,							/* U+000CCE */
+	0,							/* U+000CCF */
+	0,							/* U+000CD0 */
+	0,							/* U+000CD1 */
+	0,							/* U+000CD2 */
+	0,							/* U+000CD3 */
+	0,							/* U+000CD4 */
+	0,							/* U+000CD5 */
+	0,							/* U+000CD6 */
+	0,							/* U+000CD7 */
+	0,							/* U+000CD8 */
+	0,							/* U+000CD9 */
+	0,							/* U+000CDA */
+	0,							/* U+000CDB */
+	0,							/* U+000CDC */
+	0,							/* U+000CDD */
+	0,							/* U+000CDE */
+	0,							/* U+000CDF */
+	0,							/* U+000CE0 */
+	0,							/* U+000CE1 */
+	0,							/* U+000CE2 */
+	0,							/* U+000CE3 */
+	0,							/* U+000CE4 */
+	0,							/* U+000CE5 */
+	0,							/* U+000CE6 */
+	0,							/* U+000CE7 */
+	0,							/* U+000CE8 */
+	0,							/* U+000CE9 */
+	0,							/* U+000CEA */
+	0,							/* U+000CEB */
+	0,							/* U+000CEC */
+	0,							/* U+000CED */
+	0,							/* U+000CEE */
+	0,							/* U+000CEF */
+	0,							/* U+000CF0 */
+	0,							/* U+000CF1 */
+	0,							/* U+000CF2 */
+	0,							/* U+000CF3 */
+	0,							/* U+000CF4 */
+	0,							/* U+000CF5 */
+	0,							/* U+000CF6 */
+	0,							/* U+000CF7 */
+	0,							/* U+000CF8 */
+	0,							/* U+000CF9 */
+	0,							/* U+000CFA */
+	0,							/* U+000CFB */
+	0,							/* U+000CFC */
+	0,							/* U+000CFD */
+	0,							/* U+000CFE */
+	0,							/* U+000CFF */
+	0,							/* U+000D00 */
+	0,							/* U+000D01 */
+	0,							/* U+000D02 */
+	0,							/* U+000D03 */
+	0,							/* U+000D04 */
+	0,							/* U+000D05 */
+	0,							/* U+000D06 */
+	0,							/* U+000D07 */
+	0,							/* U+000D08 */
+	0,							/* U+000D09 */
+	0,							/* U+000D0A */
+	0,							/* U+000D0B */
+	0,							/* U+000D0C */
+	0,							/* U+000D0D */
+	0,							/* U+000D0E */
+	0,							/* U+000D0F */
+	0,							/* U+000D10 */
+	0,							/* U+000D11 */
+	0,							/* U+000D12 */
+	0,							/* U+000D13 */
+	0,							/* U+000D14 */
+	0,							/* U+000D15 */
+	0,							/* U+000D16 */
+	0,							/* U+000D17 */
+	0,							/* U+000D18 */
+	0,							/* U+000D19 */
+	0,							/* U+000D1A */
+	0,							/* U+000D1B */
+	0,							/* U+000D1C */
+	0,							/* U+000D1D */
+	0,							/* U+000D1E */
+	0,							/* U+000D1F */
+	0,							/* U+000D20 */
+	0,							/* U+000D21 */
+	0,							/* U+000D22 */
+	0,							/* U+000D23 */
+	0,							/* U+000D24 */
+	0,							/* U+000D25 */
+	0,							/* U+000D26 */
+	0,							/* U+000D27 */
+	0,							/* U+000D28 */
+	0,							/* U+000D29 */
+	0,							/* U+000D2A */
+	0,							/* U+000D2B */
+	0,							/* U+000D2C */
+	0,							/* U+000D2D */
+	0,							/* U+000D2E */
+	0,							/* U+000D2F */
+	0,							/* U+000D30 */
+	0,							/* U+000D31 */
+	0,							/* U+000D32 */
+	0,							/* U+000D33 */
+	0,							/* U+000D34 */
+	0,							/* U+000D35 */
+	0,							/* U+000D36 */
+	0,							/* U+000D37 */
+	0,							/* U+000D38 */
+	0,							/* U+000D39 */
+	0,							/* U+000D3A */
+	0,							/* U+000D3B */
+	0,							/* U+000D3C */
+	0,							/* U+000D3D */
+	0,							/* U+000D3E */
+	0,							/* U+000D3F */
+	0,							/* U+000D40 */
+	0,							/* U+000D41 */
+	0,							/* U+000D42 */
+	0,							/* U+000D43 */
+	0,							/* U+000D44 */
+	0,							/* U+000D45 */
+	3799,						/* U+000D46 */
+	3828,						/* U+000D47 */
+	0,							/* U+000D48 */
+	0,							/* U+000D49 */
+	0,							/* U+000D4A */
+	0,							/* U+000D4B */
+	0,							/* U+000D4C */
+	0,							/* U+000D4D */
+	0,							/* U+000D4E */
+	0,							/* U+000D4F */
+	0,							/* U+000D50 */
+	0,							/* U+000D51 */
+	0,							/* U+000D52 */
+	0,							/* U+000D53 */
+	0,							/* U+000D54 */
+	0,							/* U+000D55 */
+	0,							/* U+000D56 */
+	0,							/* U+000D57 */
+	0,							/* U+000D58 */
+	0,							/* U+000D59 */
+	0,							/* U+000D5A */
+	0,							/* U+000D5B */
+	0,							/* U+000D5C */
+	0,							/* U+000D5D */
+	0,							/* U+000D5E */
+	0,							/* U+000D5F */
+	0,							/* U+000D60 */
+	0,							/* U+000D61 */
+	0,							/* U+000D62 */
+	0,							/* U+000D63 */
+	0,							/* U+000D64 */
+	0,							/* U+000D65 */
+	0,							/* U+000D66 */
+	0,							/* U+000D67 */
+	0,							/* U+000D68 */
+	0,							/* U+000D69 */
+	0,							/* U+000D6A */
+	0,							/* U+000D6B */
+	0,							/* U+000D6C */
+	0,							/* U+000D6D */
+	0,							/* U+000D6E */
+	0,							/* U+000D6F */
+	0,							/* U+000D70 */
+	0,							/* U+000D71 */
+	0,							/* U+000D72 */
+	0,							/* U+000D73 */
+	0,							/* U+000D74 */
+	0,							/* U+000D75 */
+	0,							/* U+000D76 */
+	0,							/* U+000D77 */
+	0,							/* U+000D78 */
+	0,							/* U+000D79 */
+	0,							/* U+000D7A */
+	0,							/* U+000D7B */
+	0,							/* U+000D7C */
+	0,							/* U+000D7D */
+	0,							/* U+000D7E */
+	0,							/* U+000D7F */
+	0,							/* U+000D80 */
+	0,							/* U+000D81 */
+	0,							/* U+000D82 */
+	0,							/* U+000D83 */
+	0,							/* U+000D84 */
+	0,							/* U+000D85 */
+	0,							/* U+000D86 */
+	0,							/* U+000D87 */
+	0,							/* U+000D88 */
+	0,							/* U+000D89 */
+	0,							/* U+000D8A */
+	0,							/* U+000D8B */
+	0,							/* U+000D8C */
+	0,							/* U+000D8D */
+	0,							/* U+000D8E */
+	0,							/* U+000D8F */
+	0,							/* U+000D90 */
+	0,							/* U+000D91 */
+	0,							/* U+000D92 */
+	0,							/* U+000D93 */
+	0,							/* U+000D94 */
+	0,							/* U+000D95 */
+	0,							/* U+000D96 */
+	0,							/* U+000D97 */
+	0,							/* U+000D98 */
+	0,							/* U+000D99 */
+	0,							/* U+000D9A */
+	0,							/* U+000D9B */
+	0,							/* U+000D9C */
+	0,							/* U+000D9D */
+	0,							/* U+000D9E */
+	0,							/* U+000D9F */
+	0,							/* U+000DA0 */
+	0,							/* U+000DA1 */
+	0,							/* U+000DA2 */
+	0,							/* U+000DA3 */
+	0,							/* U+000DA4 */
+	0,							/* U+000DA5 */
+	0,							/* U+000DA6 */
+	0,							/* U+000DA7 */
+	0,							/* U+000DA8 */
+	0,							/* U+000DA9 */
+	0,							/* U+000DAA */
+	0,							/* U+000DAB */
+	0,							/* U+000DAC */
+	0,							/* U+000DAD */
+	0,							/* U+000DAE */
+	0,							/* U+000DAF */
+	0,							/* U+000DB0 */
+	0,							/* U+000DB1 */
+	0,							/* U+000DB2 */
+	0,							/* U+000DB3 */
+	0,							/* U+000DB4 */
+	0,							/* U+000DB5 */
+	0,							/* U+000DB6 */
+	0,							/* U+000DB7 */
+	0,							/* U+000DB8 */
+	0,							/* U+000DB9 */
+	0,							/* U+000DBA */
+	0,							/* U+000DBB */
+	0,							/* U+000DBC */
+	0,							/* U+000DBD */
+	0,							/* U+000DBE */
+	0,							/* U+000DBF */
+	0,							/* U+000DC0 */
+	0,							/* U+000DC1 */
+	0,							/* U+000DC2 */
+	0,							/* U+000DC3 */
+	0,							/* U+000DC4 */
+	0,							/* U+000DC5 */
+	0,							/* U+000DC6 */
+	0,							/* U+000DC7 */
+	0,							/* U+000DC8 */
+	0,							/* U+000DC9 */
+	0,							/* U+000DCA */
+	0,							/* U+000DCB */
+	0,							/* U+000DCC */
+	0,							/* U+000DCD */
+	0,							/* U+000DCE */
+	0,							/* U+000DCF */
+	0,							/* U+000DD0 */
+	0,							/* U+000DD1 */
+	0,							/* U+000DD2 */
+	0,							/* U+000DD3 */
+	0,							/* U+000DD4 */
+	0,							/* U+000DD5 */
+	0,							/* U+000DD6 */
+	0,							/* U+000DD7 */
+	0,							/* U+000DD8 */
+	3832,						/* U+000DD9 */
+	0,							/* U+000DDA */
+	0,							/* U+000DDB */
+	3857,						/* U+000DDC */
+	0,							/* U+000DDD */
+	0,							/* U+000DDE */
+	0,							/* U+000DDF */
+	0,							/* U+000DE0 */
+	0,							/* U+000DE1 */
+	0,							/* U+000DE2 */
+	0,							/* U+000DE3 */
+	0,							/* U+000DE4 */
+	0,							/* U+000DE5 */
+	0,							/* U+000DE6 */
+	0,							/* U+000DE7 */
+	0,							/* U+000DE8 */
+	0,							/* U+000DE9 */
+	0,							/* U+000DEA */
+	0,							/* U+000DEB */
+	0,							/* U+000DEC */
+	0,							/* U+000DED */
+	0,							/* U+000DEE */
+	0,							/* U+000DEF */
+	0,							/* U+000DF0 */
+	0,							/* U+000DF1 */
+	0,							/* U+000DF2 */
+	0,							/* U+000DF3 */
+	0,							/* U+000DF4 */
+	0,							/* U+000DF5 */
+	0,							/* U+000DF6 */
+	0,							/* U+000DF7 */
+	0,							/* U+000DF8 */
+	0,							/* U+000DF9 */
+	0,							/* U+000DFA */
+	0,							/* U+000DFB */
+	0,							/* U+000DFC */
+	0,							/* U+000DFD */
+	0,							/* U+000DFE */
+	0,							/* U+000DFF */
+	0,							/* U+000E00 */
+	0,							/* U+000E01 */
+	0,							/* U+000E02 */
+	0,							/* U+000E03 */
+	0,							/* U+000E04 */
+	0,							/* U+000E05 */
+	0,							/* U+000E06 */
+	0,							/* U+000E07 */
+	0,							/* U+000E08 */
+	0,							/* U+000E09 */
+	0,							/* U+000E0A */
+	0,							/* U+000E0B */
+	0,							/* U+000E0C */
+	0,							/* U+000E0D */
+	0,							/* U+000E0E */
+	0,							/* U+000E0F */
+	0,							/* U+000E10 */
+	0,							/* U+000E11 */
+	0,							/* U+000E12 */
+	0,							/* U+000E13 */
+	0,							/* U+000E14 */
+	0,							/* U+000E15 */
+	0,							/* U+000E16 */
+	0,							/* U+000E17 */
+	0,							/* U+000E18 */
+	0,							/* U+000E19 */
+	0,							/* U+000E1A */
+	0,							/* U+000E1B */
+	0,							/* U+000E1C */
+	0,							/* U+000E1D */
+	0,							/* U+000E1E */
+	0,							/* U+000E1F */
+	0,							/* U+000E20 */
+	0,							/* U+000E21 */
+	0,							/* U+000E22 */
+	0,							/* U+000E23 */
+	0,							/* U+000E24 */
+	0,							/* U+000E25 */
+	0,							/* U+000E26 */
+	0,							/* U+000E27 */
+	0,							/* U+000E28 */
+	0,							/* U+000E29 */
+	0,							/* U+000E2A */
+	0,							/* U+000E2B */
+	0,							/* U+000E2C */
+	0,							/* U+000E2D */
+	0,							/* U+000E2E */
+	0,							/* U+000E2F */
+	0,							/* U+000E30 */
+	0,							/* U+000E31 */
+	0,							/* U+000E32 */
+	0,							/* U+000E33 */
+	0,							/* U+000E34 */
+	0,							/* U+000E35 */
+	0,							/* U+000E36 */
+	0,							/* U+000E37 */
+	0,							/* U+000E38 */
+	0,							/* U+000E39 */
+	0,							/* U+000E3A */
+	0,							/* U+000E3B */
+	0,							/* U+000E3C */
+	0,							/* U+000E3D */
+	0,							/* U+000E3E */
+	0,							/* U+000E3F */
+	0,							/* U+000E40 */
+	0,							/* U+000E41 */
+	0,							/* U+000E42 */
+	0,							/* U+000E43 */
+	0,							/* U+000E44 */
+	0,							/* U+000E45 */
+	0,							/* U+000E46 */
+	0,							/* U+000E47 */
+	0,							/* U+000E48 */
+	0,							/* U+000E49 */
+	0,							/* U+000E4A */
+	0,							/* U+000E4B */
+	0,							/* U+000E4C */
+	0,							/* U+000E4D */
+	0,							/* U+000E4E */
+	0,							/* U+000E4F */
+	0,							/* U+000E50 */
+	0,							/* U+000E51 */
+	0,							/* U+000E52 */
+	0,							/* U+000E53 */
+	0,							/* U+000E54 */
+	0,							/* U+000E55 */
+	0,							/* U+000E56 */
+	0,							/* U+000E57 */
+	0,							/* U+000E58 */
+	0,							/* U+000E59 */
+	0,							/* U+000E5A */
+	0,							/* U+000E5B */
+	0,							/* U+000E5C */
+	0,							/* U+000E5D */
+	0,							/* U+000E5E */
+	0,							/* U+000E5F */
+	0,							/* U+000E60 */
+	0,							/* U+000E61 */
+	0,							/* U+000E62 */
+	0,							/* U+000E63 */
+	0,							/* U+000E64 */
+	0,							/* U+000E65 */
+	0,							/* U+000E66 */
+	0,							/* U+000E67 */
+	0,							/* U+000E68 */
+	0,							/* U+000E69 */
+	0,							/* U+000E6A */
+	0,							/* U+000E6B */
+	0,							/* U+000E6C */
+	0,							/* U+000E6D */
+	0,							/* U+000E6E */
+	0,							/* U+000E6F */
+	0,							/* U+000E70 */
+	0,							/* U+000E71 */
+	0,							/* U+000E72 */
+	0,							/* U+000E73 */
+	0,							/* U+000E74 */
+	0,							/* U+000E75 */
+	0,							/* U+000E76 */
+	0,							/* U+000E77 */
+	0,							/* U+000E78 */
+	0,							/* U+000E79 */
+	0,							/* U+000E7A */
+	0,							/* U+000E7B */
+	0,							/* U+000E7C */
+	0,							/* U+000E7D */
+	0,							/* U+000E7E */
+	0,							/* U+000E7F */
+	0,							/* U+000E80 */
+	0,							/* U+000E81 */
+	0,							/* U+000E82 */
+	0,							/* U+000E83 */
+	0,							/* U+000E84 */
+	0,							/* U+000E85 */
+	0,							/* U+000E86 */
+	0,							/* U+000E87 */
+	0,							/* U+000E88 */
+	0,							/* U+000E89 */
+	0,							/* U+000E8A */
+	0,							/* U+000E8B */
+	0,							/* U+000E8C */
+	0,							/* U+000E8D */
+	0,							/* U+000E8E */
+	0,							/* U+000E8F */
+	0,							/* U+000E90 */
+	0,							/* U+000E91 */
+	0,							/* U+000E92 */
+	0,							/* U+000E93 */
+	0,							/* U+000E94 */
+	0,							/* U+000E95 */
+	0,							/* U+000E96 */
+	0,							/* U+000E97 */
+	0,							/* U+000E98 */
+	0,							/* U+000E99 */
+	0,							/* U+000E9A */
+	0,							/* U+000E9B */
+	0,							/* U+000E9C */
+	0,							/* U+000E9D */
+	0,							/* U+000E9E */
+	0,							/* U+000E9F */
+	0,							/* U+000EA0 */
+	0,							/* U+000EA1 */
+	0,							/* U+000EA2 */
+	0,							/* U+000EA3 */
+	0,							/* U+000EA4 */
+	0,							/* U+000EA5 */
+	0,							/* U+000EA6 */
+	0,							/* U+000EA7 */
+	0,							/* U+000EA8 */
+	0,							/* U+000EA9 */
+	0,							/* U+000EAA */
+	0,							/* U+000EAB */
+	0,							/* U+000EAC */
+	0,							/* U+000EAD */
+	0,							/* U+000EAE */
+	0,							/* U+000EAF */
+	0,							/* U+000EB0 */
+	0,							/* U+000EB1 */
+	0,							/* U+000EB2 */
+	0,							/* U+000EB3 */
+	0,							/* U+000EB4 */
+	0,							/* U+000EB5 */
+	0,							/* U+000EB6 */
+	0,							/* U+000EB7 */
+	0,							/* U+000EB8 */
+	0,							/* U+000EB9 */
+	0,							/* U+000EBA */
+	0,							/* U+000EBB */
+	0,							/* U+000EBC */
+	0,							/* U+000EBD */
+	0,							/* U+000EBE */
+	0,							/* U+000EBF */
+	0,							/* U+000EC0 */
+	0,							/* U+000EC1 */
+	0,							/* U+000EC2 */
+	0,							/* U+000EC3 */
+	0,							/* U+000EC4 */
+	0,							/* U+000EC5 */
+	0,							/* U+000EC6 */
+	0,							/* U+000EC7 */
+	0,							/* U+000EC8 */
+	0,							/* U+000EC9 */
+	0,							/* U+000ECA */
+	0,							/* U+000ECB */
+	0,							/* U+000ECC */
+	0,							/* U+000ECD */
+	0,							/* U+000ECE */
+	0,							/* U+000ECF */
+	0,							/* U+000ED0 */
+	0,							/* U+000ED1 */
+	0,							/* U+000ED2 */
+	0,							/* U+000ED3 */
+	0,							/* U+000ED4 */
+	0,							/* U+000ED5 */
+	0,							/* U+000ED6 */
+	0,							/* U+000ED7 */
+	0,							/* U+000ED8 */
+	0,							/* U+000ED9 */
+	0,							/* U+000EDA */
+	0,							/* U+000EDB */
+	0,							/* U+000EDC */
+	0,							/* U+000EDD */
+	0,							/* U+000EDE */
+	0,							/* U+000EDF */
+	0,							/* U+000EE0 */
+	0,							/* U+000EE1 */
+	0,							/* U+000EE2 */
+	0,							/* U+000EE3 */
+	0,							/* U+000EE4 */
+	0,							/* U+000EE5 */
+	0,							/* U+000EE6 */
+	0,							/* U+000EE7 */
+	0,							/* U+000EE8 */
+	0,							/* U+000EE9 */
+	0,							/* U+000EEA */
+	0,							/* U+000EEB */
+	0,							/* U+000EEC */
+	0,							/* U+000EED */
+	0,							/* U+000EEE */
+	0,							/* U+000EEF */
+	0,							/* U+000EF0 */
+	0,							/* U+000EF1 */
+	0,							/* U+000EF2 */
+	0,							/* U+000EF3 */
+	0,							/* U+000EF4 */
+	0,							/* U+000EF5 */
+	0,							/* U+000EF6 */
+	0,							/* U+000EF7 */
+	0,							/* U+000EF8 */
+	0,							/* U+000EF9 */
+	0,							/* U+000EFA */
+	0,							/* U+000EFB */
+	0,							/* U+000EFC */
+	0,							/* U+000EFD */
+	0,							/* U+000EFE */
+	0,							/* U+000EFF */
+	0,							/* U+000F00 */
+	0,							/* U+000F01 */
+	0,							/* U+000F02 */
+	0,							/* U+000F03 */
+	0,							/* U+000F04 */
+	0,							/* U+000F05 */
+	0,							/* U+000F06 */
+	0,							/* U+000F07 */
+	0,							/* U+000F08 */
+	0,							/* U+000F09 */
+	0,							/* U+000F0A */
+	0,							/* U+000F0B */
+	0,							/* U+000F0C */
+	0,							/* U+000F0D */
+	0,							/* U+000F0E */
+	0,							/* U+000F0F */
+	0,							/* U+000F10 */
+	0,							/* U+000F11 */
+	0,							/* U+000F12 */
+	0,							/* U+000F13 */
+	0,							/* U+000F14 */
+	0,							/* U+000F15 */
+	0,							/* U+000F16 */
+	0,							/* U+000F17 */
+	0,							/* U+000F18 */
+	0,							/* U+000F19 */
+	0,							/* U+000F1A */
+	0,							/* U+000F1B */
+	0,							/* U+000F1C */
+	0,							/* U+000F1D */
+	0,							/* U+000F1E */
+	0,							/* U+000F1F */
+	0,							/* U+000F20 */
+	0,							/* U+000F21 */
+	0,							/* U+000F22 */
+	0,							/* U+000F23 */
+	0,							/* U+000F24 */
+	0,							/* U+000F25 */
+	0,							/* U+000F26 */
+	0,							/* U+000F27 */
+	0,							/* U+000F28 */
+	0,							/* U+000F29 */
+	0,							/* U+000F2A */
+	0,							/* U+000F2B */
+	0,							/* U+000F2C */
+	0,							/* U+000F2D */
+	0,							/* U+000F2E */
+	0,							/* U+000F2F */
+	0,							/* U+000F30 */
+	0,							/* U+000F31 */
+	0,							/* U+000F32 */
+	0,							/* U+000F33 */
+	0,							/* U+000F34 */
+	0,							/* U+000F35 */
+	0,							/* U+000F36 */
+	0,							/* U+000F37 */
+	0,							/* U+000F38 */
+	0,							/* U+000F39 */
+	0,							/* U+000F3A */
+	0,							/* U+000F3B */
+	0,							/* U+000F3C */
+	0,							/* U+000F3D */
+	0,							/* U+000F3E */
+	0,							/* U+000F3F */
+	0,							/* U+000F40 */
+	0,							/* U+000F41 */
+	0,							/* U+000F42 */
+	0,							/* U+000F43 */
+	0,							/* U+000F44 */
+	0,							/* U+000F45 */
+	0,							/* U+000F46 */
+	0,							/* U+000F47 */
+	0,							/* U+000F48 */
+	0,							/* U+000F49 */
+	0,							/* U+000F4A */
+	0,							/* U+000F4B */
+	0,							/* U+000F4C */
+	0,							/* U+000F4D */
+	0,							/* U+000F4E */
+	0,							/* U+000F4F */
+	0,							/* U+000F50 */
+	0,							/* U+000F51 */
+	0,							/* U+000F52 */
+	0,							/* U+000F53 */
+	0,							/* U+000F54 */
+	0,							/* U+000F55 */
+	0,							/* U+000F56 */
+	0,							/* U+000F57 */
+	0,							/* U+000F58 */
+	0,							/* U+000F59 */
+	0,							/* U+000F5A */
+	0,							/* U+000F5B */
+	0,							/* U+000F5C */
+	0,							/* U+000F5D */
+	0,							/* U+000F5E */
+	0,							/* U+000F5F */
+	0,							/* U+000F60 */
+	0,							/* U+000F61 */
+	0,							/* U+000F62 */
+	0,							/* U+000F63 */
+	0,							/* U+000F64 */
+	0,							/* U+000F65 */
+	0,							/* U+000F66 */
+	0,							/* U+000F67 */
+	0,							/* U+000F68 */
+	0,							/* U+000F69 */
+	0,							/* U+000F6A */
+	0,							/* U+000F6B */
+	0,							/* U+000F6C */
+	0,							/* U+000F6D */
+	0,							/* U+000F6E */
+	0,							/* U+000F6F */
+	0,							/* U+000F70 */
+	0,							/* U+000F71 */
+	0,							/* U+000F72 */
+	0,							/* U+000F73 */
+	0,							/* U+000F74 */
+	0,							/* U+000F75 */
+	0,							/* U+000F76 */
+	0,							/* U+000F77 */
+	0,							/* U+000F78 */
+	0,							/* U+000F79 */
+	0,							/* U+000F7A */
+	0,							/* U+000F7B */
+	0,							/* U+000F7C */
+	0,							/* U+000F7D */
+	0,							/* U+000F7E */
+	0,							/* U+000F7F */
+	0,							/* U+000F80 */
+	0,							/* U+000F81 */
+	0,							/* U+000F82 */
+	0,							/* U+000F83 */
+	0,							/* U+000F84 */
+	0,							/* U+000F85 */
+	0,							/* U+000F86 */
+	0,							/* U+000F87 */
+	0,							/* U+000F88 */
+	0,							/* U+000F89 */
+	0,							/* U+000F8A */
+	0,							/* U+000F8B */
+	0,							/* U+000F8C */
+	0,							/* U+000F8D */
+	0,							/* U+000F8E */
+	0,							/* U+000F8F */
+	0,							/* U+000F90 */
+	0,							/* U+000F91 */
+	0,							/* U+000F92 */
+	0,							/* U+000F93 */
+	0,							/* U+000F94 */
+	0,							/* U+000F95 */
+	0,							/* U+000F96 */
+	0,							/* U+000F97 */
+	0,							/* U+000F98 */
+	0,							/* U+000F99 */
+	0,							/* U+000F9A */
+	0,							/* U+000F9B */
+	0,							/* U+000F9C */
+	0,							/* U+000F9D */
+	0,							/* U+000F9E */
+	0,							/* U+000F9F */
+	0,							/* U+000FA0 */
+	0,							/* U+000FA1 */
+	0,							/* U+000FA2 */
+	0,							/* U+000FA3 */
+	0,							/* U+000FA4 */
+	0,							/* U+000FA5 */
+	0,							/* U+000FA6 */
+	0,							/* U+000FA7 */
+	0,							/* U+000FA8 */
+	0,							/* U+000FA9 */
+	0,							/* U+000FAA */
+	0,							/* U+000FAB */
+	0,							/* U+000FAC */
+	0,							/* U+000FAD */
+	0,							/* U+000FAE */
+	0,							/* U+000FAF */
+	0,							/* U+000FB0 */
+	0,							/* U+000FB1 */
+	0,							/* U+000FB2 */
+	0,							/* U+000FB3 */
+	0,							/* U+000FB4 */
+	0,							/* U+000FB5 */
+	0,							/* U+000FB6 */
+	0,							/* U+000FB7 */
+	0,							/* U+000FB8 */
+	0,							/* U+000FB9 */
+	0,							/* U+000FBA */
+	0,							/* U+000FBB */
+	0,							/* U+000FBC */
+	0,							/* U+000FBD */
+	0,							/* U+000FBE */
+	0,							/* U+000FBF */
+	0,							/* U+000FC0 */
+	0,							/* U+000FC1 */
+	0,							/* U+000FC2 */
+	0,							/* U+000FC3 */
+	0,							/* U+000FC4 */
+	0,							/* U+000FC5 */
+	0,							/* U+000FC6 */
+	0,							/* U+000FC7 */
+	0,							/* U+000FC8 */
+	0,							/* U+000FC9 */
+	0,							/* U+000FCA */
+	0,							/* U+000FCB */
+	0,							/* U+000FCC */
+	0,							/* U+000FCD */
+	0,							/* U+000FCE */
+	0,							/* U+000FCF */
+	0,							/* U+000FD0 */
+	0,							/* U+000FD1 */
+	0,							/* U+000FD2 */
+	0,							/* U+000FD3 */
+	0,							/* U+000FD4 */
+	0,							/* U+000FD5 */
+	0,							/* U+000FD6 */
+	0,							/* U+000FD7 */
+	0,							/* U+000FD8 */
+	0,							/* U+000FD9 */
+	0,							/* U+000FDA */
+	0,							/* U+000FDB */
+	0,							/* U+000FDC */
+	0,							/* U+000FDD */
+	0,							/* U+000FDE */
+	0,							/* U+000FDF */
+	0,							/* U+000FE0 */
+	0,							/* U+000FE1 */
+	0,							/* U+000FE2 */
+	0,							/* U+000FE3 */
+	0,							/* U+000FE4 */
+	0,							/* U+000FE5 */
+	0,							/* U+000FE6 */
+	0,							/* U+000FE7 */
+	0,							/* U+000FE8 */
+	0,							/* U+000FE9 */
+	0,							/* U+000FEA */
+	0,							/* U+000FEB */
+	0,							/* U+000FEC */
+	0,							/* U+000FED */
+	0,							/* U+000FEE */
+	0,							/* U+000FEF */
+	0,							/* U+000FF0 */
+	0,							/* U+000FF1 */
+	0,							/* U+000FF2 */
+	0,							/* U+000FF3 */
+	0,							/* U+000FF4 */
+	0,							/* U+000FF5 */
+	0,							/* U+000FF6 */
+	0,							/* U+000FF7 */
+	0,							/* U+000FF8 */
+	0,							/* U+000FF9 */
+	0,							/* U+000FFA */
+	0,							/* U+000FFB */
+	0,							/* U+000FFC */
+	0,							/* U+000FFD */
+	0,							/* U+000FFE */
+	0,							/* U+000FFF */
+	0,							/* U+001000 */
+	0,							/* U+001001 */
+	0,							/* U+001002 */
+	0,							/* U+001003 */
+	0,							/* U+001004 */
+	0,							/* U+001005 */
+	0,							/* U+001006 */
+	0,							/* U+001007 */
+	0,							/* U+001008 */
+	0,							/* U+001009 */
+	0,							/* U+00100A */
+	0,							/* U+00100B */
+	0,							/* U+00100C */
+	0,							/* U+00100D */
+	0,							/* U+00100E */
+	0,							/* U+00100F */
+	0,							/* U+001010 */
+	0,							/* U+001011 */
+	0,							/* U+001012 */
+	0,							/* U+001013 */
+	0,							/* U+001014 */
+	0,							/* U+001015 */
+	0,							/* U+001016 */
+	0,							/* U+001017 */
+	0,							/* U+001018 */
+	0,							/* U+001019 */
+	0,							/* U+00101A */
+	0,							/* U+00101B */
+	0,							/* U+00101C */
+	0,							/* U+00101D */
+	0,							/* U+00101E */
+	0,							/* U+00101F */
+	0,							/* U+001020 */
+	0,							/* U+001021 */
+	0,							/* U+001022 */
+	0,							/* U+001023 */
+	0,							/* U+001024 */
+	3861,						/* U+001025 */
+	3865,						/* U+001B05 */
+	0,							/* U+001B06 */
+	3869,						/* U+001B07 */
+	0,							/* U+001B08 */
+	3873,						/* U+001B09 */
+	0,							/* U+001B0A */
+	3877,						/* U+001B0B */
+	0,							/* U+001B0C */
+	3881,						/* U+001B0D */
+	0,							/* U+001B0E */
+	0,							/* U+001B0F */
+	0,							/* U+001B10 */
+	3885,						/* U+001B11 */
+	0,							/* U+001B12 */
+	0,							/* U+001B13 */
+	0,							/* U+001B14 */
+	0,							/* U+001B15 */
+	0,							/* U+001B16 */
+	0,							/* U+001B17 */
+	0,							/* U+001B18 */
+	0,							/* U+001B19 */
+	0,							/* U+001B1A */
+	0,							/* U+001B1B */
+	0,							/* U+001B1C */
+	0,							/* U+001B1D */
+	0,							/* U+001B1E */
+	0,							/* U+001B1F */
+	0,							/* U+001B20 */
+	0,							/* U+001B21 */
+	0,							/* U+001B22 */
+	0,							/* U+001B23 */
+	0,							/* U+001B24 */
+	0,							/* U+001B25 */
+	0,							/* U+001B26 */
+	0,							/* U+001B27 */
+	0,							/* U+001B28 */
+	0,							/* U+001B29 */
+	0,							/* U+001B2A */
+	0,							/* U+001B2B */
+	0,							/* U+001B2C */
+	0,							/* U+001B2D */
+	0,							/* U+001B2E */
+	0,							/* U+001B2F */
+	0,							/* U+001B30 */
+	0,							/* U+001B31 */
+	0,							/* U+001B32 */
+	0,							/* U+001B33 */
+	0,							/* U+001B34 */
+	0,							/* U+001B35 */
+	0,							/* U+001B36 */
+	0,							/* U+001B37 */
+	0,							/* U+001B38 */
+	0,							/* U+001B39 */
+	3889,						/* U+001B3A */
+	0,							/* U+001B3B */
+	3893,						/* U+001B3C */
+	0,							/* U+001B3D */
+	3897,						/* U+001B3E */
+	3901,						/* U+001B3F */
+	0,							/* U+001B40 */
+	0,							/* U+001B41 */
+	3905,						/* U+001B42 */
+	0,							/* U+001B43 */
+	0,							/* U+001B44 */
+	0,							/* U+001B45 */
+	0,							/* U+001B46 */
+	0,							/* U+001B47 */
+	0,							/* U+001B48 */
+	0,							/* U+001B49 */
+	0,							/* U+001B4A */
+	0,							/* U+001B4B */
+	0,							/* U+001B4C */
+	0,							/* U+001B4D */
+	0,							/* U+001B4E */
+	0,							/* U+001B4F */
+	0,							/* U+001B50 */
+	0,							/* U+001B51 */
+	0,							/* U+001B52 */
+	0,							/* U+001B53 */
+	0,							/* U+001B54 */
+	0,							/* U+001B55 */
+	0,							/* U+001B56 */
+	0,							/* U+001B57 */
+	0,							/* U+001B58 */
+	0,							/* U+001B59 */
+	0,							/* U+001B5A */
+	0,							/* U+001B5B */
+	0,							/* U+001B5C */
+	0,							/* U+001B5D */
+	0,							/* U+001B5E */
+	0,							/* U+001B5F */
+	0,							/* U+001B60 */
+	0,							/* U+001B61 */
+	0,							/* U+001B62 */
+	0,							/* U+001B63 */
+	0,							/* U+001B64 */
+	0,							/* U+001B65 */
+	0,							/* U+001B66 */
+	0,							/* U+001B67 */
+	0,							/* U+001B68 */
+	0,							/* U+001B69 */
+	0,							/* U+001B6A */
+	0,							/* U+001B6B */
+	0,							/* U+001B6C */
+	0,							/* U+001B6D */
+	0,							/* U+001B6E */
+	0,							/* U+001B6F */
+	0,							/* U+001B70 */
+	0,							/* U+001B71 */
+	0,							/* U+001B72 */
+	0,							/* U+001B73 */
+	0,							/* U+001B74 */
+	0,							/* U+001B75 */
+	0,							/* U+001B76 */
+	0,							/* U+001B77 */
+	0,							/* U+001B78 */
+	0,							/* U+001B79 */
+	0,							/* U+001B7A */
+	0,							/* U+001B7B */
+	0,							/* U+001B7C */
+	0,							/* U+001B7D */
+	0,							/* U+001B7E */
+	0,							/* U+001B7F */
+	0,							/* U+001B80 */
+	0,							/* U+001B81 */
+	0,							/* U+001B82 */
+	0,							/* U+001B83 */
+	0,							/* U+001B84 */
+	0,							/* U+001B85 */
+	0,							/* U+001B86 */
+	0,							/* U+001B87 */
+	0,							/* U+001B88 */
+	0,							/* U+001B89 */
+	0,							/* U+001B8A */
+	0,							/* U+001B8B */
+	0,							/* U+001B8C */
+	0,							/* U+001B8D */
+	0,							/* U+001B8E */
+	0,							/* U+001B8F */
+	0,							/* U+001B90 */
+	0,							/* U+001B91 */
+	0,							/* U+001B92 */
+	0,							/* U+001B93 */
+	0,							/* U+001B94 */
+	0,							/* U+001B95 */
+	0,							/* U+001B96 */
+	0,							/* U+001B97 */
+	0,							/* U+001B98 */
+	0,							/* U+001B99 */
+	0,							/* U+001B9A */
+	0,							/* U+001B9B */
+	0,							/* U+001B9C */
+	0,							/* U+001B9D */
+	0,							/* U+001B9E */
+	0,							/* U+001B9F */
+	0,							/* U+001BA0 */
+	0,							/* U+001BA1 */
+	0,							/* U+001BA2 */
+	0,							/* U+001BA3 */
+	0,							/* U+001BA4 */
+	0,							/* U+001BA5 */
+	0,							/* U+001BA6 */
+	0,							/* U+001BA7 */
+	0,							/* U+001BA8 */
+	0,							/* U+001BA9 */
+	0,							/* U+001BAA */
+	0,							/* U+001BAB */
+	0,							/* U+001BAC */
+	0,							/* U+001BAD */
+	0,							/* U+001BAE */
+	0,							/* U+001BAF */
+	0,							/* U+001BB0 */
+	0,							/* U+001BB1 */
+	0,							/* U+001BB2 */
+	0,							/* U+001BB3 */
+	0,							/* U+001BB4 */
+	0,							/* U+001BB5 */
+	0,							/* U+001BB6 */
+	0,							/* U+001BB7 */
+	0,							/* U+001BB8 */
+	0,							/* U+001BB9 */
+	0,							/* U+001BBA */
+	0,							/* U+001BBB */
+	0,							/* U+001BBC */
+	0,							/* U+001BBD */
+	0,							/* U+001BBE */
+	0,							/* U+001BBF */
+	0,							/* U+001BC0 */
+	0,							/* U+001BC1 */
+	0,							/* U+001BC2 */
+	0,							/* U+001BC3 */
+	0,							/* U+001BC4 */
+	0,							/* U+001BC5 */
+	0,							/* U+001BC6 */
+	0,							/* U+001BC7 */
+	0,							/* U+001BC8 */
+	0,							/* U+001BC9 */
+	0,							/* U+001BCA */
+	0,							/* U+001BCB */
+	0,							/* U+001BCC */
+	0,							/* U+001BCD */
+	0,							/* U+001BCE */
+	0,							/* U+001BCF */
+	0,							/* U+001BD0 */
+	0,							/* U+001BD1 */
+	0,							/* U+001BD2 */
+	0,							/* U+001BD3 */
+	0,							/* U+001BD4 */
+	0,							/* U+001BD5 */
+	0,							/* U+001BD6 */
+	0,							/* U+001BD7 */
+	0,							/* U+001BD8 */
+	0,							/* U+001BD9 */
+	0,							/* U+001BDA */
+	0,							/* U+001BDB */
+	0,							/* U+001BDC */
+	0,							/* U+001BDD */
+	0,							/* U+001BDE */
+	0,							/* U+001BDF */
+	0,							/* U+001BE0 */
+	0,							/* U+001BE1 */
+	0,							/* U+001BE2 */
+	0,							/* U+001BE3 */
+	0,							/* U+001BE4 */
+	0,							/* U+001BE5 */
+	0,							/* U+001BE6 */
+	0,							/* U+001BE7 */
+	0,							/* U+001BE8 */
+	0,							/* U+001BE9 */
+	0,							/* U+001BEA */
+	0,							/* U+001BEB */
+	0,							/* U+001BEC */
+	0,							/* U+001BED */
+	0,							/* U+001BEE */
+	0,							/* U+001BEF */
+	0,							/* U+001BF0 */
+	0,							/* U+001BF1 */
+	0,							/* U+001BF2 */
+	0,							/* U+001BF3 */
+	0,							/* U+001BF4 */
+	0,							/* U+001BF5 */
+	0,							/* U+001BF6 */
+	0,							/* U+001BF7 */
+	0,							/* U+001BF8 */
+	0,							/* U+001BF9 */
+	0,							/* U+001BFA */
+	0,							/* U+001BFB */
+	0,							/* U+001BFC */
+	0,							/* U+001BFD */
+	0,							/* U+001BFE */
+	0,							/* U+001BFF */
+	0,							/* U+001C00 */
+	0,							/* U+001C01 */
+	0,							/* U+001C02 */
+	0,							/* U+001C03 */
+	0,							/* U+001C04 */
+	0,							/* U+001C05 */
+	0,							/* U+001C06 */
+	0,							/* U+001C07 */
+	0,							/* U+001C08 */
+	0,							/* U+001C09 */
+	0,							/* U+001C0A */
+	0,							/* U+001C0B */
+	0,							/* U+001C0C */
+	0,							/* U+001C0D */
+	0,							/* U+001C0E */
+	0,							/* U+001C0F */
+	0,							/* U+001C10 */
+	0,							/* U+001C11 */
+	0,							/* U+001C12 */
+	0,							/* U+001C13 */
+	0,							/* U+001C14 */
+	0,							/* U+001C15 */
+	0,							/* U+001C16 */
+	0,							/* U+001C17 */
+	0,							/* U+001C18 */
+	0,							/* U+001C19 */
+	0,							/* U+001C1A */
+	0,							/* U+001C1B */
+	0,							/* U+001C1C */
+	0,							/* U+001C1D */
+	0,							/* U+001C1E */
+	0,							/* U+001C1F */
+	0,							/* U+001C20 */
+	0,							/* U+001C21 */
+	0,							/* U+001C22 */
+	0,							/* U+001C23 */
+	0,							/* U+001C24 */
+	0,							/* U+001C25 */
+	0,							/* U+001C26 */
+	0,							/* U+001C27 */
+	0,							/* U+001C28 */
+	0,							/* U+001C29 */
+	0,							/* U+001C2A */
+	0,							/* U+001C2B */
+	0,							/* U+001C2C */
+	0,							/* U+001C2D */
+	0,							/* U+001C2E */
+	0,							/* U+001C2F */
+	0,							/* U+001C30 */
+	0,							/* U+001C31 */
+	0,							/* U+001C32 */
+	0,							/* U+001C33 */
+	0,							/* U+001C34 */
+	0,							/* U+001C35 */
+	0,							/* U+001C36 */
+	0,							/* U+001C37 */
+	0,							/* U+001C38 */
+	0,							/* U+001C39 */
+	0,							/* U+001C3A */
+	0,							/* U+001C3B */
+	0,							/* U+001C3C */
+	0,							/* U+001C3D */
+	0,							/* U+001C3E */
+	0,							/* U+001C3F */
+	0,							/* U+001C40 */
+	0,							/* U+001C41 */
+	0,							/* U+001C42 */
+	0,							/* U+001C43 */
+	0,							/* U+001C44 */
+	0,							/* U+001C45 */
+	0,							/* U+001C46 */
+	0,							/* U+001C47 */
+	0,							/* U+001C48 */
+	0,							/* U+001C49 */
+	0,							/* U+001C4A */
+	0,							/* U+001C4B */
+	0,							/* U+001C4C */
+	0,							/* U+001C4D */
+	0,							/* U+001C4E */
+	0,							/* U+001C4F */
+	0,							/* U+001C50 */
+	0,							/* U+001C51 */
+	0,							/* U+001C52 */
+	0,							/* U+001C53 */
+	0,							/* U+001C54 */
+	0,							/* U+001C55 */
+	0,							/* U+001C56 */
+	0,							/* U+001C57 */
+	0,							/* U+001C58 */
+	0,							/* U+001C59 */
+	0,							/* U+001C5A */
+	0,							/* U+001C5B */
+	0,							/* U+001C5C */
+	0,							/* U+001C5D */
+	0,							/* U+001C5E */
+	0,							/* U+001C5F */
+	0,							/* U+001C60 */
+	0,							/* U+001C61 */
+	0,							/* U+001C62 */
+	0,							/* U+001C63 */
+	0,							/* U+001C64 */
+	0,							/* U+001C65 */
+	0,							/* U+001C66 */
+	0,							/* U+001C67 */
+	0,							/* U+001C68 */
+	0,							/* U+001C69 */
+	0,							/* U+001C6A */
+	0,							/* U+001C6B */
+	0,							/* U+001C6C */
+	0,							/* U+001C6D */
+	0,							/* U+001C6E */
+	0,							/* U+001C6F */
+	0,							/* U+001C70 */
+	0,							/* U+001C71 */
+	0,							/* U+001C72 */
+	0,							/* U+001C73 */
+	0,							/* U+001C74 */
+	0,							/* U+001C75 */
+	0,							/* U+001C76 */
+	0,							/* U+001C77 */
+	0,							/* U+001C78 */
+	0,							/* U+001C79 */
+	0,							/* U+001C7A */
+	0,							/* U+001C7B */
+	0,							/* U+001C7C */
+	0,							/* U+001C7D */
+	0,							/* U+001C7E */
+	0,							/* U+001C7F */
+	0,							/* U+001C80 */
+	0,							/* U+001C81 */
+	0,							/* U+001C82 */
+	0,							/* U+001C83 */
+	0,							/* U+001C84 */
+	0,							/* U+001C85 */
+	0,							/* U+001C86 */
+	0,							/* U+001C87 */
+	0,							/* U+001C88 */
+	0,							/* U+001C89 */
+	0,							/* U+001C8A */
+	0,							/* U+001C8B */
+	0,							/* U+001C8C */
+	0,							/* U+001C8D */
+	0,							/* U+001C8E */
+	0,							/* U+001C8F */
+	0,							/* U+001C90 */
+	0,							/* U+001C91 */
+	0,							/* U+001C92 */
+	0,							/* U+001C93 */
+	0,							/* U+001C94 */
+	0,							/* U+001C95 */
+	0,							/* U+001C96 */
+	0,							/* U+001C97 */
+	0,							/* U+001C98 */
+	0,							/* U+001C99 */
+	0,							/* U+001C9A */
+	0,							/* U+001C9B */
+	0,							/* U+001C9C */
+	0,							/* U+001C9D */
+	0,							/* U+001C9E */
+	0,							/* U+001C9F */
+	0,							/* U+001CA0 */
+	0,							/* U+001CA1 */
+	0,							/* U+001CA2 */
+	0,							/* U+001CA3 */
+	0,							/* U+001CA4 */
+	0,							/* U+001CA5 */
+	0,							/* U+001CA6 */
+	0,							/* U+001CA7 */
+	0,							/* U+001CA8 */
+	0,							/* U+001CA9 */
+	0,							/* U+001CAA */
+	0,							/* U+001CAB */
+	0,							/* U+001CAC */
+	0,							/* U+001CAD */
+	0,							/* U+001CAE */
+	0,							/* U+001CAF */
+	0,							/* U+001CB0 */
+	0,							/* U+001CB1 */
+	0,							/* U+001CB2 */
+	0,							/* U+001CB3 */
+	0,							/* U+001CB4 */
+	0,							/* U+001CB5 */
+	0,							/* U+001CB6 */
+	0,							/* U+001CB7 */
+	0,							/* U+001CB8 */
+	0,							/* U+001CB9 */
+	0,							/* U+001CBA */
+	0,							/* U+001CBB */
+	0,							/* U+001CBC */
+	0,							/* U+001CBD */
+	0,							/* U+001CBE */
+	0,							/* U+001CBF */
+	0,							/* U+001CC0 */
+	0,							/* U+001CC1 */
+	0,							/* U+001CC2 */
+	0,							/* U+001CC3 */
+	0,							/* U+001CC4 */
+	0,							/* U+001CC5 */
+	0,							/* U+001CC6 */
+	0,							/* U+001CC7 */
+	0,							/* U+001CC8 */
+	0,							/* U+001CC9 */
+	0,							/* U+001CCA */
+	0,							/* U+001CCB */
+	0,							/* U+001CCC */
+	0,							/* U+001CCD */
+	0,							/* U+001CCE */
+	0,							/* U+001CCF */
+	0,							/* U+001CD0 */
+	0,							/* U+001CD1 */
+	0,							/* U+001CD2 */
+	0,							/* U+001CD3 */
+	0,							/* U+001CD4 */
+	0,							/* U+001CD5 */
+	0,							/* U+001CD6 */
+	0,							/* U+001CD7 */
+	0,							/* U+001CD8 */
+	0,							/* U+001CD9 */
+	0,							/* U+001CDA */
+	0,							/* U+001CDB */
+	0,							/* U+001CDC */
+	0,							/* U+001CDD */
+	0,							/* U+001CDE */
+	0,							/* U+001CDF */
+	0,							/* U+001CE0 */
+	0,							/* U+001CE1 */
+	0,							/* U+001CE2 */
+	0,							/* U+001CE3 */
+	0,							/* U+001CE4 */
+	0,							/* U+001CE5 */
+	0,							/* U+001CE6 */
+	0,							/* U+001CE7 */
+	0,							/* U+001CE8 */
+	0,							/* U+001CE9 */
+	0,							/* U+001CEA */
+	0,							/* U+001CEB */
+	0,							/* U+001CEC */
+	0,							/* U+001CED */
+	0,							/* U+001CEE */
+	0,							/* U+001CEF */
+	0,							/* U+001CF0 */
+	0,							/* U+001CF1 */
+	0,							/* U+001CF2 */
+	0,							/* U+001CF3 */
+	0,							/* U+001CF4 */
+	0,							/* U+001CF5 */
+	0,							/* U+001CF6 */
+	0,							/* U+001CF7 */
+	0,							/* U+001CF8 */
+	0,							/* U+001CF9 */
+	0,							/* U+001CFA */
+	0,							/* U+001CFB */
+	0,							/* U+001CFC */
+	0,							/* U+001CFD */
+	0,							/* U+001CFE */
+	0,							/* U+001CFF */
+	0,							/* U+001D00 */
+	0,							/* U+001D01 */
+	0,							/* U+001D02 */
+	0,							/* U+001D03 */
+	0,							/* U+001D04 */
+	0,							/* U+001D05 */
+	0,							/* U+001D06 */
+	0,							/* U+001D07 */
+	0,							/* U+001D08 */
+	0,							/* U+001D09 */
+	0,							/* U+001D0A */
+	0,							/* U+001D0B */
+	0,							/* U+001D0C */
+	0,							/* U+001D0D */
+	0,							/* U+001D0E */
+	0,							/* U+001D0F */
+	0,							/* U+001D10 */
+	0,							/* U+001D11 */
+	0,							/* U+001D12 */
+	0,							/* U+001D13 */
+	0,							/* U+001D14 */
+	0,							/* U+001D15 */
+	0,							/* U+001D16 */
+	0,							/* U+001D17 */
+	0,							/* U+001D18 */
+	0,							/* U+001D19 */
+	0,							/* U+001D1A */
+	0,							/* U+001D1B */
+	0,							/* U+001D1C */
+	0,							/* U+001D1D */
+	0,							/* U+001D1E */
+	0,							/* U+001D1F */
+	0,							/* U+001D20 */
+	0,							/* U+001D21 */
+	0,							/* U+001D22 */
+	0,							/* U+001D23 */
+	0,							/* U+001D24 */
+	0,							/* U+001D25 */
+	0,							/* U+001D26 */
+	0,							/* U+001D27 */
+	0,							/* U+001D28 */
+	0,							/* U+001D29 */
+	0,							/* U+001D2A */
+	0,							/* U+001D2B */
+	0,							/* U+001D2C */
+	0,							/* U+001D2D */
+	0,							/* U+001D2E */
+	0,							/* U+001D2F */
+	0,							/* U+001D30 */
+	0,							/* U+001D31 */
+	0,							/* U+001D32 */
+	0,							/* U+001D33 */
+	0,							/* U+001D34 */
+	0,							/* U+001D35 */
+	0,							/* U+001D36 */
+	0,							/* U+001D37 */
+	0,							/* U+001D38 */
+	0,							/* U+001D39 */
+	0,							/* U+001D3A */
+	0,							/* U+001D3B */
+	0,							/* U+001D3C */
+	0,							/* U+001D3D */
+	0,							/* U+001D3E */
+	0,							/* U+001D3F */
+	0,							/* U+001D40 */
+	0,							/* U+001D41 */
+	0,							/* U+001D42 */
+	0,							/* U+001D43 */
+	0,							/* U+001D44 */
+	0,							/* U+001D45 */
+	0,							/* U+001D46 */
+	0,							/* U+001D47 */
+	0,							/* U+001D48 */
+	0,							/* U+001D49 */
+	0,							/* U+001D4A */
+	0,							/* U+001D4B */
+	0,							/* U+001D4C */
+	0,							/* U+001D4D */
+	0,							/* U+001D4E */
+	0,							/* U+001D4F */
+	0,							/* U+001D50 */
+	0,							/* U+001D51 */
+	0,							/* U+001D52 */
+	0,							/* U+001D53 */
+	0,							/* U+001D54 */
+	0,							/* U+001D55 */
+	0,							/* U+001D56 */
+	0,							/* U+001D57 */
+	0,							/* U+001D58 */
+	0,							/* U+001D59 */
+	0,							/* U+001D5A */
+	0,							/* U+001D5B */
+	0,							/* U+001D5C */
+	0,							/* U+001D5D */
+	0,							/* U+001D5E */
+	0,							/* U+001D5F */
+	0,							/* U+001D60 */
+	0,							/* U+001D61 */
+	0,							/* U+001D62 */
+	0,							/* U+001D63 */
+	0,							/* U+001D64 */
+	0,							/* U+001D65 */
+	0,							/* U+001D66 */
+	0,							/* U+001D67 */
+	0,							/* U+001D68 */
+	0,							/* U+001D69 */
+	0,							/* U+001D6A */
+	0,							/* U+001D6B */
+	0,							/* U+001D6C */
+	0,							/* U+001D6D */
+	0,							/* U+001D6E */
+	0,							/* U+001D6F */
+	0,							/* U+001D70 */
+	0,							/* U+001D71 */
+	0,							/* U+001D72 */
+	0,							/* U+001D73 */
+	0,							/* U+001D74 */
+	0,							/* U+001D75 */
+	0,							/* U+001D76 */
+	0,							/* U+001D77 */
+	0,							/* U+001D78 */
+	0,							/* U+001D79 */
+	0,							/* U+001D7A */
+	0,							/* U+001D7B */
+	0,							/* U+001D7C */
+	0,							/* U+001D7D */
+	0,							/* U+001D7E */
+	0,							/* U+001D7F */
+	0,							/* U+001D80 */
+	0,							/* U+001D81 */
+	0,							/* U+001D82 */
+	0,							/* U+001D83 */
+	0,							/* U+001D84 */
+	0,							/* U+001D85 */
+	0,							/* U+001D86 */
+	0,							/* U+001D87 */
+	0,							/* U+001D88 */
+	0,							/* U+001D89 */
+	0,							/* U+001D8A */
+	0,							/* U+001D8B */
+	0,							/* U+001D8C */
+	0,							/* U+001D8D */
+	0,							/* U+001D8E */
+	0,							/* U+001D8F */
+	0,							/* U+001D90 */
+	0,							/* U+001D91 */
+	0,							/* U+001D92 */
+	0,							/* U+001D93 */
+	0,							/* U+001D94 */
+	0,							/* U+001D95 */
+	0,							/* U+001D96 */
+	0,							/* U+001D97 */
+	0,							/* U+001D98 */
+	0,							/* U+001D99 */
+	0,							/* U+001D9A */
+	0,							/* U+001D9B */
+	0,							/* U+001D9C */
+	0,							/* U+001D9D */
+	0,							/* U+001D9E */
+	0,							/* U+001D9F */
+	0,							/* U+001DA0 */
+	0,							/* U+001DA1 */
+	0,							/* U+001DA2 */
+	0,							/* U+001DA3 */
+	0,							/* U+001DA4 */
+	0,							/* U+001DA5 */
+	0,							/* U+001DA6 */
+	0,							/* U+001DA7 */
+	0,							/* U+001DA8 */
+	0,							/* U+001DA9 */
+	0,							/* U+001DAA */
+	0,							/* U+001DAB */
+	0,							/* U+001DAC */
+	0,							/* U+001DAD */
+	0,							/* U+001DAE */
+	0,							/* U+001DAF */
+	0,							/* U+001DB0 */
+	0,							/* U+001DB1 */
+	0,							/* U+001DB2 */
+	0,							/* U+001DB3 */
+	0,							/* U+001DB4 */
+	0,							/* U+001DB5 */
+	0,							/* U+001DB6 */
+	0,							/* U+001DB7 */
+	0,							/* U+001DB8 */
+	0,							/* U+001DB9 */
+	0,							/* U+001DBA */
+	0,							/* U+001DBB */
+	0,							/* U+001DBC */
+	0,							/* U+001DBD */
+	0,							/* U+001DBE */
+	0,							/* U+001DBF */
+	0,							/* U+001DC0 */
+	0,							/* U+001DC1 */
+	0,							/* U+001DC2 */
+	0,							/* U+001DC3 */
+	0,							/* U+001DC4 */
+	0,							/* U+001DC5 */
+	0,							/* U+001DC6 */
+	0,							/* U+001DC7 */
+	0,							/* U+001DC8 */
+	0,							/* U+001DC9 */
+	0,							/* U+001DCA */
+	0,							/* U+001DCB */
+	0,							/* U+001DCC */
+	0,							/* U+001DCD */
+	0,							/* U+001DCE */
+	0,							/* U+001DCF */
+	0,							/* U+001DD0 */
+	0,							/* U+001DD1 */
+	0,							/* U+001DD2 */
+	0,							/* U+001DD3 */
+	0,							/* U+001DD4 */
+	0,							/* U+001DD5 */
+	0,							/* U+001DD6 */
+	0,							/* U+001DD7 */
+	0,							/* U+001DD8 */
+	0,							/* U+001DD9 */
+	0,							/* U+001DDA */
+	0,							/* U+001DDB */
+	0,							/* U+001DDC */
+	0,							/* U+001DDD */
+	0,							/* U+001DDE */
+	0,							/* U+001DDF */
+	0,							/* U+001DE0 */
+	0,							/* U+001DE1 */
+	0,							/* U+001DE2 */
+	0,							/* U+001DE3 */
+	0,							/* U+001DE4 */
+	0,							/* U+001DE5 */
+	0,							/* U+001DE6 */
+	0,							/* U+001DE7 */
+	0,							/* U+001DE8 */
+	0,							/* U+001DE9 */
+	0,							/* U+001DEA */
+	0,							/* U+001DEB */
+	0,							/* U+001DEC */
+	0,							/* U+001DED */
+	0,							/* U+001DEE */
+	0,							/* U+001DEF */
+	0,							/* U+001DF0 */
+	0,							/* U+001DF1 */
+	0,							/* U+001DF2 */
+	0,							/* U+001DF3 */
+	0,							/* U+001DF4 */
+	0,							/* U+001DF5 */
+	0,							/* U+001DF6 */
+	0,							/* U+001DF7 */
+	0,							/* U+001DF8 */
+	0,							/* U+001DF9 */
+	0,							/* U+001DFA */
+	0,							/* U+001DFB */
+	0,							/* U+001DFC */
+	0,							/* U+001DFD */
+	0,							/* U+001DFE */
+	0,							/* U+001DFF */
+	0,							/* U+001E00 */
+	0,							/* U+001E01 */
+	0,							/* U+001E02 */
+	0,							/* U+001E03 */
+	0,							/* U+001E04 */
+	0,							/* U+001E05 */
+	0,							/* U+001E06 */
+	0,							/* U+001E07 */
+	0,							/* U+001E08 */
+	0,							/* U+001E09 */
+	0,							/* U+001E0A */
+	0,							/* U+001E0B */
+	0,							/* U+001E0C */
+	0,							/* U+001E0D */
+	0,							/* U+001E0E */
+	0,							/* U+001E0F */
+	0,							/* U+001E10 */
+	0,							/* U+001E11 */
+	0,							/* U+001E12 */
+	0,							/* U+001E13 */
+	0,							/* U+001E14 */
+	0,							/* U+001E15 */
+	0,							/* U+001E16 */
+	0,							/* U+001E17 */
+	0,							/* U+001E18 */
+	0,							/* U+001E19 */
+	0,							/* U+001E1A */
+	0,							/* U+001E1B */
+	0,							/* U+001E1C */
+	0,							/* U+001E1D */
+	0,							/* U+001E1E */
+	0,							/* U+001E1F */
+	0,							/* U+001E20 */
+	0,							/* U+001E21 */
+	0,							/* U+001E22 */
+	0,							/* U+001E23 */
+	0,							/* U+001E24 */
+	0,							/* U+001E25 */
+	0,							/* U+001E26 */
+	0,							/* U+001E27 */
+	0,							/* U+001E28 */
+	0,							/* U+001E29 */
+	0,							/* U+001E2A */
+	0,							/* U+001E2B */
+	0,							/* U+001E2C */
+	0,							/* U+001E2D */
+	0,							/* U+001E2E */
+	0,							/* U+001E2F */
+	0,							/* U+001E30 */
+	0,							/* U+001E31 */
+	0,							/* U+001E32 */
+	0,							/* U+001E33 */
+	0,							/* U+001E34 */
+	0,							/* U+001E35 */
+	3909,						/* U+001E36 */
+	3913,						/* U+001E37 */
+	0,							/* U+001E38 */
+	0,							/* U+001E39 */
+	0,							/* U+001E3A */
+	0,							/* U+001E3B */
+	0,							/* U+001E3C */
+	0,							/* U+001E3D */
+	0,							/* U+001E3E */
+	0,							/* U+001E3F */
+	0,							/* U+001E40 */
+	0,							/* U+001E41 */
+	0,							/* U+001E42 */
+	0,							/* U+001E43 */
+	0,							/* U+001E44 */
+	0,							/* U+001E45 */
+	0,							/* U+001E46 */
+	0,							/* U+001E47 */
+	0,							/* U+001E48 */
+	0,							/* U+001E49 */
+	0,							/* U+001E4A */
+	0,							/* U+001E4B */
+	0,							/* U+001E4C */
+	0,							/* U+001E4D */
+	0,							/* U+001E4E */
+	0,							/* U+001E4F */
+	0,							/* U+001E50 */
+	0,							/* U+001E51 */
+	0,							/* U+001E52 */
+	0,							/* U+001E53 */
+	0,							/* U+001E54 */
+	0,							/* U+001E55 */
+	0,							/* U+001E56 */
+	0,							/* U+001E57 */
+	0,							/* U+001E58 */
+	0,							/* U+001E59 */
+	3917,						/* U+001E5A */
+	3921,						/* U+001E5B */
+	0,							/* U+001E5C */
+	0,							/* U+001E5D */
+	0,							/* U+001E5E */
+	0,							/* U+001E5F */
+	0,							/* U+001E60 */
+	0,							/* U+001E61 */
+	3925,						/* U+001E62 */
+	3929,						/* U+001E63 */
+	0,							/* U+001E64 */
+	0,							/* U+001E65 */
+	0,							/* U+001E66 */
+	0,							/* U+001E67 */
+	0,							/* U+001E68 */
+	0,							/* U+001E69 */
+	0,							/* U+001E6A */
+	0,							/* U+001E6B */
+	0,							/* U+001E6C */
+	0,							/* U+001E6D */
+	0,							/* U+001E6E */
+	0,							/* U+001E6F */
+	0,							/* U+001E70 */
+	0,							/* U+001E71 */
+	0,							/* U+001E72 */
+	0,							/* U+001E73 */
+	0,							/* U+001E74 */
+	0,							/* U+001E75 */
+	0,							/* U+001E76 */
+	0,							/* U+001E77 */
+	0,							/* U+001E78 */
+	0,							/* U+001E79 */
+	0,							/* U+001E7A */
+	0,							/* U+001E7B */
+	0,							/* U+001E7C */
+	0,							/* U+001E7D */
+	0,							/* U+001E7E */
+	0,							/* U+001E7F */
+	0,							/* U+001E80 */
+	0,							/* U+001E81 */
+	0,							/* U+001E82 */
+	0,							/* U+001E83 */
+	0,							/* U+001E84 */
+	0,							/* U+001E85 */
+	0,							/* U+001E86 */
+	0,							/* U+001E87 */
+	0,							/* U+001E88 */
+	0,							/* U+001E89 */
+	0,							/* U+001E8A */
+	0,							/* U+001E8B */
+	0,							/* U+001E8C */
+	0,							/* U+001E8D */
+	0,							/* U+001E8E */
+	0,							/* U+001E8F */
+	0,							/* U+001E90 */
+	0,							/* U+001E91 */
+	0,							/* U+001E92 */
+	0,							/* U+001E93 */
+	0,							/* U+001E94 */
+	0,							/* U+001E95 */
+	0,							/* U+001E96 */
+	0,							/* U+001E97 */
+	0,							/* U+001E98 */
+	0,							/* U+001E99 */
+	0,							/* U+001E9A */
+	0,							/* U+001E9B */
+	0,							/* U+001E9C */
+	0,							/* U+001E9D */
+	0,							/* U+001E9E */
+	0,							/* U+001E9F */
+	3933,						/* U+001EA0 */
+	3941,						/* U+001EA1 */
+	0,							/* U+001EA2 */
+	0,							/* U+001EA3 */
+	0,							/* U+001EA4 */
+	0,							/* U+001EA5 */
+	0,							/* U+001EA6 */
+	0,							/* U+001EA7 */
+	0,							/* U+001EA8 */
+	0,							/* U+001EA9 */
+	0,							/* U+001EAA */
+	0,							/* U+001EAB */
+	0,							/* U+001EAC */
+	0,							/* U+001EAD */
+	0,							/* U+001EAE */
+	0,							/* U+001EAF */
+	0,							/* U+001EB0 */
+	0,							/* U+001EB1 */
+	0,							/* U+001EB2 */
+	0,							/* U+001EB3 */
+	0,							/* U+001EB4 */
+	0,							/* U+001EB5 */
+	0,							/* U+001EB6 */
+	0,							/* U+001EB7 */
+	3949,						/* U+001EB8 */
+	3953,						/* U+001EB9 */
+	0,							/* U+001EBA */
+	0,							/* U+001EBB */
+	0,							/* U+001EBC */
+	0,							/* U+001EBD */
+	0,							/* U+001EBE */
+	0,							/* U+001EBF */
+	0,							/* U+001EC0 */
+	0,							/* U+001EC1 */
+	0,							/* U+001EC2 */
+	0,							/* U+001EC3 */
+	0,							/* U+001EC4 */
+	0,							/* U+001EC5 */
+	0,							/* U+001EC6 */
+	0,							/* U+001EC7 */
+	0,							/* U+001EC8 */
+	0,							/* U+001EC9 */
+	0,							/* U+001ECA */
+	0,							/* U+001ECB */
+	3957,						/* U+001ECC */
+	3961,						/* U+001ECD */
+	0,							/* U+001ECE */
+	0,							/* U+001ECF */
+	0,							/* U+001ED0 */
+	0,							/* U+001ED1 */
+	0,							/* U+001ED2 */
+	0,							/* U+001ED3 */
+	0,							/* U+001ED4 */
+	0,							/* U+001ED5 */
+	0,							/* U+001ED6 */
+	0,							/* U+001ED7 */
+	0,							/* U+001ED8 */
+	0,							/* U+001ED9 */
+	0,							/* U+001EDA */
+	0,							/* U+001EDB */
+	0,							/* U+001EDC */
+	0,							/* U+001EDD */
+	0,							/* U+001EDE */
+	0,							/* U+001EDF */
+	0,							/* U+001EE0 */
+	0,							/* U+001EE1 */
+	0,							/* U+001EE2 */
+	0,							/* U+001EE3 */
+	0,							/* U+001EE4 */
+	0,							/* U+001EE5 */
+	0,							/* U+001EE6 */
+	0,							/* U+001EE7 */
+	0,							/* U+001EE8 */
+	0,							/* U+001EE9 */
+	0,							/* U+001EEA */
+	0,							/* U+001EEB */
+	0,							/* U+001EEC */
+	0,							/* U+001EED */
+	0,							/* U+001EEE */
+	0,							/* U+001EEF */
+	0,							/* U+001EF0 */
+	0,							/* U+001EF1 */
+	0,							/* U+001EF2 */
+	0,							/* U+001EF3 */
+	0,							/* U+001EF4 */
+	0,							/* U+001EF5 */
+	0,							/* U+001EF6 */
+	0,							/* U+001EF7 */
+	0,							/* U+001EF8 */
+	0,							/* U+001EF9 */
+	0,							/* U+001EFA */
+	0,							/* U+001EFB */
+	0,							/* U+001EFC */
+	0,							/* U+001EFD */
+	0,							/* U+001EFE */
+	0,							/* U+001EFF */
+	3965,						/* U+001F00 */
+	4038,						/* U+001F01 */
+	4111,						/* U+001F02 */
+	4115,						/* U+001F03 */
+	4119,						/* U+001F04 */
+	4123,						/* U+001F05 */
+	4127,						/* U+001F06 */
+	4131,						/* U+001F07 */
+	4135,						/* U+001F08 */
+	4208,						/* U+001F09 */
+	4281,						/* U+001F0A */
+	4285,						/* U+001F0B */
+	4289,						/* U+001F0C */
+	4293,						/* U+001F0D */
+	4297,						/* U+001F0E */
+	4301,						/* U+001F0F */
+	4305,						/* U+001F10 */
+	4310,						/* U+001F11 */
+	0,							/* U+001F12 */
+	0,							/* U+001F13 */
+	0,							/* U+001F14 */
+	0,							/* U+001F15 */
+	0,							/* U+001F16 */
+	0,							/* U+001F17 */
+	4315,						/* U+001F18 */
+	4320,						/* U+001F19 */
+	0,							/* U+001F1A */
+	0,							/* U+001F1B */
+	0,							/* U+001F1C */
+	0,							/* U+001F1D */
+	0,							/* U+001F1E */
+	0,							/* U+001F1F */
+	4325,						/* U+001F20 */
+	4398,						/* U+001F21 */
+	4471,						/* U+001F22 */
+	4475,						/* U+001F23 */
+	4479,						/* U+001F24 */
+	4483,						/* U+001F25 */
+	4487,						/* U+001F26 */
+	4491,						/* U+001F27 */
+	4495,						/* U+001F28 */
+	4568,						/* U+001F29 */
+	4641,						/* U+001F2A */
+	4645,						/* U+001F2B */
+	4649,						/* U+001F2C */
+	4653,						/* U+001F2D */
+	4657,						/* U+001F2E */
+	4661,						/* U+001F2F */
+	4665,						/* U+001F30 */
+	4735,						/* U+001F31 */
+	0,							/* U+001F32 */
+	0,							/* U+001F33 */
+	0,							/* U+001F34 */
+	0,							/* U+001F35 */
+	0,							/* U+001F36 */
+	0,							/* U+001F37 */
+	4805,						/* U+001F38 */
+	4875,						/* U+001F39 */
+	0,							/* U+001F3A */
+	0,							/* U+001F3B */
+	0,							/* U+001F3C */
+	0,							/* U+001F3D */
+	0,							/* U+001F3E */
+	0,							/* U+001F3F */
+	4945,						/* U+001F40 */
+	4950,						/* U+001F41 */
+	0,							/* U+001F42 */
+	0,							/* U+001F43 */
+	0,							/* U+001F44 */
+	0,							/* U+001F45 */
+	0,							/* U+001F46 */
+	0,							/* U+001F47 */
+	4955,						/* U+001F48 */
+	4960,						/* U+001F49 */
+	0,							/* U+001F4A */
+	0,							/* U+001F4B */
+	0,							/* U+001F4C */
+	0,							/* U+001F4D */
+	0,							/* U+001F4E */
+	0,							/* U+001F4F */
+	4965,						/* U+001F50 */
+	5035,						/* U+001F51 */
+	0,							/* U+001F52 */
+	0,							/* U+001F53 */
+	0,							/* U+001F54 */
+	0,							/* U+001F55 */
+	0,							/* U+001F56 */
+	0,							/* U+001F57 */
+	0,							/* U+001F58 */
+	5105,						/* U+001F59 */
+	0,							/* U+001F5A */
+	0,							/* U+001F5B */
+	0,							/* U+001F5C */
+	0,							/* U+001F5D */
+	0,							/* U+001F5E */
+	0,							/* U+001F5F */
+	5175,						/* U+001F60 */
+	5248,						/* U+001F61 */
+	5321,						/* U+001F62 */
+	5325,						/* U+001F63 */
+	5329,						/* U+001F64 */
+	5333,						/* U+001F65 */
+	5337,						/* U+001F66 */
+	5341,						/* U+001F67 */
+	5345,						/* U+001F68 */
+	5418,						/* U+001F69 */
+	5491,						/* U+001F6A */
+	5495,						/* U+001F6B */
+	5499,						/* U+001F6C */
+	5503,						/* U+001F6D */
+	5507,						/* U+001F6E */
+	5511,						/* U+001F6F */
+	5515,						/* U+001F70 */
+	0,							/* U+001F71 */
+	0,							/* U+001F72 */
+	0,							/* U+001F73 */
+	5519,						/* U+001F74 */
+	0,							/* U+001F75 */
+	0,							/* U+001F76 */
+	0,							/* U+001F77 */
+	0,							/* U+001F78 */
+	0,							/* U+001F79 */
+	0,							/* U+001F7A */
+	0,							/* U+001F7B */
+	5523,						/* U+001F7C */
+	0,							/* U+001F7D */
+	0,							/* U+001F7E */
+	0,							/* U+001F7F */
+	0,							/* U+001F80 */
+	0,							/* U+001F81 */
+	0,							/* U+001F82 */
+	0,							/* U+001F83 */
+	0,							/* U+001F84 */
+	0,							/* U+001F85 */
+	0,							/* U+001F86 */
+	0,							/* U+001F87 */
+	0,							/* U+001F88 */
+	0,							/* U+001F89 */
+	0,							/* U+001F8A */
+	0,							/* U+001F8B */
+	0,							/* U+001F8C */
+	0,							/* U+001F8D */
+	0,							/* U+001F8E */
+	0,							/* U+001F8F */
+	0,							/* U+001F90 */
+	0,							/* U+001F91 */
+	0,							/* U+001F92 */
+	0,							/* U+001F93 */
+	0,							/* U+001F94 */
+	0,							/* U+001F95 */
+	0,							/* U+001F96 */
+	0,							/* U+001F97 */
+	0,							/* U+001F98 */
+	0,							/* U+001F99 */
+	0,							/* U+001F9A */
+	0,							/* U+001F9B */
+	0,							/* U+001F9C */
+	0,							/* U+001F9D */
+	0,							/* U+001F9E */
+	0,							/* U+001F9F */
+	0,							/* U+001FA0 */
+	0,							/* U+001FA1 */
+	0,							/* U+001FA2 */
+	0,							/* U+001FA3 */
+	0,							/* U+001FA4 */
+	0,							/* U+001FA5 */
+	0,							/* U+001FA6 */
+	0,							/* U+001FA7 */
+	0,							/* U+001FA8 */
+	0,							/* U+001FA9 */
+	0,							/* U+001FAA */
+	0,							/* U+001FAB */
+	0,							/* U+001FAC */
+	0,							/* U+001FAD */
+	0,							/* U+001FAE */
+	0,							/* U+001FAF */
+	0,							/* U+001FB0 */
+	0,							/* U+001FB1 */
+	0,							/* U+001FB2 */
+	0,							/* U+001FB3 */
+	0,							/* U+001FB4 */
+	0,							/* U+001FB5 */
+	5527,						/* U+001FB6 */
+	0,							/* U+001FB7 */
+	0,							/* U+001FB8 */
+	0,							/* U+001FB9 */
+	0,							/* U+001FBA */
+	0,							/* U+001FBB */
+	0,							/* U+001FBC */
+	0,							/* U+001FBD */
+	0,							/* U+001FBE */
+	5531,						/* U+001FBF */
+	0,							/* U+001FC0 */
+	0,							/* U+001FC1 */
+	0,							/* U+001FC2 */
+	0,							/* U+001FC3 */
+	0,							/* U+001FC4 */
+	0,							/* U+001FC5 */
+	5601,						/* U+001FC6 */
+	0,							/* U+001FC7 */
+	0,							/* U+001FC8 */
+	0,							/* U+001FC9 */
+	0,							/* U+001FCA */
+	0,							/* U+001FCB */
+	0,							/* U+001FCC */
+	0,							/* U+001FCD */
+	0,							/* U+001FCE */
+	0,							/* U+001FCF */
+	0,							/* U+001FD0 */
+	0,							/* U+001FD1 */
+	0,							/* U+001FD2 */
+	0,							/* U+001FD3 */
+	0,							/* U+001FD4 */
+	0,							/* U+001FD5 */
+	0,							/* U+001FD6 */
+	0,							/* U+001FD7 */
+	0,							/* U+001FD8 */
+	0,							/* U+001FD9 */
+	0,							/* U+001FDA */
+	0,							/* U+001FDB */
+	0,							/* U+001FDC */
+	0,							/* U+001FDD */
+	0,							/* U+001FDE */
+	0,							/* U+001FDF */
+	0,							/* U+001FE0 */
+	0,							/* U+001FE1 */
+	0,							/* U+001FE2 */
+	0,							/* U+001FE3 */
+	0,							/* U+001FE4 */
+	0,							/* U+001FE5 */
+	0,							/* U+001FE6 */
+	0,							/* U+001FE7 */
+	0,							/* U+001FE8 */
+	0,							/* U+001FE9 */
+	0,							/* U+001FEA */
+	0,							/* U+001FEB */
+	0,							/* U+001FEC */
+	0,							/* U+001FED */
+	0,							/* U+001FEE */
+	0,							/* U+001FEF */
+	0,							/* U+001FF0 */
+	0,							/* U+001FF1 */
+	0,							/* U+001FF2 */
+	0,							/* U+001FF3 */
+	0,							/* U+001FF4 */
+	0,							/* U+001FF5 */
+	5605,						/* U+001FF6 */
+	0,							/* U+001FF7 */
+	0,							/* U+001FF8 */
+	0,							/* U+001FF9 */
+	0,							/* U+001FFA */
+	0,							/* U+001FFB */
+	0,							/* U+001FFC */
+	0,							/* U+001FFD */
+	5609,						/* U+001FFE */
+	0,							/* U+001FFF */
+	0,							/* U+002000 */
+	0,							/* U+002001 */
+	0,							/* U+002002 */
+	0,							/* U+002003 */
+	0,							/* U+002004 */
+	0,							/* U+002005 */
+	0,							/* U+002006 */
+	0,							/* U+002007 */
+	0,							/* U+002008 */
+	0,							/* U+002009 */
+	0,							/* U+00200A */
+	0,							/* U+00200B */
+	0,							/* U+00200C */
+	0,							/* U+00200D */
+	0,							/* U+00200E */
+	0,							/* U+00200F */
+	0,							/* U+002010 */
+	0,							/* U+002011 */
+	0,							/* U+002012 */
+	0,							/* U+002013 */
+	0,							/* U+002014 */
+	0,							/* U+002015 */
+	0,							/* U+002016 */
+	0,							/* U+002017 */
+	0,							/* U+002018 */
+	0,							/* U+002019 */
+	0,							/* U+00201A */
+	0,							/* U+00201B */
+	0,							/* U+00201C */
+	0,							/* U+00201D */
+	0,							/* U+00201E */
+	0,							/* U+00201F */
+	0,							/* U+002020 */
+	0,							/* U+002021 */
+	0,							/* U+002022 */
+	0,							/* U+002023 */
+	0,							/* U+002024 */
+	0,							/* U+002025 */
+	0,							/* U+002026 */
+	0,							/* U+002027 */
+	0,							/* U+002028 */
+	0,							/* U+002029 */
+	0,							/* U+00202A */
+	0,							/* U+00202B */
+	0,							/* U+00202C */
+	0,							/* U+00202D */
+	0,							/* U+00202E */
+	0,							/* U+00202F */
+	0,							/* U+002030 */
+	0,							/* U+002031 */
+	0,							/* U+002032 */
+	0,							/* U+002033 */
+	0,							/* U+002034 */
+	0,							/* U+002035 */
+	0,							/* U+002036 */
+	0,							/* U+002037 */
+	0,							/* U+002038 */
+	0,							/* U+002039 */
+	0,							/* U+00203A */
+	0,							/* U+00203B */
+	0,							/* U+00203C */
+	0,							/* U+00203D */
+	0,							/* U+00203E */
+	0,							/* U+00203F */
+	0,							/* U+002040 */
+	0,							/* U+002041 */
+	0,							/* U+002042 */
+	0,							/* U+002043 */
+	0,							/* U+002044 */
+	0,							/* U+002045 */
+	0,							/* U+002046 */
+	0,							/* U+002047 */
+	0,							/* U+002048 */
+	0,							/* U+002049 */
+	0,							/* U+00204A */
+	0,							/* U+00204B */
+	0,							/* U+00204C */
+	0,							/* U+00204D */
+	0,							/* U+00204E */
+	0,							/* U+00204F */
+	0,							/* U+002050 */
+	0,							/* U+002051 */
+	0,							/* U+002052 */
+	0,							/* U+002053 */
+	0,							/* U+002054 */
+	0,							/* U+002055 */
+	0,							/* U+002056 */
+	0,							/* U+002057 */
+	0,							/* U+002058 */
+	0,							/* U+002059 */
+	0,							/* U+00205A */
+	0,							/* U+00205B */
+	0,							/* U+00205C */
+	0,							/* U+00205D */
+	0,							/* U+00205E */
+	0,							/* U+00205F */
+	0,							/* U+002060 */
+	0,							/* U+002061 */
+	0,							/* U+002062 */
+	0,							/* U+002063 */
+	0,							/* U+002064 */
+	0,							/* U+002065 */
+	0,							/* U+002066 */
+	0,							/* U+002067 */
+	0,							/* U+002068 */
+	0,							/* U+002069 */
+	0,							/* U+00206A */
+	0,							/* U+00206B */
+	0,							/* U+00206C */
+	0,							/* U+00206D */
+	0,							/* U+00206E */
+	0,							/* U+00206F */
+	0,							/* U+002070 */
+	0,							/* U+002071 */
+	0,							/* U+002072 */
+	0,							/* U+002073 */
+	0,							/* U+002074 */
+	0,							/* U+002075 */
+	0,							/* U+002076 */
+	0,							/* U+002077 */
+	0,							/* U+002078 */
+	0,							/* U+002079 */
+	0,							/* U+00207A */
+	0,							/* U+00207B */
+	0,							/* U+00207C */
+	0,							/* U+00207D */
+	0,							/* U+00207E */
+	0,							/* U+00207F */
+	0,							/* U+002080 */
+	0,							/* U+002081 */
+	0,							/* U+002082 */
+	0,							/* U+002083 */
+	0,							/* U+002084 */
+	0,							/* U+002085 */
+	0,							/* U+002086 */
+	0,							/* U+002087 */
+	0,							/* U+002088 */
+	0,							/* U+002089 */
+	0,							/* U+00208A */
+	0,							/* U+00208B */
+	0,							/* U+00208C */
+	0,							/* U+00208D */
+	0,							/* U+00208E */
+	0,							/* U+00208F */
+	0,							/* U+002090 */
+	0,							/* U+002091 */
+	0,							/* U+002092 */
+	0,							/* U+002093 */
+	0,							/* U+002094 */
+	0,							/* U+002095 */
+	0,							/* U+002096 */
+	0,							/* U+002097 */
+	0,							/* U+002098 */
+	0,							/* U+002099 */
+	0,							/* U+00209A */
+	0,							/* U+00209B */
+	0,							/* U+00209C */
+	0,							/* U+00209D */
+	0,							/* U+00209E */
+	0,							/* U+00209F */
+	0,							/* U+0020A0 */
+	0,							/* U+0020A1 */
+	0,							/* U+0020A2 */
+	0,							/* U+0020A3 */
+	0,							/* U+0020A4 */
+	0,							/* U+0020A5 */
+	0,							/* U+0020A6 */
+	0,							/* U+0020A7 */
+	0,							/* U+0020A8 */
+	0,							/* U+0020A9 */
+	0,							/* U+0020AA */
+	0,							/* U+0020AB */
+	0,							/* U+0020AC */
+	0,							/* U+0020AD */
+	0,							/* U+0020AE */
+	0,							/* U+0020AF */
+	0,							/* U+0020B0 */
+	0,							/* U+0020B1 */
+	0,							/* U+0020B2 */
+	0,							/* U+0020B3 */
+	0,							/* U+0020B4 */
+	0,							/* U+0020B5 */
+	0,							/* U+0020B6 */
+	0,							/* U+0020B7 */
+	0,							/* U+0020B8 */
+	0,							/* U+0020B9 */
+	0,							/* U+0020BA */
+	0,							/* U+0020BB */
+	0,							/* U+0020BC */
+	0,							/* U+0020BD */
+	0,							/* U+0020BE */
+	0,							/* U+0020BF */
+	0,							/* U+0020C0 */
+	0,							/* U+0020C1 */
+	0,							/* U+0020C2 */
+	0,							/* U+0020C3 */
+	0,							/* U+0020C4 */
+	0,							/* U+0020C5 */
+	0,							/* U+0020C6 */
+	0,							/* U+0020C7 */
+	0,							/* U+0020C8 */
+	0,							/* U+0020C9 */
+	0,							/* U+0020CA */
+	0,							/* U+0020CB */
+	0,							/* U+0020CC */
+	0,							/* U+0020CD */
+	0,							/* U+0020CE */
+	0,							/* U+0020CF */
+	0,							/* U+0020D0 */
+	0,							/* U+0020D1 */
+	0,							/* U+0020D2 */
+	0,							/* U+0020D3 */
+	0,							/* U+0020D4 */
+	0,							/* U+0020D5 */
+	0,							/* U+0020D6 */
+	0,							/* U+0020D7 */
+	0,							/* U+0020D8 */
+	0,							/* U+0020D9 */
+	0,							/* U+0020DA */
+	0,							/* U+0020DB */
+	0,							/* U+0020DC */
+	0,							/* U+0020DD */
+	0,							/* U+0020DE */
+	0,							/* U+0020DF */
+	0,							/* U+0020E0 */
+	0,							/* U+0020E1 */
+	0,							/* U+0020E2 */
+	0,							/* U+0020E3 */
+	0,							/* U+0020E4 */
+	0,							/* U+0020E5 */
+	0,							/* U+0020E6 */
+	0,							/* U+0020E7 */
+	0,							/* U+0020E8 */
+	0,							/* U+0020E9 */
+	0,							/* U+0020EA */
+	0,							/* U+0020EB */
+	0,							/* U+0020EC */
+	0,							/* U+0020ED */
+	0,							/* U+0020EE */
+	0,							/* U+0020EF */
+	0,							/* U+0020F0 */
+	0,							/* U+0020F1 */
+	0,							/* U+0020F2 */
+	0,							/* U+0020F3 */
+	0,							/* U+0020F4 */
+	0,							/* U+0020F5 */
+	0,							/* U+0020F6 */
+	0,							/* U+0020F7 */
+	0,							/* U+0020F8 */
+	0,							/* U+0020F9 */
+	0,							/* U+0020FA */
+	0,							/* U+0020FB */
+	0,							/* U+0020FC */
+	0,							/* U+0020FD */
+	0,							/* U+0020FE */
+	0,							/* U+0020FF */
+	0,							/* U+002100 */
+	0,							/* U+002101 */
+	0,							/* U+002102 */
+	0,							/* U+002103 */
+	0,							/* U+002104 */
+	0,							/* U+002105 */
+	0,							/* U+002106 */
+	0,							/* U+002107 */
+	0,							/* U+002108 */
+	0,							/* U+002109 */
+	0,							/* U+00210A */
+	0,							/* U+00210B */
+	0,							/* U+00210C */
+	0,							/* U+00210D */
+	0,							/* U+00210E */
+	0,							/* U+00210F */
+	0,							/* U+002110 */
+	0,							/* U+002111 */
+	0,							/* U+002112 */
+	0,							/* U+002113 */
+	0,							/* U+002114 */
+	0,							/* U+002115 */
+	0,							/* U+002116 */
+	0,							/* U+002117 */
+	0,							/* U+002118 */
+	0,							/* U+002119 */
+	0,							/* U+00211A */
+	0,							/* U+00211B */
+	0,							/* U+00211C */
+	0,							/* U+00211D */
+	0,							/* U+00211E */
+	0,							/* U+00211F */
+	0,							/* U+002120 */
+	0,							/* U+002121 */
+	0,							/* U+002122 */
+	0,							/* U+002123 */
+	0,							/* U+002124 */
+	0,							/* U+002125 */
+	0,							/* U+002126 */
+	0,							/* U+002127 */
+	0,							/* U+002128 */
+	0,							/* U+002129 */
+	0,							/* U+00212A */
+	0,							/* U+00212B */
+	0,							/* U+00212C */
+	0,							/* U+00212D */
+	0,							/* U+00212E */
+	0,							/* U+00212F */
+	0,							/* U+002130 */
+	0,							/* U+002131 */
+	0,							/* U+002132 */
+	0,							/* U+002133 */
+	0,							/* U+002134 */
+	0,							/* U+002135 */
+	0,							/* U+002136 */
+	0,							/* U+002137 */
+	0,							/* U+002138 */
+	0,							/* U+002139 */
+	0,							/* U+00213A */
+	0,							/* U+00213B */
+	0,							/* U+00213C */
+	0,							/* U+00213D */
+	0,							/* U+00213E */
+	0,							/* U+00213F */
+	0,							/* U+002140 */
+	0,							/* U+002141 */
+	0,							/* U+002142 */
+	0,							/* U+002143 */
+	0,							/* U+002144 */
+	0,							/* U+002145 */
+	0,							/* U+002146 */
+	0,							/* U+002147 */
+	0,							/* U+002148 */
+	0,							/* U+002149 */
+	0,							/* U+00214A */
+	0,							/* U+00214B */
+	0,							/* U+00214C */
+	0,							/* U+00214D */
+	0,							/* U+00214E */
+	0,							/* U+00214F */
+	0,							/* U+002150 */
+	0,							/* U+002151 */
+	0,							/* U+002152 */
+	0,							/* U+002153 */
+	0,							/* U+002154 */
+	0,							/* U+002155 */
+	0,							/* U+002156 */
+	0,							/* U+002157 */
+	0,							/* U+002158 */
+	0,							/* U+002159 */
+	0,							/* U+00215A */
+	0,							/* U+00215B */
+	0,							/* U+00215C */
+	0,							/* U+00215D */
+	0,							/* U+00215E */
+	0,							/* U+00215F */
+	0,							/* U+002160 */
+	0,							/* U+002161 */
+	0,							/* U+002162 */
+	0,							/* U+002163 */
+	0,							/* U+002164 */
+	0,							/* U+002165 */
+	0,							/* U+002166 */
+	0,							/* U+002167 */
+	0,							/* U+002168 */
+	0,							/* U+002169 */
+	0,							/* U+00216A */
+	0,							/* U+00216B */
+	0,							/* U+00216C */
+	0,							/* U+00216D */
+	0,							/* U+00216E */
+	0,							/* U+00216F */
+	0,							/* U+002170 */
+	0,							/* U+002171 */
+	0,							/* U+002172 */
+	0,							/* U+002173 */
+	0,							/* U+002174 */
+	0,							/* U+002175 */
+	0,							/* U+002176 */
+	0,							/* U+002177 */
+	0,							/* U+002178 */
+	0,							/* U+002179 */
+	0,							/* U+00217A */
+	0,							/* U+00217B */
+	0,							/* U+00217C */
+	0,							/* U+00217D */
+	0,							/* U+00217E */
+	0,							/* U+00217F */
+	0,							/* U+002180 */
+	0,							/* U+002181 */
+	0,							/* U+002182 */
+	0,							/* U+002183 */
+	0,							/* U+002184 */
+	0,							/* U+002185 */
+	0,							/* U+002186 */
+	0,							/* U+002187 */
+	0,							/* U+002188 */
+	0,							/* U+002189 */
+	0,							/* U+00218A */
+	0,							/* U+00218B */
+	0,							/* U+00218C */
+	0,							/* U+00218D */
+	0,							/* U+00218E */
+	0,							/* U+00218F */
+	5679,						/* U+002190 */
+	0,							/* U+002191 */
+	5683,						/* U+002192 */
+	0,							/* U+002193 */
+	5687,						/* U+002194 */
+	0,							/* U+002195 */
+	0,							/* U+002196 */
+	0,							/* U+002197 */
+	0,							/* U+002198 */
+	0,							/* U+002199 */
+	0,							/* U+00219A */
+	0,							/* U+00219B */
+	0,							/* U+00219C */
+	0,							/* U+00219D */
+	0,							/* U+00219E */
+	0,							/* U+00219F */
+	0,							/* U+0021A0 */
+	0,							/* U+0021A1 */
+	0,							/* U+0021A2 */
+	0,							/* U+0021A3 */
+	0,							/* U+0021A4 */
+	0,							/* U+0021A5 */
+	0,							/* U+0021A6 */
+	0,							/* U+0021A7 */
+	0,							/* U+0021A8 */
+	0,							/* U+0021A9 */
+	0,							/* U+0021AA */
+	0,							/* U+0021AB */
+	0,							/* U+0021AC */
+	0,							/* U+0021AD */
+	0,							/* U+0021AE */
+	0,							/* U+0021AF */
+	0,							/* U+0021B0 */
+	0,							/* U+0021B1 */
+	0,							/* U+0021B2 */
+	0,							/* U+0021B3 */
+	0,							/* U+0021B4 */
+	0,							/* U+0021B5 */
+	0,							/* U+0021B6 */
+	0,							/* U+0021B7 */
+	0,							/* U+0021B8 */
+	0,							/* U+0021B9 */
+	0,							/* U+0021BA */
+	0,							/* U+0021BB */
+	0,							/* U+0021BC */
+	0,							/* U+0021BD */
+	0,							/* U+0021BE */
+	0,							/* U+0021BF */
+	0,							/* U+0021C0 */
+	0,							/* U+0021C1 */
+	0,							/* U+0021C2 */
+	0,							/* U+0021C3 */
+	0,							/* U+0021C4 */
+	0,							/* U+0021C5 */
+	0,							/* U+0021C6 */
+	0,							/* U+0021C7 */
+	0,							/* U+0021C8 */
+	0,							/* U+0021C9 */
+	0,							/* U+0021CA */
+	0,							/* U+0021CB */
+	0,							/* U+0021CC */
+	0,							/* U+0021CD */
+	0,							/* U+0021CE */
+	0,							/* U+0021CF */
+	5691,						/* U+0021D0 */
+	0,							/* U+0021D1 */
+	5695,						/* U+0021D2 */
+	0,							/* U+0021D3 */
+	5699,						/* U+0021D4 */
+	0,							/* U+0021D5 */
+	0,							/* U+0021D6 */
+	0,							/* U+0021D7 */
+	0,							/* U+0021D8 */
+	0,							/* U+0021D9 */
+	0,							/* U+0021DA */
+	0,							/* U+0021DB */
+	0,							/* U+0021DC */
+	0,							/* U+0021DD */
+	0,							/* U+0021DE */
+	0,							/* U+0021DF */
+	0,							/* U+0021E0 */
+	0,							/* U+0021E1 */
+	0,							/* U+0021E2 */
+	0,							/* U+0021E3 */
+	0,							/* U+0021E4 */
+	0,							/* U+0021E5 */
+	0,							/* U+0021E6 */
+	0,							/* U+0021E7 */
+	0,							/* U+0021E8 */
+	0,							/* U+0021E9 */
+	0,							/* U+0021EA */
+	0,							/* U+0021EB */
+	0,							/* U+0021EC */
+	0,							/* U+0021ED */
+	0,							/* U+0021EE */
+	0,							/* U+0021EF */
+	0,							/* U+0021F0 */
+	0,							/* U+0021F1 */
+	0,							/* U+0021F2 */
+	0,							/* U+0021F3 */
+	0,							/* U+0021F4 */
+	0,							/* U+0021F5 */
+	0,							/* U+0021F6 */
+	0,							/* U+0021F7 */
+	0,							/* U+0021F8 */
+	0,							/* U+0021F9 */
+	0,							/* U+0021FA */
+	0,							/* U+0021FB */
+	0,							/* U+0021FC */
+	0,							/* U+0021FD */
+	0,							/* U+0021FE */
+	0,							/* U+0021FF */
+	0,							/* U+002200 */
+	0,							/* U+002201 */
+	0,							/* U+002202 */
+	5703,						/* U+002203 */
+	0,							/* U+002204 */
+	0,							/* U+002205 */
+	0,							/* U+002206 */
+	0,							/* U+002207 */
+	5707,						/* U+002208 */
+	0,							/* U+002209 */
+	0,							/* U+00220A */
+	5711,						/* U+00220B */
+	0,							/* U+00220C */
+	0,							/* U+00220D */
+	0,							/* U+00220E */
+	0,							/* U+00220F */
+	0,							/* U+002210 */
+	0,							/* U+002211 */
+	0,							/* U+002212 */
+	0,							/* U+002213 */
+	0,							/* U+002214 */
+	0,							/* U+002215 */
+	0,							/* U+002216 */
+	0,							/* U+002217 */
+	0,							/* U+002218 */
+	0,							/* U+002219 */
+	0,							/* U+00221A */
+	0,							/* U+00221B */
+	0,							/* U+00221C */
+	0,							/* U+00221D */
+	0,							/* U+00221E */
+	0,							/* U+00221F */
+	0,							/* U+002220 */
+	0,							/* U+002221 */
+	0,							/* U+002222 */
+	5715,						/* U+002223 */
+	0,							/* U+002224 */
+	5719,						/* U+002225 */
+	0,							/* U+002226 */
+	0,							/* U+002227 */
+	0,							/* U+002228 */
+	0,							/* U+002229 */
+	0,							/* U+00222A */
+	0,							/* U+00222B */
+	0,							/* U+00222C */
+	0,							/* U+00222D */
+	0,							/* U+00222E */
+	0,							/* U+00222F */
+	0,							/* U+002230 */
+	0,							/* U+002231 */
+	0,							/* U+002232 */
+	0,							/* U+002233 */
+	0,							/* U+002234 */
+	0,							/* U+002235 */
+	0,							/* U+002236 */
+	0,							/* U+002237 */
+	0,							/* U+002238 */
+	0,							/* U+002239 */
+	0,							/* U+00223A */
+	0,							/* U+00223B */
+	5723,						/* U+00223C */
+	0,							/* U+00223D */
+	0,							/* U+00223E */
+	0,							/* U+00223F */
+	0,							/* U+002240 */
+	0,							/* U+002241 */
+	0,							/* U+002242 */
+	5727,						/* U+002243 */
+	0,							/* U+002244 */
+	5731,						/* U+002245 */
+	0,							/* U+002246 */
+	0,							/* U+002247 */
+	5735,						/* U+002248 */
+	0,							/* U+002249 */
+	0,							/* U+00224A */
+	0,							/* U+00224B */
+	0,							/* U+00224C */
+	5739,						/* U+00224D */
+	0,							/* U+00224E */
+	0,							/* U+00224F */
+	0,							/* U+002250 */
+	0,							/* U+002251 */
+	0,							/* U+002252 */
+	0,							/* U+002253 */
+	0,							/* U+002254 */
+	0,							/* U+002255 */
+	0,							/* U+002256 */
+	0,							/* U+002257 */
+	0,							/* U+002258 */
+	0,							/* U+002259 */
+	0,							/* U+00225A */
+	0,							/* U+00225B */
+	0,							/* U+00225C */
+	0,							/* U+00225D */
+	0,							/* U+00225E */
+	0,							/* U+00225F */
+	0,							/* U+002260 */
+	5743,						/* U+002261 */
+	0,							/* U+002262 */
+	0,							/* U+002263 */
+	5747,						/* U+002264 */
+	5751,						/* U+002265 */
+	0,							/* U+002266 */
+	0,							/* U+002267 */
+	0,							/* U+002268 */
+	0,							/* U+002269 */
+	0,							/* U+00226A */
+	0,							/* U+00226B */
+	0,							/* U+00226C */
+	0,							/* U+00226D */
+	0,							/* U+00226E */
+	0,							/* U+00226F */
+	0,							/* U+002270 */
+	0,							/* U+002271 */
+	5755,						/* U+002272 */
+	5759,						/* U+002273 */
+	0,							/* U+002274 */
+	0,							/* U+002275 */
+	5763,						/* U+002276 */
+	5767,						/* U+002277 */
+	0,							/* U+002278 */
+	0,							/* U+002279 */
+	5771,						/* U+00227A */
+	5775,						/* U+00227B */
+	5779,						/* U+00227C */
+	5783,						/* U+00227D */
+	0,							/* U+00227E */
+	0,							/* U+00227F */
+	0,							/* U+002280 */
+	0,							/* U+002281 */
+	5787,						/* U+002282 */
+	5791,						/* U+002283 */
+	0,							/* U+002284 */
+	0,							/* U+002285 */
+	5795,						/* U+002286 */
+	5799,						/* U+002287 */
+	0,							/* U+002288 */
+	0,							/* U+002289 */
+	0,							/* U+00228A */
+	0,							/* U+00228B */
+	0,							/* U+00228C */
+	0,							/* U+00228D */
+	0,							/* U+00228E */
+	0,							/* U+00228F */
+	0,							/* U+002290 */
+	5803,						/* U+002291 */
+	5807,						/* U+002292 */
+	0,							/* U+002293 */
+	0,							/* U+002294 */
+	0,							/* U+002295 */
+	0,							/* U+002296 */
+	0,							/* U+002297 */
+	0,							/* U+002298 */
+	0,							/* U+002299 */
+	0,							/* U+00229A */
+	0,							/* U+00229B */
+	0,							/* U+00229C */
+	0,							/* U+00229D */
+	0,							/* U+00229E */
+	0,							/* U+00229F */
+	0,							/* U+0022A0 */
+	0,							/* U+0022A1 */
+	5811,						/* U+0022A2 */
+	0,							/* U+0022A3 */
+	0,							/* U+0022A4 */
+	0,							/* U+0022A5 */
+	0,							/* U+0022A6 */
+	0,							/* U+0022A7 */
+	5815,						/* U+0022A8 */
+	5819,						/* U+0022A9 */
+	0,							/* U+0022AA */
+	5823,						/* U+0022AB */
+	0,							/* U+0022AC */
+	0,							/* U+0022AD */
+	0,							/* U+0022AE */
+	0,							/* U+0022AF */
+	0,							/* U+0022B0 */
+	0,							/* U+0022B1 */
+	5827,						/* U+0022B2 */
+	5831,						/* U+0022B3 */
+	5835,						/* U+0022B4 */
+	5839,						/* U+0022B5 */
+	5843,						/* U+003046 */
+	0,							/* U+003047 */
+	0,							/* U+003048 */
+	0,							/* U+003049 */
+	0,							/* U+00304A */
+	5847,						/* U+00304B */
+	0,							/* U+00304C */
+	5851,						/* U+00304D */
+	0,							/* U+00304E */
+	5855,						/* U+00304F */
+	0,							/* U+003050 */
+	5859,						/* U+003051 */
+	0,							/* U+003052 */
+	5863,						/* U+003053 */
+	0,							/* U+003054 */
+	5867,						/* U+003055 */
+	0,							/* U+003056 */
+	5871,						/* U+003057 */
+	0,							/* U+003058 */
+	5875,						/* U+003059 */
+	0,							/* U+00305A */
+	5879,						/* U+00305B */
+	0,							/* U+00305C */
+	5883,						/* U+00305D */
+	0,							/* U+00305E */
+	5887,						/* U+00305F */
+	0,							/* U+003060 */
+	5891,						/* U+003061 */
+	0,							/* U+003062 */
+	0,							/* U+003063 */
+	5895,						/* U+003064 */
+	0,							/* U+003065 */
+	5899,						/* U+003066 */
+	0,							/* U+003067 */
+	5903,						/* U+003068 */
+	0,							/* U+003069 */
+	0,							/* U+00306A */
+	0,							/* U+00306B */
+	0,							/* U+00306C */
+	0,							/* U+00306D */
+	0,							/* U+00306E */
+	5907,						/* U+00306F */
+	0,							/* U+003070 */
+	0,							/* U+003071 */
+	5912,						/* U+003072 */
+	0,							/* U+003073 */
+	0,							/* U+003074 */
+	5917,						/* U+003075 */
+	0,							/* U+003076 */
+	0,							/* U+003077 */
+	5922,						/* U+003078 */
+	0,							/* U+003079 */
+	0,							/* U+00307A */
+	5927,						/* U+00307B */
+	0,							/* U+00307C */
+	0,							/* U+00307D */
+	0,							/* U+00307E */
+	0,							/* U+00307F */
+	0,							/* U+003080 */
+	0,							/* U+003081 */
+	0,							/* U+003082 */
+	0,							/* U+003083 */
+	0,							/* U+003084 */
+	0,							/* U+003085 */
+	0,							/* U+003086 */
+	0,							/* U+003087 */
+	0,							/* U+003088 */
+	0,							/* U+003089 */
+	0,							/* U+00308A */
+	0,							/* U+00308B */
+	0,							/* U+00308C */
+	0,							/* U+00308D */
+	0,							/* U+00308E */
+	0,							/* U+00308F */
+	0,							/* U+003090 */
+	0,							/* U+003091 */
+	0,							/* U+003092 */
+	0,							/* U+003093 */
+	0,							/* U+003094 */
+	0,							/* U+003095 */
+	0,							/* U+003096 */
+	0,							/* U+003097 */
+	0,							/* U+003098 */
+	0,							/* U+003099 */
+	0,							/* U+00309A */
+	0,							/* U+00309B */
+	0,							/* U+00309C */
+	5932,						/* U+00309D */
+	0,							/* U+00309E */
+	0,							/* U+00309F */
+	0,							/* U+0030A0 */
+	0,							/* U+0030A1 */
+	0,							/* U+0030A2 */
+	0,							/* U+0030A3 */
+	0,							/* U+0030A4 */
+	0,							/* U+0030A5 */
+	5936,						/* U+0030A6 */
+	0,							/* U+0030A7 */
+	0,							/* U+0030A8 */
+	0,							/* U+0030A9 */
+	0,							/* U+0030AA */
+	5940,						/* U+0030AB */
+	0,							/* U+0030AC */
+	5944,						/* U+0030AD */
+	0,							/* U+0030AE */
+	5948,						/* U+0030AF */
+	0,							/* U+0030B0 */
+	5952,						/* U+0030B1 */
+	0,							/* U+0030B2 */
+	5956,						/* U+0030B3 */
+	0,							/* U+0030B4 */
+	5960,						/* U+0030B5 */
+	0,							/* U+0030B6 */
+	5964,						/* U+0030B7 */
+	0,							/* U+0030B8 */
+	5968,						/* U+0030B9 */
+	0,							/* U+0030BA */
+	5972,						/* U+0030BB */
+	0,							/* U+0030BC */
+	5976,						/* U+0030BD */
+	0,							/* U+0030BE */
+	5980,						/* U+0030BF */
+	0,							/* U+0030C0 */
+	5984,						/* U+0030C1 */
+	0,							/* U+0030C2 */
+	0,							/* U+0030C3 */
+	5988,						/* U+0030C4 */
+	0,							/* U+0030C5 */
+	5992,						/* U+0030C6 */
+	0,							/* U+0030C7 */
+	5996,						/* U+0030C8 */
+	0,							/* U+0030C9 */
+	0,							/* U+0030CA */
+	0,							/* U+0030CB */
+	0,							/* U+0030CC */
+	0,							/* U+0030CD */
+	0,							/* U+0030CE */
+	6000,						/* U+0030CF */
+	0,							/* U+0030D0 */
+	0,							/* U+0030D1 */
+	6005,						/* U+0030D2 */
+	0,							/* U+0030D3 */
+	0,							/* U+0030D4 */
+	6010,						/* U+0030D5 */
+	0,							/* U+0030D6 */
+	0,							/* U+0030D7 */
+	6015,						/* U+0030D8 */
+	0,							/* U+0030D9 */
+	0,							/* U+0030DA */
+	6020,						/* U+0030DB */
+	0,							/* U+0030DC */
+	0,							/* U+0030DD */
+	0,							/* U+0030DE */
+	0,							/* U+0030DF */
+	0,							/* U+0030E0 */
+	0,							/* U+0030E1 */
+	0,							/* U+0030E2 */
+	0,							/* U+0030E3 */
+	0,							/* U+0030E4 */
+	0,							/* U+0030E5 */
+	0,							/* U+0030E6 */
+	0,							/* U+0030E7 */
+	0,							/* U+0030E8 */
+	0,							/* U+0030E9 */
+	0,							/* U+0030EA */
+	0,							/* U+0030EB */
+	0,							/* U+0030EC */
+	0,							/* U+0030ED */
+	0,							/* U+0030EE */
+	6025,						/* U+0030EF */
+	6029,						/* U+0030F0 */
+	6033,						/* U+0030F1 */
+	6037,						/* U+0030F2 */
+	0,							/* U+0030F3 */
+	0,							/* U+0030F4 */
+	0,							/* U+0030F5 */
+	0,							/* U+0030F6 */
+	0,							/* U+0030F7 */
+	0,							/* U+0030F8 */
+	0,							/* U+0030F9 */
+	0,							/* U+0030FA */
+	0,							/* U+0030FB */
+	0,							/* U+0030FC */
+	6041,						/* U+0030FD */
+	6045,						/* U+0105D2 */
+	0,							/* U+0105D3 */
+	0,							/* U+0105D4 */
+	0,							/* U+0105D5 */
+	0,							/* U+0105D6 */
+	0,							/* U+0105D7 */
+	0,							/* U+0105D8 */
+	0,							/* U+0105D9 */
+	6049,						/* U+0105DA */
+	6053,						/* U+011099 */
+	0,							/* U+01109A */
+	6057,						/* U+01109B */
+	0,							/* U+01109C */
+	0,							/* U+01109D */
+	0,							/* U+01109E */
+	0,							/* U+01109F */
+	0,							/* U+0110A0 */
+	0,							/* U+0110A1 */
+	0,							/* U+0110A2 */
+	0,							/* U+0110A3 */
+	0,							/* U+0110A4 */
+	6061,						/* U+0110A5 */
+	0,							/* U+0110A6 */
+	0,							/* U+0110A7 */
+	0,							/* U+0110A8 */
+	0,							/* U+0110A9 */
+	0,							/* U+0110AA */
+	0,							/* U+0110AB */
+	0,							/* U+0110AC */
+	0,							/* U+0110AD */
+	0,							/* U+0110AE */
+	0,							/* U+0110AF */
+	0,							/* U+0110B0 */
+	0,							/* U+0110B1 */
+	0,							/* U+0110B2 */
+	0,							/* U+0110B3 */
+	0,							/* U+0110B4 */
+	0,							/* U+0110B5 */
+	0,							/* U+0110B6 */
+	0,							/* U+0110B7 */
+	0,							/* U+0110B8 */
+	0,							/* U+0110B9 */
+	0,							/* U+0110BA */
+	0,							/* U+0110BB */
+	0,							/* U+0110BC */
+	0,							/* U+0110BD */
+	0,							/* U+0110BE */
+	0,							/* U+0110BF */
+	0,							/* U+0110C0 */
+	0,							/* U+0110C1 */
+	0,							/* U+0110C2 */
+	0,							/* U+0110C3 */
+	0,							/* U+0110C4 */
+	0,							/* U+0110C5 */
+	0,							/* U+0110C6 */
+	0,							/* U+0110C7 */
+	0,							/* U+0110C8 */
+	0,							/* U+0110C9 */
+	0,							/* U+0110CA */
+	0,							/* U+0110CB */
+	0,							/* U+0110CC */
+	0,							/* U+0110CD */
+	0,							/* U+0110CE */
+	0,							/* U+0110CF */
+	0,							/* U+0110D0 */
+	0,							/* U+0110D1 */
+	0,							/* U+0110D2 */
+	0,							/* U+0110D3 */
+	0,							/* U+0110D4 */
+	0,							/* U+0110D5 */
+	0,							/* U+0110D6 */
+	0,							/* U+0110D7 */
+	0,							/* U+0110D8 */
+	0,							/* U+0110D9 */
+	0,							/* U+0110DA */
+	0,							/* U+0110DB */
+	0,							/* U+0110DC */
+	0,							/* U+0110DD */
+	0,							/* U+0110DE */
+	0,							/* U+0110DF */
+	0,							/* U+0110E0 */
+	0,							/* U+0110E1 */
+	0,							/* U+0110E2 */
+	0,							/* U+0110E3 */
+	0,							/* U+0110E4 */
+	0,							/* U+0110E5 */
+	0,							/* U+0110E6 */
+	0,							/* U+0110E7 */
+	0,							/* U+0110E8 */
+	0,							/* U+0110E9 */
+	0,							/* U+0110EA */
+	0,							/* U+0110EB */
+	0,							/* U+0110EC */
+	0,							/* U+0110ED */
+	0,							/* U+0110EE */
+	0,							/* U+0110EF */
+	0,							/* U+0110F0 */
+	0,							/* U+0110F1 */
+	0,							/* U+0110F2 */
+	0,							/* U+0110F3 */
+	0,							/* U+0110F4 */
+	0,							/* U+0110F5 */
+	0,							/* U+0110F6 */
+	0,							/* U+0110F7 */
+	0,							/* U+0110F8 */
+	0,							/* U+0110F9 */
+	0,							/* U+0110FA */
+	0,							/* U+0110FB */
+	0,							/* U+0110FC */
+	0,							/* U+0110FD */
+	0,							/* U+0110FE */
+	0,							/* U+0110FF */
+	0,							/* U+011100 */
+	0,							/* U+011101 */
+	0,							/* U+011102 */
+	0,							/* U+011103 */
+	0,							/* U+011104 */
+	0,							/* U+011105 */
+	0,							/* U+011106 */
+	0,							/* U+011107 */
+	0,							/* U+011108 */
+	0,							/* U+011109 */
+	0,							/* U+01110A */
+	0,							/* U+01110B */
+	0,							/* U+01110C */
+	0,							/* U+01110D */
+	0,							/* U+01110E */
+	0,							/* U+01110F */
+	0,							/* U+011110 */
+	0,							/* U+011111 */
+	0,							/* U+011112 */
+	0,							/* U+011113 */
+	0,							/* U+011114 */
+	0,							/* U+011115 */
+	0,							/* U+011116 */
+	0,							/* U+011117 */
+	0,							/* U+011118 */
+	0,							/* U+011119 */
+	0,							/* U+01111A */
+	0,							/* U+01111B */
+	0,							/* U+01111C */
+	0,							/* U+01111D */
+	0,							/* U+01111E */
+	0,							/* U+01111F */
+	0,							/* U+011120 */
+	0,							/* U+011121 */
+	0,							/* U+011122 */
+	0,							/* U+011123 */
+	0,							/* U+011124 */
+	0,							/* U+011125 */
+	0,							/* U+011126 */
+	0,							/* U+011127 */
+	0,							/* U+011128 */
+	0,							/* U+011129 */
+	0,							/* U+01112A */
+	0,							/* U+01112B */
+	0,							/* U+01112C */
+	0,							/* U+01112D */
+	0,							/* U+01112E */
+	0,							/* U+01112F */
+	0,							/* U+011130 */
+	6065,						/* U+011131 */
+	6069,						/* U+011132 */
+	0,							/* U+011133 */
+	0,							/* U+011134 */
+	0,							/* U+011135 */
+	0,							/* U+011136 */
+	0,							/* U+011137 */
+	0,							/* U+011138 */
+	0,							/* U+011139 */
+	0,							/* U+01113A */
+	0,							/* U+01113B */
+	0,							/* U+01113C */
+	0,							/* U+01113D */
+	0,							/* U+01113E */
+	0,							/* U+01113F */
+	0,							/* U+011140 */
+	0,							/* U+011141 */
+	0,							/* U+011142 */
+	0,							/* U+011143 */
+	0,							/* U+011144 */
+	0,							/* U+011145 */
+	0,							/* U+011146 */
+	0,							/* U+011147 */
+	0,							/* U+011148 */
+	0,							/* U+011149 */
+	0,							/* U+01114A */
+	0,							/* U+01114B */
+	0,							/* U+01114C */
+	0,							/* U+01114D */
+	0,							/* U+01114E */
+	0,							/* U+01114F */
+	0,							/* U+011150 */
+	0,							/* U+011151 */
+	0,							/* U+011152 */
+	0,							/* U+011153 */
+	0,							/* U+011154 */
+	0,							/* U+011155 */
+	0,							/* U+011156 */
+	0,							/* U+011157 */
+	0,							/* U+011158 */
+	0,							/* U+011159 */
+	0,							/* U+01115A */
+	0,							/* U+01115B */
+	0,							/* U+01115C */
+	0,							/* U+01115D */
+	0,							/* U+01115E */
+	0,							/* U+01115F */
+	0,							/* U+011160 */
+	0,							/* U+011161 */
+	0,							/* U+011162 */
+	0,							/* U+011163 */
+	0,							/* U+011164 */
+	0,							/* U+011165 */
+	0,							/* U+011166 */
+	0,							/* U+011167 */
+	0,							/* U+011168 */
+	0,							/* U+011169 */
+	0,							/* U+01116A */
+	0,							/* U+01116B */
+	0,							/* U+01116C */
+	0,							/* U+01116D */
+	0,							/* U+01116E */
+	0,							/* U+01116F */
+	0,							/* U+011170 */
+	0,							/* U+011171 */
+	0,							/* U+011172 */
+	0,							/* U+011173 */
+	0,							/* U+011174 */
+	0,							/* U+011175 */
+	0,							/* U+011176 */
+	0,							/* U+011177 */
+	0,							/* U+011178 */
+	0,							/* U+011179 */
+	0,							/* U+01117A */
+	0,							/* U+01117B */
+	0,							/* U+01117C */
+	0,							/* U+01117D */
+	0,							/* U+01117E */
+	0,							/* U+01117F */
+	0,							/* U+011180 */
+	0,							/* U+011181 */
+	0,							/* U+011182 */
+	0,							/* U+011183 */
+	0,							/* U+011184 */
+	0,							/* U+011185 */
+	0,							/* U+011186 */
+	0,							/* U+011187 */
+	0,							/* U+011188 */
+	0,							/* U+011189 */
+	0,							/* U+01118A */
+	0,							/* U+01118B */
+	0,							/* U+01118C */
+	0,							/* U+01118D */
+	0,							/* U+01118E */
+	0,							/* U+01118F */
+	0,							/* U+011190 */
+	0,							/* U+011191 */
+	0,							/* U+011192 */
+	0,							/* U+011193 */
+	0,							/* U+011194 */
+	0,							/* U+011195 */
+	0,							/* U+011196 */
+	0,							/* U+011197 */
+	0,							/* U+011198 */
+	0,							/* U+011199 */
+	0,							/* U+01119A */
+	0,							/* U+01119B */
+	0,							/* U+01119C */
+	0,							/* U+01119D */
+	0,							/* U+01119E */
+	0,							/* U+01119F */
+	0,							/* U+0111A0 */
+	0,							/* U+0111A1 */
+	0,							/* U+0111A2 */
+	0,							/* U+0111A3 */
+	0,							/* U+0111A4 */
+	0,							/* U+0111A5 */
+	0,							/* U+0111A6 */
+	0,							/* U+0111A7 */
+	0,							/* U+0111A8 */
+	0,							/* U+0111A9 */
+	0,							/* U+0111AA */
+	0,							/* U+0111AB */
+	0,							/* U+0111AC */
+	0,							/* U+0111AD */
+	0,							/* U+0111AE */
+	0,							/* U+0111AF */
+	0,							/* U+0111B0 */
+	0,							/* U+0111B1 */
+	0,							/* U+0111B2 */
+	0,							/* U+0111B3 */
+	0,							/* U+0111B4 */
+	0,							/* U+0111B5 */
+	0,							/* U+0111B6 */
+	0,							/* U+0111B7 */
+	0,							/* U+0111B8 */
+	0,							/* U+0111B9 */
+	0,							/* U+0111BA */
+	0,							/* U+0111BB */
+	0,							/* U+0111BC */
+	0,							/* U+0111BD */
+	0,							/* U+0111BE */
+	0,							/* U+0111BF */
+	0,							/* U+0111C0 */
+	0,							/* U+0111C1 */
+	0,							/* U+0111C2 */
+	0,							/* U+0111C3 */
+	0,							/* U+0111C4 */
+	0,							/* U+0111C5 */
+	0,							/* U+0111C6 */
+	0,							/* U+0111C7 */
+	0,							/* U+0111C8 */
+	0,							/* U+0111C9 */
+	0,							/* U+0111CA */
+	0,							/* U+0111CB */
+	0,							/* U+0111CC */
+	0,							/* U+0111CD */
+	0,							/* U+0111CE */
+	0,							/* U+0111CF */
+	0,							/* U+0111D0 */
+	0,							/* U+0111D1 */
+	0,							/* U+0111D2 */
+	0,							/* U+0111D3 */
+	0,							/* U+0111D4 */
+	0,							/* U+0111D5 */
+	0,							/* U+0111D6 */
+	0,							/* U+0111D7 */
+	0,							/* U+0111D8 */
+	0,							/* U+0111D9 */
+	0,							/* U+0111DA */
+	0,							/* U+0111DB */
+	0,							/* U+0111DC */
+	0,							/* U+0111DD */
+	0,							/* U+0111DE */
+	0,							/* U+0111DF */
+	0,							/* U+0111E0 */
+	0,							/* U+0111E1 */
+	0,							/* U+0111E2 */
+	0,							/* U+0111E3 */
+	0,							/* U+0111E4 */
+	0,							/* U+0111E5 */
+	0,							/* U+0111E6 */
+	0,							/* U+0111E7 */
+	0,							/* U+0111E8 */
+	0,							/* U+0111E9 */
+	0,							/* U+0111EA */
+	0,							/* U+0111EB */
+	0,							/* U+0111EC */
+	0,							/* U+0111ED */
+	0,							/* U+0111EE */
+	0,							/* U+0111EF */
+	0,							/* U+0111F0 */
+	0,							/* U+0111F1 */
+	0,							/* U+0111F2 */
+	0,							/* U+0111F3 */
+	0,							/* U+0111F4 */
+	0,							/* U+0111F5 */
+	0,							/* U+0111F6 */
+	0,							/* U+0111F7 */
+	0,							/* U+0111F8 */
+	0,							/* U+0111F9 */
+	0,							/* U+0111FA */
+	0,							/* U+0111FB */
+	0,							/* U+0111FC */
+	0,							/* U+0111FD */
+	0,							/* U+0111FE */
+	0,							/* U+0111FF */
+	0,							/* U+011200 */
+	0,							/* U+011201 */
+	0,							/* U+011202 */
+	0,							/* U+011203 */
+	0,							/* U+011204 */
+	0,							/* U+011205 */
+	0,							/* U+011206 */
+	0,							/* U+011207 */
+	0,							/* U+011208 */
+	0,							/* U+011209 */
+	0,							/* U+01120A */
+	0,							/* U+01120B */
+	0,							/* U+01120C */
+	0,							/* U+01120D */
+	0,							/* U+01120E */
+	0,							/* U+01120F */
+	0,							/* U+011210 */
+	0,							/* U+011211 */
+	0,							/* U+011212 */
+	0,							/* U+011213 */
+	0,							/* U+011214 */
+	0,							/* U+011215 */
+	0,							/* U+011216 */
+	0,							/* U+011217 */
+	0,							/* U+011218 */
+	0,							/* U+011219 */
+	0,							/* U+01121A */
+	0,							/* U+01121B */
+	0,							/* U+01121C */
+	0,							/* U+01121D */
+	0,							/* U+01121E */
+	0,							/* U+01121F */
+	0,							/* U+011220 */
+	0,							/* U+011221 */
+	0,							/* U+011222 */
+	0,							/* U+011223 */
+	0,							/* U+011224 */
+	0,							/* U+011225 */
+	0,							/* U+011226 */
+	0,							/* U+011227 */
+	0,							/* U+011228 */
+	0,							/* U+011229 */
+	0,							/* U+01122A */
+	0,							/* U+01122B */
+	0,							/* U+01122C */
+	0,							/* U+01122D */
+	0,							/* U+01122E */
+	0,							/* U+01122F */
+	0,							/* U+011230 */
+	0,							/* U+011231 */
+	0,							/* U+011232 */
+	0,							/* U+011233 */
+	0,							/* U+011234 */
+	0,							/* U+011235 */
+	0,							/* U+011236 */
+	0,							/* U+011237 */
+	0,							/* U+011238 */
+	0,							/* U+011239 */
+	0,							/* U+01123A */
+	0,							/* U+01123B */
+	0,							/* U+01123C */
+	0,							/* U+01123D */
+	0,							/* U+01123E */
+	0,							/* U+01123F */
+	0,							/* U+011240 */
+	0,							/* U+011241 */
+	0,							/* U+011242 */
+	0,							/* U+011243 */
+	0,							/* U+011244 */
+	0,							/* U+011245 */
+	0,							/* U+011246 */
+	0,							/* U+011247 */
+	0,							/* U+011248 */
+	0,							/* U+011249 */
+	0,							/* U+01124A */
+	0,							/* U+01124B */
+	0,							/* U+01124C */
+	0,							/* U+01124D */
+	0,							/* U+01124E */
+	0,							/* U+01124F */
+	0,							/* U+011250 */
+	0,							/* U+011251 */
+	0,							/* U+011252 */
+	0,							/* U+011253 */
+	0,							/* U+011254 */
+	0,							/* U+011255 */
+	0,							/* U+011256 */
+	0,							/* U+011257 */
+	0,							/* U+011258 */
+	0,							/* U+011259 */
+	0,							/* U+01125A */
+	0,							/* U+01125B */
+	0,							/* U+01125C */
+	0,							/* U+01125D */
+	0,							/* U+01125E */
+	0,							/* U+01125F */
+	0,							/* U+011260 */
+	0,							/* U+011261 */
+	0,							/* U+011262 */
+	0,							/* U+011263 */
+	0,							/* U+011264 */
+	0,							/* U+011265 */
+	0,							/* U+011266 */
+	0,							/* U+011267 */
+	0,							/* U+011268 */
+	0,							/* U+011269 */
+	0,							/* U+01126A */
+	0,							/* U+01126B */
+	0,							/* U+01126C */
+	0,							/* U+01126D */
+	0,							/* U+01126E */
+	0,							/* U+01126F */
+	0,							/* U+011270 */
+	0,							/* U+011271 */
+	0,							/* U+011272 */
+	0,							/* U+011273 */
+	0,							/* U+011274 */
+	0,							/* U+011275 */
+	0,							/* U+011276 */
+	0,							/* U+011277 */
+	0,							/* U+011278 */
+	0,							/* U+011279 */
+	0,							/* U+01127A */
+	0,							/* U+01127B */
+	0,							/* U+01127C */
+	0,							/* U+01127D */
+	0,							/* U+01127E */
+	0,							/* U+01127F */
+	0,							/* U+011280 */
+	0,							/* U+011281 */
+	0,							/* U+011282 */
+	0,							/* U+011283 */
+	0,							/* U+011284 */
+	0,							/* U+011285 */
+	0,							/* U+011286 */
+	0,							/* U+011287 */
+	0,							/* U+011288 */
+	0,							/* U+011289 */
+	0,							/* U+01128A */
+	0,							/* U+01128B */
+	0,							/* U+01128C */
+	0,							/* U+01128D */
+	0,							/* U+01128E */
+	0,							/* U+01128F */
+	0,							/* U+011290 */
+	0,							/* U+011291 */
+	0,							/* U+011292 */
+	0,							/* U+011293 */
+	0,							/* U+011294 */
+	0,							/* U+011295 */
+	0,							/* U+011296 */
+	0,							/* U+011297 */
+	0,							/* U+011298 */
+	0,							/* U+011299 */
+	0,							/* U+01129A */
+	0,							/* U+01129B */
+	0,							/* U+01129C */
+	0,							/* U+01129D */
+	0,							/* U+01129E */
+	0,							/* U+01129F */
+	0,							/* U+0112A0 */
+	0,							/* U+0112A1 */
+	0,							/* U+0112A2 */
+	0,							/* U+0112A3 */
+	0,							/* U+0112A4 */
+	0,							/* U+0112A5 */
+	0,							/* U+0112A6 */
+	0,							/* U+0112A7 */
+	0,							/* U+0112A8 */
+	0,							/* U+0112A9 */
+	0,							/* U+0112AA */
+	0,							/* U+0112AB */
+	0,							/* U+0112AC */
+	0,							/* U+0112AD */
+	0,							/* U+0112AE */
+	0,							/* U+0112AF */
+	0,							/* U+0112B0 */
+	0,							/* U+0112B1 */
+	0,							/* U+0112B2 */
+	0,							/* U+0112B3 */
+	0,							/* U+0112B4 */
+	0,							/* U+0112B5 */
+	0,							/* U+0112B6 */
+	0,							/* U+0112B7 */
+	0,							/* U+0112B8 */
+	0,							/* U+0112B9 */
+	0,							/* U+0112BA */
+	0,							/* U+0112BB */
+	0,							/* U+0112BC */
+	0,							/* U+0112BD */
+	0,							/* U+0112BE */
+	0,							/* U+0112BF */
+	0,							/* U+0112C0 */
+	0,							/* U+0112C1 */
+	0,							/* U+0112C2 */
+	0,							/* U+0112C3 */
+	0,							/* U+0112C4 */
+	0,							/* U+0112C5 */
+	0,							/* U+0112C6 */
+	0,							/* U+0112C7 */
+	0,							/* U+0112C8 */
+	0,							/* U+0112C9 */
+	0,							/* U+0112CA */
+	0,							/* U+0112CB */
+	0,							/* U+0112CC */
+	0,							/* U+0112CD */
+	0,							/* U+0112CE */
+	0,							/* U+0112CF */
+	0,							/* U+0112D0 */
+	0,							/* U+0112D1 */
+	0,							/* U+0112D2 */
+	0,							/* U+0112D3 */
+	0,							/* U+0112D4 */
+	0,							/* U+0112D5 */
+	0,							/* U+0112D6 */
+	0,							/* U+0112D7 */
+	0,							/* U+0112D8 */
+	0,							/* U+0112D9 */
+	0,							/* U+0112DA */
+	0,							/* U+0112DB */
+	0,							/* U+0112DC */
+	0,							/* U+0112DD */
+	0,							/* U+0112DE */
+	0,							/* U+0112DF */
+	0,							/* U+0112E0 */
+	0,							/* U+0112E1 */
+	0,							/* U+0112E2 */
+	0,							/* U+0112E3 */
+	0,							/* U+0112E4 */
+	0,							/* U+0112E5 */
+	0,							/* U+0112E6 */
+	0,							/* U+0112E7 */
+	0,							/* U+0112E8 */
+	0,							/* U+0112E9 */
+	0,							/* U+0112EA */
+	0,							/* U+0112EB */
+	0,							/* U+0112EC */
+	0,							/* U+0112ED */
+	0,							/* U+0112EE */
+	0,							/* U+0112EF */
+	0,							/* U+0112F0 */
+	0,							/* U+0112F1 */
+	0,							/* U+0112F2 */
+	0,							/* U+0112F3 */
+	0,							/* U+0112F4 */
+	0,							/* U+0112F5 */
+	0,							/* U+0112F6 */
+	0,							/* U+0112F7 */
+	0,							/* U+0112F8 */
+	0,							/* U+0112F9 */
+	0,							/* U+0112FA */
+	0,							/* U+0112FB */
+	0,							/* U+0112FC */
+	0,							/* U+0112FD */
+	0,							/* U+0112FE */
+	0,							/* U+0112FF */
+	0,							/* U+011300 */
+	0,							/* U+011301 */
+	0,							/* U+011302 */
+	0,							/* U+011303 */
+	0,							/* U+011304 */
+	0,							/* U+011305 */
+	0,							/* U+011306 */
+	0,							/* U+011307 */
+	0,							/* U+011308 */
+	0,							/* U+011309 */
+	0,							/* U+01130A */
+	0,							/* U+01130B */
+	0,							/* U+01130C */
+	0,							/* U+01130D */
+	0,							/* U+01130E */
+	0,							/* U+01130F */
+	0,							/* U+011310 */
+	0,							/* U+011311 */
+	0,							/* U+011312 */
+	0,							/* U+011313 */
+	0,							/* U+011314 */
+	0,							/* U+011315 */
+	0,							/* U+011316 */
+	0,							/* U+011317 */
+	0,							/* U+011318 */
+	0,							/* U+011319 */
+	0,							/* U+01131A */
+	0,							/* U+01131B */
+	0,							/* U+01131C */
+	0,							/* U+01131D */
+	0,							/* U+01131E */
+	0,							/* U+01131F */
+	0,							/* U+011320 */
+	0,							/* U+011321 */
+	0,							/* U+011322 */
+	0,							/* U+011323 */
+	0,							/* U+011324 */
+	0,							/* U+011325 */
+	0,							/* U+011326 */
+	0,							/* U+011327 */
+	0,							/* U+011328 */
+	0,							/* U+011329 */
+	0,							/* U+01132A */
+	0,							/* U+01132B */
+	0,							/* U+01132C */
+	0,							/* U+01132D */
+	0,							/* U+01132E */
+	0,							/* U+01132F */
+	0,							/* U+011330 */
+	0,							/* U+011331 */
+	0,							/* U+011332 */
+	0,							/* U+011333 */
+	0,							/* U+011334 */
+	0,							/* U+011335 */
+	0,							/* U+011336 */
+	0,							/* U+011337 */
+	0,							/* U+011338 */
+	0,							/* U+011339 */
+	0,							/* U+01133A */
+	0,							/* U+01133B */
+	0,							/* U+01133C */
+	0,							/* U+01133D */
+	0,							/* U+01133E */
+	0,							/* U+01133F */
+	0,							/* U+011340 */
+	0,							/* U+011341 */
+	0,							/* U+011342 */
+	0,							/* U+011343 */
+	0,							/* U+011344 */
+	0,							/* U+011345 */
+	0,							/* U+011346 */
+	6073,						/* U+011347 */
+	0,							/* U+011348 */
+	0,							/* U+011349 */
+	0,							/* U+01134A */
+	0,							/* U+01134B */
+	0,							/* U+01134C */
+	0,							/* U+01134D */
+	0,							/* U+01134E */
+	0,							/* U+01134F */
+	0,							/* U+011350 */
+	0,							/* U+011351 */
+	0,							/* U+011352 */
+	0,							/* U+011353 */
+	0,							/* U+011354 */
+	0,							/* U+011355 */
+	0,							/* U+011356 */
+	0,							/* U+011357 */
+	0,							/* U+011358 */
+	0,							/* U+011359 */
+	0,							/* U+01135A */
+	0,							/* U+01135B */
+	0,							/* U+01135C */
+	0,							/* U+01135D */
+	0,							/* U+01135E */
+	0,							/* U+01135F */
+	0,							/* U+011360 */
+	0,							/* U+011361 */
+	0,							/* U+011362 */
+	0,							/* U+011363 */
+	0,							/* U+011364 */
+	0,							/* U+011365 */
+	0,							/* U+011366 */
+	0,							/* U+011367 */
+	0,							/* U+011368 */
+	0,							/* U+011369 */
+	0,							/* U+01136A */
+	0,							/* U+01136B */
+	0,							/* U+01136C */
+	0,							/* U+01136D */
+	0,							/* U+01136E */
+	0,							/* U+01136F */
+	0,							/* U+011370 */
+	0,							/* U+011371 */
+	0,							/* U+011372 */
+	0,							/* U+011373 */
+	0,							/* U+011374 */
+	0,							/* U+011375 */
+	0,							/* U+011376 */
+	0,							/* U+011377 */
+	0,							/* U+011378 */
+	0,							/* U+011379 */
+	0,							/* U+01137A */
+	0,							/* U+01137B */
+	0,							/* U+01137C */
+	0,							/* U+01137D */
+	0,							/* U+01137E */
+	0,							/* U+01137F */
+	0,							/* U+011380 */
+	0,							/* U+011381 */
+	6102,						/* U+011382 */
+	0,							/* U+011383 */
+	6106,						/* U+011384 */
+	0,							/* U+011385 */
+	0,							/* U+011386 */
+	0,							/* U+011387 */
+	0,							/* U+011388 */
+	0,							/* U+011389 */
+	0,							/* U+01138A */
+	6110,						/* U+01138B */
+	0,							/* U+01138C */
+	0,							/* U+01138D */
+	0,							/* U+01138E */
+	0,							/* U+01138F */
+	6114,						/* U+011390 */
+	0,							/* U+011391 */
+	0,							/* U+011392 */
+	0,							/* U+011393 */
+	0,							/* U+011394 */
+	0,							/* U+011395 */
+	0,							/* U+011396 */
+	0,							/* U+011397 */
+	0,							/* U+011398 */
+	0,							/* U+011399 */
+	0,							/* U+01139A */
+	0,							/* U+01139B */
+	0,							/* U+01139C */
+	0,							/* U+01139D */
+	0,							/* U+01139E */
+	0,							/* U+01139F */
+	0,							/* U+0113A0 */
+	0,							/* U+0113A1 */
+	0,							/* U+0113A2 */
+	0,							/* U+0113A3 */
+	0,							/* U+0113A4 */
+	0,							/* U+0113A5 */
+	0,							/* U+0113A6 */
+	0,							/* U+0113A7 */
+	0,							/* U+0113A8 */
+	0,							/* U+0113A9 */
+	0,							/* U+0113AA */
+	0,							/* U+0113AB */
+	0,							/* U+0113AC */
+	0,							/* U+0113AD */
+	0,							/* U+0113AE */
+	0,							/* U+0113AF */
+	0,							/* U+0113B0 */
+	0,							/* U+0113B1 */
+	0,							/* U+0113B2 */
+	0,							/* U+0113B3 */
+	0,							/* U+0113B4 */
+	0,							/* U+0113B5 */
+	0,							/* U+0113B6 */
+	0,							/* U+0113B7 */
+	0,							/* U+0113B8 */
+	0,							/* U+0113B9 */
+	0,							/* U+0113BA */
+	0,							/* U+0113BB */
+	0,							/* U+0113BC */
+	0,							/* U+0113BD */
+	0,							/* U+0113BE */
+	0,							/* U+0113BF */
+	0,							/* U+0113C0 */
+	0,							/* U+0113C1 */
+	6118,						/* U+0113C2 */
+	0,							/* U+0113C3 */
+	0,							/* U+0113C4 */
+	0,							/* U+0113C5 */
+	0,							/* U+0113C6 */
+	0,							/* U+0113C7 */
+	0,							/* U+0113C8 */
+	0,							/* U+0113C9 */
+	0,							/* U+0113CA */
+	0,							/* U+0113CB */
+	0,							/* U+0113CC */
+	0,							/* U+0113CD */
+	0,							/* U+0113CE */
+	0,							/* U+0113CF */
+	0,							/* U+0113D0 */
+	0,							/* U+0113D1 */
+	0,							/* U+0113D2 */
+	0,							/* U+0113D3 */
+	0,							/* U+0113D4 */
+	0,							/* U+0113D5 */
+	0,							/* U+0113D6 */
+	0,							/* U+0113D7 */
+	0,							/* U+0113D8 */
+	0,							/* U+0113D9 */
+	0,							/* U+0113DA */
+	0,							/* U+0113DB */
+	0,							/* U+0113DC */
+	0,							/* U+0113DD */
+	0,							/* U+0113DE */
+	0,							/* U+0113DF */
+	0,							/* U+0113E0 */
+	0,							/* U+0113E1 */
+	0,							/* U+0113E2 */
+	0,							/* U+0113E3 */
+	0,							/* U+0113E4 */
+	0,							/* U+0113E5 */
+	0,							/* U+0113E6 */
+	0,							/* U+0113E7 */
+	0,							/* U+0113E8 */
+	0,							/* U+0113E9 */
+	0,							/* U+0113EA */
+	0,							/* U+0113EB */
+	0,							/* U+0113EC */
+	0,							/* U+0113ED */
+	0,							/* U+0113EE */
+	0,							/* U+0113EF */
+	0,							/* U+0113F0 */
+	0,							/* U+0113F1 */
+	0,							/* U+0113F2 */
+	0,							/* U+0113F3 */
+	0,							/* U+0113F4 */
+	0,							/* U+0113F5 */
+	0,							/* U+0113F6 */
+	0,							/* U+0113F7 */
+	0,							/* U+0113F8 */
+	0,							/* U+0113F9 */
+	0,							/* U+0113FA */
+	0,							/* U+0113FB */
+	0,							/* U+0113FC */
+	0,							/* U+0113FD */
+	0,							/* U+0113FE */
+	0,							/* U+0113FF */
+	0,							/* U+011400 */
+	0,							/* U+011401 */
+	0,							/* U+011402 */
+	0,							/* U+011403 */
+	0,							/* U+011404 */
+	0,							/* U+011405 */
+	0,							/* U+011406 */
+	0,							/* U+011407 */
+	0,							/* U+011408 */
+	0,							/* U+011409 */
+	0,							/* U+01140A */
+	0,							/* U+01140B */
+	0,							/* U+01140C */
+	0,							/* U+01140D */
+	0,							/* U+01140E */
+	0,							/* U+01140F */
+	0,							/* U+011410 */
+	0,							/* U+011411 */
+	0,							/* U+011412 */
+	0,							/* U+011413 */
+	0,							/* U+011414 */
+	0,							/* U+011415 */
+	0,							/* U+011416 */
+	0,							/* U+011417 */
+	0,							/* U+011418 */
+	0,							/* U+011419 */
+	0,							/* U+01141A */
+	0,							/* U+01141B */
+	0,							/* U+01141C */
+	0,							/* U+01141D */
+	0,							/* U+01141E */
+	0,							/* U+01141F */
+	0,							/* U+011420 */
+	0,							/* U+011421 */
+	0,							/* U+011422 */
+	0,							/* U+011423 */
+	0,							/* U+011424 */
+	0,							/* U+011425 */
+	0,							/* U+011426 */
+	0,							/* U+011427 */
+	0,							/* U+011428 */
+	0,							/* U+011429 */
+	0,							/* U+01142A */
+	0,							/* U+01142B */
+	0,							/* U+01142C */
+	0,							/* U+01142D */
+	0,							/* U+01142E */
+	0,							/* U+01142F */
+	0,							/* U+011430 */
+	0,							/* U+011431 */
+	0,							/* U+011432 */
+	0,							/* U+011433 */
+	0,							/* U+011434 */
+	0,							/* U+011435 */
+	0,							/* U+011436 */
+	0,							/* U+011437 */
+	0,							/* U+011438 */
+	0,							/* U+011439 */
+	0,							/* U+01143A */
+	0,							/* U+01143B */
+	0,							/* U+01143C */
+	0,							/* U+01143D */
+	0,							/* U+01143E */
+	0,							/* U+01143F */
+	0,							/* U+011440 */
+	0,							/* U+011441 */
+	0,							/* U+011442 */
+	0,							/* U+011443 */
+	0,							/* U+011444 */
+	0,							/* U+011445 */
+	0,							/* U+011446 */
+	0,							/* U+011447 */
+	0,							/* U+011448 */
+	0,							/* U+011449 */
+	0,							/* U+01144A */
+	0,							/* U+01144B */
+	0,							/* U+01144C */
+	0,							/* U+01144D */
+	0,							/* U+01144E */
+	0,							/* U+01144F */
+	0,							/* U+011450 */
+	0,							/* U+011451 */
+	0,							/* U+011452 */
+	0,							/* U+011453 */
+	0,							/* U+011454 */
+	0,							/* U+011455 */
+	0,							/* U+011456 */
+	0,							/* U+011457 */
+	0,							/* U+011458 */
+	0,							/* U+011459 */
+	0,							/* U+01145A */
+	0,							/* U+01145B */
+	0,							/* U+01145C */
+	0,							/* U+01145D */
+	0,							/* U+01145E */
+	0,							/* U+01145F */
+	0,							/* U+011460 */
+	0,							/* U+011461 */
+	0,							/* U+011462 */
+	0,							/* U+011463 */
+	0,							/* U+011464 */
+	0,							/* U+011465 */
+	0,							/* U+011466 */
+	0,							/* U+011467 */
+	0,							/* U+011468 */
+	0,							/* U+011469 */
+	0,							/* U+01146A */
+	0,							/* U+01146B */
+	0,							/* U+01146C */
+	0,							/* U+01146D */
+	0,							/* U+01146E */
+	0,							/* U+01146F */
+	0,							/* U+011470 */
+	0,							/* U+011471 */
+	0,							/* U+011472 */
+	0,							/* U+011473 */
+	0,							/* U+011474 */
+	0,							/* U+011475 */
+	0,							/* U+011476 */
+	0,							/* U+011477 */
+	0,							/* U+011478 */
+	0,							/* U+011479 */
+	0,							/* U+01147A */
+	0,							/* U+01147B */
+	0,							/* U+01147C */
+	0,							/* U+01147D */
+	0,							/* U+01147E */
+	0,							/* U+01147F */
+	0,							/* U+011480 */
+	0,							/* U+011481 */
+	0,							/* U+011482 */
+	0,							/* U+011483 */
+	0,							/* U+011484 */
+	0,							/* U+011485 */
+	0,							/* U+011486 */
+	0,							/* U+011487 */
+	0,							/* U+011488 */
+	0,							/* U+011489 */
+	0,							/* U+01148A */
+	0,							/* U+01148B */
+	0,							/* U+01148C */
+	0,							/* U+01148D */
+	0,							/* U+01148E */
+	0,							/* U+01148F */
+	0,							/* U+011490 */
+	0,							/* U+011491 */
+	0,							/* U+011492 */
+	0,							/* U+011493 */
+	0,							/* U+011494 */
+	0,							/* U+011495 */
+	0,							/* U+011496 */
+	0,							/* U+011497 */
+	0,							/* U+011498 */
+	0,							/* U+011499 */
+	0,							/* U+01149A */
+	0,							/* U+01149B */
+	0,							/* U+01149C */
+	0,							/* U+01149D */
+	0,							/* U+01149E */
+	0,							/* U+01149F */
+	0,							/* U+0114A0 */
+	0,							/* U+0114A1 */
+	0,							/* U+0114A2 */
+	0,							/* U+0114A3 */
+	0,							/* U+0114A4 */
+	0,							/* U+0114A5 */
+	0,							/* U+0114A6 */
+	0,							/* U+0114A7 */
+	0,							/* U+0114A8 */
+	0,							/* U+0114A9 */
+	0,							/* U+0114AA */
+	0,							/* U+0114AB */
+	0,							/* U+0114AC */
+	0,							/* U+0114AD */
+	0,							/* U+0114AE */
+	0,							/* U+0114AF */
+	0,							/* U+0114B0 */
+	0,							/* U+0114B1 */
+	0,							/* U+0114B2 */
+	0,							/* U+0114B3 */
+	0,							/* U+0114B4 */
+	0,							/* U+0114B5 */
+	0,							/* U+0114B6 */
+	0,							/* U+0114B7 */
+	0,							/* U+0114B8 */
+	6139,						/* U+0114B9 */
+	0,							/* U+0114BA */
+	0,							/* U+0114BB */
+	0,							/* U+0114BC */
+	0,							/* U+0114BD */
+	0,							/* U+0114BE */
+	0,							/* U+0114BF */
+	0,							/* U+0114C0 */
+	0,							/* U+0114C1 */
+	0,							/* U+0114C2 */
+	0,							/* U+0114C3 */
+	0,							/* U+0114C4 */
+	0,							/* U+0114C5 */
+	0,							/* U+0114C6 */
+	0,							/* U+0114C7 */
+	0,							/* U+0114C8 */
+	0,							/* U+0114C9 */
+	0,							/* U+0114CA */
+	0,							/* U+0114CB */
+	0,							/* U+0114CC */
+	0,							/* U+0114CD */
+	0,							/* U+0114CE */
+	0,							/* U+0114CF */
+	0,							/* U+0114D0 */
+	0,							/* U+0114D1 */
+	0,							/* U+0114D2 */
+	0,							/* U+0114D3 */
+	0,							/* U+0114D4 */
+	0,							/* U+0114D5 */
+	0,							/* U+0114D6 */
+	0,							/* U+0114D7 */
+	0,							/* U+0114D8 */
+	0,							/* U+0114D9 */
+	0,							/* U+0114DA */
+	0,							/* U+0114DB */
+	0,							/* U+0114DC */
+	0,							/* U+0114DD */
+	0,							/* U+0114DE */
+	0,							/* U+0114DF */
+	0,							/* U+0114E0 */
+	0,							/* U+0114E1 */
+	0,							/* U+0114E2 */
+	0,							/* U+0114E3 */
+	0,							/* U+0114E4 */
+	0,							/* U+0114E5 */
+	0,							/* U+0114E6 */
+	0,							/* U+0114E7 */
+	0,							/* U+0114E8 */
+	0,							/* U+0114E9 */
+	0,							/* U+0114EA */
+	0,							/* U+0114EB */
+	0,							/* U+0114EC */
+	0,							/* U+0114ED */
+	0,							/* U+0114EE */
+	0,							/* U+0114EF */
+	0,							/* U+0114F0 */
+	0,							/* U+0114F1 */
+	0,							/* U+0114F2 */
+	0,							/* U+0114F3 */
+	0,							/* U+0114F4 */
+	0,							/* U+0114F5 */
+	0,							/* U+0114F6 */
+	0,							/* U+0114F7 */
+	0,							/* U+0114F8 */
+	0,							/* U+0114F9 */
+	0,							/* U+0114FA */
+	0,							/* U+0114FB */
+	0,							/* U+0114FC */
+	0,							/* U+0114FD */
+	0,							/* U+0114FE */
+	0,							/* U+0114FF */
+	0,							/* U+011500 */
+	0,							/* U+011501 */
+	0,							/* U+011502 */
+	0,							/* U+011503 */
+	0,							/* U+011504 */
+	0,							/* U+011505 */
+	0,							/* U+011506 */
+	0,							/* U+011507 */
+	0,							/* U+011508 */
+	0,							/* U+011509 */
+	0,							/* U+01150A */
+	0,							/* U+01150B */
+	0,							/* U+01150C */
+	0,							/* U+01150D */
+	0,							/* U+01150E */
+	0,							/* U+01150F */
+	0,							/* U+011510 */
+	0,							/* U+011511 */
+	0,							/* U+011512 */
+	0,							/* U+011513 */
+	0,							/* U+011514 */
+	0,							/* U+011515 */
+	0,							/* U+011516 */
+	0,							/* U+011517 */
+	0,							/* U+011518 */
+	0,							/* U+011519 */
+	0,							/* U+01151A */
+	0,							/* U+01151B */
+	0,							/* U+01151C */
+	0,							/* U+01151D */
+	0,							/* U+01151E */
+	0,							/* U+01151F */
+	0,							/* U+011520 */
+	0,							/* U+011521 */
+	0,							/* U+011522 */
+	0,							/* U+011523 */
+	0,							/* U+011524 */
+	0,							/* U+011525 */
+	0,							/* U+011526 */
+	0,							/* U+011527 */
+	0,							/* U+011528 */
+	0,							/* U+011529 */
+	0,							/* U+01152A */
+	0,							/* U+01152B */
+	0,							/* U+01152C */
+	0,							/* U+01152D */
+	0,							/* U+01152E */
+	0,							/* U+01152F */
+	0,							/* U+011530 */
+	0,							/* U+011531 */
+	0,							/* U+011532 */
+	0,							/* U+011533 */
+	0,							/* U+011534 */
+	0,							/* U+011535 */
+	0,							/* U+011536 */
+	0,							/* U+011537 */
+	0,							/* U+011538 */
+	0,							/* U+011539 */
+	0,							/* U+01153A */
+	0,							/* U+01153B */
+	0,							/* U+01153C */
+	0,							/* U+01153D */
+	0,							/* U+01153E */
+	0,							/* U+01153F */
+	0,							/* U+011540 */
+	0,							/* U+011541 */
+	0,							/* U+011542 */
+	0,							/* U+011543 */
+	0,							/* U+011544 */
+	0,							/* U+011545 */
+	0,							/* U+011546 */
+	0,							/* U+011547 */
+	0,							/* U+011548 */
+	0,							/* U+011549 */
+	0,							/* U+01154A */
+	0,							/* U+01154B */
+	0,							/* U+01154C */
+	0,							/* U+01154D */
+	0,							/* U+01154E */
+	0,							/* U+01154F */
+	0,							/* U+011550 */
+	0,							/* U+011551 */
+	0,							/* U+011552 */
+	0,							/* U+011553 */
+	0,							/* U+011554 */
+	0,							/* U+011555 */
+	0,							/* U+011556 */
+	0,							/* U+011557 */
+	0,							/* U+011558 */
+	0,							/* U+011559 */
+	0,							/* U+01155A */
+	0,							/* U+01155B */
+	0,							/* U+01155C */
+	0,							/* U+01155D */
+	0,							/* U+01155E */
+	0,							/* U+01155F */
+	0,							/* U+011560 */
+	0,							/* U+011561 */
+	0,							/* U+011562 */
+	0,							/* U+011563 */
+	0,							/* U+011564 */
+	0,							/* U+011565 */
+	0,							/* U+011566 */
+	0,							/* U+011567 */
+	0,							/* U+011568 */
+	0,							/* U+011569 */
+	0,							/* U+01156A */
+	0,							/* U+01156B */
+	0,							/* U+01156C */
+	0,							/* U+01156D */
+	0,							/* U+01156E */
+	0,							/* U+01156F */
+	0,							/* U+011570 */
+	0,							/* U+011571 */
+	0,							/* U+011572 */
+	0,							/* U+011573 */
+	0,							/* U+011574 */
+	0,							/* U+011575 */
+	0,							/* U+011576 */
+	0,							/* U+011577 */
+	0,							/* U+011578 */
+	0,							/* U+011579 */
+	0,							/* U+01157A */
+	0,							/* U+01157B */
+	0,							/* U+01157C */
+	0,							/* U+01157D */
+	0,							/* U+01157E */
+	0,							/* U+01157F */
+	0,							/* U+011580 */
+	0,							/* U+011581 */
+	0,							/* U+011582 */
+	0,							/* U+011583 */
+	0,							/* U+011584 */
+	0,							/* U+011585 */
+	0,							/* U+011586 */
+	0,							/* U+011587 */
+	0,							/* U+011588 */
+	0,							/* U+011589 */
+	0,							/* U+01158A */
+	0,							/* U+01158B */
+	0,							/* U+01158C */
+	0,							/* U+01158D */
+	0,							/* U+01158E */
+	0,							/* U+01158F */
+	0,							/* U+011590 */
+	0,							/* U+011591 */
+	0,							/* U+011592 */
+	0,							/* U+011593 */
+	0,							/* U+011594 */
+	0,							/* U+011595 */
+	0,							/* U+011596 */
+	0,							/* U+011597 */
+	0,							/* U+011598 */
+	0,							/* U+011599 */
+	0,							/* U+01159A */
+	0,							/* U+01159B */
+	0,							/* U+01159C */
+	0,							/* U+01159D */
+	0,							/* U+01159E */
+	0,							/* U+01159F */
+	0,							/* U+0115A0 */
+	0,							/* U+0115A1 */
+	0,							/* U+0115A2 */
+	0,							/* U+0115A3 */
+	0,							/* U+0115A4 */
+	0,							/* U+0115A5 */
+	0,							/* U+0115A6 */
+	0,							/* U+0115A7 */
+	0,							/* U+0115A8 */
+	0,							/* U+0115A9 */
+	0,							/* U+0115AA */
+	0,							/* U+0115AB */
+	0,							/* U+0115AC */
+	0,							/* U+0115AD */
+	0,							/* U+0115AE */
+	0,							/* U+0115AF */
+	0,							/* U+0115B0 */
+	0,							/* U+0115B1 */
+	0,							/* U+0115B2 */
+	0,							/* U+0115B3 */
+	0,							/* U+0115B4 */
+	0,							/* U+0115B5 */
+	0,							/* U+0115B6 */
+	0,							/* U+0115B7 */
+	6156,						/* U+0115B8 */
+	6160,						/* U+0115B9 */
+	0,							/* U+0115BA */
+	0,							/* U+0115BB */
+	0,							/* U+0115BC */
+	0,							/* U+0115BD */
+	0,							/* U+0115BE */
+	0,							/* U+0115BF */
+	0,							/* U+0115C0 */
+	0,							/* U+0115C1 */
+	0,							/* U+0115C2 */
+	0,							/* U+0115C3 */
+	0,							/* U+0115C4 */
+	0,							/* U+0115C5 */
+	0,							/* U+0115C6 */
+	0,							/* U+0115C7 */
+	0,							/* U+0115C8 */
+	0,							/* U+0115C9 */
+	0,							/* U+0115CA */
+	0,							/* U+0115CB */
+	0,							/* U+0115CC */
+	0,							/* U+0115CD */
+	0,							/* U+0115CE */
+	0,							/* U+0115CF */
+	0,							/* U+0115D0 */
+	0,							/* U+0115D1 */
+	0,							/* U+0115D2 */
+	0,							/* U+0115D3 */
+	0,							/* U+0115D4 */
+	0,							/* U+0115D5 */
+	0,							/* U+0115D6 */
+	0,							/* U+0115D7 */
+	0,							/* U+0115D8 */
+	0,							/* U+0115D9 */
+	0,							/* U+0115DA */
+	0,							/* U+0115DB */
+	0,							/* U+0115DC */
+	0,							/* U+0115DD */
+	0,							/* U+0115DE */
+	0,							/* U+0115DF */
+	0,							/* U+0115E0 */
+	0,							/* U+0115E1 */
+	0,							/* U+0115E2 */
+	0,							/* U+0115E3 */
+	0,							/* U+0115E4 */
+	0,							/* U+0115E5 */
+	0,							/* U+0115E6 */
+	0,							/* U+0115E7 */
+	0,							/* U+0115E8 */
+	0,							/* U+0115E9 */
+	0,							/* U+0115EA */
+	0,							/* U+0115EB */
+	0,							/* U+0115EC */
+	0,							/* U+0115ED */
+	0,							/* U+0115EE */
+	0,							/* U+0115EF */
+	0,							/* U+0115F0 */
+	0,							/* U+0115F1 */
+	0,							/* U+0115F2 */
+	0,							/* U+0115F3 */
+	0,							/* U+0115F4 */
+	0,							/* U+0115F5 */
+	0,							/* U+0115F6 */
+	0,							/* U+0115F7 */
+	0,							/* U+0115F8 */
+	0,							/* U+0115F9 */
+	0,							/* U+0115FA */
+	0,							/* U+0115FB */
+	0,							/* U+0115FC */
+	0,							/* U+0115FD */
+	0,							/* U+0115FE */
+	0,							/* U+0115FF */
+	0,							/* U+011600 */
+	0,							/* U+011601 */
+	0,							/* U+011602 */
+	0,							/* U+011603 */
+	0,							/* U+011604 */
+	0,							/* U+011605 */
+	0,							/* U+011606 */
+	0,							/* U+011607 */
+	0,							/* U+011608 */
+	0,							/* U+011609 */
+	0,							/* U+01160A */
+	0,							/* U+01160B */
+	0,							/* U+01160C */
+	0,							/* U+01160D */
+	0,							/* U+01160E */
+	0,							/* U+01160F */
+	0,							/* U+011610 */
+	0,							/* U+011611 */
+	0,							/* U+011612 */
+	0,							/* U+011613 */
+	0,							/* U+011614 */
+	0,							/* U+011615 */
+	0,							/* U+011616 */
+	0,							/* U+011617 */
+	0,							/* U+011618 */
+	0,							/* U+011619 */
+	0,							/* U+01161A */
+	0,							/* U+01161B */
+	0,							/* U+01161C */
+	0,							/* U+01161D */
+	0,							/* U+01161E */
+	0,							/* U+01161F */
+	0,							/* U+011620 */
+	0,							/* U+011621 */
+	0,							/* U+011622 */
+	0,							/* U+011623 */
+	0,							/* U+011624 */
+	0,							/* U+011625 */
+	0,							/* U+011626 */
+	0,							/* U+011627 */
+	0,							/* U+011628 */
+	0,							/* U+011629 */
+	0,							/* U+01162A */
+	0,							/* U+01162B */
+	0,							/* U+01162C */
+	0,							/* U+01162D */
+	0,							/* U+01162E */
+	0,							/* U+01162F */
+	0,							/* U+011630 */
+	0,							/* U+011631 */
+	0,							/* U+011632 */
+	0,							/* U+011633 */
+	0,							/* U+011634 */
+	0,							/* U+011635 */
+	0,							/* U+011636 */
+	0,							/* U+011637 */
+	0,							/* U+011638 */
+	0,							/* U+011639 */
+	0,							/* U+01163A */
+	0,							/* U+01163B */
+	0,							/* U+01163C */
+	0,							/* U+01163D */
+	0,							/* U+01163E */
+	0,							/* U+01163F */
+	0,							/* U+011640 */
+	0,							/* U+011641 */
+	0,							/* U+011642 */
+	0,							/* U+011643 */
+	0,							/* U+011644 */
+	0,							/* U+011645 */
+	0,							/* U+011646 */
+	0,							/* U+011647 */
+	0,							/* U+011648 */
+	0,							/* U+011649 */
+	0,							/* U+01164A */
+	0,							/* U+01164B */
+	0,							/* U+01164C */
+	0,							/* U+01164D */
+	0,							/* U+01164E */
+	0,							/* U+01164F */
+	0,							/* U+011650 */
+	0,							/* U+011651 */
+	0,							/* U+011652 */
+	0,							/* U+011653 */
+	0,							/* U+011654 */
+	0,							/* U+011655 */
+	0,							/* U+011656 */
+	0,							/* U+011657 */
+	0,							/* U+011658 */
+	0,							/* U+011659 */
+	0,							/* U+01165A */
+	0,							/* U+01165B */
+	0,							/* U+01165C */
+	0,							/* U+01165D */
+	0,							/* U+01165E */
+	0,							/* U+01165F */
+	0,							/* U+011660 */
+	0,							/* U+011661 */
+	0,							/* U+011662 */
+	0,							/* U+011663 */
+	0,							/* U+011664 */
+	0,							/* U+011665 */
+	0,							/* U+011666 */
+	0,							/* U+011667 */
+	0,							/* U+011668 */
+	0,							/* U+011669 */
+	0,							/* U+01166A */
+	0,							/* U+01166B */
+	0,							/* U+01166C */
+	0,							/* U+01166D */
+	0,							/* U+01166E */
+	0,							/* U+01166F */
+	0,							/* U+011670 */
+	0,							/* U+011671 */
+	0,							/* U+011672 */
+	0,							/* U+011673 */
+	0,							/* U+011674 */
+	0,							/* U+011675 */
+	0,							/* U+011676 */
+	0,							/* U+011677 */
+	0,							/* U+011678 */
+	0,							/* U+011679 */
+	0,							/* U+01167A */
+	0,							/* U+01167B */
+	0,							/* U+01167C */
+	0,							/* U+01167D */
+	0,							/* U+01167E */
+	0,							/* U+01167F */
+	0,							/* U+011680 */
+	0,							/* U+011681 */
+	0,							/* U+011682 */
+	0,							/* U+011683 */
+	0,							/* U+011684 */
+	0,							/* U+011685 */
+	0,							/* U+011686 */
+	0,							/* U+011687 */
+	0,							/* U+011688 */
+	0,							/* U+011689 */
+	0,							/* U+01168A */
+	0,							/* U+01168B */
+	0,							/* U+01168C */
+	0,							/* U+01168D */
+	0,							/* U+01168E */
+	0,							/* U+01168F */
+	0,							/* U+011690 */
+	0,							/* U+011691 */
+	0,							/* U+011692 */
+	0,							/* U+011693 */
+	0,							/* U+011694 */
+	0,							/* U+011695 */
+	0,							/* U+011696 */
+	0,							/* U+011697 */
+	0,							/* U+011698 */
+	0,							/* U+011699 */
+	0,							/* U+01169A */
+	0,							/* U+01169B */
+	0,							/* U+01169C */
+	0,							/* U+01169D */
+	0,							/* U+01169E */
+	0,							/* U+01169F */
+	0,							/* U+0116A0 */
+	0,							/* U+0116A1 */
+	0,							/* U+0116A2 */
+	0,							/* U+0116A3 */
+	0,							/* U+0116A4 */
+	0,							/* U+0116A5 */
+	0,							/* U+0116A6 */
+	0,							/* U+0116A7 */
+	0,							/* U+0116A8 */
+	0,							/* U+0116A9 */
+	0,							/* U+0116AA */
+	0,							/* U+0116AB */
+	0,							/* U+0116AC */
+	0,							/* U+0116AD */
+	0,							/* U+0116AE */
+	0,							/* U+0116AF */
+	0,							/* U+0116B0 */
+	0,							/* U+0116B1 */
+	0,							/* U+0116B2 */
+	0,							/* U+0116B3 */
+	0,							/* U+0116B4 */
+	0,							/* U+0116B5 */
+	0,							/* U+0116B6 */
+	0,							/* U+0116B7 */
+	0,							/* U+0116B8 */
+	0,							/* U+0116B9 */
+	0,							/* U+0116BA */
+	0,							/* U+0116BB */
+	0,							/* U+0116BC */
+	0,							/* U+0116BD */
+	0,							/* U+0116BE */
+	0,							/* U+0116BF */
+	0,							/* U+0116C0 */
+	0,							/* U+0116C1 */
+	0,							/* U+0116C2 */
+	0,							/* U+0116C3 */
+	0,							/* U+0116C4 */
+	0,							/* U+0116C5 */
+	0,							/* U+0116C6 */
+	0,							/* U+0116C7 */
+	0,							/* U+0116C8 */
+	0,							/* U+0116C9 */
+	0,							/* U+0116CA */
+	0,							/* U+0116CB */
+	0,							/* U+0116CC */
+	0,							/* U+0116CD */
+	0,							/* U+0116CE */
+	0,							/* U+0116CF */
+	0,							/* U+0116D0 */
+	0,							/* U+0116D1 */
+	0,							/* U+0116D2 */
+	0,							/* U+0116D3 */
+	0,							/* U+0116D4 */
+	0,							/* U+0116D5 */
+	0,							/* U+0116D6 */
+	0,							/* U+0116D7 */
+	0,							/* U+0116D8 */
+	0,							/* U+0116D9 */
+	0,							/* U+0116DA */
+	0,							/* U+0116DB */
+	0,							/* U+0116DC */
+	0,							/* U+0116DD */
+	0,							/* U+0116DE */
+	0,							/* U+0116DF */
+	0,							/* U+0116E0 */
+	0,							/* U+0116E1 */
+	0,							/* U+0116E2 */
+	0,							/* U+0116E3 */
+	0,							/* U+0116E4 */
+	0,							/* U+0116E5 */
+	0,							/* U+0116E6 */
+	0,							/* U+0116E7 */
+	0,							/* U+0116E8 */
+	0,							/* U+0116E9 */
+	0,							/* U+0116EA */
+	0,							/* U+0116EB */
+	0,							/* U+0116EC */
+	0,							/* U+0116ED */
+	0,							/* U+0116EE */
+	0,							/* U+0116EF */
+	0,							/* U+0116F0 */
+	0,							/* U+0116F1 */
+	0,							/* U+0116F2 */
+	0,							/* U+0116F3 */
+	0,							/* U+0116F4 */
+	0,							/* U+0116F5 */
+	0,							/* U+0116F6 */
+	0,							/* U+0116F7 */
+	0,							/* U+0116F8 */
+	0,							/* U+0116F9 */
+	0,							/* U+0116FA */
+	0,							/* U+0116FB */
+	0,							/* U+0116FC */
+	0,							/* U+0116FD */
+	0,							/* U+0116FE */
+	0,							/* U+0116FF */
+	0,							/* U+011700 */
+	0,							/* U+011701 */
+	0,							/* U+011702 */
+	0,							/* U+011703 */
+	0,							/* U+011704 */
+	0,							/* U+011705 */
+	0,							/* U+011706 */
+	0,							/* U+011707 */
+	0,							/* U+011708 */
+	0,							/* U+011709 */
+	0,							/* U+01170A */
+	0,							/* U+01170B */
+	0,							/* U+01170C */
+	0,							/* U+01170D */
+	0,							/* U+01170E */
+	0,							/* U+01170F */
+	0,							/* U+011710 */
+	0,							/* U+011711 */
+	0,							/* U+011712 */
+	0,							/* U+011713 */
+	0,							/* U+011714 */
+	0,							/* U+011715 */
+	0,							/* U+011716 */
+	0,							/* U+011717 */
+	0,							/* U+011718 */
+	0,							/* U+011719 */
+	0,							/* U+01171A */
+	0,							/* U+01171B */
+	0,							/* U+01171C */
+	0,							/* U+01171D */
+	0,							/* U+01171E */
+	0,							/* U+01171F */
+	0,							/* U+011720 */
+	0,							/* U+011721 */
+	0,							/* U+011722 */
+	0,							/* U+011723 */
+	0,							/* U+011724 */
+	0,							/* U+011725 */
+	0,							/* U+011726 */
+	0,							/* U+011727 */
+	0,							/* U+011728 */
+	0,							/* U+011729 */
+	0,							/* U+01172A */
+	0,							/* U+01172B */
+	0,							/* U+01172C */
+	0,							/* U+01172D */
+	0,							/* U+01172E */
+	0,							/* U+01172F */
+	0,							/* U+011730 */
+	0,							/* U+011731 */
+	0,							/* U+011732 */
+	0,							/* U+011733 */
+	0,							/* U+011734 */
+	0,							/* U+011735 */
+	0,							/* U+011736 */
+	0,							/* U+011737 */
+	0,							/* U+011738 */
+	0,							/* U+011739 */
+	0,							/* U+01173A */
+	0,							/* U+01173B */
+	0,							/* U+01173C */
+	0,							/* U+01173D */
+	0,							/* U+01173E */
+	0,							/* U+01173F */
+	0,							/* U+011740 */
+	0,							/* U+011741 */
+	0,							/* U+011742 */
+	0,							/* U+011743 */
+	0,							/* U+011744 */
+	0,							/* U+011745 */
+	0,							/* U+011746 */
+	0,							/* U+011747 */
+	0,							/* U+011748 */
+	0,							/* U+011749 */
+	0,							/* U+01174A */
+	0,							/* U+01174B */
+	0,							/* U+01174C */
+	0,							/* U+01174D */
+	0,							/* U+01174E */
+	0,							/* U+01174F */
+	0,							/* U+011750 */
+	0,							/* U+011751 */
+	0,							/* U+011752 */
+	0,							/* U+011753 */
+	0,							/* U+011754 */
+	0,							/* U+011755 */
+	0,							/* U+011756 */
+	0,							/* U+011757 */
+	0,							/* U+011758 */
+	0,							/* U+011759 */
+	0,							/* U+01175A */
+	0,							/* U+01175B */
+	0,							/* U+01175C */
+	0,							/* U+01175D */
+	0,							/* U+01175E */
+	0,							/* U+01175F */
+	0,							/* U+011760 */
+	0,							/* U+011761 */
+	0,							/* U+011762 */
+	0,							/* U+011763 */
+	0,							/* U+011764 */
+	0,							/* U+011765 */
+	0,							/* U+011766 */
+	0,							/* U+011767 */
+	0,							/* U+011768 */
+	0,							/* U+011769 */
+	0,							/* U+01176A */
+	0,							/* U+01176B */
+	0,							/* U+01176C */
+	0,							/* U+01176D */
+	0,							/* U+01176E */
+	0,							/* U+01176F */
+	0,							/* U+011770 */
+	0,							/* U+011771 */
+	0,							/* U+011772 */
+	0,							/* U+011773 */
+	0,							/* U+011774 */
+	0,							/* U+011775 */
+	0,							/* U+011776 */
+	0,							/* U+011777 */
+	0,							/* U+011778 */
+	0,							/* U+011779 */
+	0,							/* U+01177A */
+	0,							/* U+01177B */
+	0,							/* U+01177C */
+	0,							/* U+01177D */
+	0,							/* U+01177E */
+	0,							/* U+01177F */
+	0,							/* U+011780 */
+	0,							/* U+011781 */
+	0,							/* U+011782 */
+	0,							/* U+011783 */
+	0,							/* U+011784 */
+	0,							/* U+011785 */
+	0,							/* U+011786 */
+	0,							/* U+011787 */
+	0,							/* U+011788 */
+	0,							/* U+011789 */
+	0,							/* U+01178A */
+	0,							/* U+01178B */
+	0,							/* U+01178C */
+	0,							/* U+01178D */
+	0,							/* U+01178E */
+	0,							/* U+01178F */
+	0,							/* U+011790 */
+	0,							/* U+011791 */
+	0,							/* U+011792 */
+	0,							/* U+011793 */
+	0,							/* U+011794 */
+	0,							/* U+011795 */
+	0,							/* U+011796 */
+	0,							/* U+011797 */
+	0,							/* U+011798 */
+	0,							/* U+011799 */
+	0,							/* U+01179A */
+	0,							/* U+01179B */
+	0,							/* U+01179C */
+	0,							/* U+01179D */
+	0,							/* U+01179E */
+	0,							/* U+01179F */
+	0,							/* U+0117A0 */
+	0,							/* U+0117A1 */
+	0,							/* U+0117A2 */
+	0,							/* U+0117A3 */
+	0,							/* U+0117A4 */
+	0,							/* U+0117A5 */
+	0,							/* U+0117A6 */
+	0,							/* U+0117A7 */
+	0,							/* U+0117A8 */
+	0,							/* U+0117A9 */
+	0,							/* U+0117AA */
+	0,							/* U+0117AB */
+	0,							/* U+0117AC */
+	0,							/* U+0117AD */
+	0,							/* U+0117AE */
+	0,							/* U+0117AF */
+	0,							/* U+0117B0 */
+	0,							/* U+0117B1 */
+	0,							/* U+0117B2 */
+	0,							/* U+0117B3 */
+	0,							/* U+0117B4 */
+	0,							/* U+0117B5 */
+	0,							/* U+0117B6 */
+	0,							/* U+0117B7 */
+	0,							/* U+0117B8 */
+	0,							/* U+0117B9 */
+	0,							/* U+0117BA */
+	0,							/* U+0117BB */
+	0,							/* U+0117BC */
+	0,							/* U+0117BD */
+	0,							/* U+0117BE */
+	0,							/* U+0117BF */
+	0,							/* U+0117C0 */
+	0,							/* U+0117C1 */
+	0,							/* U+0117C2 */
+	0,							/* U+0117C3 */
+	0,							/* U+0117C4 */
+	0,							/* U+0117C5 */
+	0,							/* U+0117C6 */
+	0,							/* U+0117C7 */
+	0,							/* U+0117C8 */
+	0,							/* U+0117C9 */
+	0,							/* U+0117CA */
+	0,							/* U+0117CB */
+	0,							/* U+0117CC */
+	0,							/* U+0117CD */
+	0,							/* U+0117CE */
+	0,							/* U+0117CF */
+	0,							/* U+0117D0 */
+	0,							/* U+0117D1 */
+	0,							/* U+0117D2 */
+	0,							/* U+0117D3 */
+	0,							/* U+0117D4 */
+	0,							/* U+0117D5 */
+	0,							/* U+0117D6 */
+	0,							/* U+0117D7 */
+	0,							/* U+0117D8 */
+	0,							/* U+0117D9 */
+	0,							/* U+0117DA */
+	0,							/* U+0117DB */
+	0,							/* U+0117DC */
+	0,							/* U+0117DD */
+	0,							/* U+0117DE */
+	0,							/* U+0117DF */
+	0,							/* U+0117E0 */
+	0,							/* U+0117E1 */
+	0,							/* U+0117E2 */
+	0,							/* U+0117E3 */
+	0,							/* U+0117E4 */
+	0,							/* U+0117E5 */
+	0,							/* U+0117E6 */
+	0,							/* U+0117E7 */
+	0,							/* U+0117E8 */
+	0,							/* U+0117E9 */
+	0,							/* U+0117EA */
+	0,							/* U+0117EB */
+	0,							/* U+0117EC */
+	0,							/* U+0117ED */
+	0,							/* U+0117EE */
+	0,							/* U+0117EF */
+	0,							/* U+0117F0 */
+	0,							/* U+0117F1 */
+	0,							/* U+0117F2 */
+	0,							/* U+0117F3 */
+	0,							/* U+0117F4 */
+	0,							/* U+0117F5 */
+	0,							/* U+0117F6 */
+	0,							/* U+0117F7 */
+	0,							/* U+0117F8 */
+	0,							/* U+0117F9 */
+	0,							/* U+0117FA */
+	0,							/* U+0117FB */
+	0,							/* U+0117FC */
+	0,							/* U+0117FD */
+	0,							/* U+0117FE */
+	0,							/* U+0117FF */
+	0,							/* U+011800 */
+	0,							/* U+011801 */
+	0,							/* U+011802 */
+	0,							/* U+011803 */
+	0,							/* U+011804 */
+	0,							/* U+011805 */
+	0,							/* U+011806 */
+	0,							/* U+011807 */
+	0,							/* U+011808 */
+	0,							/* U+011809 */
+	0,							/* U+01180A */
+	0,							/* U+01180B */
+	0,							/* U+01180C */
+	0,							/* U+01180D */
+	0,							/* U+01180E */
+	0,							/* U+01180F */
+	0,							/* U+011810 */
+	0,							/* U+011811 */
+	0,							/* U+011812 */
+	0,							/* U+011813 */
+	0,							/* U+011814 */
+	0,							/* U+011815 */
+	0,							/* U+011816 */
+	0,							/* U+011817 */
+	0,							/* U+011818 */
+	0,							/* U+011819 */
+	0,							/* U+01181A */
+	0,							/* U+01181B */
+	0,							/* U+01181C */
+	0,							/* U+01181D */
+	0,							/* U+01181E */
+	0,							/* U+01181F */
+	0,							/* U+011820 */
+	0,							/* U+011821 */
+	0,							/* U+011822 */
+	0,							/* U+011823 */
+	0,							/* U+011824 */
+	0,							/* U+011825 */
+	0,							/* U+011826 */
+	0,							/* U+011827 */
+	0,							/* U+011828 */
+	0,							/* U+011829 */
+	0,							/* U+01182A */
+	0,							/* U+01182B */
+	0,							/* U+01182C */
+	0,							/* U+01182D */
+	0,							/* U+01182E */
+	0,							/* U+01182F */
+	0,							/* U+011830 */
+	0,							/* U+011831 */
+	0,							/* U+011832 */
+	0,							/* U+011833 */
+	0,							/* U+011834 */
+	0,							/* U+011835 */
+	0,							/* U+011836 */
+	0,							/* U+011837 */
+	0,							/* U+011838 */
+	0,							/* U+011839 */
+	0,							/* U+01183A */
+	0,							/* U+01183B */
+	0,							/* U+01183C */
+	0,							/* U+01183D */
+	0,							/* U+01183E */
+	0,							/* U+01183F */
+	0,							/* U+011840 */
+	0,							/* U+011841 */
+	0,							/* U+011842 */
+	0,							/* U+011843 */
+	0,							/* U+011844 */
+	0,							/* U+011845 */
+	0,							/* U+011846 */
+	0,							/* U+011847 */
+	0,							/* U+011848 */
+	0,							/* U+011849 */
+	0,							/* U+01184A */
+	0,							/* U+01184B */
+	0,							/* U+01184C */
+	0,							/* U+01184D */
+	0,							/* U+01184E */
+	0,							/* U+01184F */
+	0,							/* U+011850 */
+	0,							/* U+011851 */
+	0,							/* U+011852 */
+	0,							/* U+011853 */
+	0,							/* U+011854 */
+	0,							/* U+011855 */
+	0,							/* U+011856 */
+	0,							/* U+011857 */
+	0,							/* U+011858 */
+	0,							/* U+011859 */
+	0,							/* U+01185A */
+	0,							/* U+01185B */
+	0,							/* U+01185C */
+	0,							/* U+01185D */
+	0,							/* U+01185E */
+	0,							/* U+01185F */
+	0,							/* U+011860 */
+	0,							/* U+011861 */
+	0,							/* U+011862 */
+	0,							/* U+011863 */
+	0,							/* U+011864 */
+	0,							/* U+011865 */
+	0,							/* U+011866 */
+	0,							/* U+011867 */
+	0,							/* U+011868 */
+	0,							/* U+011869 */
+	0,							/* U+01186A */
+	0,							/* U+01186B */
+	0,							/* U+01186C */
+	0,							/* U+01186D */
+	0,							/* U+01186E */
+	0,							/* U+01186F */
+	0,							/* U+011870 */
+	0,							/* U+011871 */
+	0,							/* U+011872 */
+	0,							/* U+011873 */
+	0,							/* U+011874 */
+	0,							/* U+011875 */
+	0,							/* U+011876 */
+	0,							/* U+011877 */
+	0,							/* U+011878 */
+	0,							/* U+011879 */
+	0,							/* U+01187A */
+	0,							/* U+01187B */
+	0,							/* U+01187C */
+	0,							/* U+01187D */
+	0,							/* U+01187E */
+	0,							/* U+01187F */
+	0,							/* U+011880 */
+	0,							/* U+011881 */
+	0,							/* U+011882 */
+	0,							/* U+011883 */
+	0,							/* U+011884 */
+	0,							/* U+011885 */
+	0,							/* U+011886 */
+	0,							/* U+011887 */
+	0,							/* U+011888 */
+	0,							/* U+011889 */
+	0,							/* U+01188A */
+	0,							/* U+01188B */
+	0,							/* U+01188C */
+	0,							/* U+01188D */
+	0,							/* U+01188E */
+	0,							/* U+01188F */
+	0,							/* U+011890 */
+	0,							/* U+011891 */
+	0,							/* U+011892 */
+	0,							/* U+011893 */
+	0,							/* U+011894 */
+	0,							/* U+011895 */
+	0,							/* U+011896 */
+	0,							/* U+011897 */
+	0,							/* U+011898 */
+	0,							/* U+011899 */
+	0,							/* U+01189A */
+	0,							/* U+01189B */
+	0,							/* U+01189C */
+	0,							/* U+01189D */
+	0,							/* U+01189E */
+	0,							/* U+01189F */
+	0,							/* U+0118A0 */
+	0,							/* U+0118A1 */
+	0,							/* U+0118A2 */
+	0,							/* U+0118A3 */
+	0,							/* U+0118A4 */
+	0,							/* U+0118A5 */
+	0,							/* U+0118A6 */
+	0,							/* U+0118A7 */
+	0,							/* U+0118A8 */
+	0,							/* U+0118A9 */
+	0,							/* U+0118AA */
+	0,							/* U+0118AB */
+	0,							/* U+0118AC */
+	0,							/* U+0118AD */
+	0,							/* U+0118AE */
+	0,							/* U+0118AF */
+	0,							/* U+0118B0 */
+	0,							/* U+0118B1 */
+	0,							/* U+0118B2 */
+	0,							/* U+0118B3 */
+	0,							/* U+0118B4 */
+	0,							/* U+0118B5 */
+	0,							/* U+0118B6 */
+	0,							/* U+0118B7 */
+	0,							/* U+0118B8 */
+	0,							/* U+0118B9 */
+	0,							/* U+0118BA */
+	0,							/* U+0118BB */
+	0,							/* U+0118BC */
+	0,							/* U+0118BD */
+	0,							/* U+0118BE */
+	0,							/* U+0118BF */
+	0,							/* U+0118C0 */
+	0,							/* U+0118C1 */
+	0,							/* U+0118C2 */
+	0,							/* U+0118C3 */
+	0,							/* U+0118C4 */
+	0,							/* U+0118C5 */
+	0,							/* U+0118C6 */
+	0,							/* U+0118C7 */
+	0,							/* U+0118C8 */
+	0,							/* U+0118C9 */
+	0,							/* U+0118CA */
+	0,							/* U+0118CB */
+	0,							/* U+0118CC */
+	0,							/* U+0118CD */
+	0,							/* U+0118CE */
+	0,							/* U+0118CF */
+	0,							/* U+0118D0 */
+	0,							/* U+0118D1 */
+	0,							/* U+0118D2 */
+	0,							/* U+0118D3 */
+	0,							/* U+0118D4 */
+	0,							/* U+0118D5 */
+	0,							/* U+0118D6 */
+	0,							/* U+0118D7 */
+	0,							/* U+0118D8 */
+	0,							/* U+0118D9 */
+	0,							/* U+0118DA */
+	0,							/* U+0118DB */
+	0,							/* U+0118DC */
+	0,							/* U+0118DD */
+	0,							/* U+0118DE */
+	0,							/* U+0118DF */
+	0,							/* U+0118E0 */
+	0,							/* U+0118E1 */
+	0,							/* U+0118E2 */
+	0,							/* U+0118E3 */
+	0,							/* U+0118E4 */
+	0,							/* U+0118E5 */
+	0,							/* U+0118E6 */
+	0,							/* U+0118E7 */
+	0,							/* U+0118E8 */
+	0,							/* U+0118E9 */
+	0,							/* U+0118EA */
+	0,							/* U+0118EB */
+	0,							/* U+0118EC */
+	0,							/* U+0118ED */
+	0,							/* U+0118EE */
+	0,							/* U+0118EF */
+	0,							/* U+0118F0 */
+	0,							/* U+0118F1 */
+	0,							/* U+0118F2 */
+	0,							/* U+0118F3 */
+	0,							/* U+0118F4 */
+	0,							/* U+0118F5 */
+	0,							/* U+0118F6 */
+	0,							/* U+0118F7 */
+	0,							/* U+0118F8 */
+	0,							/* U+0118F9 */
+	0,							/* U+0118FA */
+	0,							/* U+0118FB */
+	0,							/* U+0118FC */
+	0,							/* U+0118FD */
+	0,							/* U+0118FE */
+	0,							/* U+0118FF */
+	0,							/* U+011900 */
+	0,							/* U+011901 */
+	0,							/* U+011902 */
+	0,							/* U+011903 */
+	0,							/* U+011904 */
+	0,							/* U+011905 */
+	0,							/* U+011906 */
+	0,							/* U+011907 */
+	0,							/* U+011908 */
+	0,							/* U+011909 */
+	0,							/* U+01190A */
+	0,							/* U+01190B */
+	0,							/* U+01190C */
+	0,							/* U+01190D */
+	0,							/* U+01190E */
+	0,							/* U+01190F */
+	0,							/* U+011910 */
+	0,							/* U+011911 */
+	0,							/* U+011912 */
+	0,							/* U+011913 */
+	0,							/* U+011914 */
+	0,							/* U+011915 */
+	0,							/* U+011916 */
+	0,							/* U+011917 */
+	0,							/* U+011918 */
+	0,							/* U+011919 */
+	0,							/* U+01191A */
+	0,							/* U+01191B */
+	0,							/* U+01191C */
+	0,							/* U+01191D */
+	0,							/* U+01191E */
+	0,							/* U+01191F */
+	0,							/* U+011920 */
+	0,							/* U+011921 */
+	0,							/* U+011922 */
+	0,							/* U+011923 */
+	0,							/* U+011924 */
+	0,							/* U+011925 */
+	0,							/* U+011926 */
+	0,							/* U+011927 */
+	0,							/* U+011928 */
+	0,							/* U+011929 */
+	0,							/* U+01192A */
+	0,							/* U+01192B */
+	0,							/* U+01192C */
+	0,							/* U+01192D */
+	0,							/* U+01192E */
+	0,							/* U+01192F */
+	0,							/* U+011930 */
+	0,							/* U+011931 */
+	0,							/* U+011932 */
+	0,							/* U+011933 */
+	0,							/* U+011934 */
+	6164,						/* U+011935 */
+	6168,						/* U+01611E */
+	0,							/* U+01611F */
+	0,							/* U+016120 */
+	6183,						/* U+016121 */
+	6188,						/* U+016122 */
+	0,							/* U+016123 */
+	0,							/* U+016124 */
+	0,							/* U+016125 */
+	0,							/* U+016126 */
+	0,							/* U+016127 */
+	0,							/* U+016128 */
+	6192,						/* U+016129 */
+	6196,						/* U+016D63 */
+	0,							/* U+016D64 */
+	0,							/* U+016D65 */
+	0,							/* U+016D66 */
+	6200,						/* U+016D67 */
+	0,							/* U+016D68 */
+	6204,						/* U+016D69 */
+};
+
+
+/*
+ * normalization_index()
+ *
+ * Given a code point, compute the index in the decomp_map at which we can find
+ * the offset into the mapping tables.
+ */
+static uint16
+normalization_index(pg_wchar cp)
+{
+	if (cp < 0x16FF2)
+	{
+		if (cp < 0xABEE)
+		{
+			if (cp >= 0x00A0 && cp < 0x3400)
+			{
+				return decomp_map[cp - 0x00A0 + 0];
+			}
+			else if (cp >= 0xA66F)
+			{
+				return decomp_map[cp - 0xA66F + 13152];
+			}
+		}
+		else if (cp >= 0xF900)
+		{
+			if (cp < 0x11F43)
+			{
+				return decomp_map[cp - 0xF900 + 14559];
+			}
+			else if (cp >= 0x16121)
+			{
+				if (cp < 0x16130)
+				{
+					return decomp_map[cp - 0x16121 + 24354];
+				}
+				else if (cp >= 0x16AF0)
+				{
+					return decomp_map[cp - 0x16AF0 + 24369];
+				}
+			}
+		}
+	}
+	else if (cp >= 0x1BC9E)
+	{
+		if (cp < 0x1F252)
+		{
+			if (cp < 0x1BC9F)
+			{
+				return decomp_map[cp - 0x1BC9E + 25651];
+			}
+			else if (cp >= 0x1CCD6)
+			{
+				if (cp < 0x1D800)
+				{
+					return decomp_map[cp - 0x1CCD6 + 25652];
+				}
+				else if (cp >= 0x1E000)
+				{
+					return decomp_map[cp - 0x1E000 + 28510];
+				}
+			}
+		}
+		else if (cp >= 0x1FBF0)
+		{
+			if (cp < 0x1FBFA)
+			{
+				return decomp_map[cp - 0x1FBF0 + 33200];
+			}
+			else if (cp >= 0x2F800)
+			{
+				if (cp < 0x2FA1E)
+				{
+					return decomp_map[cp - 0x2F800 + 33210];
+				}
+			}
+		}
+	}
+
+	return 0;
+}
+
+/*
+ * inverse_index()
+ *
+ * Like normalization_index(), only the index is searched for in the inverse_map
+ * table.
+ */
+static uint16
+inverse_index(pg_wchar cp)
+{
+	if (cp < 0x105DB)
+	{
+		if (cp < 0x22B6)
+		{
+			if (cp >= 0x003C && cp < 0x1026)
+			{
+				return inverse_map[cp - 0x003C + 0];
+			}
+			else if (cp >= 0x1B05)
+			{
+				return inverse_map[cp - 0x1B05 + 4074];
+			}
+		}
+		else if (cp >= 0x3046)
+		{
+			if (cp < 0x30FE)
+			{
+				return inverse_map[cp - 0x3046 + 6043];
+			}
+			else if (cp >= 0x105D2)
+			{
+				return inverse_map[cp - 0x105D2 + 6227];
+			}
+		}
+	}
+	else if (cp >= 0x11099)
+	{
+		if (cp < 0x1612A)
+		{
+			if (cp < 0x11936)
+			{
+				return inverse_map[cp - 0x11099 + 6236];
+			}
+			else if (cp >= 0x1611E)
+			{
+				return inverse_map[cp - 0x1611E + 8441];
+			}
+		}
+		else if (cp >= 0x16D63)
+		{
+			if (cp < 0x16D6A)
+			{
+				return inverse_map[cp - 0x16D63 + 8453];
+			}
+		}
+	}
+
+	return 0;
+}
+
+/*
+ * normalization_inverse()
+ *
+ * Returns the code point for recomposition of the reordered Unicode string
+ * based on two code points.
+ * Codepoint 0x0000 means "not found".
+ */
+static pg_wchar
+normalization_inverse(pg_wchar first, pg_wchar second)
+{
+	uint16		idx;
+	uint32		start,
+				stop;
+	const uint16 *entry;
+
+	idx = inverse_index(first);
+	entry = &UnicodeDecompInverseSecond[idx];
+
+	start = entry[0] << 16 | entry[1];
+	stop = start + entry[2];
+
+	if (idx != 0 && second >= start && second <= stop)
+	{
+		return UnicodeDecompInverseCodes[entry[second - start + 3]];
+	}
+
+	return 0x0000;
+}
diff --git a/src/tools/pgindent/exclude_file_patterns b/src/tools/pgindent/exclude_file_patterns
index 4976a373f9e..7e9e93442f0 100644
--- a/src/tools/pgindent/exclude_file_patterns
+++ b/src/tools/pgindent/exclude_file_patterns
@@ -33,7 +33,6 @@ kwlist_d\.h$
 # These are generated by the scripts from src/common/unicode/.  They use
 # hash functions generated by PerfectHash.pm whose format looks worse with
 # pgindent.
-src/include/common/unicode_norm_hashfunc\.h$
 src/include/common/unicode_normprops_table\.h$
 #
 # Exclude ecpg test files to avoid breaking the ecpg regression tests
-- 
2.39.5 (Apple Git-154)

